/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtcore_python.h"

#include "qabstractfileengine_wrapper.h"

// Extra includes
#include <QDateTime>
#include <QStringList>
#include <qabstractfileengine.h>
#include <qdatetime.h>


// Native ---------------------------------------------------------

QAbstractFileEngineWrapper::QAbstractFileEngineWrapper() : QAbstractFileEngine() {
    // ... middle
}

bool QAbstractFileEngineWrapper::caseSensitive() const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return bool(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "caseSensitive"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QAbstractFileEngine::caseSensitive();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QAbstractFileEngine.caseSensitive", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    return cppResult;
}

bool QAbstractFileEngineWrapper::close()
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return bool(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "close"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QAbstractFileEngine::close();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QAbstractFileEngine.close", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    return cppResult;
}

bool QAbstractFileEngineWrapper::copy(const QString & newName)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return bool(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "copy"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QAbstractFileEngine::copy(newName);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< QString >::toPython(newName)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QAbstractFileEngine.copy", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    return cppResult;
}

QStringList QAbstractFileEngineWrapper::entryList(QFlags<QDir::Filter> filters, const QStringList & filterNames) const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return QStringList();
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "entryList"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QAbstractFileEngine::entryList(filters, filterNames);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter< ::QFlags<QDir::Filter> >::toPython(filters),
        Shiboken::Converter< ::QStringList >::toPython(filterNames)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QStringList();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QStringList >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QAbstractFileEngine.entryList", "list", pyResult->ob_type->tp_name);
        return QStringList();
    }
    QStringList cppResult(Shiboken::Converter< ::QStringList >::toCpp(pyResult));
    return cppResult;
}

QFlags<QAbstractFileEngine::FileFlag> QAbstractFileEngineWrapper::fileFlags(QFlags<QAbstractFileEngine::FileFlag> type) const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return QFlags<QAbstractFileEngine::FileFlag>();
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "fileFlags"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QAbstractFileEngine::fileFlags(type);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QFlags<QAbstractFileEngine::FileFlag> >::toPython(type)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QFlags<QAbstractFileEngine::FileFlag>();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QFlags<QAbstractFileEngine::FileFlag> >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QAbstractFileEngine.fileFlags", Shiboken::SbkType<QFlags<QAbstractFileEngine::FileFlag> >()->tp_name, pyResult->ob_type->tp_name);
        return QFlags<QAbstractFileEngine::FileFlag>();
    }
    QFlags<QAbstractFileEngine::FileFlag> cppResult(Shiboken::Converter< ::QFlags<QAbstractFileEngine::FileFlag> >::toCpp(pyResult));
    return cppResult;
}

QString QAbstractFileEngineWrapper::fileName(QAbstractFileEngine::FileName file) const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return QString();
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "fileName"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QAbstractFileEngine::fileName(file);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QAbstractFileEngine::FileName >::toPython(file)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QString();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< QString >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QAbstractFileEngine.fileName", "QString", pyResult->ob_type->tp_name);
        return QString();
    }
    QString cppResult(Shiboken::Converter< QString >::toCpp(pyResult));
    return cppResult;
}

QDateTime QAbstractFileEngineWrapper::fileTime(QAbstractFileEngine::FileTime time) const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return QDateTime();
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "fileTime"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QAbstractFileEngine::fileTime(time);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QAbstractFileEngine::FileTime >::toPython(time)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QDateTime();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QDateTime >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QAbstractFileEngine.fileTime", Shiboken::SbkType<QDateTime >()->tp_name, pyResult->ob_type->tp_name);
        return QDateTime();
    }
    QDateTime cppResult(Shiboken::Converter< ::QDateTime >::toCpp(pyResult));
    return cppResult;
}

bool QAbstractFileEngineWrapper::flush()
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return bool(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "flush"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QAbstractFileEngine::flush();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QAbstractFileEngine.flush", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    return cppResult;
}

int QAbstractFileEngineWrapper::handle() const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return int(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "handle"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QAbstractFileEngine::handle();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return int(0);
    }
    // Check return type
    bool typeIsValid = PyInt_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QAbstractFileEngine.handle", "int", pyResult->ob_type->tp_name);
        return int(0);
    }
    int cppResult(Shiboken::Converter< int >::toCpp(pyResult));
    return cppResult;
}

bool QAbstractFileEngineWrapper::isRelativePath() const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return bool(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "isRelativePath"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QAbstractFileEngine::isRelativePath();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QAbstractFileEngine.isRelativePath", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    return cppResult;
}

bool QAbstractFileEngineWrapper::isSequential() const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return bool(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "isSequential"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QAbstractFileEngine::isSequential();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QAbstractFileEngine.isSequential", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    return cppResult;
}

bool QAbstractFileEngineWrapper::link(const QString & newName)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return bool(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "link"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QAbstractFileEngine::link(newName);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< QString >::toPython(newName)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QAbstractFileEngine.link", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    return cppResult;
}

bool QAbstractFileEngineWrapper::mkdir(const QString & dirName, bool createParentDirectories) const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return bool(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "mkdir"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QAbstractFileEngine::mkdir(dirName, createParentDirectories);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter< QString >::toPython(dirName),
        Shiboken::Converter< bool >::toPython(createParentDirectories)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QAbstractFileEngine.mkdir", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    return cppResult;
}

bool QAbstractFileEngineWrapper::open(QFlags<QIODevice::OpenModeFlag> openMode)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return bool(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "open"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QAbstractFileEngine::open(openMode);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QFlags<QIODevice::OpenModeFlag> >::toPython(openMode)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QAbstractFileEngine.open", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    return cppResult;
}

QString QAbstractFileEngineWrapper::owner(QAbstractFileEngine::FileOwner arg__1) const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return QString();
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "owner"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QAbstractFileEngine::owner(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QAbstractFileEngine::FileOwner >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QString();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< QString >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QAbstractFileEngine.owner", "QString", pyResult->ob_type->tp_name);
        return QString();
    }
    QString cppResult(Shiboken::Converter< QString >::toCpp(pyResult));
    return cppResult;
}

uint QAbstractFileEngineWrapper::ownerId(QAbstractFileEngine::FileOwner arg__1) const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return uint(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "ownerId"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QAbstractFileEngine::ownerId(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QAbstractFileEngine::FileOwner >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return uint(0);
    }
    // Check return type
    bool typeIsValid = PyInt_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QAbstractFileEngine.ownerId", "uint", pyResult->ob_type->tp_name);
        return uint(0);
    }
    uint cppResult(Shiboken::Converter< unsigned int >::toCpp(pyResult));
    return cppResult;
}

qint64 QAbstractFileEngineWrapper::pos() const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return qint64(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "pos"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QAbstractFileEngine::pos();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return qint64(0);
    }
    // Check return type
    bool typeIsValid = PyLong_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QAbstractFileEngine.pos", "qint64", pyResult->ob_type->tp_name);
        return qint64(0);
    }
    qint64 cppResult(Shiboken::Converter< long long >::toCpp(pyResult));
    return cppResult;
}

qint64 QAbstractFileEngineWrapper::read(char * data, qint64 maxlen)
{

    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return qint64(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "read"));
    if (py_override.isNull()) {

        gil.release();
        return this->::QAbstractFileEngine::read(data, maxlen);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(L)",
        maxlen
    ));


    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return qint64(0);
    }
    // Begin code injection

    qint64 cppResult;
    if (!PyString_Check(pyResult)) {
        cppResult = -1;
    } else {
        cppResult = PyString_GET_SIZE((PyObject*)pyResult);
        qstrncpy(data, PyString_AS_STRING((PyObject*)pyResult), cppResult + 1);
    }

    // End of code injection

    return cppResult;
}

qint64 QAbstractFileEngineWrapper::readLine(char * data, qint64 maxlen)
{

    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return qint64(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "readLine"));
    if (py_override.isNull()) {

        gil.release();
        return this->::QAbstractFileEngine::readLine(data, maxlen);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(L)",
        maxlen
    ));


    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return qint64(0);
    }
    // Begin code injection

    qint64 cppResult;
    if (!PyString_Check(pyResult)) {
        cppResult = -1;
    } else {
        cppResult = PyString_GET_SIZE((PyObject*)pyResult);
        qstrncpy(data, PyString_AS_STRING((PyObject*)pyResult), cppResult + 1);
    }

    // End of code injection

    return cppResult;
}

bool QAbstractFileEngineWrapper::remove()
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return bool(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "remove"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QAbstractFileEngine::remove();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QAbstractFileEngine.remove", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    return cppResult;
}

bool QAbstractFileEngineWrapper::rename(const QString & newName)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return bool(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "rename"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QAbstractFileEngine::rename(newName);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< QString >::toPython(newName)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QAbstractFileEngine.rename", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    return cppResult;
}

bool QAbstractFileEngineWrapper::rmdir(const QString & dirName, bool recurseParentDirectories) const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return bool(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "rmdir"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QAbstractFileEngine::rmdir(dirName, recurseParentDirectories);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter< QString >::toPython(dirName),
        Shiboken::Converter< bool >::toPython(recurseParentDirectories)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QAbstractFileEngine.rmdir", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    return cppResult;
}

bool QAbstractFileEngineWrapper::seek(qint64 pos)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return bool(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "seek"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QAbstractFileEngine::seek(pos);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(L)",
        pos
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QAbstractFileEngine.seek", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    return cppResult;
}

void QAbstractFileEngineWrapper::setFileName(const QString & file)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "setFileName"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QAbstractFileEngine::setFileName(file);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< QString >::toPython(file)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

bool QAbstractFileEngineWrapper::setPermissions(uint perms)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return bool(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "setPermissions"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QAbstractFileEngine::setPermissions(perms);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(I)",
        perms
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QAbstractFileEngine.setPermissions", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    return cppResult;
}

bool QAbstractFileEngineWrapper::setSize(qint64 size)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return bool(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "setSize"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QAbstractFileEngine::setSize(size);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(L)",
        size
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QAbstractFileEngine.setSize", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    return cppResult;
}

qint64 QAbstractFileEngineWrapper::size() const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return qint64(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "size"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QAbstractFileEngine::size();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return qint64(0);
    }
    // Check return type
    bool typeIsValid = PyLong_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QAbstractFileEngine.size", "qint64", pyResult->ob_type->tp_name);
        return qint64(0);
    }
    qint64 cppResult(Shiboken::Converter< long long >::toCpp(pyResult));
    return cppResult;
}

bool QAbstractFileEngineWrapper::supportsExtension(QAbstractFileEngine::Extension extension) const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return bool(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "supportsExtension"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QAbstractFileEngine::supportsExtension(extension);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QAbstractFileEngine::Extension >::toPython(extension)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QAbstractFileEngine.supportsExtension", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    return cppResult;
}

qint64 QAbstractFileEngineWrapper::write(const char * data, qint64 len)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return qint64(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "write"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QAbstractFileEngine::write(data, len);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NL)",
        Shiboken::Converter< const char * >::toPython(data),
        len
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return qint64(0);
    }
    // Check return type
    bool typeIsValid = PyLong_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QAbstractFileEngine.write", "qint64", pyResult->ob_type->tp_name);
        return qint64(0);
    }
    qint64 cppResult(Shiboken::Converter< long long >::toCpp(pyResult));
    return cppResult;
}

QAbstractFileEngineWrapper::~QAbstractFileEngineWrapper()
{
    SbkObject* wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QAbstractFileEngine_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QAbstractFileEngine >()))
        return -1;

    QAbstractFileEngineWrapper* cptr = 0;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // QAbstractFileEngine()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new QAbstractFileEngineWrapper();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QAbstractFileEngine >(), cptr)) {
        delete cptr;
        return -1;
    }
    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject* Sbk_QAbstractFileEngineFunc_atEnd(PyObject* self)
{
    QAbstractFileEngine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QAbstractFileEngine* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // atEnd()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QAbstractFileEngine*>(cppSelf)->atEnd();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QAbstractFileEngineFunc_caseSensitive(PyObject* self)
{
    QAbstractFileEngine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QAbstractFileEngine* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // caseSensitive()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = (Shiboken::Object::isUserType(self) ? const_cast<const QAbstractFileEngine*>(cppSelf)->::QAbstractFileEngine::caseSensitive() : const_cast<const QAbstractFileEngine*>(cppSelf)->caseSensitive());
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QAbstractFileEngineFunc_close(PyObject* self)
{
    QAbstractFileEngine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QAbstractFileEngine* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // close()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = (Shiboken::Object::isUserType(self) ? cppSelf->::QAbstractFileEngine::close() : cppSelf->close());
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QAbstractFileEngineFunc_copy(PyObject* self, PyObject* arg)
{
    QAbstractFileEngine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QAbstractFileEngine* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: copy(QString)
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // copy(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QAbstractFileEngineFunc_copy_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // copy(QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = (Shiboken::Object::isUserType(self) ? cppSelf->::QAbstractFileEngine::copy(cppArg0) : cppSelf->copy(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QAbstractFileEngineFunc_copy_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QAbstractFileEngine.copy", overloads);
        return 0;
}

static PyObject* Sbk_QAbstractFileEngineFunc_create(PyObject* self, PyObject* arg)
{
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: create(QString)
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // create(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QAbstractFileEngineFunc_create_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // create(QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QAbstractFileEngine * cppResult = QAbstractFileEngine::create(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QAbstractFileEngine * >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QAbstractFileEngineFunc_create_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QAbstractFileEngine.create", overloads);
        return 0;
}

static PyObject* Sbk_QAbstractFileEngineFunc_entryList(PyObject* self, PyObject* args)
{
    QAbstractFileEngine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QAbstractFileEngine* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "entryList", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: entryList(QFlags<QDir::Filter>,QStringList)const
    if (numArgs == 2 && Shiboken::Converter< ::QFlags<QDir::Filter> >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QStringList >::isConvertible(pyargs[1])) {
        overloadId = 0; // entryList(QFlags<QDir::Filter>,QStringList)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QAbstractFileEngineFunc_entryList_TypeError;

    // Call function/method
    {
        {
            QFlags<QDir::Filter> cppArg0 = Shiboken::Converter<QFlags<QDir::Filter> >::toCpp(pyargs[0]);
            QStringList cppArg1 = Shiboken::Converter<QStringList >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // entryList(QFlags<QDir::Filter>,QStringList)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QStringList cppResult = (Shiboken::Object::isUserType(self) ? const_cast<const QAbstractFileEngine*>(cppSelf)->::QAbstractFileEngine::entryList(cppArg0, cppArg1) : const_cast<const QAbstractFileEngine*>(cppSelf)->entryList(cppArg0, cppArg1));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QStringList >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QAbstractFileEngineFunc_entryList_TypeError:
        const char* overloads[] = {"PySide.QtCore.QDir.Filters, list", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QAbstractFileEngine.entryList", overloads);
        return 0;
}

static PyObject* Sbk_QAbstractFileEngineFunc_error(PyObject* self)
{
    QAbstractFileEngine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QAbstractFileEngine* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // error()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QFile::FileError cppResult = const_cast<const QAbstractFileEngine*>(cppSelf)->error();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QFile::FileError >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QAbstractFileEngineFunc_errorString(PyObject* self)
{
    QAbstractFileEngine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QAbstractFileEngine* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // errorString()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = const_cast<const QAbstractFileEngine*>(cppSelf)->errorString();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QAbstractFileEngineFunc_fileFlags(PyObject* self, PyObject* args, PyObject* kwds)
{
    QAbstractFileEngine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QAbstractFileEngine* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QAbstractFileEngine.fileFlags(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:fileFlags", &(pyargs[0])))
        return 0;


    // Overloaded function decisor
    // 0: fileFlags(QFlags<QAbstractFileEngine::FileFlag>)const
    if (numArgs == 0) {
        overloadId = 0; // fileFlags(QFlags<QAbstractFileEngine::FileFlag>)const
    } else if (Shiboken::Converter< ::QFlags<QAbstractFileEngine::FileFlag> >::isConvertible(pyargs[0])) {
        overloadId = 0; // fileFlags(QFlags<QAbstractFileEngine::FileFlag>)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QAbstractFileEngineFunc_fileFlags_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "type");
                if (value) {
                    if (pyargs[0])
                        errorArgName = "type";
                    else if (Shiboken::Converter< ::QFlags<QAbstractFileEngine::FileFlag> >::isConvertible(value))
                        pyargs[0] = value;
                    else
                        goto Sbk_QAbstractFileEngineFunc_fileFlags_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtCore.QAbstractFileEngine.fileFlags(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QFlags<QAbstractFileEngine::FileFlag> cppArg0 = pyargs[0] ? Shiboken::Converter<QFlags<QAbstractFileEngine::FileFlag> >::toCpp(pyargs[0]) : QAbstractFileEngine::FileInfoAll;

            if(!PyErr_Occurred()) {
                // fileFlags(QFlags<QAbstractFileEngine::FileFlag>)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QFlags<QAbstractFileEngine::FileFlag> cppResult = (Shiboken::Object::isUserType(self) ? const_cast<const QAbstractFileEngine*>(cppSelf)->::QAbstractFileEngine::fileFlags(cppArg0) : const_cast<const QAbstractFileEngine*>(cppSelf)->fileFlags(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QFlags<QAbstractFileEngine::FileFlag> >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QAbstractFileEngineFunc_fileFlags_TypeError:
        const char* overloads[] = {"PySide.QtCore.QAbstractFileEngine.FileFlags = QAbstractFileEngine.FileInfoAll", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QAbstractFileEngine.fileFlags", overloads);
        return 0;
}

static PyObject* Sbk_QAbstractFileEngineFunc_fileName(PyObject* self, PyObject* args, PyObject* kwds)
{
    QAbstractFileEngine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QAbstractFileEngine* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QAbstractFileEngine.fileName(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:fileName", &(pyargs[0])))
        return 0;


    // Overloaded function decisor
    // 0: fileName(QAbstractFileEngine::FileName)const
    if (numArgs == 0) {
        overloadId = 0; // fileName(QAbstractFileEngine::FileName)const
    } else if (Shiboken::Converter< ::QAbstractFileEngine::FileName >::isConvertible(pyargs[0])) {
        overloadId = 0; // fileName(QAbstractFileEngine::FileName)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QAbstractFileEngineFunc_fileName_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "file");
                if (value) {
                    if (pyargs[0])
                        errorArgName = "file";
                    else if (Shiboken::Converter< ::QAbstractFileEngine::FileName >::isConvertible(value))
                        pyargs[0] = value;
                    else
                        goto Sbk_QAbstractFileEngineFunc_fileName_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtCore.QAbstractFileEngine.fileName(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QAbstractFileEngine::FileName cppArg0 = pyargs[0] ? Shiboken::Converter<QAbstractFileEngine::FileName >::toCpp(pyargs[0]) : QAbstractFileEngine::DefaultName;

            if(!PyErr_Occurred()) {
                // fileName(QAbstractFileEngine::FileName)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = (Shiboken::Object::isUserType(self) ? const_cast<const QAbstractFileEngine*>(cppSelf)->::QAbstractFileEngine::fileName(cppArg0) : const_cast<const QAbstractFileEngine*>(cppSelf)->fileName(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QAbstractFileEngineFunc_fileName_TypeError:
        const char* overloads[] = {"PySide.QtCore.QAbstractFileEngine.FileName = DefaultName", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QAbstractFileEngine.fileName", overloads);
        return 0;
}

static PyObject* Sbk_QAbstractFileEngineFunc_fileTime(PyObject* self, PyObject* arg)
{
    QAbstractFileEngine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QAbstractFileEngine* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: fileTime(QAbstractFileEngine::FileTime)const
    if (Shiboken::Converter< ::QAbstractFileEngine::FileTime >::isConvertible(arg)) {
        overloadId = 0; // fileTime(QAbstractFileEngine::FileTime)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QAbstractFileEngineFunc_fileTime_TypeError;

    // Call function/method
    {
        {
            QAbstractFileEngine::FileTime cppArg0 = Shiboken::Converter<QAbstractFileEngine::FileTime >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // fileTime(QAbstractFileEngine::FileTime)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QDateTime cppResult = (Shiboken::Object::isUserType(self) ? const_cast<const QAbstractFileEngine*>(cppSelf)->::QAbstractFileEngine::fileTime(cppArg0) : const_cast<const QAbstractFileEngine*>(cppSelf)->fileTime(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QDateTime >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QAbstractFileEngineFunc_fileTime_TypeError:
        const char* overloads[] = {"PySide.QtCore.QAbstractFileEngine.FileTime", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QAbstractFileEngine.fileTime", overloads);
        return 0;
}

static PyObject* Sbk_QAbstractFileEngineFunc_flush(PyObject* self)
{
    QAbstractFileEngine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QAbstractFileEngine* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // flush()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = (Shiboken::Object::isUserType(self) ? cppSelf->::QAbstractFileEngine::flush() : cppSelf->flush());
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QAbstractFileEngineFunc_handle(PyObject* self)
{
    QAbstractFileEngine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QAbstractFileEngine* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // handle()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = (Shiboken::Object::isUserType(self) ? const_cast<const QAbstractFileEngine*>(cppSelf)->::QAbstractFileEngine::handle() : const_cast<const QAbstractFileEngine*>(cppSelf)->handle());
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QAbstractFileEngineFunc_isRelativePath(PyObject* self)
{
    QAbstractFileEngine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QAbstractFileEngine* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isRelativePath()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = (Shiboken::Object::isUserType(self) ? const_cast<const QAbstractFileEngine*>(cppSelf)->::QAbstractFileEngine::isRelativePath() : const_cast<const QAbstractFileEngine*>(cppSelf)->isRelativePath());
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QAbstractFileEngineFunc_isSequential(PyObject* self)
{
    QAbstractFileEngine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QAbstractFileEngine* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isSequential()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = (Shiboken::Object::isUserType(self) ? const_cast<const QAbstractFileEngine*>(cppSelf)->::QAbstractFileEngine::isSequential() : const_cast<const QAbstractFileEngine*>(cppSelf)->isSequential());
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QAbstractFileEngineFunc_link(PyObject* self, PyObject* arg)
{
    QAbstractFileEngine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QAbstractFileEngine* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: link(QString)
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // link(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QAbstractFileEngineFunc_link_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // link(QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = (Shiboken::Object::isUserType(self) ? cppSelf->::QAbstractFileEngine::link(cppArg0) : cppSelf->link(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QAbstractFileEngineFunc_link_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QAbstractFileEngine.link", overloads);
        return 0;
}

static PyObject* Sbk_QAbstractFileEngineFunc_map(PyObject* self, PyObject* args)
{
    QAbstractFileEngine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QAbstractFileEngine* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "map", 3, 3, &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: map(qint64,qint64,QFile::MemoryMapFlags)
    if (numArgs == 3 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && Shiboken::Converter< ::QFile::MemoryMapFlags >::isConvertible(pyargs[2])) {
        overloadId = 0; // map(qint64,qint64,QFile::MemoryMapFlags)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QAbstractFileEngineFunc_map_TypeError;

    // Call function/method
    {
        {
            qint64 cppArg0 = Shiboken::Converter<qint64 >::toCpp(pyargs[0]);
            qint64 cppArg1 = Shiboken::Converter<qint64 >::toCpp(pyargs[1]);
            QFile::MemoryMapFlags cppArg2 = Shiboken::Converter<QFile::MemoryMapFlags >::toCpp(pyargs[2]);

            if(!PyErr_Occurred()) {
                // map(qint64,qint64,QFile::MemoryMapFlags)
                // Begin code injection

                pyResult = PyBuffer_FromReadWriteMemory(cppSelf->map(cppArg0, cppArg1, cppArg2), cppArg1);

                // End of code injection


            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QAbstractFileEngineFunc_map_TypeError:
        const char* overloads[] = {"long long, long long, PySide.QtCore.QFile.MemoryMapFlags", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QAbstractFileEngine.map", overloads);
        return 0;
}

static PyObject* Sbk_QAbstractFileEngineFunc_mkdir(PyObject* self, PyObject* args)
{
    QAbstractFileEngine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QAbstractFileEngine* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "mkdir", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: mkdir(QString,bool)const
    if (numArgs == 2 && Shiboken::Converter< QString >::isConvertible(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 0; // mkdir(QString,bool)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QAbstractFileEngineFunc_mkdir_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            bool cppArg1 = Shiboken::Converter<bool >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // mkdir(QString,bool)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = (Shiboken::Object::isUserType(self) ? const_cast<const QAbstractFileEngine*>(cppSelf)->::QAbstractFileEngine::mkdir(cppArg0, cppArg1) : const_cast<const QAbstractFileEngine*>(cppSelf)->mkdir(cppArg0, cppArg1));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QAbstractFileEngineFunc_mkdir_TypeError:
        const char* overloads[] = {"QString, bool", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QAbstractFileEngine.mkdir", overloads);
        return 0;
}

static PyObject* Sbk_QAbstractFileEngineFunc_open(PyObject* self, PyObject* arg)
{
    QAbstractFileEngine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QAbstractFileEngine* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: open(QFlags<QIODevice::OpenModeFlag>)
    if (Shiboken::Converter< ::QFlags<QIODevice::OpenModeFlag> >::isConvertible(arg)) {
        overloadId = 0; // open(QFlags<QIODevice::OpenModeFlag>)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QAbstractFileEngineFunc_open_TypeError;

    // Call function/method
    {
        {
            QFlags<QIODevice::OpenModeFlag> cppArg0 = Shiboken::Converter<QFlags<QIODevice::OpenModeFlag> >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // open(QFlags<QIODevice::OpenModeFlag>)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = (Shiboken::Object::isUserType(self) ? cppSelf->::QAbstractFileEngine::open(cppArg0) : cppSelf->open(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QAbstractFileEngineFunc_open_TypeError:
        const char* overloads[] = {"PySide.QtCore.QIODevice.OpenMode", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QAbstractFileEngine.open", overloads);
        return 0;
}

static PyObject* Sbk_QAbstractFileEngineFunc_owner(PyObject* self, PyObject* arg)
{
    QAbstractFileEngine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QAbstractFileEngine* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: owner(QAbstractFileEngine::FileOwner)const
    if (Shiboken::Converter< ::QAbstractFileEngine::FileOwner >::isConvertible(arg)) {
        overloadId = 0; // owner(QAbstractFileEngine::FileOwner)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QAbstractFileEngineFunc_owner_TypeError;

    // Call function/method
    {
        {
            QAbstractFileEngine::FileOwner cppArg0 = Shiboken::Converter<QAbstractFileEngine::FileOwner >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // owner(QAbstractFileEngine::FileOwner)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = (Shiboken::Object::isUserType(self) ? const_cast<const QAbstractFileEngine*>(cppSelf)->::QAbstractFileEngine::owner(cppArg0) : const_cast<const QAbstractFileEngine*>(cppSelf)->owner(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QAbstractFileEngineFunc_owner_TypeError:
        const char* overloads[] = {"PySide.QtCore.QAbstractFileEngine.FileOwner", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QAbstractFileEngine.owner", overloads);
        return 0;
}

static PyObject* Sbk_QAbstractFileEngineFunc_ownerId(PyObject* self, PyObject* arg)
{
    QAbstractFileEngine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QAbstractFileEngine* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: ownerId(QAbstractFileEngine::FileOwner)const
    if (Shiboken::Converter< ::QAbstractFileEngine::FileOwner >::isConvertible(arg)) {
        overloadId = 0; // ownerId(QAbstractFileEngine::FileOwner)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QAbstractFileEngineFunc_ownerId_TypeError;

    // Call function/method
    {
        {
            QAbstractFileEngine::FileOwner cppArg0 = Shiboken::Converter<QAbstractFileEngine::FileOwner >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // ownerId(QAbstractFileEngine::FileOwner)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                uint cppResult = (Shiboken::Object::isUserType(self) ? const_cast<const QAbstractFileEngine*>(cppSelf)->::QAbstractFileEngine::ownerId(cppArg0) : const_cast<const QAbstractFileEngine*>(cppSelf)->ownerId(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< unsigned int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QAbstractFileEngineFunc_ownerId_TypeError:
        const char* overloads[] = {"PySide.QtCore.QAbstractFileEngine.FileOwner", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QAbstractFileEngine.ownerId", overloads);
        return 0;
}

static PyObject* Sbk_QAbstractFileEngineFunc_pos(PyObject* self)
{
    QAbstractFileEngine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QAbstractFileEngine* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // pos()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                qint64 cppResult = (Shiboken::Object::isUserType(self) ? const_cast<const QAbstractFileEngine*>(cppSelf)->::QAbstractFileEngine::pos() : const_cast<const QAbstractFileEngine*>(cppSelf)->pos());
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< long long >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QAbstractFileEngineFunc_read(PyObject* self, PyObject* arg)
{
    QAbstractFileEngine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QAbstractFileEngine* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: read(char*,qint64)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // read(char*,qint64)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QAbstractFileEngineFunc_read_TypeError;

    // Call function/method
    {
        {
            qint64 cppArg0 = Shiboken::Converter<qint64 >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // read(char*,qint64)
                // Begin code injection

                QByteArray ba;
                ba.resize(cppArg0);
                cppSelf->read(ba.data(), ba.size());
                pyResult = PyString_FromStringAndSize(ba.constData(), ba.size());

                // End of code injection


            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QAbstractFileEngineFunc_read_TypeError:
        const char* overloads[] = {"str, long long", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QAbstractFileEngine.read", overloads);
        return 0;
}

static PyObject* Sbk_QAbstractFileEngineFunc_readLine(PyObject* self, PyObject* arg)
{
    QAbstractFileEngine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QAbstractFileEngine* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: readLine(char*,qint64)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // readLine(char*,qint64)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QAbstractFileEngineFunc_readLine_TypeError;

    // Call function/method
    {
        {
            qint64 cppArg0 = Shiboken::Converter<qint64 >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // readLine(char*,qint64)
                // Begin code injection

                QByteArray ba;
                ba.resize(cppArg0);
                cppSelf->readLine(ba.data(), ba.size());
                pyResult = PyString_FromStringAndSize(ba.constData(), ba.size());

                // End of code injection


            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QAbstractFileEngineFunc_readLine_TypeError:
        const char* overloads[] = {"str, long long", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QAbstractFileEngine.readLine", overloads);
        return 0;
}

static PyObject* Sbk_QAbstractFileEngineFunc_remove(PyObject* self)
{
    QAbstractFileEngine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QAbstractFileEngine* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // remove()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = (Shiboken::Object::isUserType(self) ? cppSelf->::QAbstractFileEngine::remove() : cppSelf->remove());
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QAbstractFileEngineFunc_rename(PyObject* self, PyObject* arg)
{
    QAbstractFileEngine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QAbstractFileEngine* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: rename(QString)
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // rename(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QAbstractFileEngineFunc_rename_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // rename(QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = (Shiboken::Object::isUserType(self) ? cppSelf->::QAbstractFileEngine::rename(cppArg0) : cppSelf->rename(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QAbstractFileEngineFunc_rename_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QAbstractFileEngine.rename", overloads);
        return 0;
}

static PyObject* Sbk_QAbstractFileEngineFunc_rmdir(PyObject* self, PyObject* args)
{
    QAbstractFileEngine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QAbstractFileEngine* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "rmdir", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: rmdir(QString,bool)const
    if (numArgs == 2 && Shiboken::Converter< QString >::isConvertible(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 0; // rmdir(QString,bool)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QAbstractFileEngineFunc_rmdir_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            bool cppArg1 = Shiboken::Converter<bool >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // rmdir(QString,bool)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = (Shiboken::Object::isUserType(self) ? const_cast<const QAbstractFileEngine*>(cppSelf)->::QAbstractFileEngine::rmdir(cppArg0, cppArg1) : const_cast<const QAbstractFileEngine*>(cppSelf)->rmdir(cppArg0, cppArg1));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QAbstractFileEngineFunc_rmdir_TypeError:
        const char* overloads[] = {"QString, bool", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QAbstractFileEngine.rmdir", overloads);
        return 0;
}

static PyObject* Sbk_QAbstractFileEngineFunc_seek(PyObject* self, PyObject* arg)
{
    QAbstractFileEngine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QAbstractFileEngine* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: seek(qint64)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // seek(qint64)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QAbstractFileEngineFunc_seek_TypeError;

    // Call function/method
    {
        {
            qint64 cppArg0 = Shiboken::Converter<qint64 >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // seek(qint64)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = (Shiboken::Object::isUserType(self) ? cppSelf->::QAbstractFileEngine::seek(cppArg0) : cppSelf->seek(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QAbstractFileEngineFunc_seek_TypeError:
        const char* overloads[] = {"long long", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QAbstractFileEngine.seek", overloads);
        return 0;
}

static PyObject* Sbk_QAbstractFileEngineFunc_setError(PyObject* self, PyObject* args)
{
    QAbstractFileEngine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QAbstractFileEngine* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setError", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setError(QFile::FileError,QString)
    if (numArgs == 2 && Shiboken::Converter< ::QFile::FileError >::isConvertible(pyargs[0]) && Shiboken::Converter< QString >::isConvertible(pyargs[1])) {
        overloadId = 0; // setError(QFile::FileError,QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QAbstractFileEngineFunc_setError_TypeError;

    // Call function/method
    {
        {
            QFile::FileError cppArg0 = Shiboken::Converter<QFile::FileError >::toCpp(pyargs[0]);
            QString cppArg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // setError(QFile::FileError,QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setError(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QAbstractFileEngineFunc_setError_TypeError:
        const char* overloads[] = {"PySide.QtCore.QFile.FileError, QString", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QAbstractFileEngine.setError", overloads);
        return 0;
}

static PyObject* Sbk_QAbstractFileEngineFunc_setFileName(PyObject* self, PyObject* arg)
{
    QAbstractFileEngine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QAbstractFileEngine* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setFileName(QString)
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // setFileName(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QAbstractFileEngineFunc_setFileName_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setFileName(QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QAbstractFileEngine::setFileName(cppArg0) : cppSelf->setFileName(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QAbstractFileEngineFunc_setFileName_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QAbstractFileEngine.setFileName", overloads);
        return 0;
}

static PyObject* Sbk_QAbstractFileEngineFunc_setPermissions(PyObject* self, PyObject* arg)
{
    QAbstractFileEngine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QAbstractFileEngine* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setPermissions(uint)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setPermissions(uint)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QAbstractFileEngineFunc_setPermissions_TypeError;

    // Call function/method
    {
        {
            uint cppArg0 = Shiboken::Converter<uint >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setPermissions(uint)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = (Shiboken::Object::isUserType(self) ? cppSelf->::QAbstractFileEngine::setPermissions(cppArg0) : cppSelf->setPermissions(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QAbstractFileEngineFunc_setPermissions_TypeError:
        const char* overloads[] = {"unsigned int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QAbstractFileEngine.setPermissions", overloads);
        return 0;
}

static PyObject* Sbk_QAbstractFileEngineFunc_setSize(PyObject* self, PyObject* arg)
{
    QAbstractFileEngine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QAbstractFileEngine* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setSize(qint64)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setSize(qint64)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QAbstractFileEngineFunc_setSize_TypeError;

    // Call function/method
    {
        {
            qint64 cppArg0 = Shiboken::Converter<qint64 >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setSize(qint64)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = (Shiboken::Object::isUserType(self) ? cppSelf->::QAbstractFileEngine::setSize(cppArg0) : cppSelf->setSize(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QAbstractFileEngineFunc_setSize_TypeError:
        const char* overloads[] = {"long long", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QAbstractFileEngine.setSize", overloads);
        return 0;
}

static PyObject* Sbk_QAbstractFileEngineFunc_size(PyObject* self)
{
    QAbstractFileEngine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QAbstractFileEngine* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // size()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                qint64 cppResult = (Shiboken::Object::isUserType(self) ? const_cast<const QAbstractFileEngine*>(cppSelf)->::QAbstractFileEngine::size() : const_cast<const QAbstractFileEngine*>(cppSelf)->size());
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< long long >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QAbstractFileEngineFunc_supportsExtension(PyObject* self, PyObject* arg)
{
    QAbstractFileEngine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QAbstractFileEngine* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: supportsExtension(QAbstractFileEngine::Extension)const
    if (Shiboken::Converter< ::QAbstractFileEngine::Extension >::isConvertible(arg)) {
        overloadId = 0; // supportsExtension(QAbstractFileEngine::Extension)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QAbstractFileEngineFunc_supportsExtension_TypeError;

    // Call function/method
    {
        {
            QAbstractFileEngine::Extension cppArg0 = Shiboken::Converter<QAbstractFileEngine::Extension >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // supportsExtension(QAbstractFileEngine::Extension)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = (Shiboken::Object::isUserType(self) ? const_cast<const QAbstractFileEngine*>(cppSelf)->::QAbstractFileEngine::supportsExtension(cppArg0) : const_cast<const QAbstractFileEngine*>(cppSelf)->supportsExtension(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QAbstractFileEngineFunc_supportsExtension_TypeError:
        const char* overloads[] = {"PySide.QtCore.QAbstractFileEngine.Extension", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QAbstractFileEngine.supportsExtension", overloads);
        return 0;
}

static PyObject* Sbk_QAbstractFileEngineFunc_unmap(PyObject* self, PyObject* arg)
{
    QAbstractFileEngine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QAbstractFileEngine* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: unmap(uchar*)
    if (PyBuffer_Check(arg)) {
        overloadId = 0; // unmap(uchar*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QAbstractFileEngineFunc_unmap_TypeError;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // unmap(uchar*)
                // Begin code injection

                const void* ptr;
                Py_ssize_t len;
                PyObject_AsReadBuffer(arg, &ptr, &len);
                pyResult = Shiboken::Converter<bool >::toPython(cppSelf->unmap((uchar*)ptr));

                // End of code injection


            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QAbstractFileEngineFunc_unmap_TypeError:
        const char* overloads[] = {"buffer", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QAbstractFileEngine.unmap", overloads);
        return 0;
}

static PyObject* Sbk_QAbstractFileEngineFunc_write(PyObject* self, PyObject* args)
{
    QAbstractFileEngine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QAbstractFileEngine* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "write", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: write(const char*,qint64)
    if (numArgs == 2 && Shiboken::Converter< const char * >::isConvertible(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 0; // write(const char*,qint64)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QAbstractFileEngineFunc_write_TypeError;

    // Call function/method
    {
        {
            const char * cppArg0 = Shiboken::Converter<const char * >::toCpp(pyargs[0]);
            qint64 cppArg1 = Shiboken::Converter<qint64 >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // write(const char*,qint64)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                qint64 cppResult = (Shiboken::Object::isUserType(self) ? cppSelf->::QAbstractFileEngine::write(cppArg0, cppArg1) : cppSelf->write(cppArg0, cppArg1));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< long long >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QAbstractFileEngineFunc_write_TypeError:
        const char* overloads[] = {"str, long long", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QAbstractFileEngine.write", overloads);
        return 0;
}

static PyMethodDef Sbk_QAbstractFileEngine_methods[] = {
    {"atEnd", (PyCFunction)Sbk_QAbstractFileEngineFunc_atEnd, METH_NOARGS},
    {"caseSensitive", (PyCFunction)Sbk_QAbstractFileEngineFunc_caseSensitive, METH_NOARGS},
    {"close", (PyCFunction)Sbk_QAbstractFileEngineFunc_close, METH_NOARGS},
    {"copy", (PyCFunction)Sbk_QAbstractFileEngineFunc_copy, METH_O},
    {"create", (PyCFunction)Sbk_QAbstractFileEngineFunc_create, METH_O|METH_STATIC},
    {"entryList", (PyCFunction)Sbk_QAbstractFileEngineFunc_entryList, METH_VARARGS},
    {"error", (PyCFunction)Sbk_QAbstractFileEngineFunc_error, METH_NOARGS},
    {"errorString", (PyCFunction)Sbk_QAbstractFileEngineFunc_errorString, METH_NOARGS},
    {"fileFlags", (PyCFunction)Sbk_QAbstractFileEngineFunc_fileFlags, METH_VARARGS|METH_KEYWORDS},
    {"fileName", (PyCFunction)Sbk_QAbstractFileEngineFunc_fileName, METH_VARARGS|METH_KEYWORDS},
    {"fileTime", (PyCFunction)Sbk_QAbstractFileEngineFunc_fileTime, METH_O},
    {"flush", (PyCFunction)Sbk_QAbstractFileEngineFunc_flush, METH_NOARGS},
    {"handle", (PyCFunction)Sbk_QAbstractFileEngineFunc_handle, METH_NOARGS},
    {"isRelativePath", (PyCFunction)Sbk_QAbstractFileEngineFunc_isRelativePath, METH_NOARGS},
    {"isSequential", (PyCFunction)Sbk_QAbstractFileEngineFunc_isSequential, METH_NOARGS},
    {"link", (PyCFunction)Sbk_QAbstractFileEngineFunc_link, METH_O},
    {"map", (PyCFunction)Sbk_QAbstractFileEngineFunc_map, METH_VARARGS},
    {"mkdir", (PyCFunction)Sbk_QAbstractFileEngineFunc_mkdir, METH_VARARGS},
    {"open", (PyCFunction)Sbk_QAbstractFileEngineFunc_open, METH_O},
    {"owner", (PyCFunction)Sbk_QAbstractFileEngineFunc_owner, METH_O},
    {"ownerId", (PyCFunction)Sbk_QAbstractFileEngineFunc_ownerId, METH_O},
    {"pos", (PyCFunction)Sbk_QAbstractFileEngineFunc_pos, METH_NOARGS},
    {"read", (PyCFunction)Sbk_QAbstractFileEngineFunc_read, METH_O},
    {"readLine", (PyCFunction)Sbk_QAbstractFileEngineFunc_readLine, METH_O},
    {"remove", (PyCFunction)Sbk_QAbstractFileEngineFunc_remove, METH_NOARGS},
    {"rename", (PyCFunction)Sbk_QAbstractFileEngineFunc_rename, METH_O},
    {"rmdir", (PyCFunction)Sbk_QAbstractFileEngineFunc_rmdir, METH_VARARGS},
    {"seek", (PyCFunction)Sbk_QAbstractFileEngineFunc_seek, METH_O},
    {"setError", (PyCFunction)Sbk_QAbstractFileEngineFunc_setError, METH_VARARGS},
    {"setFileName", (PyCFunction)Sbk_QAbstractFileEngineFunc_setFileName, METH_O},
    {"setPermissions", (PyCFunction)Sbk_QAbstractFileEngineFunc_setPermissions, METH_O},
    {"setSize", (PyCFunction)Sbk_QAbstractFileEngineFunc_setSize, METH_O},
    {"size", (PyCFunction)Sbk_QAbstractFileEngineFunc_size, METH_NOARGS},
    {"supportsExtension", (PyCFunction)Sbk_QAbstractFileEngineFunc_supportsExtension, METH_O},
    {"unmap", (PyCFunction)Sbk_QAbstractFileEngineFunc_unmap, METH_O},
    {"write", (PyCFunction)Sbk_QAbstractFileEngineFunc_write, METH_VARARGS},

    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QAbstractFileEngine_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtCore.QAbstractFileEngine",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QAbstractFileEngine_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&SbkObject_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QAbstractFileEngine_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern

PyObject* SbkPySide_QtCore_QAbstractFileEngine_FileFlag___and__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QAbstractFileEngine::FileFlags >::toPython(
        Shiboken::Converter<QAbstractFileEngine::FileFlags>::toCpp(self)
        & Shiboken::Converter< QAbstractFileEngine::FileFlags >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtCore_QAbstractFileEngine_FileFlag___or__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QAbstractFileEngine::FileFlags >::toPython(
        Shiboken::Converter<QAbstractFileEngine::FileFlags>::toCpp(self)
        | Shiboken::Converter< QAbstractFileEngine::FileFlags >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtCore_QAbstractFileEngine_FileFlag___xor__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QAbstractFileEngine::FileFlags >::toPython(
        Shiboken::Converter<QAbstractFileEngine::FileFlags>::toCpp(self)
        ^ Shiboken::Converter< QAbstractFileEngine::FileFlags >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtCore_QAbstractFileEngine_FileFlag___invert__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QAbstractFileEngine::FileFlags >::toPython(
        ~Shiboken::Converter<QAbstractFileEngine::FileFlags >::toCpp(self)
    );
}


static PyNumberMethods SbkPySide_QtCore_QAbstractFileEngine_FileFlag_as_number = {
    /*nb_add*/                  0,
    /*nb_subtract*/             0,
    /*nb_multiply*/             0,
    /*nb_divide*/               0,
    /*nb_remainder*/            0,
    /*nb_divmod*/               0,
    /*nb_power*/                0,
    /*nb_negative*/             0,
    /*nb_positive*/             0,
    /*nb_absolute*/             0,
    /*nb_nonzero*/              0,
    /*nb_invert*/               (unaryfunc)SbkPySide_QtCore_QAbstractFileEngine_FileFlag___invert__,
    /*nb_lshift*/               0,
    /*nb_rshift*/               0,
    /*nb_and*/                  (binaryfunc)SbkPySide_QtCore_QAbstractFileEngine_FileFlag___and__,
    /*nb_xor*/                  (binaryfunc)SbkPySide_QtCore_QAbstractFileEngine_FileFlag___xor__,
    /*nb_or*/                   (binaryfunc)SbkPySide_QtCore_QAbstractFileEngine_FileFlag___or__,
    /*nb_coerce*/               0,
    /*nb_int*/                  0,
    /*nb_long*/                 0,
    /*nb_float*/                0,
    /*nb_oct*/                  0,
    /*nb_hex*/                  0,
    /*nb_inplace_add*/          0,
    /*nb_inplace_subtract*/     0,
    /*nb_inplace_multiply*/     0,
    /*nb_inplace_divide*/       0,
    /*nb_inplace_remainder*/    0,
    /*nb_inplace_power*/        0,
    /*nb_inplace_lshift*/       0,
    /*nb_inplace_rshift*/       0,
    /*nb_inplace_and*/          0,
    /*nb_inplace_xor*/          0,
    /*nb_inplace_or*/           0,
    /*nb_floor_divide*/         0,
    /*nb_true_divide*/          0,
    /*nb_inplace_floor_divide*/ 0,
    /*nb_inplace_true_divide*/  0,
    /*nb_index*/                0
};


// forward declaration of new function
static PyTypeObject SbkPySide_QtCore_QAbstractFileEngine_FileFlags_Type = {
    PyObject_HEAD_INIT(&PyType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "FileFlags",
    /*tp_basicsize*/        0,
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        &SbkPySide_QtCore_QAbstractFileEngine_FileFlag_as_number,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT | Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              PyInt_Type.tp_new,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};



void init_QAbstractFileEngine(PyObject* module)
{
    SbkPySide_QtCoreTypes[SBK_QABSTRACTFILEENGINE_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QAbstractFileEngine_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QAbstractFileEngine_Type);
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QAbstractFileEngine_Type, &Shiboken::callCppDestructor<QAbstractFileEngine >);
    Py_INCREF((PyObject*)&Sbk_QAbstractFileEngine_Type); //Incref due the 'PyModule_AddObject' steals the reference.
    if (PyType_Ready((PyTypeObject*)&Sbk_QAbstractFileEngine_Type) < 0)
        return;

    // Fill type discovery information

    Shiboken::ObjectType::setOriginalName(&Sbk_QAbstractFileEngine_Type, "QAbstractFileEngine*");
    PyModule_AddObject(module, "QAbstractFileEngine",
        ((PyObject*)&Sbk_QAbstractFileEngine_Type));

    // Initialize enums
    PyObject* enumItem;

    // init enum: FileName
    PyTypeObject* SbkPySide_QtCore_QAbstractFileEngine_FileName = Shiboken::Enum::newType("PySide.QtCore.QAbstractFileEngine.FileName");
    SbkPySide_QtCoreTypes[SBK_QABSTRACTFILEENGINE_FILENAME_IDX] = SbkPySide_QtCore_QAbstractFileEngine_FileName;
    if (PyType_Ready(SbkPySide_QtCore_QAbstractFileEngine_FileName) < 0)
        return;
    PyDict_SetItemString(Sbk_QAbstractFileEngine_Type.super.ht_type.tp_dict,
            "FileName",((PyObject*)SbkPySide_QtCore_QAbstractFileEngine_FileName));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QAbstractFileEngine_FileName,(long) QAbstractFileEngine::DefaultName, "DefaultName");
    PyDict_SetItemString(Sbk_QAbstractFileEngine_Type.super.ht_type.tp_dict,"DefaultName", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QAbstractFileEngine_FileName->tp_dict,"DefaultName", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QAbstractFileEngine_FileName,(long) QAbstractFileEngine::BaseName, "BaseName");
    PyDict_SetItemString(Sbk_QAbstractFileEngine_Type.super.ht_type.tp_dict,"BaseName", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QAbstractFileEngine_FileName->tp_dict,"BaseName", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QAbstractFileEngine_FileName,(long) QAbstractFileEngine::PathName, "PathName");
    PyDict_SetItemString(Sbk_QAbstractFileEngine_Type.super.ht_type.tp_dict,"PathName", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QAbstractFileEngine_FileName->tp_dict,"PathName", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QAbstractFileEngine_FileName,(long) QAbstractFileEngine::AbsoluteName, "AbsoluteName");
    PyDict_SetItemString(Sbk_QAbstractFileEngine_Type.super.ht_type.tp_dict,"AbsoluteName", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QAbstractFileEngine_FileName->tp_dict,"AbsoluteName", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QAbstractFileEngine_FileName,(long) QAbstractFileEngine::AbsolutePathName, "AbsolutePathName");
    PyDict_SetItemString(Sbk_QAbstractFileEngine_Type.super.ht_type.tp_dict,"AbsolutePathName", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QAbstractFileEngine_FileName->tp_dict,"AbsolutePathName", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QAbstractFileEngine_FileName,(long) QAbstractFileEngine::LinkName, "LinkName");
    PyDict_SetItemString(Sbk_QAbstractFileEngine_Type.super.ht_type.tp_dict,"LinkName", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QAbstractFileEngine_FileName->tp_dict,"LinkName", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QAbstractFileEngine_FileName,(long) QAbstractFileEngine::CanonicalName, "CanonicalName");
    PyDict_SetItemString(Sbk_QAbstractFileEngine_Type.super.ht_type.tp_dict,"CanonicalName", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QAbstractFileEngine_FileName->tp_dict,"CanonicalName", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QAbstractFileEngine_FileName,(long) QAbstractFileEngine::CanonicalPathName, "CanonicalPathName");
    PyDict_SetItemString(Sbk_QAbstractFileEngine_Type.super.ht_type.tp_dict,"CanonicalPathName", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QAbstractFileEngine_FileName->tp_dict,"CanonicalPathName", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QAbstractFileEngine_FileName,(long) QAbstractFileEngine::BundleName, "BundleName");
    PyDict_SetItemString(Sbk_QAbstractFileEngine_Type.super.ht_type.tp_dict,"BundleName", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QAbstractFileEngine_FileName->tp_dict,"BundleName", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QAbstractFileEngine_FileName,(long) QAbstractFileEngine::NFileNames, "NFileNames");
    PyDict_SetItemString(Sbk_QAbstractFileEngine_Type.super.ht_type.tp_dict,"NFileNames", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QAbstractFileEngine_FileName->tp_dict,"NFileNames", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QAbstractFileEngine::FileName");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::FileName");
    // end of enum FileName

    // init enum: FileTime
    PyTypeObject* SbkPySide_QtCore_QAbstractFileEngine_FileTime = Shiboken::Enum::newType("PySide.QtCore.QAbstractFileEngine.FileTime");
    SbkPySide_QtCoreTypes[SBK_QABSTRACTFILEENGINE_FILETIME_IDX] = SbkPySide_QtCore_QAbstractFileEngine_FileTime;
    if (PyType_Ready(SbkPySide_QtCore_QAbstractFileEngine_FileTime) < 0)
        return;
    PyDict_SetItemString(Sbk_QAbstractFileEngine_Type.super.ht_type.tp_dict,
            "FileTime",((PyObject*)SbkPySide_QtCore_QAbstractFileEngine_FileTime));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QAbstractFileEngine_FileTime,(long) QAbstractFileEngine::CreationTime, "CreationTime");
    PyDict_SetItemString(Sbk_QAbstractFileEngine_Type.super.ht_type.tp_dict,"CreationTime", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QAbstractFileEngine_FileTime->tp_dict,"CreationTime", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QAbstractFileEngine_FileTime,(long) QAbstractFileEngine::ModificationTime, "ModificationTime");
    PyDict_SetItemString(Sbk_QAbstractFileEngine_Type.super.ht_type.tp_dict,"ModificationTime", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QAbstractFileEngine_FileTime->tp_dict,"ModificationTime", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QAbstractFileEngine_FileTime,(long) QAbstractFileEngine::AccessTime, "AccessTime");
    PyDict_SetItemString(Sbk_QAbstractFileEngine_Type.super.ht_type.tp_dict,"AccessTime", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QAbstractFileEngine_FileTime->tp_dict,"AccessTime", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QAbstractFileEngine::FileTime");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::FileTime");
    // end of enum FileTime

    // init enum: FileOwner
    PyTypeObject* SbkPySide_QtCore_QAbstractFileEngine_FileOwner = Shiboken::Enum::newType("PySide.QtCore.QAbstractFileEngine.FileOwner");
    SbkPySide_QtCoreTypes[SBK_QABSTRACTFILEENGINE_FILEOWNER_IDX] = SbkPySide_QtCore_QAbstractFileEngine_FileOwner;
    if (PyType_Ready(SbkPySide_QtCore_QAbstractFileEngine_FileOwner) < 0)
        return;
    PyDict_SetItemString(Sbk_QAbstractFileEngine_Type.super.ht_type.tp_dict,
            "FileOwner",((PyObject*)SbkPySide_QtCore_QAbstractFileEngine_FileOwner));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QAbstractFileEngine_FileOwner,(long) QAbstractFileEngine::OwnerUser, "OwnerUser");
    PyDict_SetItemString(Sbk_QAbstractFileEngine_Type.super.ht_type.tp_dict,"OwnerUser", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QAbstractFileEngine_FileOwner->tp_dict,"OwnerUser", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QAbstractFileEngine_FileOwner,(long) QAbstractFileEngine::OwnerGroup, "OwnerGroup");
    PyDict_SetItemString(Sbk_QAbstractFileEngine_Type.super.ht_type.tp_dict,"OwnerGroup", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QAbstractFileEngine_FileOwner->tp_dict,"OwnerGroup", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QAbstractFileEngine::FileOwner");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::FileOwner");
    // end of enum FileOwner

    // init enum: Extension
    PyTypeObject* SbkPySide_QtCore_QAbstractFileEngine_Extension = Shiboken::Enum::newType("PySide.QtCore.QAbstractFileEngine.Extension");
    SbkPySide_QtCoreTypes[SBK_QABSTRACTFILEENGINE_EXTENSION_IDX] = SbkPySide_QtCore_QAbstractFileEngine_Extension;
    if (PyType_Ready(SbkPySide_QtCore_QAbstractFileEngine_Extension) < 0)
        return;
    PyDict_SetItemString(Sbk_QAbstractFileEngine_Type.super.ht_type.tp_dict,
            "Extension",((PyObject*)SbkPySide_QtCore_QAbstractFileEngine_Extension));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QAbstractFileEngine_Extension,(long) QAbstractFileEngine::AtEndExtension, "AtEndExtension");
    PyDict_SetItemString(Sbk_QAbstractFileEngine_Type.super.ht_type.tp_dict,"AtEndExtension", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QAbstractFileEngine_Extension->tp_dict,"AtEndExtension", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QAbstractFileEngine_Extension,(long) QAbstractFileEngine::FastReadLineExtension, "FastReadLineExtension");
    PyDict_SetItemString(Sbk_QAbstractFileEngine_Type.super.ht_type.tp_dict,"FastReadLineExtension", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QAbstractFileEngine_Extension->tp_dict,"FastReadLineExtension", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QAbstractFileEngine_Extension,(long) QAbstractFileEngine::MapExtension, "MapExtension");
    PyDict_SetItemString(Sbk_QAbstractFileEngine_Type.super.ht_type.tp_dict,"MapExtension", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QAbstractFileEngine_Extension->tp_dict,"MapExtension", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QAbstractFileEngine_Extension,(long) QAbstractFileEngine::UnMapExtension, "UnMapExtension");
    PyDict_SetItemString(Sbk_QAbstractFileEngine_Type.super.ht_type.tp_dict,"UnMapExtension", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QAbstractFileEngine_Extension->tp_dict,"UnMapExtension", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QAbstractFileEngine::Extension");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::Extension");
    // end of enum Extension

    // init enum: FileFlag
    PyTypeObject* SbkPySide_QtCore_QAbstractFileEngine_FileFlag = Shiboken::Enum::newType("PySide.QtCore.QAbstractFileEngine.FileFlag");
    SbkPySide_QtCore_QAbstractFileEngine_FileFlag->tp_as_number = &SbkPySide_QtCore_QAbstractFileEngine_FileFlag_as_number;
    SbkPySide_QtCoreTypes[SBK_QABSTRACTFILEENGINE_FILEFLAG_IDX] = SbkPySide_QtCore_QAbstractFileEngine_FileFlag;
    if (PyType_Ready(SbkPySide_QtCore_QAbstractFileEngine_FileFlag) < 0)
        return;
    PyDict_SetItemString(Sbk_QAbstractFileEngine_Type.super.ht_type.tp_dict,
            "FileFlag",((PyObject*)SbkPySide_QtCore_QAbstractFileEngine_FileFlag));

    // init flags class: QFlags<QAbstractFileEngine::FileFlag>
    SbkPySide_QtCoreTypes[SBK_QFLAGS_QABSTRACTFILEENGINE_FILEFLAG__IDX] = &SbkPySide_QtCore_QAbstractFileEngine_FileFlags_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtCore_QAbstractFileEngine_FileFlags_Type) < 0)
        return;
    PyDict_SetItemString(Sbk_QAbstractFileEngine_Type.super.ht_type.tp_dict,
            "FileFlags",((PyObject*)&SbkPySide_QtCore_QAbstractFileEngine_FileFlags_Type));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QAbstractFileEngine_FileFlag,(long) QAbstractFileEngine::ReadOwnerPerm, "ReadOwnerPerm");
    PyDict_SetItemString(Sbk_QAbstractFileEngine_Type.super.ht_type.tp_dict,"ReadOwnerPerm", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QAbstractFileEngine_FileFlag->tp_dict,"ReadOwnerPerm", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QAbstractFileEngine_FileFlag,(long) QAbstractFileEngine::WriteOwnerPerm, "WriteOwnerPerm");
    PyDict_SetItemString(Sbk_QAbstractFileEngine_Type.super.ht_type.tp_dict,"WriteOwnerPerm", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QAbstractFileEngine_FileFlag->tp_dict,"WriteOwnerPerm", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QAbstractFileEngine_FileFlag,(long) QAbstractFileEngine::ExeOwnerPerm, "ExeOwnerPerm");
    PyDict_SetItemString(Sbk_QAbstractFileEngine_Type.super.ht_type.tp_dict,"ExeOwnerPerm", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QAbstractFileEngine_FileFlag->tp_dict,"ExeOwnerPerm", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QAbstractFileEngine_FileFlag,(long) QAbstractFileEngine::ReadUserPerm, "ReadUserPerm");
    PyDict_SetItemString(Sbk_QAbstractFileEngine_Type.super.ht_type.tp_dict,"ReadUserPerm", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QAbstractFileEngine_FileFlag->tp_dict,"ReadUserPerm", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QAbstractFileEngine_FileFlag,(long) QAbstractFileEngine::WriteUserPerm, "WriteUserPerm");
    PyDict_SetItemString(Sbk_QAbstractFileEngine_Type.super.ht_type.tp_dict,"WriteUserPerm", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QAbstractFileEngine_FileFlag->tp_dict,"WriteUserPerm", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QAbstractFileEngine_FileFlag,(long) QAbstractFileEngine::ExeUserPerm, "ExeUserPerm");
    PyDict_SetItemString(Sbk_QAbstractFileEngine_Type.super.ht_type.tp_dict,"ExeUserPerm", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QAbstractFileEngine_FileFlag->tp_dict,"ExeUserPerm", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QAbstractFileEngine_FileFlag,(long) QAbstractFileEngine::ReadGroupPerm, "ReadGroupPerm");
    PyDict_SetItemString(Sbk_QAbstractFileEngine_Type.super.ht_type.tp_dict,"ReadGroupPerm", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QAbstractFileEngine_FileFlag->tp_dict,"ReadGroupPerm", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QAbstractFileEngine_FileFlag,(long) QAbstractFileEngine::WriteGroupPerm, "WriteGroupPerm");
    PyDict_SetItemString(Sbk_QAbstractFileEngine_Type.super.ht_type.tp_dict,"WriteGroupPerm", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QAbstractFileEngine_FileFlag->tp_dict,"WriteGroupPerm", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QAbstractFileEngine_FileFlag,(long) QAbstractFileEngine::ExeGroupPerm, "ExeGroupPerm");
    PyDict_SetItemString(Sbk_QAbstractFileEngine_Type.super.ht_type.tp_dict,"ExeGroupPerm", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QAbstractFileEngine_FileFlag->tp_dict,"ExeGroupPerm", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QAbstractFileEngine_FileFlag,(long) QAbstractFileEngine::ReadOtherPerm, "ReadOtherPerm");
    PyDict_SetItemString(Sbk_QAbstractFileEngine_Type.super.ht_type.tp_dict,"ReadOtherPerm", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QAbstractFileEngine_FileFlag->tp_dict,"ReadOtherPerm", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QAbstractFileEngine_FileFlag,(long) QAbstractFileEngine::WriteOtherPerm, "WriteOtherPerm");
    PyDict_SetItemString(Sbk_QAbstractFileEngine_Type.super.ht_type.tp_dict,"WriteOtherPerm", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QAbstractFileEngine_FileFlag->tp_dict,"WriteOtherPerm", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QAbstractFileEngine_FileFlag,(long) QAbstractFileEngine::ExeOtherPerm, "ExeOtherPerm");
    PyDict_SetItemString(Sbk_QAbstractFileEngine_Type.super.ht_type.tp_dict,"ExeOtherPerm", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QAbstractFileEngine_FileFlag->tp_dict,"ExeOtherPerm", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QAbstractFileEngine_FileFlag,(long) QAbstractFileEngine::LinkType, "LinkType");
    PyDict_SetItemString(Sbk_QAbstractFileEngine_Type.super.ht_type.tp_dict,"LinkType", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QAbstractFileEngine_FileFlag->tp_dict,"LinkType", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QAbstractFileEngine_FileFlag,(long) QAbstractFileEngine::FileType, "FileType");
    PyDict_SetItemString(Sbk_QAbstractFileEngine_Type.super.ht_type.tp_dict,"FileType", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QAbstractFileEngine_FileFlag->tp_dict,"FileType", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QAbstractFileEngine_FileFlag,(long) QAbstractFileEngine::DirectoryType, "DirectoryType");
    PyDict_SetItemString(Sbk_QAbstractFileEngine_Type.super.ht_type.tp_dict,"DirectoryType", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QAbstractFileEngine_FileFlag->tp_dict,"DirectoryType", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QAbstractFileEngine_FileFlag,(long) QAbstractFileEngine::BundleType, "BundleType");
    PyDict_SetItemString(Sbk_QAbstractFileEngine_Type.super.ht_type.tp_dict,"BundleType", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QAbstractFileEngine_FileFlag->tp_dict,"BundleType", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QAbstractFileEngine_FileFlag,(long) QAbstractFileEngine::HiddenFlag, "HiddenFlag");
    PyDict_SetItemString(Sbk_QAbstractFileEngine_Type.super.ht_type.tp_dict,"HiddenFlag", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QAbstractFileEngine_FileFlag->tp_dict,"HiddenFlag", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QAbstractFileEngine_FileFlag,(long) QAbstractFileEngine::LocalDiskFlag, "LocalDiskFlag");
    PyDict_SetItemString(Sbk_QAbstractFileEngine_Type.super.ht_type.tp_dict,"LocalDiskFlag", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QAbstractFileEngine_FileFlag->tp_dict,"LocalDiskFlag", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QAbstractFileEngine_FileFlag,(long) QAbstractFileEngine::ExistsFlag, "ExistsFlag");
    PyDict_SetItemString(Sbk_QAbstractFileEngine_Type.super.ht_type.tp_dict,"ExistsFlag", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QAbstractFileEngine_FileFlag->tp_dict,"ExistsFlag", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QAbstractFileEngine_FileFlag,(long) QAbstractFileEngine::RootFlag, "RootFlag");
    PyDict_SetItemString(Sbk_QAbstractFileEngine_Type.super.ht_type.tp_dict,"RootFlag", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QAbstractFileEngine_FileFlag->tp_dict,"RootFlag", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QAbstractFileEngine_FileFlag,(long) QAbstractFileEngine::Refresh, "Refresh");
    PyDict_SetItemString(Sbk_QAbstractFileEngine_Type.super.ht_type.tp_dict,"Refresh", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QAbstractFileEngine_FileFlag->tp_dict,"Refresh", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QAbstractFileEngine_FileFlag,(long) QAbstractFileEngine::PermsMask, "PermsMask");
    PyDict_SetItemString(Sbk_QAbstractFileEngine_Type.super.ht_type.tp_dict,"PermsMask", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QAbstractFileEngine_FileFlag->tp_dict,"PermsMask", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QAbstractFileEngine_FileFlag,(long) QAbstractFileEngine::TypesMask, "TypesMask");
    PyDict_SetItemString(Sbk_QAbstractFileEngine_Type.super.ht_type.tp_dict,"TypesMask", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QAbstractFileEngine_FileFlag->tp_dict,"TypesMask", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QAbstractFileEngine_FileFlag,(long) QAbstractFileEngine::FlagsMask, "FlagsMask");
    PyDict_SetItemString(Sbk_QAbstractFileEngine_Type.super.ht_type.tp_dict,"FlagsMask", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QAbstractFileEngine_FileFlag->tp_dict,"FlagsMask", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QAbstractFileEngine_FileFlag,(long) QAbstractFileEngine::FileInfoAll, "FileInfoAll");
    PyDict_SetItemString(Sbk_QAbstractFileEngine_Type.super.ht_type.tp_dict,"FileInfoAll", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QAbstractFileEngine_FileFlag->tp_dict,"FileInfoAll", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QAbstractFileEngine::FileFlag");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::FileFlag");
    // end of enum FileFlag


    Shiboken::TypeResolver::createObjectTypeResolver<QAbstractFileEngine >("QAbstractFileEngine*");
    Shiboken::TypeResolver::createObjectTypeResolver<QAbstractFileEngine >(typeid(QAbstractFileEngine).name());
    Shiboken::TypeResolver::createObjectTypeResolver<QAbstractFileEngine >(typeid(QAbstractFileEngineWrapper).name());
    qRegisterMetaType< ::QAbstractFileEngine* >("QAbstractFileEngine*");
    qRegisterMetaType< ::QAbstractFileEngine::FileName >("QAbstractFileEngine::FileName");
    qRegisterMetaType< ::QAbstractFileEngine::FileTime >("QAbstractFileEngine::FileTime");
    qRegisterMetaType< ::QAbstractFileEngine::FileOwner >("QAbstractFileEngine::FileOwner");
    qRegisterMetaType< ::QAbstractFileEngine::Extension >("QAbstractFileEngine::Extension");
    qRegisterMetaType< ::QAbstractFileEngine::FileFlag >("QAbstractFileEngine::FileFlag");
    qRegisterMetaType< ::QAbstractFileEngine::FileFlags >("QAbstractFileEngine::FileFlags");
}

