/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtcore_python.h"

#include "qdatastream_wrapper.h"

// Extra includes
#include <QStringList>
#include <QtCore/QtCore>
#include <qbitarray.h>
#include <qbytearray.h>
#include <qdatastream.h>
#include <qdatetime.h>
#include <qeasingcurve.h>
#include <qiodevice.h>
#include <qline.h>
#include <qlocale.h>
#include <qpoint.h>
#include <qrect.h>
#include <qregexp.h>
#include <qsize.h>
#include <qurl.h>
#include <quuid.h>


// Native ---------------------------------------------------------

QDataStreamWrapper::QDataStreamWrapper() : QDataStream() {
    // ... middle
}

QDataStreamWrapper::QDataStreamWrapper(QByteArray * arg__1, QFlags<QIODevice::OpenModeFlag> flags) : QDataStream(arg__1, flags) {
    // ... middle
}

QDataStreamWrapper::QDataStreamWrapper(QIODevice * arg__1) : QDataStream(arg__1) {
    // ... middle
}

QDataStreamWrapper::QDataStreamWrapper(const QByteArray & arg__1) : QDataStream(arg__1) {
    // ... middle
}

QDataStreamWrapper::~QDataStreamWrapper()
{
    SbkObject* wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QDataStream_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QDataStream >()))
        return -1;

    QDataStreamWrapper* cptr = 0;
    int overloadId = -1;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QDataStream", 0, 2, &(pyargs[0]), &(pyargs[1])))
        return -1;

    // Overloaded function decisor
    // 0: QDataStream()
    // 1: QDataStream(QByteArray*,QFlags<QIODevice::OpenModeFlag>)
    // 2: QDataStream(QIODevice*)
    // 3: QDataStream(QByteArray)
    if (numArgs == 0) {
        overloadId = 0; // QDataStream()
    } else if (numArgs == 1 && Shiboken::Converter< ::QIODevice * >::isConvertible(pyargs[0])) {
        overloadId = 2; // QDataStream(QIODevice*)
    } else if (Shiboken::Converter< ::QByteArray * >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 3; // QDataStream(QByteArray)
        } else if (numArgs == 2 && Shiboken::Converter< ::QFlags<QIODevice::OpenModeFlag> >::isConvertible(pyargs[1])) {
            overloadId = 1; // QDataStream(QByteArray*,QFlags<QIODevice::OpenModeFlag>)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QDataStream_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QDataStream()
            {

                if(!PyErr_Occurred()) {
                    // QDataStream()
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QDataStreamWrapper();
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // QDataStream(QByteArray*,QFlags<QIODevice::OpenModeFlag>)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QByteArray * cppArg0 = Shiboken::Converter<QByteArray * >::toCpp(pyargs[0]);
                QFlags<QIODevice::OpenModeFlag> cppArg1 = Shiboken::Converter<QFlags<QIODevice::OpenModeFlag> >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // QDataStream(QByteArray*,QFlags<QIODevice::OpenModeFlag>)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QDataStreamWrapper(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 2: // QDataStream(QIODevice*)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QIODevice * cppArg0 = Shiboken::Converter<QIODevice * >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QDataStream(QIODevice*)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QDataStreamWrapper(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 3: // QDataStream(QByteArray)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QByteArray cppArg0 = Shiboken::Converter<QByteArray >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QDataStream(QByteArray)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QDataStreamWrapper(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QDataStream >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QDataStream_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QDataStream_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtCore.QByteArray, PySide.QtCore.QIODevice.OpenMode", "PySide.QtCore.QIODevice", "PySide.QtCore.QByteArray", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QDataStream", overloads);
        return -1;
}

static PyObject* Sbk_QDataStreamFunc_atEnd(PyObject* self)
{
    QDataStream* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDataStream* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // atEnd()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QDataStream*>(cppSelf)->atEnd();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QDataStreamFunc_byteOrder(PyObject* self)
{
    QDataStream* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDataStream* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // byteOrder()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QDataStream::ByteOrder cppResult = const_cast<const QDataStream*>(cppSelf)->byteOrder();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QDataStream::ByteOrder >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QDataStreamFunc_device(PyObject* self)
{
    QDataStream* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDataStream* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // device()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QIODevice * cppResult = const_cast<const QDataStream*>(cppSelf)->device();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QIODevice * >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QDataStreamFunc_floatingPointPrecision(PyObject* self)
{
    QDataStream* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDataStream* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // floatingPointPrecision()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QDataStream::FloatingPointPrecision cppResult = const_cast<const QDataStream*>(cppSelf)->floatingPointPrecision();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QDataStream::FloatingPointPrecision >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QDataStreamFunc_readBool(PyObject* self)
{
    QDataStream* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDataStream* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // readBool()


                // Begin code injection

                // TEMPLATE - stream_read_method - START
                bool _cpp_result;
                (*cppSelf) >> _cpp_result;
                pyResult = Shiboken::Converter<bool >::toPython(_cpp_result);
                // TEMPLATE - stream_read_method - END

                // End of code injection
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QDataStreamFunc_readDouble(PyObject* self)
{
    QDataStream* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDataStream* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // readDouble()


                // Begin code injection

                // TEMPLATE - stream_read_method - START
                qreal _cpp_result;
                (*cppSelf) >> _cpp_result;
                pyResult = Shiboken::Converter<qreal >::toPython(_cpp_result);
                // TEMPLATE - stream_read_method - END

                // End of code injection
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QDataStreamFunc_readFloat(PyObject* self)
{
    QDataStream* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDataStream* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // readFloat()


                // Begin code injection

                // TEMPLATE - stream_read_method - START
                float _cpp_result;
                (*cppSelf) >> _cpp_result;
                pyResult = Shiboken::Converter<float >::toPython(_cpp_result);
                // TEMPLATE - stream_read_method - END

                // End of code injection
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QDataStreamFunc_readInt16(PyObject* self)
{
    QDataStream* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDataStream* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // readInt16()


                // Begin code injection

                // TEMPLATE - stream_read_method - START
                qint16 _cpp_result;
                (*cppSelf) >> _cpp_result;
                pyResult = Shiboken::Converter<qint16 >::toPython(_cpp_result);
                // TEMPLATE - stream_read_method - END

                // End of code injection
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QDataStreamFunc_readInt32(PyObject* self)
{
    QDataStream* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDataStream* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // readInt32()


                // Begin code injection

                // TEMPLATE - stream_read_method - START
                qint32 _cpp_result;
                (*cppSelf) >> _cpp_result;
                pyResult = Shiboken::Converter<qint32 >::toPython(_cpp_result);
                // TEMPLATE - stream_read_method - END

                // End of code injection
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QDataStreamFunc_readInt64(PyObject* self)
{
    QDataStream* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDataStream* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // readInt64()


                // Begin code injection

                // TEMPLATE - stream_read_method - START
                qint64 _cpp_result;
                (*cppSelf) >> _cpp_result;
                pyResult = Shiboken::Converter<qint64 >::toPython(_cpp_result);
                // TEMPLATE - stream_read_method - END

                // End of code injection
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QDataStreamFunc_readInt8(PyObject* self)
{
    QDataStream* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDataStream* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // readInt8()


                // Begin code injection

                // TEMPLATE - stream_read_method - START
                qint8 _cpp_result;
                (*cppSelf) >> _cpp_result;
                pyResult = Shiboken::Converter<qint8 >::toPython(_cpp_result);
                // TEMPLATE - stream_read_method - END

                // End of code injection
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QDataStreamFunc_readQChar(PyObject* self)
{
    QDataStream* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDataStream* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // readQChar()
                // Begin code injection

                QChar val;
                *(cppSelf) >> val;
                pyResult = Shiboken::Converter<QChar >::toPython(val);

                // End of code injection


            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QDataStreamFunc_readQString(PyObject* self)
{
    QDataStream* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDataStream* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // readQString()
                // Begin code injection

                QString val;
                *(cppSelf) >> val;
                pyResult = Shiboken::Converter<QString >::toPython(val);

                // End of code injection


            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QDataStreamFunc_readQStringList(PyObject* self)
{
    QDataStream* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDataStream* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // readQStringList()
                // Begin code injection

                QStringList val;
                *(cppSelf) >> val;
                pyResult = Shiboken::Converter<QStringList >::toPython(val);

                // End of code injection


            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QDataStreamFunc_readQVariant(PyObject* self)
{
    QDataStream* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDataStream* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // readQVariant()
                // Begin code injection

                QVariant val;
                *(cppSelf) >> val;
                pyResult = Shiboken::Converter<QVariant >::toPython(val);

                // End of code injection


            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QDataStreamFunc_readRawData(PyObject* self, PyObject* arg)
{
    QDataStream* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDataStream* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: readRawData(char*,int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // readRawData(char*,int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QDataStreamFunc_readRawData_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // readRawData(char*,int)
                // Begin code injection

                QByteArray data;
                data.resize(cppArg0);
                int result = cppSelf->readRawData(data.data(), data.size());
                if (result == -1) {
                    Py_INCREF(Py_None);
                    pyResult = Py_None;
                } else {
                    pyResult = PyString_FromStringAndSize(data.data(), result);
                }

                // End of code injection


            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QDataStreamFunc_readRawData_TypeError:
        const char* overloads[] = {"str, int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QDataStream.readRawData", overloads);
        return 0;
}

static PyObject* Sbk_QDataStreamFunc_readString(PyObject* self)
{
    QDataStream* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDataStream* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // readString()


                // Begin code injection

                // TEMPLATE - stream_read_method - START
                QString _cpp_result;
                (*cppSelf) >> _cpp_result;
                pyResult = Shiboken::Converter<QString >::toPython(_cpp_result);
                // TEMPLATE - stream_read_method - END

                // End of code injection
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QDataStreamFunc_readUInt16(PyObject* self)
{
    QDataStream* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDataStream* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // readUInt16()


                // Begin code injection

                // TEMPLATE - stream_read_method - START
                quint16 _cpp_result;
                (*cppSelf) >> _cpp_result;
                pyResult = Shiboken::Converter<quint16 >::toPython(_cpp_result);
                // TEMPLATE - stream_read_method - END

                // End of code injection
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QDataStreamFunc_readUInt32(PyObject* self)
{
    QDataStream* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDataStream* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // readUInt32()


                // Begin code injection

                // TEMPLATE - stream_read_method - START
                quint32 _cpp_result;
                (*cppSelf) >> _cpp_result;
                pyResult = Shiboken::Converter<quint32 >::toPython(_cpp_result);
                // TEMPLATE - stream_read_method - END

                // End of code injection
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QDataStreamFunc_readUInt64(PyObject* self)
{
    QDataStream* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDataStream* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // readUInt64()


                // Begin code injection

                // TEMPLATE - stream_read_method - START
                quint64 _cpp_result;
                (*cppSelf) >> _cpp_result;
                pyResult = Shiboken::Converter<quint64 >::toPython(_cpp_result);
                // TEMPLATE - stream_read_method - END

                // End of code injection
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QDataStreamFunc_readUInt8(PyObject* self)
{
    QDataStream* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDataStream* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // readUInt8()


                // Begin code injection

                // TEMPLATE - stream_read_method - START
                quint8 _cpp_result;
                (*cppSelf) >> _cpp_result;
                pyResult = Shiboken::Converter<quint8 >::toPython(_cpp_result);
                // TEMPLATE - stream_read_method - END

                // End of code injection
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QDataStreamFunc_resetStatus(PyObject* self)
{
    QDataStream* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDataStream* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // resetStatus()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->resetStatus();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QDataStreamFunc_setByteOrder(PyObject* self, PyObject* arg)
{
    QDataStream* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDataStream* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setByteOrder(QDataStream::ByteOrder)
    if (Shiboken::Converter< ::QDataStream::ByteOrder >::isConvertible(arg)) {
        overloadId = 0; // setByteOrder(QDataStream::ByteOrder)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QDataStreamFunc_setByteOrder_TypeError;

    // Call function/method
    {
        {
            QDataStream::ByteOrder cppArg0 = Shiboken::Converter<QDataStream::ByteOrder >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setByteOrder(QDataStream::ByteOrder)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setByteOrder(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QDataStreamFunc_setByteOrder_TypeError:
        const char* overloads[] = {"PySide.QtCore.QDataStream.ByteOrder", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QDataStream.setByteOrder", overloads);
        return 0;
}

static PyObject* Sbk_QDataStreamFunc_setDevice(PyObject* self, PyObject* arg)
{
    QDataStream* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDataStream* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setDevice(QIODevice*)
    if (Shiboken::Converter< ::QIODevice * >::isConvertible(arg)) {
        overloadId = 0; // setDevice(QIODevice*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QDataStreamFunc_setDevice_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QIODevice * cppArg0 = Shiboken::Converter<QIODevice * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setDevice(QIODevice*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setDevice(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                Shiboken::Object::setParent(self, arg);
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QDataStreamFunc_setDevice_TypeError:
        const char* overloads[] = {"PySide.QtCore.QIODevice", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QDataStream.setDevice", overloads);
        return 0;
}

static PyObject* Sbk_QDataStreamFunc_setFloatingPointPrecision(PyObject* self, PyObject* arg)
{
    QDataStream* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDataStream* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setFloatingPointPrecision(QDataStream::FloatingPointPrecision)
    if (Shiboken::Converter< ::QDataStream::FloatingPointPrecision >::isConvertible(arg)) {
        overloadId = 0; // setFloatingPointPrecision(QDataStream::FloatingPointPrecision)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QDataStreamFunc_setFloatingPointPrecision_TypeError;

    // Call function/method
    {
        {
            QDataStream::FloatingPointPrecision cppArg0 = Shiboken::Converter<QDataStream::FloatingPointPrecision >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setFloatingPointPrecision(QDataStream::FloatingPointPrecision)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setFloatingPointPrecision(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QDataStreamFunc_setFloatingPointPrecision_TypeError:
        const char* overloads[] = {"PySide.QtCore.QDataStream.FloatingPointPrecision", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QDataStream.setFloatingPointPrecision", overloads);
        return 0;
}

static PyObject* Sbk_QDataStreamFunc_setStatus(PyObject* self, PyObject* arg)
{
    QDataStream* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDataStream* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setStatus(QDataStream::Status)
    if (Shiboken::Converter< ::QDataStream::Status >::isConvertible(arg)) {
        overloadId = 0; // setStatus(QDataStream::Status)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QDataStreamFunc_setStatus_TypeError;

    // Call function/method
    {
        {
            QDataStream::Status cppArg0 = Shiboken::Converter<QDataStream::Status >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setStatus(QDataStream::Status)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setStatus(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QDataStreamFunc_setStatus_TypeError:
        const char* overloads[] = {"PySide.QtCore.QDataStream.Status", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QDataStream.setStatus", overloads);
        return 0;
}

static PyObject* Sbk_QDataStreamFunc_setVersion(PyObject* self, PyObject* arg)
{
    QDataStream* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDataStream* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setVersion(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setVersion(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QDataStreamFunc_setVersion_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setVersion(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setVersion(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QDataStreamFunc_setVersion_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QDataStream.setVersion", overloads);
        return 0;
}

static PyObject* Sbk_QDataStreamFunc_skipRawData(PyObject* self, PyObject* arg)
{
    QDataStream* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDataStream* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: skipRawData(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // skipRawData(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QDataStreamFunc_skipRawData_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // skipRawData(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = cppSelf->skipRawData(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QDataStreamFunc_skipRawData_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QDataStream.skipRawData", overloads);
        return 0;
}

static PyObject* Sbk_QDataStreamFunc_status(PyObject* self)
{
    QDataStream* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDataStream* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // status()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QDataStream::Status cppResult = const_cast<const QDataStream*>(cppSelf)->status();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QDataStream::Status >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QDataStreamFunc_unsetDevice(PyObject* self)
{
    QDataStream* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDataStream* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // unsetDevice()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->unsetDevice();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QDataStreamFunc_version(PyObject* self)
{
    QDataStream* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDataStream* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // version()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QDataStream*>(cppSelf)->version();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QDataStreamFunc_writeBool(PyObject* self, PyObject* arg)
{
    QDataStream* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDataStream* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: writeBool(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // writeBool(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QDataStreamFunc_writeBool_TypeError;

    // Call function/method
    {
        {
            bool cppArg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // writeBool(bool)


                // Begin code injection

                // TEMPLATE - stream_write_method - START
                (*cppSelf) << cppArg0;
                // TEMPLATE - stream_write_method - END

                // End of code injection
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QDataStreamFunc_writeBool_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QDataStream.writeBool", overloads);
        return 0;
}

static PyObject* Sbk_QDataStreamFunc_writeDouble(PyObject* self, PyObject* arg)
{
    QDataStream* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDataStream* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: writeDouble(qreal)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // writeDouble(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QDataStreamFunc_writeDouble_TypeError;

    // Call function/method
    {
        {
            qreal cppArg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // writeDouble(qreal)


                // Begin code injection

                // TEMPLATE - stream_write_method - START
                (*cppSelf) << cppArg0;
                // TEMPLATE - stream_write_method - END

                // End of code injection
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QDataStreamFunc_writeDouble_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QDataStream.writeDouble", overloads);
        return 0;
}

static PyObject* Sbk_QDataStreamFunc_writeFloat(PyObject* self, PyObject* arg)
{
    QDataStream* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDataStream* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: writeFloat(float)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // writeFloat(float)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QDataStreamFunc_writeFloat_TypeError;

    // Call function/method
    {
        {
            float cppArg0 = Shiboken::Converter<float >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // writeFloat(float)


                // Begin code injection

                // TEMPLATE - stream_write_method - START
                (*cppSelf) << cppArg0;
                // TEMPLATE - stream_write_method - END

                // End of code injection
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QDataStreamFunc_writeFloat_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QDataStream.writeFloat", overloads);
        return 0;
}

static PyObject* Sbk_QDataStreamFunc_writeInt16(PyObject* self, PyObject* arg)
{
    QDataStream* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDataStream* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: writeInt16(qint16)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // writeInt16(qint16)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QDataStreamFunc_writeInt16_TypeError;

    // Call function/method
    {
        {
            qint16 cppArg0 = Shiboken::Converter<qint16 >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // writeInt16(qint16)


                // Begin code injection

                // TEMPLATE - stream_write_method - START
                (*cppSelf) << cppArg0;
                // TEMPLATE - stream_write_method - END

                // End of code injection
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QDataStreamFunc_writeInt16_TypeError:
        const char* overloads[] = {"short", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QDataStream.writeInt16", overloads);
        return 0;
}

static PyObject* Sbk_QDataStreamFunc_writeInt32(PyObject* self, PyObject* arg)
{
    QDataStream* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDataStream* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: writeInt32(qint32)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // writeInt32(qint32)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QDataStreamFunc_writeInt32_TypeError;

    // Call function/method
    {
        {
            qint32 cppArg0 = Shiboken::Converter<qint32 >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // writeInt32(qint32)


                // Begin code injection

                // TEMPLATE - stream_write_method - START
                (*cppSelf) << cppArg0;
                // TEMPLATE - stream_write_method - END

                // End of code injection
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QDataStreamFunc_writeInt32_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QDataStream.writeInt32", overloads);
        return 0;
}

static PyObject* Sbk_QDataStreamFunc_writeInt64(PyObject* self, PyObject* arg)
{
    QDataStream* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDataStream* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: writeInt64(qint64)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // writeInt64(qint64)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QDataStreamFunc_writeInt64_TypeError;

    // Call function/method
    {
        {
            qint64 cppArg0 = Shiboken::Converter<qint64 >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // writeInt64(qint64)


                // Begin code injection

                // TEMPLATE - stream_write_method - START
                (*cppSelf) << cppArg0;
                // TEMPLATE - stream_write_method - END

                // End of code injection
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QDataStreamFunc_writeInt64_TypeError:
        const char* overloads[] = {"long long", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QDataStream.writeInt64", overloads);
        return 0;
}

static PyObject* Sbk_QDataStreamFunc_writeInt8(PyObject* self, PyObject* arg)
{
    QDataStream* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDataStream* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: writeInt8(qint8)
    if (Shiboken::Converter< signed char >::isConvertible(arg)) {
        overloadId = 0; // writeInt8(qint8)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QDataStreamFunc_writeInt8_TypeError;

    // Call function/method
    {
        {
            qint8 cppArg0 = Shiboken::Converter<qint8 >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // writeInt8(qint8)


                // Begin code injection

                // TEMPLATE - stream_write_method - START
                (*cppSelf) << cppArg0;
                // TEMPLATE - stream_write_method - END

                // End of code injection
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QDataStreamFunc_writeInt8_TypeError:
        const char* overloads[] = {"char", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QDataStream.writeInt8", overloads);
        return 0;
}

static PyObject* Sbk_QDataStreamFunc_writeQChar(PyObject* self, PyObject* arg)
{
    QDataStream* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDataStream* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: writeQChar(QChar)
    if (Shiboken::Converter< QChar >::isConvertible(arg)) {
        overloadId = 0; // writeQChar(QChar)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QDataStreamFunc_writeQChar_TypeError;

    // Call function/method
    {
        {
            QChar cppArg0 = Shiboken::Converter<QChar >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // writeQChar(QChar)
                // Begin code injection

                *(cppSelf) << cppArg0;

                // End of code injection


            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QDataStreamFunc_writeQChar_TypeError:
        const char* overloads[] = {"QChar", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QDataStream.writeQChar", overloads);
        return 0;
}

static PyObject* Sbk_QDataStreamFunc_writeQString(PyObject* self, PyObject* arg)
{
    QDataStream* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDataStream* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: writeQString(QString)
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // writeQString(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QDataStreamFunc_writeQString_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // writeQString(QString)
                // Begin code injection

                *(cppSelf) << cppArg0;

                // End of code injection


            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QDataStreamFunc_writeQString_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QDataStream.writeQString", overloads);
        return 0;
}

static PyObject* Sbk_QDataStreamFunc_writeQStringList(PyObject* self, PyObject* arg)
{
    QDataStream* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDataStream* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: writeQStringList(QStringList)
    if (Shiboken::Converter< ::QStringList >::isConvertible(arg)) {
        overloadId = 0; // writeQStringList(QStringList)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QDataStreamFunc_writeQStringList_TypeError;

    // Call function/method
    {
        {
            QStringList cppArg0 = Shiboken::Converter<QStringList >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // writeQStringList(QStringList)
                // Begin code injection

                *(cppSelf) << cppArg0;

                // End of code injection


            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QDataStreamFunc_writeQStringList_TypeError:
        const char* overloads[] = {"list", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QDataStream.writeQStringList", overloads);
        return 0;
}

static PyObject* Sbk_QDataStreamFunc_writeQVariant(PyObject* self, PyObject* arg)
{
    QDataStream* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDataStream* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: writeQVariant(QVariant)
    if (Shiboken::Converter< QVariant >::isConvertible(arg)) {
        overloadId = 0; // writeQVariant(QVariant)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QDataStreamFunc_writeQVariant_TypeError;

    // Call function/method
    {
        {
            QVariant cppArg0 = Shiboken::Converter<QVariant >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // writeQVariant(QVariant)
                // Begin code injection

                *(cppSelf) << cppArg0;

                // End of code injection


            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QDataStreamFunc_writeQVariant_TypeError:
        const char* overloads[] = {"QVariant", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QDataStream.writeQVariant", overloads);
        return 0;
}

static PyObject* Sbk_QDataStreamFunc_writeRawData(PyObject* self, PyObject* arg)
{
    QDataStream* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDataStream* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: writeRawData(const char*,int)
    if (Shiboken::Converter< const char * >::isConvertible(arg)) {
        overloadId = 0; // writeRawData(const char*,int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QDataStreamFunc_writeRawData_TypeError;

    // Call function/method
    {
        {
            const char * cppArg0 = Shiboken::Converter<const char * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // writeRawData(const char*,int)
                // Begin code injection

                int r = cppSelf->writeRawData(cppArg0, PyString_GET_SIZE(arg));
                pyResult = Shiboken::Converter<int >::toPython(r);

                // End of code injection


            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QDataStreamFunc_writeRawData_TypeError:
        const char* overloads[] = {"str, int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QDataStream.writeRawData", overloads);
        return 0;
}

static PyObject* Sbk_QDataStreamFunc_writeString(PyObject* self, PyObject* arg)
{
    QDataStream* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDataStream* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: writeString(QString)
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // writeString(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QDataStreamFunc_writeString_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // writeString(QString)


                // Begin code injection

                // TEMPLATE - stream_write_method - START
                (*cppSelf) << cppArg0;
                // TEMPLATE - stream_write_method - END

                // End of code injection
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QDataStreamFunc_writeString_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QDataStream.writeString", overloads);
        return 0;
}

static PyObject* Sbk_QDataStreamFunc_writeUInt16(PyObject* self, PyObject* arg)
{
    QDataStream* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDataStream* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: writeUInt16(quint16)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // writeUInt16(quint16)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QDataStreamFunc_writeUInt16_TypeError;

    // Call function/method
    {
        {
            quint16 cppArg0 = Shiboken::Converter<quint16 >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // writeUInt16(quint16)


                // Begin code injection

                // TEMPLATE - stream_write_method - START
                (*cppSelf) << cppArg0;
                // TEMPLATE - stream_write_method - END

                // End of code injection
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QDataStreamFunc_writeUInt16_TypeError:
        const char* overloads[] = {"unsigned short", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QDataStream.writeUInt16", overloads);
        return 0;
}

static PyObject* Sbk_QDataStreamFunc_writeUInt32(PyObject* self, PyObject* arg)
{
    QDataStream* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDataStream* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: writeUInt32(quint32)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // writeUInt32(quint32)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QDataStreamFunc_writeUInt32_TypeError;

    // Call function/method
    {
        {
            quint32 cppArg0 = Shiboken::Converter<quint32 >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // writeUInt32(quint32)


                // Begin code injection

                // TEMPLATE - stream_write_method - START
                (*cppSelf) << cppArg0;
                // TEMPLATE - stream_write_method - END

                // End of code injection
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QDataStreamFunc_writeUInt32_TypeError:
        const char* overloads[] = {"unsigned int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QDataStream.writeUInt32", overloads);
        return 0;
}

static PyObject* Sbk_QDataStreamFunc_writeUInt64(PyObject* self, PyObject* arg)
{
    QDataStream* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDataStream* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: writeUInt64(quint64)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // writeUInt64(quint64)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QDataStreamFunc_writeUInt64_TypeError;

    // Call function/method
    {
        {
            quint64 cppArg0 = Shiboken::Converter<quint64 >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // writeUInt64(quint64)


                // Begin code injection

                // TEMPLATE - stream_write_method - START
                (*cppSelf) << cppArg0;
                // TEMPLATE - stream_write_method - END

                // End of code injection
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QDataStreamFunc_writeUInt64_TypeError:
        const char* overloads[] = {"unsigned long long", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QDataStream.writeUInt64", overloads);
        return 0;
}

static PyObject* Sbk_QDataStreamFunc_writeUInt8(PyObject* self, PyObject* arg)
{
    QDataStream* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDataStream* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: writeUInt8(quint8)
    if (Shiboken::Converter< unsigned char >::isConvertible(arg)) {
        overloadId = 0; // writeUInt8(quint8)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QDataStreamFunc_writeUInt8_TypeError;

    // Call function/method
    {
        {
            quint8 cppArg0 = Shiboken::Converter<quint8 >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // writeUInt8(quint8)


                // Begin code injection

                // TEMPLATE - stream_write_method - START
                (*cppSelf) << cppArg0;
                // TEMPLATE - stream_write_method - END

                // End of code injection
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QDataStreamFunc_writeUInt8_TypeError:
        const char* overloads[] = {"unsigned char", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QDataStream.writeUInt8", overloads);
        return 0;
}

static PyMethodDef Sbk_QDataStream_methods[] = {
    {"atEnd", (PyCFunction)Sbk_QDataStreamFunc_atEnd, METH_NOARGS},
    {"byteOrder", (PyCFunction)Sbk_QDataStreamFunc_byteOrder, METH_NOARGS},
    {"device", (PyCFunction)Sbk_QDataStreamFunc_device, METH_NOARGS},
    {"floatingPointPrecision", (PyCFunction)Sbk_QDataStreamFunc_floatingPointPrecision, METH_NOARGS},
    {"readBool", (PyCFunction)Sbk_QDataStreamFunc_readBool, METH_NOARGS},
    {"readDouble", (PyCFunction)Sbk_QDataStreamFunc_readDouble, METH_NOARGS},
    {"readFloat", (PyCFunction)Sbk_QDataStreamFunc_readFloat, METH_NOARGS},
    {"readInt16", (PyCFunction)Sbk_QDataStreamFunc_readInt16, METH_NOARGS},
    {"readInt32", (PyCFunction)Sbk_QDataStreamFunc_readInt32, METH_NOARGS},
    {"readInt64", (PyCFunction)Sbk_QDataStreamFunc_readInt64, METH_NOARGS},
    {"readInt8", (PyCFunction)Sbk_QDataStreamFunc_readInt8, METH_NOARGS},
    {"readQChar", (PyCFunction)Sbk_QDataStreamFunc_readQChar, METH_NOARGS},
    {"readQString", (PyCFunction)Sbk_QDataStreamFunc_readQString, METH_NOARGS},
    {"readQStringList", (PyCFunction)Sbk_QDataStreamFunc_readQStringList, METH_NOARGS},
    {"readQVariant", (PyCFunction)Sbk_QDataStreamFunc_readQVariant, METH_NOARGS},
    {"readRawData", (PyCFunction)Sbk_QDataStreamFunc_readRawData, METH_O},
    {"readString", (PyCFunction)Sbk_QDataStreamFunc_readString, METH_NOARGS},
    {"readUInt16", (PyCFunction)Sbk_QDataStreamFunc_readUInt16, METH_NOARGS},
    {"readUInt32", (PyCFunction)Sbk_QDataStreamFunc_readUInt32, METH_NOARGS},
    {"readUInt64", (PyCFunction)Sbk_QDataStreamFunc_readUInt64, METH_NOARGS},
    {"readUInt8", (PyCFunction)Sbk_QDataStreamFunc_readUInt8, METH_NOARGS},
    {"resetStatus", (PyCFunction)Sbk_QDataStreamFunc_resetStatus, METH_NOARGS},
    {"setByteOrder", (PyCFunction)Sbk_QDataStreamFunc_setByteOrder, METH_O},
    {"setDevice", (PyCFunction)Sbk_QDataStreamFunc_setDevice, METH_O},
    {"setFloatingPointPrecision", (PyCFunction)Sbk_QDataStreamFunc_setFloatingPointPrecision, METH_O},
    {"setStatus", (PyCFunction)Sbk_QDataStreamFunc_setStatus, METH_O},
    {"setVersion", (PyCFunction)Sbk_QDataStreamFunc_setVersion, METH_O},
    {"skipRawData", (PyCFunction)Sbk_QDataStreamFunc_skipRawData, METH_O},
    {"status", (PyCFunction)Sbk_QDataStreamFunc_status, METH_NOARGS},
    {"unsetDevice", (PyCFunction)Sbk_QDataStreamFunc_unsetDevice, METH_NOARGS},
    {"version", (PyCFunction)Sbk_QDataStreamFunc_version, METH_NOARGS},
    {"writeBool", (PyCFunction)Sbk_QDataStreamFunc_writeBool, METH_O},
    {"writeDouble", (PyCFunction)Sbk_QDataStreamFunc_writeDouble, METH_O},
    {"writeFloat", (PyCFunction)Sbk_QDataStreamFunc_writeFloat, METH_O},
    {"writeInt16", (PyCFunction)Sbk_QDataStreamFunc_writeInt16, METH_O},
    {"writeInt32", (PyCFunction)Sbk_QDataStreamFunc_writeInt32, METH_O},
    {"writeInt64", (PyCFunction)Sbk_QDataStreamFunc_writeInt64, METH_O},
    {"writeInt8", (PyCFunction)Sbk_QDataStreamFunc_writeInt8, METH_O},
    {"writeQChar", (PyCFunction)Sbk_QDataStreamFunc_writeQChar, METH_O},
    {"writeQString", (PyCFunction)Sbk_QDataStreamFunc_writeQString, METH_O},
    {"writeQStringList", (PyCFunction)Sbk_QDataStreamFunc_writeQStringList, METH_O},
    {"writeQVariant", (PyCFunction)Sbk_QDataStreamFunc_writeQVariant, METH_O},
    {"writeRawData", (PyCFunction)Sbk_QDataStreamFunc_writeRawData, METH_O},
    {"writeString", (PyCFunction)Sbk_QDataStreamFunc_writeString, METH_O},
    {"writeUInt16", (PyCFunction)Sbk_QDataStreamFunc_writeUInt16, METH_O},
    {"writeUInt32", (PyCFunction)Sbk_QDataStreamFunc_writeUInt32, METH_O},
    {"writeUInt64", (PyCFunction)Sbk_QDataStreamFunc_writeUInt64, METH_O},
    {"writeUInt8", (PyCFunction)Sbk_QDataStreamFunc_writeUInt8, METH_O},

    {0} // Sentinel
};

static PyObject* Sbk_QDataStreamFunc___lshift__(PyObject* self, PyObject* arg)
{
    QDataStream* cppSelf = 0;
    bool isReverse = Shiboken::Converter< ::QDataStream* >::checkType(arg) && !Shiboken::Converter< ::QDataStream* >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDataStream* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && Shiboken::Object::checkType(arg)
        && !PyObject_TypeCheck(arg, self->ob_type)
        && PyObject_HasAttrString(arg, const_cast<char*>("__rlshift__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(arg, const_cast<char*>("__rlshift__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator<<(QDataStream&,QBitArray)
    // 1: operator<<(QDataStream&,QByteArray)
    // 2: operator<<(QDataStream&,QDate)
    // 3: operator<<(QDataStream&,QDateTime)
    // 4: operator<<(QDataStream&,QEasingCurve)
    // 5: operator<<(QDataStream&,QLine)
    // 6: operator<<(QDataStream&,QLineF)
    // 7: operator<<(QDataStream&,QLocale)
    // 8: operator<<(QDataStream&,QPoint)
    // 9: operator<<(QDataStream&,QPointF)
    // 10: operator<<(QDataStream&,QRect)
    // 11: operator<<(QDataStream&,QRectF)
    // 12: operator<<(QDataStream&,QRegExp)
    // 13: operator<<(QDataStream&,QSize)
    // 14: operator<<(QDataStream&,QSizeF)
    // 15: operator<<(QDataStream&,QTime)
    // 16: operator<<(QDataStream&,QUrl)
    // 17: operator<<(QDataStream&,QUuid)
    if (!isReverse && Shiboken::Converter< ::QUuid >::isConvertible(arg)) {
        overloadId = 17; // operator<<(QDataStream&,QUuid)
    } else if (!isReverse && Shiboken::Converter< ::QUrl >::isConvertible(arg)) {
        overloadId = 16; // operator<<(QDataStream&,QUrl)
    } else if (!isReverse && Shiboken::Converter< ::QTime >::isConvertible(arg)) {
        overloadId = 15; // operator<<(QDataStream&,QTime)
    } else if (!isReverse && Shiboken::Converter< ::QSize >::isConvertible(arg)) {
        overloadId = 13; // operator<<(QDataStream&,QSize)
    } else if (!isReverse && Shiboken::Converter< ::QSizeF >::isConvertible(arg)) {
        overloadId = 14; // operator<<(QDataStream&,QSizeF)
    } else if (!isReverse && Shiboken::Converter< ::QRegExp >::isConvertible(arg)) {
        overloadId = 12; // operator<<(QDataStream&,QRegExp)
    } else if (!isReverse && Shiboken::Converter< ::QRect >::isConvertible(arg)) {
        overloadId = 10; // operator<<(QDataStream&,QRect)
    } else if (!isReverse && Shiboken::Converter< ::QRectF >::isConvertible(arg)) {
        overloadId = 11; // operator<<(QDataStream&,QRectF)
    } else if (!isReverse && Shiboken::Converter< ::QPoint >::isConvertible(arg)) {
        overloadId = 8; // operator<<(QDataStream&,QPoint)
    } else if (!isReverse && Shiboken::Converter< ::QPointF >::isConvertible(arg)) {
        overloadId = 9; // operator<<(QDataStream&,QPointF)
    } else if (!isReverse && Shiboken::Converter< ::QLocale >::isConvertible(arg)) {
        overloadId = 7; // operator<<(QDataStream&,QLocale)
    } else if (!isReverse && Shiboken::Converter< ::QLine >::isConvertible(arg)) {
        overloadId = 5; // operator<<(QDataStream&,QLine)
    } else if (!isReverse && Shiboken::Converter< ::QLineF >::isConvertible(arg)) {
        overloadId = 6; // operator<<(QDataStream&,QLineF)
    } else if (!isReverse && Shiboken::Converter< ::QEasingCurve >::isConvertible(arg)) {
        overloadId = 4; // operator<<(QDataStream&,QEasingCurve)
    } else if (!isReverse && Shiboken::Converter< ::QDateTime >::isConvertible(arg)) {
        overloadId = 3; // operator<<(QDataStream&,QDateTime)
    } else if (!isReverse && Shiboken::Converter< ::QDate >::isConvertible(arg)) {
        overloadId = 2; // operator<<(QDataStream&,QDate)
    } else if (!isReverse && Shiboken::Converter< ::QByteArray >::isConvertible(arg)) {
        overloadId = 1; // operator<<(QDataStream&,QByteArray)
    } else if (!isReverse && Shiboken::Converter< ::QBitArray >::isConvertible(arg)) {
        overloadId = 0; // operator<<(QDataStream&,QBitArray)
    }

    if (isReverse && overloadId == -1) {
        PyErr_SetString(PyExc_NotImplementedError, "reverse operator not implemented.");
        return 0;
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QDataStreamFunc___lshift___TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // operator<<(QDataStream&,QBitArray)
            {
                if (!Shiboken::Object::isValid(arg))
                    return 0;
                QBitArray cppArg0 = Shiboken::Converter<QBitArray >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // operator<<(QDataStream&,QBitArray)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QDataStream & cppResult = (*cppSelf) << (cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QDataStream & >::toPython(cppResult);
                    Shiboken::Object::setParent(self, pyResult);
                }
                break;
            }
            case 1: // operator<<(QDataStream&,QByteArray)
            {
                if (!Shiboken::Object::isValid(arg))
                    return 0;
                QByteArray cppArg0 = Shiboken::Converter<QByteArray >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // operator<<(QDataStream&,QByteArray)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QDataStream & cppResult = (*cppSelf) << (cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QDataStream & >::toPython(cppResult);
                    Shiboken::Object::setParent(self, pyResult);
                }
                break;
            }
            case 2: // operator<<(QDataStream&,QDate)
            {
                if (!Shiboken::Object::isValid(arg))
                    return 0;
                QDate cppArg0 = Shiboken::Converter<QDate >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // operator<<(QDataStream&,QDate)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QDataStream & cppResult = (*cppSelf) << (cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QDataStream & >::toPython(cppResult);
                    Shiboken::Object::setParent(self, pyResult);
                }
                break;
            }
            case 3: // operator<<(QDataStream&,QDateTime)
            {
                if (!Shiboken::Object::isValid(arg))
                    return 0;
                QDateTime cppArg0 = Shiboken::Converter<QDateTime >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // operator<<(QDataStream&,QDateTime)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QDataStream & cppResult = (*cppSelf) << (cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QDataStream & >::toPython(cppResult);
                    Shiboken::Object::setParent(self, pyResult);
                }
                break;
            }
            case 4: // operator<<(QDataStream&,QEasingCurve)
            {
                if (!Shiboken::Object::isValid(arg))
                    return 0;
                QEasingCurve cppArg0 = Shiboken::Converter<QEasingCurve >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // operator<<(QDataStream&,QEasingCurve)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QDataStream & cppResult = (*cppSelf) << (cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QDataStream & >::toPython(cppResult);
                    Shiboken::Object::setParent(self, pyResult);
                }
                break;
            }
            case 5: // operator<<(QDataStream&,QLine)
            {
                if (!Shiboken::Object::isValid(arg))
                    return 0;
                QLine cppArg0 = Shiboken::Converter<QLine >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // operator<<(QDataStream&,QLine)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QDataStream & cppResult = (*cppSelf) << (cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QDataStream & >::toPython(cppResult);
                    Shiboken::Object::setParent(self, pyResult);
                }
                break;
            }
            case 6: // operator<<(QDataStream&,QLineF)
            {
                if (!Shiboken::Object::isValid(arg))
                    return 0;
                QLineF cppArg0 = Shiboken::Converter<QLineF >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // operator<<(QDataStream&,QLineF)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QDataStream & cppResult = (*cppSelf) << (cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QDataStream & >::toPython(cppResult);
                    Shiboken::Object::setParent(self, pyResult);
                }
                break;
            }
            case 7: // operator<<(QDataStream&,QLocale)
            {
                if (!Shiboken::Object::isValid(arg))
                    return 0;
                QLocale cppArg0 = Shiboken::Converter<QLocale >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // operator<<(QDataStream&,QLocale)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QDataStream & cppResult = (*cppSelf) << (cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QDataStream & >::toPython(cppResult);
                    Shiboken::Object::setParent(self, pyResult);
                }
                break;
            }
            case 8: // operator<<(QDataStream&,QPoint)
            {
                if (!Shiboken::Object::isValid(arg))
                    return 0;
                QPoint cppArg0 = Shiboken::Converter<QPoint >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // operator<<(QDataStream&,QPoint)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QDataStream & cppResult = (*cppSelf) << (cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QDataStream & >::toPython(cppResult);
                    Shiboken::Object::setParent(self, pyResult);
                }
                break;
            }
            case 9: // operator<<(QDataStream&,QPointF)
            {
                if (!Shiboken::Object::isValid(arg))
                    return 0;
                QPointF cppArg0 = Shiboken::Converter<QPointF >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // operator<<(QDataStream&,QPointF)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QDataStream & cppResult = (*cppSelf) << (cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QDataStream & >::toPython(cppResult);
                    Shiboken::Object::setParent(self, pyResult);
                }
                break;
            }
            case 10: // operator<<(QDataStream&,QRect)
            {
                if (!Shiboken::Object::isValid(arg))
                    return 0;
                QRect cppArg0 = Shiboken::Converter<QRect >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // operator<<(QDataStream&,QRect)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QDataStream & cppResult = (*cppSelf) << (cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QDataStream & >::toPython(cppResult);
                    Shiboken::Object::setParent(self, pyResult);
                }
                break;
            }
            case 11: // operator<<(QDataStream&,QRectF)
            {
                if (!Shiboken::Object::isValid(arg))
                    return 0;
                QRectF cppArg0 = Shiboken::Converter<QRectF >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // operator<<(QDataStream&,QRectF)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QDataStream & cppResult = (*cppSelf) << (cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QDataStream & >::toPython(cppResult);
                    Shiboken::Object::setParent(self, pyResult);
                }
                break;
            }
            case 12: // operator<<(QDataStream&,QRegExp)
            {
                if (!Shiboken::Object::isValid(arg))
                    return 0;
                QRegExp cppArg0 = Shiboken::Converter<QRegExp >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // operator<<(QDataStream&,QRegExp)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QDataStream & cppResult = (*cppSelf) << (cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QDataStream & >::toPython(cppResult);
                    Shiboken::Object::setParent(self, pyResult);
                }
                break;
            }
            case 13: // operator<<(QDataStream&,QSize)
            {
                if (!Shiboken::Object::isValid(arg))
                    return 0;
                QSize cppArg0 = Shiboken::Converter<QSize >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // operator<<(QDataStream&,QSize)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QDataStream & cppResult = (*cppSelf) << (cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QDataStream & >::toPython(cppResult);
                    Shiboken::Object::setParent(self, pyResult);
                }
                break;
            }
            case 14: // operator<<(QDataStream&,QSizeF)
            {
                if (!Shiboken::Object::isValid(arg))
                    return 0;
                QSizeF cppArg0 = Shiboken::Converter<QSizeF >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // operator<<(QDataStream&,QSizeF)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QDataStream & cppResult = (*cppSelf) << (cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QDataStream & >::toPython(cppResult);
                    Shiboken::Object::setParent(self, pyResult);
                }
                break;
            }
            case 15: // operator<<(QDataStream&,QTime)
            {
                if (!Shiboken::Object::isValid(arg))
                    return 0;
                QTime cppArg0 = Shiboken::Converter<QTime >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // operator<<(QDataStream&,QTime)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QDataStream & cppResult = (*cppSelf) << (cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QDataStream & >::toPython(cppResult);
                    Shiboken::Object::setParent(self, pyResult);
                }
                break;
            }
            case 16: // operator<<(QDataStream&,QUrl)
            {
                if (!Shiboken::Object::isValid(arg))
                    return 0;
                QUrl cppArg0 = Shiboken::Converter<QUrl >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // operator<<(QDataStream&,QUrl)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QDataStream & cppResult = (*cppSelf) << (cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QDataStream & >::toPython(cppResult);
                    Shiboken::Object::setParent(self, pyResult);
                }
                break;
            }
            case 17: // operator<<(QDataStream&,QUuid)
            {
                if (!Shiboken::Object::isValid(arg))
                    return 0;
                QUuid cppArg0 = Shiboken::Converter<QUuid >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // operator<<(QDataStream&,QUuid)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QDataStream & cppResult = (*cppSelf) << (cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QDataStream & >::toPython(cppResult);
                    Shiboken::Object::setParent(self, pyResult);
                }
                break;
            }
        }
    }


    } // End of "if (!pyResult)"


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QDataStreamFunc___lshift___TypeError:
        const char* overloads[] = {"PySide.QtCore.QBitArray", "PySide.QtCore.QByteArray", "PySide.QtCore.QDate", "PySide.QtCore.QDateTime", "PySide.QtCore.QEasingCurve", "PySide.QtCore.QLine", "PySide.QtCore.QLineF", "PySide.QtCore.QLocale", "PySide.QtCore.QPoint", "PySide.QtCore.QPointF", "PySide.QtCore.QRect", "PySide.QtCore.QRectF", "PySide.QtCore.QRegExp", "PySide.QtCore.QSize", "PySide.QtCore.QSizeF", "PySide.QtCore.QTime", "PySide.QtCore.QUrl", "PySide.QtCore.QUuid", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QDataStream.__lshift__", overloads);
        return 0;
}

static PyObject* Sbk_QDataStreamFunc___rshift__(PyObject* self, PyObject* arg)
{
    QDataStream* cppSelf = 0;
    bool isReverse = Shiboken::Converter< ::QDataStream* >::checkType(arg) && !Shiboken::Converter< ::QDataStream* >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDataStream* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && Shiboken::Object::checkType(arg)
        && !PyObject_TypeCheck(arg, self->ob_type)
        && PyObject_HasAttrString(arg, const_cast<char*>("__rrshift__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(arg, const_cast<char*>("__rrshift__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator>>(QDataStream&,QBitArray&)
    // 1: operator>>(QDataStream&,QByteArray&)
    // 2: operator>>(QDataStream&,QDate&)
    // 3: operator>>(QDataStream&,QDateTime&)
    // 4: operator>>(QDataStream&,QEasingCurve&)
    // 5: operator>>(QDataStream&,QLine&)
    // 6: operator>>(QDataStream&,QLineF&)
    // 7: operator>>(QDataStream&,QLocale&)
    // 8: operator>>(QDataStream&,QPoint&)
    // 9: operator>>(QDataStream&,QPointF&)
    // 10: operator>>(QDataStream&,QRect&)
    // 11: operator>>(QDataStream&,QRectF&)
    // 12: operator>>(QDataStream&,QRegExp&)
    // 13: operator>>(QDataStream&,QSize&)
    // 14: operator>>(QDataStream&,QSizeF&)
    // 15: operator>>(QDataStream&,QTime&)
    // 16: operator>>(QDataStream&,QUrl&)
    // 17: operator>>(QDataStream&,QUuid&)
    if (!isReverse && Shiboken::Converter< ::QUuid & >::isConvertible(arg)) {
        overloadId = 17; // operator>>(QDataStream&,QUuid&)
    } else if (!isReverse && Shiboken::Converter< ::QUrl & >::isConvertible(arg)) {
        overloadId = 16; // operator>>(QDataStream&,QUrl&)
    } else if (!isReverse && Shiboken::Converter< ::QTime & >::isConvertible(arg)) {
        overloadId = 15; // operator>>(QDataStream&,QTime&)
    } else if (!isReverse && Shiboken::Converter< ::QSize & >::isConvertible(arg)) {
        overloadId = 13; // operator>>(QDataStream&,QSize&)
    } else if (!isReverse && Shiboken::Converter< ::QSizeF & >::isConvertible(arg)) {
        overloadId = 14; // operator>>(QDataStream&,QSizeF&)
    } else if (!isReverse && Shiboken::Converter< ::QRegExp & >::isConvertible(arg)) {
        overloadId = 12; // operator>>(QDataStream&,QRegExp&)
    } else if (!isReverse && Shiboken::Converter< ::QRect & >::isConvertible(arg)) {
        overloadId = 10; // operator>>(QDataStream&,QRect&)
    } else if (!isReverse && Shiboken::Converter< ::QRectF & >::isConvertible(arg)) {
        overloadId = 11; // operator>>(QDataStream&,QRectF&)
    } else if (!isReverse && Shiboken::Converter< ::QPoint & >::isConvertible(arg)) {
        overloadId = 8; // operator>>(QDataStream&,QPoint&)
    } else if (!isReverse && Shiboken::Converter< ::QPointF & >::isConvertible(arg)) {
        overloadId = 9; // operator>>(QDataStream&,QPointF&)
    } else if (!isReverse && Shiboken::Converter< ::QLocale & >::isConvertible(arg)) {
        overloadId = 7; // operator>>(QDataStream&,QLocale&)
    } else if (!isReverse && Shiboken::Converter< ::QLine & >::isConvertible(arg)) {
        overloadId = 5; // operator>>(QDataStream&,QLine&)
    } else if (!isReverse && Shiboken::Converter< ::QLineF & >::isConvertible(arg)) {
        overloadId = 6; // operator>>(QDataStream&,QLineF&)
    } else if (!isReverse && Shiboken::Converter< ::QEasingCurve & >::isConvertible(arg)) {
        overloadId = 4; // operator>>(QDataStream&,QEasingCurve&)
    } else if (!isReverse && Shiboken::Converter< ::QDateTime & >::isConvertible(arg)) {
        overloadId = 3; // operator>>(QDataStream&,QDateTime&)
    } else if (!isReverse && Shiboken::Converter< ::QDate & >::isConvertible(arg)) {
        overloadId = 2; // operator>>(QDataStream&,QDate&)
    } else if (!isReverse && Shiboken::Converter< ::QByteArray & >::isConvertible(arg)) {
        overloadId = 1; // operator>>(QDataStream&,QByteArray&)
    } else if (!isReverse && Shiboken::Converter< ::QBitArray & >::isConvertible(arg)) {
        overloadId = 0; // operator>>(QDataStream&,QBitArray&)
    }

    if (isReverse && overloadId == -1) {
        PyErr_SetString(PyExc_NotImplementedError, "reverse operator not implemented.");
        return 0;
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QDataStreamFunc___rshift___TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // operator>>(QDataStream&,QBitArray&)
            {
                if (!Shiboken::Object::isValid(arg))
                    return 0;
                QBitArray & cppArg0 = Shiboken::Converter<QBitArray & >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // operator>>(QDataStream&,QBitArray&)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QDataStream & cppResult = (*cppSelf) >> (cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QDataStream & >::toPython(cppResult);
                    Shiboken::Object::setParent(self, pyResult);
                }
                break;
            }
            case 1: // operator>>(QDataStream&,QByteArray&)
            {
                if (!Shiboken::Object::isValid(arg))
                    return 0;
                QByteArray & cppArg0 = Shiboken::Converter<QByteArray & >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // operator>>(QDataStream&,QByteArray&)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QDataStream & cppResult = (*cppSelf) >> (cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QDataStream & >::toPython(cppResult);
                    Shiboken::Object::setParent(self, pyResult);
                }
                break;
            }
            case 2: // operator>>(QDataStream&,QDate&)
            {
                if (!Shiboken::Object::isValid(arg))
                    return 0;
                QDate & cppArg0 = Shiboken::Converter<QDate & >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // operator>>(QDataStream&,QDate&)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QDataStream & cppResult = (*cppSelf) >> (cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QDataStream & >::toPython(cppResult);
                    Shiboken::Object::setParent(self, pyResult);
                }
                break;
            }
            case 3: // operator>>(QDataStream&,QDateTime&)
            {
                if (!Shiboken::Object::isValid(arg))
                    return 0;
                QDateTime & cppArg0 = Shiboken::Converter<QDateTime & >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // operator>>(QDataStream&,QDateTime&)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QDataStream & cppResult = (*cppSelf) >> (cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QDataStream & >::toPython(cppResult);
                    Shiboken::Object::setParent(self, pyResult);
                }
                break;
            }
            case 4: // operator>>(QDataStream&,QEasingCurve&)
            {
                if (!Shiboken::Object::isValid(arg))
                    return 0;
                QEasingCurve & cppArg0 = Shiboken::Converter<QEasingCurve & >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // operator>>(QDataStream&,QEasingCurve&)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QDataStream & cppResult = (*cppSelf) >> (cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QDataStream & >::toPython(cppResult);
                    Shiboken::Object::setParent(self, pyResult);
                }
                break;
            }
            case 5: // operator>>(QDataStream&,QLine&)
            {
                if (!Shiboken::Object::isValid(arg))
                    return 0;
                QLine & cppArg0 = Shiboken::Converter<QLine & >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // operator>>(QDataStream&,QLine&)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QDataStream & cppResult = (*cppSelf) >> (cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QDataStream & >::toPython(cppResult);
                    Shiboken::Object::setParent(self, pyResult);
                }
                break;
            }
            case 6: // operator>>(QDataStream&,QLineF&)
            {
                if (!Shiboken::Object::isValid(arg))
                    return 0;
                QLineF & cppArg0 = Shiboken::Converter<QLineF & >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // operator>>(QDataStream&,QLineF&)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QDataStream & cppResult = (*cppSelf) >> (cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QDataStream & >::toPython(cppResult);
                    Shiboken::Object::setParent(self, pyResult);
                }
                break;
            }
            case 7: // operator>>(QDataStream&,QLocale&)
            {
                if (!Shiboken::Object::isValid(arg))
                    return 0;
                QLocale & cppArg0 = Shiboken::Converter<QLocale & >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // operator>>(QDataStream&,QLocale&)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QDataStream & cppResult = (*cppSelf) >> (cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QDataStream & >::toPython(cppResult);
                    Shiboken::Object::setParent(self, pyResult);
                }
                break;
            }
            case 8: // operator>>(QDataStream&,QPoint&)
            {
                if (!Shiboken::Object::isValid(arg))
                    return 0;
                QPoint & cppArg0 = Shiboken::Converter<QPoint & >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // operator>>(QDataStream&,QPoint&)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QDataStream & cppResult = (*cppSelf) >> (cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QDataStream & >::toPython(cppResult);
                    Shiboken::Object::setParent(self, pyResult);
                }
                break;
            }
            case 9: // operator>>(QDataStream&,QPointF&)
            {
                if (!Shiboken::Object::isValid(arg))
                    return 0;
                QPointF & cppArg0 = Shiboken::Converter<QPointF & >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // operator>>(QDataStream&,QPointF&)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QDataStream & cppResult = (*cppSelf) >> (cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QDataStream & >::toPython(cppResult);
                    Shiboken::Object::setParent(self, pyResult);
                }
                break;
            }
            case 10: // operator>>(QDataStream&,QRect&)
            {
                if (!Shiboken::Object::isValid(arg))
                    return 0;
                QRect & cppArg0 = Shiboken::Converter<QRect & >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // operator>>(QDataStream&,QRect&)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QDataStream & cppResult = (*cppSelf) >> (cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QDataStream & >::toPython(cppResult);
                    Shiboken::Object::setParent(self, pyResult);
                }
                break;
            }
            case 11: // operator>>(QDataStream&,QRectF&)
            {
                if (!Shiboken::Object::isValid(arg))
                    return 0;
                QRectF & cppArg0 = Shiboken::Converter<QRectF & >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // operator>>(QDataStream&,QRectF&)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QDataStream & cppResult = (*cppSelf) >> (cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QDataStream & >::toPython(cppResult);
                    Shiboken::Object::setParent(self, pyResult);
                }
                break;
            }
            case 12: // operator>>(QDataStream&,QRegExp&)
            {
                if (!Shiboken::Object::isValid(arg))
                    return 0;
                QRegExp & cppArg0 = Shiboken::Converter<QRegExp & >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // operator>>(QDataStream&,QRegExp&)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QDataStream & cppResult = (*cppSelf) >> (cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QDataStream & >::toPython(cppResult);
                    Shiboken::Object::setParent(self, pyResult);
                }
                break;
            }
            case 13: // operator>>(QDataStream&,QSize&)
            {
                if (!Shiboken::Object::isValid(arg))
                    return 0;
                QSize & cppArg0 = Shiboken::Converter<QSize & >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // operator>>(QDataStream&,QSize&)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QDataStream & cppResult = (*cppSelf) >> (cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QDataStream & >::toPython(cppResult);
                    Shiboken::Object::setParent(self, pyResult);
                }
                break;
            }
            case 14: // operator>>(QDataStream&,QSizeF&)
            {
                if (!Shiboken::Object::isValid(arg))
                    return 0;
                QSizeF & cppArg0 = Shiboken::Converter<QSizeF & >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // operator>>(QDataStream&,QSizeF&)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QDataStream & cppResult = (*cppSelf) >> (cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QDataStream & >::toPython(cppResult);
                    Shiboken::Object::setParent(self, pyResult);
                }
                break;
            }
            case 15: // operator>>(QDataStream&,QTime&)
            {
                if (!Shiboken::Object::isValid(arg))
                    return 0;
                QTime & cppArg0 = Shiboken::Converter<QTime & >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // operator>>(QDataStream&,QTime&)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QDataStream & cppResult = (*cppSelf) >> (cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QDataStream & >::toPython(cppResult);
                    Shiboken::Object::setParent(self, pyResult);
                }
                break;
            }
            case 16: // operator>>(QDataStream&,QUrl&)
            {
                if (!Shiboken::Object::isValid(arg))
                    return 0;
                QUrl & cppArg0 = Shiboken::Converter<QUrl & >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // operator>>(QDataStream&,QUrl&)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QDataStream & cppResult = (*cppSelf) >> (cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QDataStream & >::toPython(cppResult);
                    Shiboken::Object::setParent(self, pyResult);
                }
                break;
            }
            case 17: // operator>>(QDataStream&,QUuid&)
            {
                if (!Shiboken::Object::isValid(arg))
                    return 0;
                QUuid & cppArg0 = Shiboken::Converter<QUuid & >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // operator>>(QDataStream&,QUuid&)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QDataStream & cppResult = (*cppSelf) >> (cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QDataStream & >::toPython(cppResult);
                    Shiboken::Object::setParent(self, pyResult);
                }
                break;
            }
        }
    }


    } // End of "if (!pyResult)"


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QDataStreamFunc___rshift___TypeError:
        const char* overloads[] = {"PySide.QtCore.QBitArray", "PySide.QtCore.QByteArray", "PySide.QtCore.QDate", "PySide.QtCore.QDateTime", "PySide.QtCore.QEasingCurve", "PySide.QtCore.QLine", "PySide.QtCore.QLineF", "PySide.QtCore.QLocale", "PySide.QtCore.QPoint", "PySide.QtCore.QPointF", "PySide.QtCore.QRect", "PySide.QtCore.QRectF", "PySide.QtCore.QRegExp", "PySide.QtCore.QSize", "PySide.QtCore.QSizeF", "PySide.QtCore.QTime", "PySide.QtCore.QUrl", "PySide.QtCore.QUuid", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QDataStream.__rshift__", overloads);
        return 0;
}

// type has number operators
static PyNumberMethods Sbk_QDataStream_as_number = {
    /*nb_add*/                  (binaryfunc)0,
    /*nb_subtract*/             (binaryfunc)0,
    /*nb_multiply*/             (binaryfunc)0,
    /*nb_divide*/               (binaryfunc)0,
    /*nb_remainder*/            (binaryfunc)0,
    /*nb_divmod*/               0,
    /*nb_power*/                0,
    /*nb_negative*/             (unaryfunc)0,
    /*nb_positive*/             (unaryfunc)0,
    /*nb_absolute*/             0,
    /*nb_nonzero*/              0,
    /*nb_invert*/               (unaryfunc)0,
    /*nb_lshift*/               (binaryfunc)Sbk_QDataStreamFunc___lshift__,
    /*nb_rshift*/               (binaryfunc)Sbk_QDataStreamFunc___rshift__,
    /*nb_and*/                  (binaryfunc)0,
    /*nb_xor*/                  (binaryfunc)0,
    /*nb_or*/                   (binaryfunc)0,
    /*nb_coerce*/               0,
    /*nb_int*/                  0,
    /*nb_long*/                 0,
    /*nb_float*/                0,
    /*nb_oct*/                  0,
    /*nb_hex*/                  0,
    /*nb_inplace_add*/          (binaryfunc)0,
    /*nb_inplace_subtract*/     (binaryfunc)0,
    /*nb_inplace_multiply*/     (binaryfunc)0,
    /*nb_inplace_divide*/       (binaryfunc)0,
    /*nb_inplace_remainder*/    (binaryfunc)0,
    /*nb_inplace_power*/        0,
    /*nb_inplace_lshift*/       (binaryfunc)0,
    /*nb_inplace_rshift*/       (binaryfunc)0,
    /*nb_inplace_and*/          (binaryfunc)0,
    /*nb_inplace_xor*/          (binaryfunc)0,
    /*nb_inplace_or*/           (binaryfunc)0,
    /*nb_floor_divide*/         0,
    /*nb_true_divide*/          (binaryfunc)0,
    /*nb_inplace_floor_divide*/ 0,
    /*nb_inplace_true_divide*/  0,
    /*nb_index*/                0
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QDataStream_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtCore.QDataStream",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        &Sbk_QDataStream_as_number,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QDataStream_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&SbkObject_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QDataStream_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern


void init_QDataStream(PyObject* module)
{
    SbkPySide_QtCoreTypes[SBK_QDATASTREAM_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QDataStream_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QDataStream_Type);
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QDataStream_Type, &Shiboken::callCppDestructor<QDataStream >);
    Py_INCREF((PyObject*)&Sbk_QDataStream_Type); //Incref due the 'PyModule_AddObject' steals the reference.
    if (PyType_Ready((PyTypeObject*)&Sbk_QDataStream_Type) < 0)
        return;

    // Fill type discovery information

    Shiboken::ObjectType::setOriginalName(&Sbk_QDataStream_Type, "QDataStream*");
    PyModule_AddObject(module, "QDataStream",
        ((PyObject*)&Sbk_QDataStream_Type));

    // Initialize enums
    PyObject* enumItem;

    // init enum: ByteOrder
    PyTypeObject* SbkPySide_QtCore_QDataStream_ByteOrder = Shiboken::Enum::newType("PySide.QtCore.QDataStream.ByteOrder");
    SbkPySide_QtCoreTypes[SBK_QDATASTREAM_BYTEORDER_IDX] = SbkPySide_QtCore_QDataStream_ByteOrder;
    if (PyType_Ready(SbkPySide_QtCore_QDataStream_ByteOrder) < 0)
        return;
    PyDict_SetItemString(Sbk_QDataStream_Type.super.ht_type.tp_dict,
            "ByteOrder",((PyObject*)SbkPySide_QtCore_QDataStream_ByteOrder));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QDataStream_ByteOrder,(long) QDataStream::BigEndian, "BigEndian");
    PyDict_SetItemString(Sbk_QDataStream_Type.super.ht_type.tp_dict,"BigEndian", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QDataStream_ByteOrder->tp_dict,"BigEndian", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QDataStream_ByteOrder,(long) QDataStream::LittleEndian, "LittleEndian");
    PyDict_SetItemString(Sbk_QDataStream_Type.super.ht_type.tp_dict,"LittleEndian", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QDataStream_ByteOrder->tp_dict,"LittleEndian", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QDataStream::ByteOrder");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::ByteOrder");
    // end of enum ByteOrder

    // init enum: FloatingPointPrecision
    PyTypeObject* SbkPySide_QtCore_QDataStream_FloatingPointPrecision = Shiboken::Enum::newType("PySide.QtCore.QDataStream.FloatingPointPrecision");
    SbkPySide_QtCoreTypes[SBK_QDATASTREAM_FLOATINGPOINTPRECISION_IDX] = SbkPySide_QtCore_QDataStream_FloatingPointPrecision;
    if (PyType_Ready(SbkPySide_QtCore_QDataStream_FloatingPointPrecision) < 0)
        return;
    PyDict_SetItemString(Sbk_QDataStream_Type.super.ht_type.tp_dict,
            "FloatingPointPrecision",((PyObject*)SbkPySide_QtCore_QDataStream_FloatingPointPrecision));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QDataStream_FloatingPointPrecision,(long) QDataStream::SinglePrecision, "SinglePrecision");
    PyDict_SetItemString(Sbk_QDataStream_Type.super.ht_type.tp_dict,"SinglePrecision", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QDataStream_FloatingPointPrecision->tp_dict,"SinglePrecision", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QDataStream_FloatingPointPrecision,(long) QDataStream::DoublePrecision, "DoublePrecision");
    PyDict_SetItemString(Sbk_QDataStream_Type.super.ht_type.tp_dict,"DoublePrecision", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QDataStream_FloatingPointPrecision->tp_dict,"DoublePrecision", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QDataStream::FloatingPointPrecision");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::FloatingPointPrecision");
    // end of enum FloatingPointPrecision

    // init enum: Version
    PyTypeObject* SbkPySide_QtCore_QDataStream_Version = Shiboken::Enum::newType("PySide.QtCore.QDataStream.Version");
    SbkPySide_QtCoreTypes[SBK_QDATASTREAM_VERSION_IDX] = SbkPySide_QtCore_QDataStream_Version;
    if (PyType_Ready(SbkPySide_QtCore_QDataStream_Version) < 0)
        return;
    PyDict_SetItemString(Sbk_QDataStream_Type.super.ht_type.tp_dict,
            "Version",((PyObject*)SbkPySide_QtCore_QDataStream_Version));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QDataStream_Version,(long) QDataStream::Qt_1_0, "Qt_1_0");
    PyDict_SetItemString(Sbk_QDataStream_Type.super.ht_type.tp_dict,"Qt_1_0", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QDataStream_Version->tp_dict,"Qt_1_0", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QDataStream_Version,(long) QDataStream::Qt_2_0, "Qt_2_0");
    PyDict_SetItemString(Sbk_QDataStream_Type.super.ht_type.tp_dict,"Qt_2_0", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QDataStream_Version->tp_dict,"Qt_2_0", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QDataStream_Version,(long) QDataStream::Qt_2_1, "Qt_2_1");
    PyDict_SetItemString(Sbk_QDataStream_Type.super.ht_type.tp_dict,"Qt_2_1", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QDataStream_Version->tp_dict,"Qt_2_1", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QDataStream_Version,(long) QDataStream::Qt_3_0, "Qt_3_0");
    PyDict_SetItemString(Sbk_QDataStream_Type.super.ht_type.tp_dict,"Qt_3_0", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QDataStream_Version->tp_dict,"Qt_3_0", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QDataStream_Version,(long) QDataStream::Qt_3_1, "Qt_3_1");
    PyDict_SetItemString(Sbk_QDataStream_Type.super.ht_type.tp_dict,"Qt_3_1", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QDataStream_Version->tp_dict,"Qt_3_1", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QDataStream_Version,(long) QDataStream::Qt_3_3, "Qt_3_3");
    PyDict_SetItemString(Sbk_QDataStream_Type.super.ht_type.tp_dict,"Qt_3_3", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QDataStream_Version->tp_dict,"Qt_3_3", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QDataStream_Version,(long) QDataStream::Qt_4_0, "Qt_4_0");
    PyDict_SetItemString(Sbk_QDataStream_Type.super.ht_type.tp_dict,"Qt_4_0", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QDataStream_Version->tp_dict,"Qt_4_0", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QDataStream_Version,(long) QDataStream::Qt_4_1, "Qt_4_1");
    PyDict_SetItemString(Sbk_QDataStream_Type.super.ht_type.tp_dict,"Qt_4_1", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QDataStream_Version->tp_dict,"Qt_4_1", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QDataStream_Version,(long) QDataStream::Qt_4_2, "Qt_4_2");
    PyDict_SetItemString(Sbk_QDataStream_Type.super.ht_type.tp_dict,"Qt_4_2", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QDataStream_Version->tp_dict,"Qt_4_2", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QDataStream_Version,(long) QDataStream::Qt_4_3, "Qt_4_3");
    PyDict_SetItemString(Sbk_QDataStream_Type.super.ht_type.tp_dict,"Qt_4_3", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QDataStream_Version->tp_dict,"Qt_4_3", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QDataStream_Version,(long) QDataStream::Qt_4_4, "Qt_4_4");
    PyDict_SetItemString(Sbk_QDataStream_Type.super.ht_type.tp_dict,"Qt_4_4", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QDataStream_Version->tp_dict,"Qt_4_4", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QDataStream_Version,(long) QDataStream::Qt_4_5, "Qt_4_5");
    PyDict_SetItemString(Sbk_QDataStream_Type.super.ht_type.tp_dict,"Qt_4_5", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QDataStream_Version->tp_dict,"Qt_4_5", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QDataStream_Version,(long) QDataStream::Qt_4_6, "Qt_4_6");
    PyDict_SetItemString(Sbk_QDataStream_Type.super.ht_type.tp_dict,"Qt_4_6", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QDataStream_Version->tp_dict,"Qt_4_6", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QDataStream_Version,(long) QDataStream::Qt_4_7, "Qt_4_7");
    PyDict_SetItemString(Sbk_QDataStream_Type.super.ht_type.tp_dict,"Qt_4_7", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QDataStream_Version->tp_dict,"Qt_4_7", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QDataStream::Version");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::Version");
    // end of enum Version

    // init enum: Status
    PyTypeObject* SbkPySide_QtCore_QDataStream_Status = Shiboken::Enum::newType("PySide.QtCore.QDataStream.Status");
    SbkPySide_QtCoreTypes[SBK_QDATASTREAM_STATUS_IDX] = SbkPySide_QtCore_QDataStream_Status;
    if (PyType_Ready(SbkPySide_QtCore_QDataStream_Status) < 0)
        return;
    PyDict_SetItemString(Sbk_QDataStream_Type.super.ht_type.tp_dict,
            "Status",((PyObject*)SbkPySide_QtCore_QDataStream_Status));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QDataStream_Status,(long) QDataStream::Ok, "Ok");
    PyDict_SetItemString(Sbk_QDataStream_Type.super.ht_type.tp_dict,"Ok", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QDataStream_Status->tp_dict,"Ok", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QDataStream_Status,(long) QDataStream::ReadPastEnd, "ReadPastEnd");
    PyDict_SetItemString(Sbk_QDataStream_Type.super.ht_type.tp_dict,"ReadPastEnd", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QDataStream_Status->tp_dict,"ReadPastEnd", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QDataStream_Status,(long) QDataStream::ReadCorruptData, "ReadCorruptData");
    PyDict_SetItemString(Sbk_QDataStream_Type.super.ht_type.tp_dict,"ReadCorruptData", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QDataStream_Status->tp_dict,"ReadCorruptData", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QDataStream::Status");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::Status");
    // end of enum Status


    Shiboken::TypeResolver::createObjectTypeResolver<QDataStream >("QDataStream*");
    Shiboken::TypeResolver::createObjectTypeResolver<QDataStream >(typeid(QDataStream).name());
    Shiboken::TypeResolver::createObjectTypeResolver<QDataStream >(typeid(QDataStreamWrapper).name());
    qRegisterMetaType< ::QDataStream* >("QDataStream*");
    qRegisterMetaType< ::QDataStream::ByteOrder >("QDataStream::ByteOrder");
    qRegisterMetaType< ::QDataStream::FloatingPointPrecision >("QDataStream::FloatingPointPrecision");
    qRegisterMetaType< ::QDataStream::Version >("QDataStream::Version");
    qRegisterMetaType< ::QDataStream::Status >("QDataStream::Status");
}

