/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include "pyside_qtcore_python.h"

#include "qstatemachine_wrapper.h"
#include "qstatemachine_wrappedevent_wrapper.h"
#include "qstatemachine_signalevent_wrapper.h"

// Extra includes
#include <QList>
#include <QSet>
#include <qabstractanimation.h>
#include <qabstractstate.h>
#include <qabstracttransition.h>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qsignaltransition.h>
#include <qstate.h>
#include <qstatemachine.h>
#include <qthread.h>


// Native ---------------------------------------------------------

QStateMachineWrapper::QStateMachineWrapper(QObject * parent) : QStateMachine(parent) {
    // ... middle
}

void QStateMachineWrapper::beginMicrostep(QEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "beginMicrostep"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QStateMachine::beginMicrostep(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QEvent * >::toPython(event)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QStateMachineWrapper::beginSelectTransitions(QEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "beginSelectTransitions"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QStateMachine::beginSelectTransitions(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QEvent * >::toPython(event)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QStateMachineWrapper::childEvent(QChildEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "childEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::childEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QChildEvent * >::toPython(arg__1)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QStateMachineWrapper::connectNotify(const char * signal)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "connectNotify"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::connectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QStateMachineWrapper::customEvent(QEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "customEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::customEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QEvent * >::toPython(arg__1)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QStateMachineWrapper::disconnectNotify(const char * signal)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "disconnectNotify"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::disconnectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QStateMachineWrapper::endMicrostep(QEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "endMicrostep"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QStateMachine::endMicrostep(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QEvent * >::toPython(event)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QStateMachineWrapper::endSelectTransitions(QEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "endSelectTransitions"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QStateMachine::endSelectTransitions(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QEvent * >::toPython(event)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

bool QStateMachineWrapper::event(QEvent * e)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return bool(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "event"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QStateMachine::event(e);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QEvent * >::toPython(e)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QStateMachine.event", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
    return cppResult;
}

bool QStateMachineWrapper::eventFilter(QObject * watched, QEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return bool(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "eventFilter"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QStateMachine::eventFilter(watched, event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter< ::QObject * >::toPython(watched),
        Shiboken::Converter< ::QEvent * >::toPython(event)
    ));
    bool invalidadeArg2 = PyTuple_GET_ITEM(pyargs, 1)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QStateMachine.eventFilter", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    if (invalidadeArg2)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 1));
    return cppResult;
}

void QStateMachineWrapper::onEntry(QEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "onEntry"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QStateMachine::onEntry(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QEvent * >::toPython(event)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QStateMachineWrapper::onExit(QEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "onExit"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QStateMachine::onExit(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QEvent * >::toPython(event)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QStateMachineWrapper::timerEvent(QTimerEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "timerEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::timerEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QTimerEvent * >::toPython(arg__1)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

const QMetaObject* QStateMachineWrapper::metaObject() const
{
    SbkObject* pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    return reinterpret_cast<QMetaObject*>(Shiboken::Object::getTypeUserData(pySelf));
}

int QStateMachineWrapper::qt_metacall(QMetaObject::Call call, int id, void** args)
{
    int result = QStateMachine::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

QStateMachineWrapper::~QStateMachineWrapper()
{
    SbkObject* wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QStateMachine_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QStateMachine >()))
        return -1;

    QStateMachineWrapper* cptr = 0;
    int overloadId = -1;
    const char* argNames[] = {"parent"};
    const QMetaObject* metaObject;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths


    if (!PyArg_ParseTuple(args, "|O:QStateMachine", &(pyargs[0])))
        return -1;

    // Overloaded function decisor
    // 0: QStateMachine(QObject*)
    if (numArgs == 0) {
        overloadId = 0; // QStateMachine(QObject*)
    } else if (Shiboken::Converter< ::QObject * >::isConvertible(pyargs[0])) {
        overloadId = 0; // QStateMachine(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QStateMachine_Init_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "parent");
                if (value) {
                    if (pyargs[0])
                        errorArgName = "parent";
                    else if (Shiboken::Converter< ::QObject * >::isConvertible(value))
                        pyargs[0] = value;
                    else
                        goto Sbk_QStateMachine_Init_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtCore.QStateMachine(): got multiple values for keyword argument '%s'", errorArgName);
                    return -1;
                }
            }
            if (!Shiboken::Object::isValid(pyargs[0]))
                return -1;
            QObject * cppArg0 = pyargs[0] ? Shiboken::Converter<QObject * >::toCpp(pyargs[0]) : 0;

            if(!PyErr_Occurred()) {
                // QStateMachine(QObject*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new QStateMachineWrapper(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                Shiboken::Object::setParent(pyargs[0], self);
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QStateMachine >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QStateMachine_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    metaObject = cptr->metaObject(); // <- init python qt properties
    if (kwds && !PySide::fillQtProperties(self, metaObject, kwds, argNames, 1))
        return -1;


    return 1;

    Sbk_QStateMachine_Init_TypeError:
        const char* overloads[] = {"PySide.QtCore.QObject = None", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QStateMachine", overloads);
        return -1;
}

static PyObject* Sbk_QStateMachineFunc_addDefaultAnimation(PyObject* self, PyObject* arg)
{
    QStateMachine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QStateMachine* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: addDefaultAnimation(QAbstractAnimation*)
    if (Shiboken::Converter< ::QAbstractAnimation * >::isConvertible(arg)) {
        overloadId = 0; // addDefaultAnimation(QAbstractAnimation*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QStateMachineFunc_addDefaultAnimation_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QAbstractAnimation * cppArg0 = Shiboken::Converter<QAbstractAnimation * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // addDefaultAnimation(QAbstractAnimation*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->addDefaultAnimation(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QStateMachineFunc_addDefaultAnimation_TypeError:
        const char* overloads[] = {"PySide.QtCore.QAbstractAnimation", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QStateMachine.addDefaultAnimation", overloads);
        return 0;
}

static PyObject* Sbk_QStateMachineFunc_addState(PyObject* self, PyObject* arg)
{
    QStateMachine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QStateMachine* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: addState(QAbstractState*)
    if (Shiboken::Converter< ::QAbstractState * >::isConvertible(arg)) {
        overloadId = 0; // addState(QAbstractState*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QStateMachineFunc_addState_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QAbstractState * cppArg0 = Shiboken::Converter<QAbstractState * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // addState(QAbstractState*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->addState(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                Shiboken::Object::setParent(self, arg);
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QStateMachineFunc_addState_TypeError:
        const char* overloads[] = {"PySide.QtCore.QAbstractState", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QStateMachine.addState", overloads);
        return 0;
}

static PyObject* Sbk_QStateMachineFunc_beginMicrostep(PyObject* self, PyObject* arg)
{
    QStateMachine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QStateMachine* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: beginMicrostep(QEvent*)
    if (Shiboken::Converter< ::QEvent * >::isConvertible(arg)) {
        overloadId = 0; // beginMicrostep(QEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QStateMachineFunc_beginMicrostep_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QEvent * cppArg0 = Shiboken::Converter<QEvent * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // beginMicrostep(QEvent*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QStateMachine::beginMicrostep(cppArg0) : cppSelf->beginMicrostep(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QStateMachineFunc_beginMicrostep_TypeError:
        const char* overloads[] = {"PySide.QtCore.QEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QStateMachine.beginMicrostep", overloads);
        return 0;
}

static PyObject* Sbk_QStateMachineFunc_beginSelectTransitions(PyObject* self, PyObject* arg)
{
    QStateMachine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QStateMachine* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: beginSelectTransitions(QEvent*)
    if (Shiboken::Converter< ::QEvent * >::isConvertible(arg)) {
        overloadId = 0; // beginSelectTransitions(QEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QStateMachineFunc_beginSelectTransitions_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QEvent * cppArg0 = Shiboken::Converter<QEvent * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // beginSelectTransitions(QEvent*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QStateMachine::beginSelectTransitions(cppArg0) : cppSelf->beginSelectTransitions(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QStateMachineFunc_beginSelectTransitions_TypeError:
        const char* overloads[] = {"PySide.QtCore.QEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QStateMachine.beginSelectTransitions", overloads);
        return 0;
}

static PyObject* Sbk_QStateMachineFunc_cancelDelayedEvent(PyObject* self, PyObject* arg)
{
    QStateMachine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QStateMachine* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: cancelDelayedEvent(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // cancelDelayedEvent(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QStateMachineFunc_cancelDelayedEvent_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // cancelDelayedEvent(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->cancelDelayedEvent(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QStateMachineFunc_cancelDelayedEvent_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QStateMachine.cancelDelayedEvent", overloads);
        return 0;
}

static PyObject* Sbk_QStateMachineFunc_clearError(PyObject* self)
{
    QStateMachine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QStateMachine* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // clearError()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->clearError();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QStateMachineFunc_configuration(PyObject* self)
{
    QStateMachine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QStateMachine* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // configuration()
                // Begin code injection

                pyResult = PySet_New(0);
                foreach(QAbstractState* abs_state, cppSelf->configuration()) {
                        Shiboken::AutoDecRef obj(Shiboken::Converter<QAbstractState* >::toPython(abs_state));
                        Shiboken::Object::setParent(self, obj);
                        PySet_Add(pyResult, obj);
                }

                // End of code injection


            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QStateMachineFunc_defaultAnimations(PyObject* self)
{
    QStateMachine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QStateMachine* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // defaultAnimations()
                // Begin code injection

                pyResult = PyList_New(0);
                foreach(QAbstractAnimation* abs_anim, cppSelf->defaultAnimations()) {
                        Shiboken::AutoDecRef obj(Shiboken::Converter<QAbstractAnimation* >::toPython(abs_anim));
                        Shiboken::Object::setParent(self, obj);
                        PyList_Append(pyResult, obj);
                }

                // End of code injection


            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QStateMachineFunc_endMicrostep(PyObject* self, PyObject* arg)
{
    QStateMachine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QStateMachine* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: endMicrostep(QEvent*)
    if (Shiboken::Converter< ::QEvent * >::isConvertible(arg)) {
        overloadId = 0; // endMicrostep(QEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QStateMachineFunc_endMicrostep_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QEvent * cppArg0 = Shiboken::Converter<QEvent * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // endMicrostep(QEvent*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QStateMachine::endMicrostep(cppArg0) : cppSelf->endMicrostep(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QStateMachineFunc_endMicrostep_TypeError:
        const char* overloads[] = {"PySide.QtCore.QEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QStateMachine.endMicrostep", overloads);
        return 0;
}

static PyObject* Sbk_QStateMachineFunc_endSelectTransitions(PyObject* self, PyObject* arg)
{
    QStateMachine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QStateMachine* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: endSelectTransitions(QEvent*)
    if (Shiboken::Converter< ::QEvent * >::isConvertible(arg)) {
        overloadId = 0; // endSelectTransitions(QEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QStateMachineFunc_endSelectTransitions_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QEvent * cppArg0 = Shiboken::Converter<QEvent * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // endSelectTransitions(QEvent*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QStateMachine::endSelectTransitions(cppArg0) : cppSelf->endSelectTransitions(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QStateMachineFunc_endSelectTransitions_TypeError:
        const char* overloads[] = {"PySide.QtCore.QEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QStateMachine.endSelectTransitions", overloads);
        return 0;
}

static PyObject* Sbk_QStateMachineFunc_error(PyObject* self)
{
    QStateMachine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QStateMachine* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // error()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QStateMachine::Error cppResult = const_cast<const QStateMachine*>(cppSelf)->error();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QStateMachine::Error >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QStateMachineFunc_errorString(PyObject* self)
{
    QStateMachine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QStateMachine* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // errorString()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = const_cast<const QStateMachine*>(cppSelf)->errorString();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QStateMachineFunc_event(PyObject* self, PyObject* arg)
{
    QStateMachine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QStateMachine* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: event(QEvent*)
    if (Shiboken::Converter< ::QEvent * >::isConvertible(arg)) {
        overloadId = 0; // event(QEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QStateMachineFunc_event_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QEvent * cppArg0 = Shiboken::Converter<QEvent * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // event(QEvent*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = (Shiboken::Object::isUserType(self) ? cppSelf->::QStateMachine::event(cppArg0) : cppSelf->event(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QStateMachineFunc_event_TypeError:
        const char* overloads[] = {"PySide.QtCore.QEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QStateMachine.event", overloads);
        return 0;
}

static PyObject* Sbk_QStateMachineFunc_eventFilter(PyObject* self, PyObject* args)
{
    QStateMachine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QStateMachine* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "eventFilter", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: eventFilter(QObject*,QEvent*)
    if (numArgs == 2 && Shiboken::Converter< ::QObject * >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QEvent * >::isConvertible(pyargs[1])) {
        overloadId = 0; // eventFilter(QObject*,QEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QStateMachineFunc_eventFilter_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QObject * cppArg0 = Shiboken::Converter<QObject * >::toCpp(pyargs[0]);
            if (!Shiboken::Object::isValid(pyargs[1]))
                return 0;
            QEvent * cppArg1 = Shiboken::Converter<QEvent * >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // eventFilter(QObject*,QEvent*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = (Shiboken::Object::isUserType(self) ? cppSelf->::QStateMachine::eventFilter(cppArg0, cppArg1) : cppSelf->eventFilter(cppArg0, cppArg1));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QStateMachineFunc_eventFilter_TypeError:
        const char* overloads[] = {"PySide.QtCore.QObject, PySide.QtCore.QEvent", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QStateMachine.eventFilter", overloads);
        return 0;
}

static PyObject* Sbk_QStateMachineFunc_globalRestorePolicy(PyObject* self)
{
    QStateMachine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QStateMachine* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // globalRestorePolicy()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QStateMachine::RestorePolicy cppResult = const_cast<const QStateMachine*>(cppSelf)->globalRestorePolicy();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QStateMachine::RestorePolicy >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QStateMachineFunc_isAnimated(PyObject* self)
{
    QStateMachine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QStateMachine* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isAnimated()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QStateMachine*>(cppSelf)->isAnimated();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QStateMachineFunc_isRunning(PyObject* self)
{
    QStateMachine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QStateMachine* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isRunning()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QStateMachine*>(cppSelf)->isRunning();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QStateMachineFunc_onEntry(PyObject* self, PyObject* arg)
{
    QStateMachine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QStateMachine* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: onEntry(QEvent*)
    if (Shiboken::Converter< ::QEvent * >::isConvertible(arg)) {
        overloadId = 0; // onEntry(QEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QStateMachineFunc_onEntry_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QEvent * cppArg0 = Shiboken::Converter<QEvent * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // onEntry(QEvent*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QStateMachine::onEntry(cppArg0) : cppSelf->onEntry(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QStateMachineFunc_onEntry_TypeError:
        const char* overloads[] = {"PySide.QtCore.QEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QStateMachine.onEntry", overloads);
        return 0;
}

static PyObject* Sbk_QStateMachineFunc_onExit(PyObject* self, PyObject* arg)
{
    QStateMachine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QStateMachine* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: onExit(QEvent*)
    if (Shiboken::Converter< ::QEvent * >::isConvertible(arg)) {
        overloadId = 0; // onExit(QEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QStateMachineFunc_onExit_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QEvent * cppArg0 = Shiboken::Converter<QEvent * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // onExit(QEvent*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QStateMachine::onExit(cppArg0) : cppSelf->onExit(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QStateMachineFunc_onExit_TypeError:
        const char* overloads[] = {"PySide.QtCore.QEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QStateMachine.onExit", overloads);
        return 0;
}

static PyObject* Sbk_QStateMachineFunc_postDelayedEvent(PyObject* self, PyObject* args)
{
    QStateMachine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QStateMachine* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "postDelayedEvent", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: postDelayedEvent(QEvent*,int)
    if (numArgs == 2 && Shiboken::Converter< ::QEvent * >::isConvertible(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 0; // postDelayedEvent(QEvent*,int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QStateMachineFunc_postDelayedEvent_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QEvent * cppArg0 = Shiboken::Converter<QEvent * >::toCpp(pyargs[0]);
            int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // postDelayedEvent(QEvent*,int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = cppSelf->postDelayedEvent(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QStateMachineFunc_postDelayedEvent_TypeError:
        const char* overloads[] = {"PySide.QtCore.QEvent, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QStateMachine.postDelayedEvent", overloads);
        return 0;
}

static PyObject* Sbk_QStateMachineFunc_postEvent(PyObject* self, PyObject* args, PyObject* kwds)
{
    QStateMachine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QStateMachine* >::toCpp(self);

    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QStateMachine.postEvent(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QStateMachine.postEvent(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:postEvent", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: postEvent(QEvent*,QStateMachine::EventPriority)
    if (Shiboken::Converter< ::QEvent * >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // postEvent(QEvent*,QStateMachine::EventPriority)
        } else if (Shiboken::Converter< ::QStateMachine::EventPriority >::isConvertible(pyargs[1])) {
            overloadId = 0; // postEvent(QEvent*,QStateMachine::EventPriority)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QStateMachineFunc_postEvent_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "priority");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "priority";
                    else if (Shiboken::Converter< ::QStateMachine::EventPriority >::isConvertible(value))
                        pyargs[1] = value;
                    else
                        goto Sbk_QStateMachineFunc_postEvent_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtCore.QStateMachine.postEvent(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QEvent * cppArg0 = Shiboken::Converter<QEvent * >::toCpp(pyargs[0]);
            QStateMachine::EventPriority cppArg1 = pyargs[1] ? Shiboken::Converter<QStateMachine::EventPriority >::toCpp(pyargs[1]) : QStateMachine::NormalPriority;

            if(!PyErr_Occurred()) {
                // postEvent(QEvent*,QStateMachine::EventPriority)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->postEvent(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QStateMachineFunc_postEvent_TypeError:
        const char* overloads[] = {"PySide.QtCore.QEvent, PySide.QtCore.QStateMachine.EventPriority = NormalPriority", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QStateMachine.postEvent", overloads);
        return 0;
}

static PyObject* Sbk_QStateMachineFunc_removeDefaultAnimation(PyObject* self, PyObject* arg)
{
    QStateMachine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QStateMachine* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: removeDefaultAnimation(QAbstractAnimation*)
    if (Shiboken::Converter< ::QAbstractAnimation * >::isConvertible(arg)) {
        overloadId = 0; // removeDefaultAnimation(QAbstractAnimation*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QStateMachineFunc_removeDefaultAnimation_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QAbstractAnimation * cppArg0 = Shiboken::Converter<QAbstractAnimation * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // removeDefaultAnimation(QAbstractAnimation*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->removeDefaultAnimation(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QStateMachineFunc_removeDefaultAnimation_TypeError:
        const char* overloads[] = {"PySide.QtCore.QAbstractAnimation", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QStateMachine.removeDefaultAnimation", overloads);
        return 0;
}

static PyObject* Sbk_QStateMachineFunc_removeState(PyObject* self, PyObject* arg)
{
    QStateMachine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QStateMachine* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: removeState(QAbstractState*)
    if (Shiboken::Converter< ::QAbstractState * >::isConvertible(arg)) {
        overloadId = 0; // removeState(QAbstractState*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QStateMachineFunc_removeState_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QAbstractState * cppArg0 = Shiboken::Converter<QAbstractState * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // removeState(QAbstractState*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->removeState(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                Shiboken::Object::setParent(Py_None, arg);
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QStateMachineFunc_removeState_TypeError:
        const char* overloads[] = {"PySide.QtCore.QAbstractState", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QStateMachine.removeState", overloads);
        return 0;
}

static PyObject* Sbk_QStateMachineFunc_setAnimated(PyObject* self, PyObject* arg)
{
    QStateMachine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QStateMachine* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setAnimated(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setAnimated(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QStateMachineFunc_setAnimated_TypeError;

    // Call function/method
    {
        {
            bool cppArg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setAnimated(bool)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setAnimated(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QStateMachineFunc_setAnimated_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QStateMachine.setAnimated", overloads);
        return 0;
}

static PyObject* Sbk_QStateMachineFunc_setGlobalRestorePolicy(PyObject* self, PyObject* arg)
{
    QStateMachine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QStateMachine* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setGlobalRestorePolicy(QStateMachine::RestorePolicy)
    if (Shiboken::Converter< ::QStateMachine::RestorePolicy >::isConvertible(arg)) {
        overloadId = 0; // setGlobalRestorePolicy(QStateMachine::RestorePolicy)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QStateMachineFunc_setGlobalRestorePolicy_TypeError;

    // Call function/method
    {
        {
            QStateMachine::RestorePolicy cppArg0 = Shiboken::Converter<QStateMachine::RestorePolicy >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setGlobalRestorePolicy(QStateMachine::RestorePolicy)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setGlobalRestorePolicy(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QStateMachineFunc_setGlobalRestorePolicy_TypeError:
        const char* overloads[] = {"PySide.QtCore.QStateMachine.RestorePolicy", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QStateMachine.setGlobalRestorePolicy", overloads);
        return 0;
}

static PyObject* Sbk_QStateMachineFunc_start(PyObject* self)
{
    QStateMachine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QStateMachine* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // start()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->start();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QStateMachineFunc_stop(PyObject* self)
{
    QStateMachine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QStateMachine* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // stop()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->stop();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyMethodDef Sbk_QStateMachine_methods[] = {
    {"addDefaultAnimation", (PyCFunction)Sbk_QStateMachineFunc_addDefaultAnimation, METH_O},
    {"addState", (PyCFunction)Sbk_QStateMachineFunc_addState, METH_O},
    {"beginMicrostep", (PyCFunction)Sbk_QStateMachineFunc_beginMicrostep, METH_O},
    {"beginSelectTransitions", (PyCFunction)Sbk_QStateMachineFunc_beginSelectTransitions, METH_O},
    {"cancelDelayedEvent", (PyCFunction)Sbk_QStateMachineFunc_cancelDelayedEvent, METH_O},
    {"clearError", (PyCFunction)Sbk_QStateMachineFunc_clearError, METH_NOARGS},
    {"configuration", (PyCFunction)Sbk_QStateMachineFunc_configuration, METH_NOARGS},
    {"defaultAnimations", (PyCFunction)Sbk_QStateMachineFunc_defaultAnimations, METH_NOARGS},
    {"endMicrostep", (PyCFunction)Sbk_QStateMachineFunc_endMicrostep, METH_O},
    {"endSelectTransitions", (PyCFunction)Sbk_QStateMachineFunc_endSelectTransitions, METH_O},
    {"error", (PyCFunction)Sbk_QStateMachineFunc_error, METH_NOARGS},
    {"errorString", (PyCFunction)Sbk_QStateMachineFunc_errorString, METH_NOARGS},
    {"event", (PyCFunction)Sbk_QStateMachineFunc_event, METH_O},
    {"eventFilter", (PyCFunction)Sbk_QStateMachineFunc_eventFilter, METH_VARARGS},
    {"globalRestorePolicy", (PyCFunction)Sbk_QStateMachineFunc_globalRestorePolicy, METH_NOARGS},
    {"isAnimated", (PyCFunction)Sbk_QStateMachineFunc_isAnimated, METH_NOARGS},
    {"isRunning", (PyCFunction)Sbk_QStateMachineFunc_isRunning, METH_NOARGS},
    {"onEntry", (PyCFunction)Sbk_QStateMachineFunc_onEntry, METH_O},
    {"onExit", (PyCFunction)Sbk_QStateMachineFunc_onExit, METH_O},
    {"postDelayedEvent", (PyCFunction)Sbk_QStateMachineFunc_postDelayedEvent, METH_VARARGS},
    {"postEvent", (PyCFunction)Sbk_QStateMachineFunc_postEvent, METH_VARARGS|METH_KEYWORDS},
    {"removeDefaultAnimation", (PyCFunction)Sbk_QStateMachineFunc_removeDefaultAnimation, METH_O},
    {"removeState", (PyCFunction)Sbk_QStateMachineFunc_removeState, METH_O},
    {"setAnimated", (PyCFunction)Sbk_QStateMachineFunc_setAnimated, METH_O},
    {"setGlobalRestorePolicy", (PyCFunction)Sbk_QStateMachineFunc_setGlobalRestorePolicy, METH_O},
    {"start", (PyCFunction)Sbk_QStateMachineFunc_start, METH_NOARGS},
    {"stop", (PyCFunction)Sbk_QStateMachineFunc_stop, METH_NOARGS},

    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QStateMachine_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtCore.QStateMachine",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QStateMachine_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QStateMachine_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern

static SbkObjectType* Sbk_QStateMachine_typeDiscovery(void* cptr, SbkObjectType* instanceType)
{
    if (instanceType == reinterpret_cast<SbkObjectType*>(Shiboken::SbkType<QObject >()) && dynamic_cast<QStateMachine*>(reinterpret_cast<QObject*>(cptr)))
        return &Sbk_QStateMachine_Type;
    return 0;
}


void init_QStateMachine(PyObject* module)
{
    SbkPySide_QtCoreTypes[SBK_QSTATEMACHINE_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QStateMachine_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QStateMachine_Type);
    Shiboken::ObjectType::setSubTypeInitHook(&Sbk_QStateMachine_Type, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(&Sbk_QStateMachine_Type, &QStateMachine::staticMetaObject);    Sbk_QStateMachine_Type.super.ht_type.tp_base = SbkPySide_QtCoreTypes[SBK_QSTATE_IDX];
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QStateMachine_Type, &Shiboken::callCppDestructor<QStateMachine >);
    Py_INCREF((PyObject*)&Sbk_QStateMachine_Type); //Incref due the 'PyModule_AddObject' steals the reference.
    if (PyType_Ready((PyTypeObject*)&Sbk_QStateMachine_Type) < 0)
        return;

    // Fill type discovery information
    Shiboken::ObjectType::setTypeDiscoveryFunction(&Sbk_QStateMachine_Type, &Sbk_QStateMachine_typeDiscovery);
    Shiboken::BindingManager& bm = Shiboken::BindingManager::instance();
    bm.addClassInheritance(reinterpret_cast<SbkObjectType*>(SbkPySide_QtCoreTypes[SBK_QSTATE_IDX]), &Sbk_QStateMachine_Type);

    Shiboken::ObjectType::setOriginalName(&Sbk_QStateMachine_Type, "QStateMachine*");
    PyModule_AddObject(module, "QStateMachine",
        ((PyObject*)&Sbk_QStateMachine_Type));

    // Initialize enums
    PyObject* enumItem;

    // init enum: Error
    PyTypeObject* SbkPySide_QtCore_QStateMachine_Error = Shiboken::Enum::newType("PySide.QtCore.QStateMachine.Error");
    SbkPySide_QtCoreTypes[SBK_QSTATEMACHINE_ERROR_IDX] = SbkPySide_QtCore_QStateMachine_Error;
    if (PyType_Ready(SbkPySide_QtCore_QStateMachine_Error) < 0)
        return;
    PyDict_SetItemString(Sbk_QStateMachine_Type.super.ht_type.tp_dict,
            "Error",((PyObject*)SbkPySide_QtCore_QStateMachine_Error));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QStateMachine_Error,(long) QStateMachine::NoError, "NoError");
    PyDict_SetItemString(Sbk_QStateMachine_Type.super.ht_type.tp_dict,"NoError", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QStateMachine_Error->tp_dict,"NoError", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QStateMachine_Error,(long) QStateMachine::NoInitialStateError, "NoInitialStateError");
    PyDict_SetItemString(Sbk_QStateMachine_Type.super.ht_type.tp_dict,"NoInitialStateError", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QStateMachine_Error->tp_dict,"NoInitialStateError", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QStateMachine_Error,(long) QStateMachine::NoDefaultStateInHistoryStateError, "NoDefaultStateInHistoryStateError");
    PyDict_SetItemString(Sbk_QStateMachine_Type.super.ht_type.tp_dict,"NoDefaultStateInHistoryStateError", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QStateMachine_Error->tp_dict,"NoDefaultStateInHistoryStateError", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QStateMachine_Error,(long) QStateMachine::NoCommonAncestorForTransitionError, "NoCommonAncestorForTransitionError");
    PyDict_SetItemString(Sbk_QStateMachine_Type.super.ht_type.tp_dict,"NoCommonAncestorForTransitionError", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QStateMachine_Error->tp_dict,"NoCommonAncestorForTransitionError", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QStateMachine::Error");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::Error");
    // end of enum Error

    // init enum: EventPriority
    PyTypeObject* SbkPySide_QtCore_QStateMachine_EventPriority = Shiboken::Enum::newType("PySide.QtCore.QStateMachine.EventPriority");
    SbkPySide_QtCoreTypes[SBK_QSTATEMACHINE_EVENTPRIORITY_IDX] = SbkPySide_QtCore_QStateMachine_EventPriority;
    if (PyType_Ready(SbkPySide_QtCore_QStateMachine_EventPriority) < 0)
        return;
    PyDict_SetItemString(Sbk_QStateMachine_Type.super.ht_type.tp_dict,
            "EventPriority",((PyObject*)SbkPySide_QtCore_QStateMachine_EventPriority));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QStateMachine_EventPriority,(long) QStateMachine::NormalPriority, "NormalPriority");
    PyDict_SetItemString(Sbk_QStateMachine_Type.super.ht_type.tp_dict,"NormalPriority", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QStateMachine_EventPriority->tp_dict,"NormalPriority", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QStateMachine_EventPriority,(long) QStateMachine::HighPriority, "HighPriority");
    PyDict_SetItemString(Sbk_QStateMachine_Type.super.ht_type.tp_dict,"HighPriority", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QStateMachine_EventPriority->tp_dict,"HighPriority", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QStateMachine::EventPriority");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::EventPriority");
    // end of enum EventPriority

    // init enum: RestorePolicy
    PyTypeObject* SbkPySide_QtCore_QStateMachine_RestorePolicy = Shiboken::Enum::newType("PySide.QtCore.QStateMachine.RestorePolicy");
    SbkPySide_QtCoreTypes[SBK_QSTATEMACHINE_RESTOREPOLICY_IDX] = SbkPySide_QtCore_QStateMachine_RestorePolicy;
    if (PyType_Ready(SbkPySide_QtCore_QStateMachine_RestorePolicy) < 0)
        return;
    PyDict_SetItemString(Sbk_QStateMachine_Type.super.ht_type.tp_dict,
            "RestorePolicy",((PyObject*)SbkPySide_QtCore_QStateMachine_RestorePolicy));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QStateMachine_RestorePolicy,(long) QStateMachine::DontRestoreProperties, "DontRestoreProperties");
    PyDict_SetItemString(Sbk_QStateMachine_Type.super.ht_type.tp_dict,"DontRestoreProperties", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QStateMachine_RestorePolicy->tp_dict,"DontRestoreProperties", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QStateMachine_RestorePolicy,(long) QStateMachine::RestoreProperties, "RestoreProperties");
    PyDict_SetItemString(Sbk_QStateMachine_Type.super.ht_type.tp_dict,"RestoreProperties", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QStateMachine_RestorePolicy->tp_dict,"RestoreProperties", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QStateMachine::RestorePolicy");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::RestorePolicy");
    // end of enum RestorePolicy

    // Initialize signals
    PySideSignal* signal_item;

    signal_item = PySide::Signal::newObject("stopped", "void", NULL);
    PySide::Signal::addSignalToWrapper(&Sbk_QStateMachine_Type, "stopped", signal_item);
    Py_DECREF((PyObject*) signal_item);
    signal_item = PySide::Signal::newObject("started", "void", NULL);
    PySide::Signal::addSignalToWrapper(&Sbk_QStateMachine_Type, "started", signal_item);
    Py_DECREF((PyObject*) signal_item);


    Shiboken::TypeResolver::createObjectTypeResolver<QStateMachine >("QStateMachine*");
    Shiboken::TypeResolver::createObjectTypeResolver<QStateMachine >(typeid(QStateMachine).name());
    Shiboken::TypeResolver::createObjectTypeResolver<QStateMachine >(typeid(QStateMachineWrapper).name());
    qRegisterMetaType< ::QStateMachine* >("QStateMachine*");
    qRegisterMetaType< ::QStateMachine::Error >("QStateMachine::Error");
    qRegisterMetaType< ::QStateMachine::EventPriority >("QStateMachine::EventPriority");
    qRegisterMetaType< ::QStateMachine::RestorePolicy >("QStateMachine::RestorePolicy");
}

