/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtcore_python.h"

#include "qtextstream_wrapper.h"

// Extra includes
#include <qbytearray.h>
#include <qiodevice.h>
#include <qlocale.h>
#include <qtextcodec.h>
#include <qtextstream.h>


// Native ---------------------------------------------------------

QTextStreamWrapper::QTextStreamWrapper() : QTextStream() {
    // ... middle
}

QTextStreamWrapper::QTextStreamWrapper(QByteArray * array, QFlags<QIODevice::OpenModeFlag> openMode) : QTextStream(array, openMode) {
    // ... middle
}

QTextStreamWrapper::QTextStreamWrapper(QIODevice * device) : QTextStream(device) {
    // ... middle
}

QTextStreamWrapper::QTextStreamWrapper(QString * string, QFlags<QIODevice::OpenModeFlag> openMode) : QTextStream(string, openMode) {
    // ... middle
}

QTextStreamWrapper::~QTextStreamWrapper()
{
    SbkObject* wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QTextStream_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QTextStream >()))
        return -1;

    QTextStreamWrapper* cptr = 0;
    int overloadId = -1;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);

    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);

    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QTextStream(): too many arguments");
        return -1;
    }

    if (!PyArg_ParseTuple(args, "|OO:QTextStream", &(pyargs[0]), &(pyargs[1])))
        return -1;

    // Overloaded function decisor
    // 0: QTextStream()
    // 1: QTextStream(QByteArray*,QFlags<QIODevice::OpenModeFlag>)
    // 2: QTextStream(QIODevice*)
    // 3: QTextStream(QString*,QFlags<QIODevice::OpenModeFlag>)
    if (numArgs == 0) {
        overloadId = 0; // QTextStream()
    } else if (numArgs == 1 && Shiboken::Converter< ::QIODevice * >::isConvertible(pyargs[0])) {
        overloadId = 2; // QTextStream(QIODevice*)
    } else if (Shiboken::Converter< ::QString * >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 3; // QTextStream(QString*,QFlags<QIODevice::OpenModeFlag>)
        } else if (Shiboken::Converter< ::QFlags<QIODevice::OpenModeFlag> >::isConvertible(pyargs[1])) {
            overloadId = 3; // QTextStream(QString*,QFlags<QIODevice::OpenModeFlag>)
        }
    } else if (Shiboken::Converter< ::QByteArray * >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 1; // QTextStream(QByteArray*,QFlags<QIODevice::OpenModeFlag>)
        } else if (Shiboken::Converter< ::QFlags<QIODevice::OpenModeFlag> >::isConvertible(pyargs[1])) {
            overloadId = 1; // QTextStream(QByteArray*,QFlags<QIODevice::OpenModeFlag>)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextStream_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QTextStream()
            {

                if(!PyErr_Occurred()) {
                    // QTextStream()
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QTextStreamWrapper();
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // QTextStream(QByteArray*,QFlags<QIODevice::OpenModeFlag>)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "openMode");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "openMode";
                        else if (Shiboken::Converter< ::QFlags<QIODevice::OpenModeFlag> >::isConvertible(value))
                            pyargs[1] = value;
                        else
                            goto Sbk_QTextStream_Init_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtCore.QTextStream(): got multiple values for keyword argument '%s'", errorArgName);
                        return -1;
                    }
                }
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QByteArray * cppArg0 = Shiboken::Converter<QByteArray * >::toCpp(pyargs[0]);
                QFlags<QIODevice::OpenModeFlag> cppArg1 = pyargs[1] ? Shiboken::Converter<QFlags<QIODevice::OpenModeFlag> >::toCpp(pyargs[1]) : QIODevice::ReadWrite;

                if(!PyErr_Occurred()) {
                    // QTextStream(QByteArray*,QFlags<QIODevice::OpenModeFlag>)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QTextStreamWrapper(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 2: // QTextStream(QIODevice*)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QIODevice * cppArg0 = Shiboken::Converter<QIODevice * >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QTextStream(QIODevice*)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QTextStreamWrapper(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 3: // QTextStream(QString*,QFlags<QIODevice::OpenModeFlag>)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "openMode");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "openMode";
                        else if (Shiboken::Converter< ::QFlags<QIODevice::OpenModeFlag> >::isConvertible(value))
                            pyargs[1] = value;
                        else
                            goto Sbk_QTextStream_Init_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtCore.QTextStream(): got multiple values for keyword argument '%s'", errorArgName);
                        return -1;
                    }
                }
                QString * cppArg0 = Shiboken::Converter<QString * >::toCpp(pyargs[0]);
                QFlags<QIODevice::OpenModeFlag> cppArg1 = pyargs[1] ? Shiboken::Converter<QFlags<QIODevice::OpenModeFlag> >::toCpp(pyargs[1]) : QIODevice::ReadWrite;

                if(!PyErr_Occurred()) {
                    // QTextStream(QString*,QFlags<QIODevice::OpenModeFlag>)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QTextStreamWrapper(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QTextStream >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QTextStream_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QTextStream_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtCore.QByteArray, PySide.QtCore.QIODevice.OpenMode = QIODevice.ReadWrite", "PySide.QtCore.QIODevice", "QString, PySide.QtCore.QIODevice.OpenMode = QIODevice.ReadWrite", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QTextStream", overloads);
        return -1;
}

static PyObject* Sbk_QTextStreamFunc_atEnd(PyObject* self)
{
    QTextStream* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextStream* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // atEnd()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QTextStream*>(cppSelf)->atEnd();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextStreamFunc_autoDetectUnicode(PyObject* self)
{
    QTextStream* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextStream* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // autoDetectUnicode()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QTextStream*>(cppSelf)->autoDetectUnicode();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextStreamFunc_codec(PyObject* self)
{
    QTextStream* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextStream* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // codec()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QTextCodec * cppResult = const_cast<const QTextStream*>(cppSelf)->codec();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QTextCodec * >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextStreamFunc_device(PyObject* self)
{
    QTextStream* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextStream* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // device()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QIODevice * cppResult = const_cast<const QTextStream*>(cppSelf)->device();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QIODevice * >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextStreamFunc_fieldAlignment(PyObject* self)
{
    QTextStream* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextStream* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // fieldAlignment()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QTextStream::FieldAlignment cppResult = const_cast<const QTextStream*>(cppSelf)->fieldAlignment();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QTextStream::FieldAlignment >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextStreamFunc_fieldWidth(PyObject* self)
{
    QTextStream* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextStream* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // fieldWidth()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QTextStream*>(cppSelf)->fieldWidth();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextStreamFunc_flush(PyObject* self)
{
    QTextStream* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextStream* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // flush()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->flush();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QTextStreamFunc_generateByteOrderMark(PyObject* self)
{
    QTextStream* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextStream* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // generateByteOrderMark()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QTextStream*>(cppSelf)->generateByteOrderMark();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextStreamFunc_integerBase(PyObject* self)
{
    QTextStream* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextStream* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // integerBase()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QTextStream*>(cppSelf)->integerBase();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextStreamFunc_locale(PyObject* self)
{
    QTextStream* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextStream* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // locale()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QLocale cppResult = const_cast<const QTextStream*>(cppSelf)->locale();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QLocale >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextStreamFunc_numberFlags(PyObject* self)
{
    QTextStream* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextStream* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // numberFlags()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QFlags<QTextStream::NumberFlag> cppResult = const_cast<const QTextStream*>(cppSelf)->numberFlags();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QFlags<QTextStream::NumberFlag> >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextStreamFunc_padChar(PyObject* self)
{
    QTextStream* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextStream* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // padChar()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QChar cppResult = const_cast<const QTextStream*>(cppSelf)->padChar();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QChar >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextStreamFunc_pos(PyObject* self)
{
    QTextStream* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextStream* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // pos()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                qint64 cppResult = const_cast<const QTextStream*>(cppSelf)->pos();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< long long >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextStreamFunc_read(PyObject* self, PyObject* arg)
{
    QTextStream* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextStream* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: read(qint64)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // read(qint64)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextStreamFunc_read_TypeError;

    // Call function/method
    {
        {
            qint64 cppArg0 = Shiboken::Converter<qint64 >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // read(qint64)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = cppSelf->read(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QTextStreamFunc_read_TypeError:
        const char* overloads[] = {"long long", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QTextStream.read", overloads);
        return 0;
}

static PyObject* Sbk_QTextStreamFunc_readAll(PyObject* self)
{
    QTextStream* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextStream* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // readAll()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = cppSelf->readAll();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextStreamFunc_readLine(PyObject* self, PyObject* args, PyObject* kwds)
{
    QTextStream* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextStream* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QTextStream.readLine(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:readLine", &(pyargs[0])))
        return 0;


    // Overloaded function decisor
    // 0: readLine(qint64)
    if (numArgs == 0) {
        overloadId = 0; // readLine(qint64)
    } else if (SbkNumber_Check(pyargs[0])) {
        overloadId = 0; // readLine(qint64)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextStreamFunc_readLine_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "maxlen");
                if (value) {
                    if (pyargs[0])
                        errorArgName = "maxlen";
                    else if (SbkNumber_Check(value))
                        pyargs[0] = value;
                    else
                        goto Sbk_QTextStreamFunc_readLine_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtCore.QTextStream.readLine(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            qint64 cppArg0 = pyargs[0] ? Shiboken::Converter<qint64 >::toCpp(pyargs[0]) : 0;

            if(!PyErr_Occurred()) {
                // readLine(qint64)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = cppSelf->readLine(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QTextStreamFunc_readLine_TypeError:
        const char* overloads[] = {"long long = 0", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QTextStream.readLine", overloads);
        return 0;
}

static PyObject* Sbk_QTextStreamFunc_realNumberNotation(PyObject* self)
{
    QTextStream* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextStream* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // realNumberNotation()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QTextStream::RealNumberNotation cppResult = const_cast<const QTextStream*>(cppSelf)->realNumberNotation();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QTextStream::RealNumberNotation >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextStreamFunc_realNumberPrecision(PyObject* self)
{
    QTextStream* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextStream* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // realNumberPrecision()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QTextStream*>(cppSelf)->realNumberPrecision();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextStreamFunc_reset(PyObject* self)
{
    QTextStream* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextStream* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // reset()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->reset();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QTextStreamFunc_resetStatus(PyObject* self)
{
    QTextStream* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextStream* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // resetStatus()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->resetStatus();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QTextStreamFunc_seek(PyObject* self, PyObject* arg)
{
    QTextStream* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextStream* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: seek(qint64)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // seek(qint64)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextStreamFunc_seek_TypeError;

    // Call function/method
    {
        {
            qint64 cppArg0 = Shiboken::Converter<qint64 >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // seek(qint64)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->seek(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QTextStreamFunc_seek_TypeError:
        const char* overloads[] = {"long long", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QTextStream.seek", overloads);
        return 0;
}

static PyObject* Sbk_QTextStreamFunc_setAutoDetectUnicode(PyObject* self, PyObject* arg)
{
    QTextStream* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextStream* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setAutoDetectUnicode(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setAutoDetectUnicode(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextStreamFunc_setAutoDetectUnicode_TypeError;

    // Call function/method
    {
        {
            bool cppArg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setAutoDetectUnicode(bool)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setAutoDetectUnicode(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextStreamFunc_setAutoDetectUnicode_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QTextStream.setAutoDetectUnicode", overloads);
        return 0;
}

static PyObject* Sbk_QTextStreamFunc_setCodec(PyObject* self, PyObject* arg)
{
    QTextStream* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextStream* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setCodec(QTextCodec*)
    // 1: setCodec(const char*)
    if (Shiboken::Converter< const char * >::isConvertible(arg)) {
        overloadId = 1; // setCodec(const char*)
    } else if (Shiboken::Converter< ::QTextCodec * >::isConvertible(arg)) {
        overloadId = 0; // setCodec(QTextCodec*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextStreamFunc_setCodec_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // setCodec(QTextCodec*)
            {
                if (!Shiboken::Object::isValid(arg))
                    return 0;
                QTextCodec * cppArg0 = Shiboken::Converter<QTextCodec * >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // setCodec(QTextCodec*)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setCodec(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // setCodec(const char*)
            {
                const char * cppArg0 = Shiboken::Converter<const char * >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // setCodec(const char*)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setCodec(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextStreamFunc_setCodec_TypeError:
        const char* overloads[] = {"PySide.QtCore.QTextCodec", "str", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QTextStream.setCodec", overloads);
        return 0;
}

static PyObject* Sbk_QTextStreamFunc_setDevice(PyObject* self, PyObject* arg)
{
    QTextStream* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextStream* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setDevice(QIODevice*)
    if (Shiboken::Converter< ::QIODevice * >::isConvertible(arg)) {
        overloadId = 0; // setDevice(QIODevice*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextStreamFunc_setDevice_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QIODevice * cppArg0 = Shiboken::Converter<QIODevice * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setDevice(QIODevice*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setDevice(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextStreamFunc_setDevice_TypeError:
        const char* overloads[] = {"PySide.QtCore.QIODevice", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QTextStream.setDevice", overloads);
        return 0;
}

static PyObject* Sbk_QTextStreamFunc_setFieldAlignment(PyObject* self, PyObject* arg)
{
    QTextStream* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextStream* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setFieldAlignment(QTextStream::FieldAlignment)
    if (Shiboken::Converter< ::QTextStream::FieldAlignment >::isConvertible(arg)) {
        overloadId = 0; // setFieldAlignment(QTextStream::FieldAlignment)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextStreamFunc_setFieldAlignment_TypeError;

    // Call function/method
    {
        {
            QTextStream::FieldAlignment cppArg0 = Shiboken::Converter<QTextStream::FieldAlignment >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setFieldAlignment(QTextStream::FieldAlignment)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setFieldAlignment(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextStreamFunc_setFieldAlignment_TypeError:
        const char* overloads[] = {"PySide.QtCore.QTextStream.FieldAlignment", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QTextStream.setFieldAlignment", overloads);
        return 0;
}

static PyObject* Sbk_QTextStreamFunc_setFieldWidth(PyObject* self, PyObject* arg)
{
    QTextStream* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextStream* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setFieldWidth(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setFieldWidth(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextStreamFunc_setFieldWidth_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setFieldWidth(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setFieldWidth(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextStreamFunc_setFieldWidth_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QTextStream.setFieldWidth", overloads);
        return 0;
}

static PyObject* Sbk_QTextStreamFunc_setGenerateByteOrderMark(PyObject* self, PyObject* arg)
{
    QTextStream* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextStream* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setGenerateByteOrderMark(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setGenerateByteOrderMark(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextStreamFunc_setGenerateByteOrderMark_TypeError;

    // Call function/method
    {
        {
            bool cppArg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setGenerateByteOrderMark(bool)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setGenerateByteOrderMark(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextStreamFunc_setGenerateByteOrderMark_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QTextStream.setGenerateByteOrderMark", overloads);
        return 0;
}

static PyObject* Sbk_QTextStreamFunc_setIntegerBase(PyObject* self, PyObject* arg)
{
    QTextStream* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextStream* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setIntegerBase(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setIntegerBase(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextStreamFunc_setIntegerBase_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setIntegerBase(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setIntegerBase(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextStreamFunc_setIntegerBase_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QTextStream.setIntegerBase", overloads);
        return 0;
}

static PyObject* Sbk_QTextStreamFunc_setLocale(PyObject* self, PyObject* arg)
{
    QTextStream* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextStream* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setLocale(QLocale)
    if (Shiboken::Converter< ::QLocale >::isConvertible(arg)) {
        overloadId = 0; // setLocale(QLocale)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextStreamFunc_setLocale_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QLocale cppArg0 = Shiboken::Converter<QLocale >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setLocale(QLocale)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setLocale(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextStreamFunc_setLocale_TypeError:
        const char* overloads[] = {"PySide.QtCore.QLocale", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QTextStream.setLocale", overloads);
        return 0;
}

static PyObject* Sbk_QTextStreamFunc_setNumberFlags(PyObject* self, PyObject* arg)
{
    QTextStream* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextStream* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setNumberFlags(QFlags<QTextStream::NumberFlag>)
    if (Shiboken::Converter< ::QFlags<QTextStream::NumberFlag> >::isConvertible(arg)) {
        overloadId = 0; // setNumberFlags(QFlags<QTextStream::NumberFlag>)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextStreamFunc_setNumberFlags_TypeError;

    // Call function/method
    {
        {
            QFlags<QTextStream::NumberFlag> cppArg0 = Shiboken::Converter<QFlags<QTextStream::NumberFlag> >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setNumberFlags(QFlags<QTextStream::NumberFlag>)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setNumberFlags(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextStreamFunc_setNumberFlags_TypeError:
        const char* overloads[] = {"PySide.QtCore.QTextStream.NumberFlags", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QTextStream.setNumberFlags", overloads);
        return 0;
}

static PyObject* Sbk_QTextStreamFunc_setPadChar(PyObject* self, PyObject* arg)
{
    QTextStream* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextStream* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setPadChar(QChar)
    if (Shiboken::Converter< QChar >::isConvertible(arg)) {
        overloadId = 0; // setPadChar(QChar)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextStreamFunc_setPadChar_TypeError;

    // Call function/method
    {
        {
            QChar cppArg0 = Shiboken::Converter<QChar >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setPadChar(QChar)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setPadChar(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextStreamFunc_setPadChar_TypeError:
        const char* overloads[] = {"QChar", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QTextStream.setPadChar", overloads);
        return 0;
}

static PyObject* Sbk_QTextStreamFunc_setRealNumberNotation(PyObject* self, PyObject* arg)
{
    QTextStream* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextStream* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setRealNumberNotation(QTextStream::RealNumberNotation)
    if (Shiboken::Converter< ::QTextStream::RealNumberNotation >::isConvertible(arg)) {
        overloadId = 0; // setRealNumberNotation(QTextStream::RealNumberNotation)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextStreamFunc_setRealNumberNotation_TypeError;

    // Call function/method
    {
        {
            QTextStream::RealNumberNotation cppArg0 = Shiboken::Converter<QTextStream::RealNumberNotation >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setRealNumberNotation(QTextStream::RealNumberNotation)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setRealNumberNotation(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextStreamFunc_setRealNumberNotation_TypeError:
        const char* overloads[] = {"PySide.QtCore.QTextStream.RealNumberNotation", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QTextStream.setRealNumberNotation", overloads);
        return 0;
}

static PyObject* Sbk_QTextStreamFunc_setRealNumberPrecision(PyObject* self, PyObject* arg)
{
    QTextStream* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextStream* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setRealNumberPrecision(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setRealNumberPrecision(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextStreamFunc_setRealNumberPrecision_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setRealNumberPrecision(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setRealNumberPrecision(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextStreamFunc_setRealNumberPrecision_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QTextStream.setRealNumberPrecision", overloads);
        return 0;
}

static PyObject* Sbk_QTextStreamFunc_setStatus(PyObject* self, PyObject* arg)
{
    QTextStream* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextStream* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setStatus(QTextStream::Status)
    if (Shiboken::Converter< ::QTextStream::Status >::isConvertible(arg)) {
        overloadId = 0; // setStatus(QTextStream::Status)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextStreamFunc_setStatus_TypeError;

    // Call function/method
    {
        {
            QTextStream::Status cppArg0 = Shiboken::Converter<QTextStream::Status >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setStatus(QTextStream::Status)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setStatus(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextStreamFunc_setStatus_TypeError:
        const char* overloads[] = {"PySide.QtCore.QTextStream.Status", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QTextStream.setStatus", overloads);
        return 0;
}

static PyObject* Sbk_QTextStreamFunc_skipWhiteSpace(PyObject* self)
{
    QTextStream* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextStream* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // skipWhiteSpace()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->skipWhiteSpace();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QTextStreamFunc_status(PyObject* self)
{
    QTextStream* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextStream* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // status()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QTextStream::Status cppResult = const_cast<const QTextStream*>(cppSelf)->status();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QTextStream::Status >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextStreamFunc_string(PyObject* self)
{
    QTextStream* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextStream* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // string()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString * cppResult = const_cast<const QTextStream*>(cppSelf)->string();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QString * >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef Sbk_QTextStream_methods[] = {
    {"atEnd", (PyCFunction)Sbk_QTextStreamFunc_atEnd, METH_NOARGS},
    {"autoDetectUnicode", (PyCFunction)Sbk_QTextStreamFunc_autoDetectUnicode, METH_NOARGS},
    {"codec", (PyCFunction)Sbk_QTextStreamFunc_codec, METH_NOARGS},
    {"device", (PyCFunction)Sbk_QTextStreamFunc_device, METH_NOARGS},
    {"fieldAlignment", (PyCFunction)Sbk_QTextStreamFunc_fieldAlignment, METH_NOARGS},
    {"fieldWidth", (PyCFunction)Sbk_QTextStreamFunc_fieldWidth, METH_NOARGS},
    {"flush", (PyCFunction)Sbk_QTextStreamFunc_flush, METH_NOARGS},
    {"generateByteOrderMark", (PyCFunction)Sbk_QTextStreamFunc_generateByteOrderMark, METH_NOARGS},
    {"integerBase", (PyCFunction)Sbk_QTextStreamFunc_integerBase, METH_NOARGS},
    {"locale", (PyCFunction)Sbk_QTextStreamFunc_locale, METH_NOARGS},
    {"numberFlags", (PyCFunction)Sbk_QTextStreamFunc_numberFlags, METH_NOARGS},
    {"padChar", (PyCFunction)Sbk_QTextStreamFunc_padChar, METH_NOARGS},
    {"pos", (PyCFunction)Sbk_QTextStreamFunc_pos, METH_NOARGS},
    {"read", (PyCFunction)Sbk_QTextStreamFunc_read, METH_O},
    {"readAll", (PyCFunction)Sbk_QTextStreamFunc_readAll, METH_NOARGS},
    {"readLine", (PyCFunction)Sbk_QTextStreamFunc_readLine, METH_VARARGS|METH_KEYWORDS},
    {"realNumberNotation", (PyCFunction)Sbk_QTextStreamFunc_realNumberNotation, METH_NOARGS},
    {"realNumberPrecision", (PyCFunction)Sbk_QTextStreamFunc_realNumberPrecision, METH_NOARGS},
    {"reset", (PyCFunction)Sbk_QTextStreamFunc_reset, METH_NOARGS},
    {"resetStatus", (PyCFunction)Sbk_QTextStreamFunc_resetStatus, METH_NOARGS},
    {"seek", (PyCFunction)Sbk_QTextStreamFunc_seek, METH_O},
    {"setAutoDetectUnicode", (PyCFunction)Sbk_QTextStreamFunc_setAutoDetectUnicode, METH_O},
    {"setCodec", (PyCFunction)Sbk_QTextStreamFunc_setCodec, METH_O},
    {"setDevice", (PyCFunction)Sbk_QTextStreamFunc_setDevice, METH_O},
    {"setFieldAlignment", (PyCFunction)Sbk_QTextStreamFunc_setFieldAlignment, METH_O},
    {"setFieldWidth", (PyCFunction)Sbk_QTextStreamFunc_setFieldWidth, METH_O},
    {"setGenerateByteOrderMark", (PyCFunction)Sbk_QTextStreamFunc_setGenerateByteOrderMark, METH_O},
    {"setIntegerBase", (PyCFunction)Sbk_QTextStreamFunc_setIntegerBase, METH_O},
    {"setLocale", (PyCFunction)Sbk_QTextStreamFunc_setLocale, METH_O},
    {"setNumberFlags", (PyCFunction)Sbk_QTextStreamFunc_setNumberFlags, METH_O},
    {"setPadChar", (PyCFunction)Sbk_QTextStreamFunc_setPadChar, METH_O},
    {"setRealNumberNotation", (PyCFunction)Sbk_QTextStreamFunc_setRealNumberNotation, METH_O},
    {"setRealNumberPrecision", (PyCFunction)Sbk_QTextStreamFunc_setRealNumberPrecision, METH_O},
    {"setStatus", (PyCFunction)Sbk_QTextStreamFunc_setStatus, METH_O},
    {"skipWhiteSpace", (PyCFunction)Sbk_QTextStreamFunc_skipWhiteSpace, METH_NOARGS},
    {"status", (PyCFunction)Sbk_QTextStreamFunc_status, METH_NOARGS},
    {"string", (PyCFunction)Sbk_QTextStreamFunc_string, METH_NOARGS},

    {0} // Sentinel
};

static PyObject* Sbk_QTextStreamFunc___lshift__(PyObject* self, PyObject* arg)
{
    QTextStream* cppSelf = 0;
    bool isReverse = Shiboken::Converter< ::QTextStream* >::checkType(arg) && !Shiboken::Converter< ::QTextStream* >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextStream* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && Shiboken::Object::checkType(arg)
        && !PyObject_TypeCheck(arg, self->ob_type)
        && PyObject_HasAttrString(arg, const_cast<char*>("__rlshift__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(arg, const_cast<char*>("__rlshift__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator<<(QChar)
    // 1: operator<<(QTextStream&,QTextStreamManipulator)
    // 2: operator<<(char)
    // 3: operator<<(QByteArray)
    // 4: operator<<(QString)
    // 5: operator<<(const char*)
    // 6: operator<<(double)
    // 7: operator<<(signed long)
    // 8: operator<<(ulong)
    if (!isReverse && PyLong_Check(arg)) {
        overloadId = 8; // operator<<(ulong)
    } else if (!isReverse && PyLong_Check(arg)) {
        overloadId = 7; // operator<<(signed long)
    } else if (!isReverse && PyFloat_Check(arg)) {
        overloadId = 6; // operator<<(double)
    } else if (!isReverse && Shiboken::Converter< const char * >::isConvertible(arg)) {
        overloadId = 5; // operator<<(const char*)
    } else if (!isReverse && Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 4; // operator<<(QString)
    } else if (!isReverse && Shiboken::Converter< ::QByteArray >::isConvertible(arg)) {
        overloadId = 3; // operator<<(QByteArray)
    } else if (!isReverse && Shiboken::Converter< char >::isConvertible(arg)) {
        overloadId = 2; // operator<<(char)
    } else if (!isReverse && Shiboken::Converter< ::QTextStreamManipulator >::isConvertible(arg)) {
        overloadId = 1; // operator<<(QTextStream&,QTextStreamManipulator)
    } else if (!isReverse && Shiboken::Converter< QChar >::isConvertible(arg)) {
        overloadId = 0; // operator<<(QChar)
    }

    if (isReverse && overloadId == -1) {
        PyErr_SetString(PyExc_NotImplementedError, "reverse operator not implemented.");
        return 0;
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextStreamFunc___lshift___TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // operator<<(QChar)
            {
                QChar cppArg0 = Shiboken::Converter<QChar >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // operator<<(QChar)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QTextStream & cppResult = (*cppSelf) << cppArg0;
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QTextStream & >::toPython(cppResult);
                    Shiboken::Object::setParent(self, pyResult);
                }
                break;
            }
            case 1: // operator<<(QTextStream&,QTextStreamManipulator)
            {
                if (!Shiboken::Object::isValid(arg))
                    return 0;
                QTextStreamManipulator cppArg0 = Shiboken::Converter<QTextStreamManipulator >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // operator<<(QTextStream&,QTextStreamManipulator)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QTextStream & cppResult = (*cppSelf) << (cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QTextStream & >::toPython(cppResult);
                    Shiboken::Object::setParent(self, pyResult);
                }
                break;
            }
            case 2: // operator<<(char)
            {
                char cppArg0 = Shiboken::Converter<char >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // operator<<(char)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QTextStream & cppResult = (*cppSelf) << cppArg0;
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QTextStream & >::toPython(cppResult);
                    Shiboken::Object::setParent(self, pyResult);
                }
                break;
            }
            case 3: // operator<<(QByteArray)
            {
                if (!Shiboken::Object::isValid(arg))
                    return 0;
                QByteArray cppArg0 = Shiboken::Converter<QByteArray >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // operator<<(QByteArray)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QTextStream & cppResult = (*cppSelf) << (cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QTextStream & >::toPython(cppResult);
                    Shiboken::Object::setParent(self, pyResult);
                }
                break;
            }
            case 4: // operator<<(QString)
            {
                QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // operator<<(QString)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QTextStream & cppResult = (*cppSelf) << cppArg0;
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QTextStream & >::toPython(cppResult);
                    Shiboken::Object::setParent(self, pyResult);
                }
                break;
            }
            case 5: // operator<<(const char*)
            {
                const char * cppArg0 = Shiboken::Converter<const char * >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // operator<<(const char*)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QTextStream & cppResult = (*cppSelf) << cppArg0;
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QTextStream & >::toPython(cppResult);
                    Shiboken::Object::setParent(self, pyResult);
                }
                break;
            }
            case 6: // operator<<(double)
            {
                double cppArg0 = Shiboken::Converter<double >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // operator<<(double)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QTextStream & cppResult = (*cppSelf) << cppArg0;
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QTextStream & >::toPython(cppResult);
                    Shiboken::Object::setParent(self, pyResult);
                }
                break;
            }
            case 7: // operator<<(signed long)
            {
                signed long cppArg0 = Shiboken::Converter<signed long >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // operator<<(signed long)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QTextStream & cppResult = (*cppSelf) << cppArg0;
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QTextStream & >::toPython(cppResult);
                    Shiboken::Object::setParent(self, pyResult);
                }
                break;
            }
            case 8: // operator<<(ulong)
            {
                unsigned long cppArg0 = Shiboken::Converter<unsigned long >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // operator<<(ulong)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QTextStream & cppResult = (*cppSelf) << cppArg0;
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QTextStream & >::toPython(cppResult);
                    Shiboken::Object::setParent(self, pyResult);
                }
                break;
            }
        }
    }


    } // End of "if (!pyResult)"


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QTextStreamFunc___lshift___TypeError:
        const char* overloads[] = {"QChar", "PySide.QtCore.QTextStreamManipulator", "char", "PySide.QtCore.QByteArray", "QString", "str", "float", "long", "unsigned long", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QTextStream.__lshift__", overloads);
        return 0;
}

static PyObject* Sbk_QTextStreamFunc___rshift__(PyObject* self, PyObject* arg)
{
    QTextStream* cppSelf = 0;
    bool isReverse = Shiboken::Converter< ::QTextStream* >::checkType(arg) && !Shiboken::Converter< ::QTextStream* >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextStream* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && Shiboken::Object::checkType(arg)
        && !PyObject_TypeCheck(arg, self->ob_type)
        && PyObject_HasAttrString(arg, const_cast<char*>("__rrshift__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(arg, const_cast<char*>("__rrshift__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator>>(QByteArray&)
    // 1: operator>>(char&)
    // 2: operator>>(char*)
    // 3: operator>>(double&)
    // 4: operator>>(signed long&)
    // 5: operator>>(ulong&)
    if (!isReverse && PyLong_Check(arg)) {
        overloadId = 5; // operator>>(ulong&)
    } else if (!isReverse && PyLong_Check(arg)) {
        overloadId = 4; // operator>>(signed long&)
    } else if (!isReverse && PyFloat_Check(arg)) {
        overloadId = 3; // operator>>(double&)
    } else if (!isReverse && Shiboken::Converter< char * >::isConvertible(arg)) {
        overloadId = 2; // operator>>(char*)
    } else if (!isReverse && Shiboken::Converter< char & >::isConvertible(arg)) {
        overloadId = 1; // operator>>(char&)
    } else if (!isReverse && Shiboken::Converter< ::QByteArray & >::isConvertible(arg)) {
        overloadId = 0; // operator>>(QByteArray&)
    }

    if (isReverse && overloadId == -1) {
        PyErr_SetString(PyExc_NotImplementedError, "reverse operator not implemented.");
        return 0;
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextStreamFunc___rshift___TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // operator>>(QByteArray&)
            {
                if (!Shiboken::Object::isValid(arg))
                    return 0;
                QByteArray & cppArg0 = Shiboken::Converter<QByteArray & >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // operator>>(QByteArray&)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QTextStream & cppResult = (*cppSelf) >> (cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QTextStream & >::toPython(cppResult);
                    Shiboken::Object::setParent(self, pyResult);
                }
                break;
            }
            case 1: // operator>>(char&)
            {
                char & cppArg0 = Shiboken::Converter<char & >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // operator>>(char&)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QTextStream & cppResult = (*cppSelf) >> cppArg0;
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QTextStream & >::toPython(cppResult);
                    Shiboken::Object::setParent(self, pyResult);
                }
                break;
            }
            case 2: // operator>>(char*)
            {
                char * cppArg0 = Shiboken::Converter<char * >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // operator>>(char*)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QTextStream & cppResult = (*cppSelf) >> cppArg0;
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QTextStream & >::toPython(cppResult);
                    Shiboken::Object::setParent(self, pyResult);
                }
                break;
            }
            case 3: // operator>>(double&)
            {
                double cppArg0 = Shiboken::Converter<double >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // operator>>(double&)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QTextStream & cppResult = (*cppSelf) >> cppArg0;
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QTextStream & >::toPython(cppResult);
                    Shiboken::Object::setParent(self, pyResult);
                }
                break;
            }
            case 4: // operator>>(signed long&)
            {
                signed long cppArg0 = Shiboken::Converter<signed long >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // operator>>(signed long&)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QTextStream & cppResult = (*cppSelf) >> cppArg0;
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QTextStream & >::toPython(cppResult);
                    Shiboken::Object::setParent(self, pyResult);
                }
                break;
            }
            case 5: // operator>>(ulong&)
            {
                unsigned long cppArg0 = Shiboken::Converter<unsigned long >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // operator>>(ulong&)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QTextStream & cppResult = (*cppSelf) >> cppArg0;
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QTextStream & >::toPython(cppResult);
                    Shiboken::Object::setParent(self, pyResult);
                }
                break;
            }
        }
    }


    } // End of "if (!pyResult)"


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QTextStreamFunc___rshift___TypeError:
        const char* overloads[] = {"PySide.QtCore.QByteArray", "str", "str", "double", "signed long", "unsigned long", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QTextStream.__rshift__", overloads);
        return 0;
}

// type has number operators
static PyNumberMethods Sbk_QTextStream_as_number = {
    /*nb_add*/                  (binaryfunc)0,
    /*nb_subtract*/             (binaryfunc)0,
    /*nb_multiply*/             (binaryfunc)0,
    /*nb_divide*/               (binaryfunc)0,
    /*nb_remainder*/            (binaryfunc)0,
    /*nb_divmod*/               0,
    /*nb_power*/                0,
    /*nb_negative*/             (unaryfunc)0,
    /*nb_positive*/             (unaryfunc)0,
    /*nb_absolute*/             0,
    /*nb_nonzero*/              0,
    /*nb_invert*/               (unaryfunc)0,
    /*nb_lshift*/               (binaryfunc)Sbk_QTextStreamFunc___lshift__,
    /*nb_rshift*/               (binaryfunc)Sbk_QTextStreamFunc___rshift__,
    /*nb_and*/                  (binaryfunc)0,
    /*nb_xor*/                  (binaryfunc)0,
    /*nb_or*/                   (binaryfunc)0,
    /*nb_coerce*/               0,
    /*nb_int*/                  0,
    /*nb_long*/                 0,
    /*nb_float*/                0,
    /*nb_oct*/                  0,
    /*nb_hex*/                  0,
    /*nb_inplace_add*/          (binaryfunc)0,
    /*nb_inplace_subtract*/     (binaryfunc)0,
    /*nb_inplace_multiply*/     (binaryfunc)0,
    /*nb_inplace_divide*/       (binaryfunc)0,
    /*nb_inplace_remainder*/    (binaryfunc)0,
    /*nb_inplace_power*/        0,
    /*nb_inplace_lshift*/       (binaryfunc)0,
    /*nb_inplace_rshift*/       (binaryfunc)0,
    /*nb_inplace_and*/          (binaryfunc)0,
    /*nb_inplace_xor*/          (binaryfunc)0,
    /*nb_inplace_or*/           (binaryfunc)0,
    /*nb_floor_divide*/         0,
    /*nb_true_divide*/          (binaryfunc)0,
    /*nb_inplace_floor_divide*/ 0,
    /*nb_inplace_true_divide*/  0,
    /*nb_index*/                0
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QTextStream_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtCore.QTextStream",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        &Sbk_QTextStream_as_number,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QTextStream_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&SbkObject_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QTextStream_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern

PyObject* SbkPySide_QtCore_QTextStream_NumberFlag___and__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QTextStream::NumberFlags >::toPython(
        Shiboken::Converter<QTextStream::NumberFlags>::toCpp(self)
        & Shiboken::Converter< QTextStream::NumberFlags >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtCore_QTextStream_NumberFlag___or__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QTextStream::NumberFlags >::toPython(
        Shiboken::Converter<QTextStream::NumberFlags>::toCpp(self)
        | Shiboken::Converter< QTextStream::NumberFlags >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtCore_QTextStream_NumberFlag___xor__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QTextStream::NumberFlags >::toPython(
        Shiboken::Converter<QTextStream::NumberFlags>::toCpp(self)
        ^ Shiboken::Converter< QTextStream::NumberFlags >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtCore_QTextStream_NumberFlag___invert__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QTextStream::NumberFlags >::toPython(
        ~Shiboken::Converter<QTextStream::NumberFlags >::toCpp(self)
    );
}


static PyNumberMethods SbkPySide_QtCore_QTextStream_NumberFlag_as_number = {
    /*nb_add*/                  0,
    /*nb_subtract*/             0,
    /*nb_multiply*/             0,
    /*nb_divide*/               0,
    /*nb_remainder*/            0,
    /*nb_divmod*/               0,
    /*nb_power*/                0,
    /*nb_negative*/             0,
    /*nb_positive*/             0,
    /*nb_absolute*/             0,
    /*nb_nonzero*/              0,
    /*nb_invert*/               (unaryfunc)SbkPySide_QtCore_QTextStream_NumberFlag___invert__,
    /*nb_lshift*/               0,
    /*nb_rshift*/               0,
    /*nb_and*/                  (binaryfunc)SbkPySide_QtCore_QTextStream_NumberFlag___and__,
    /*nb_xor*/                  (binaryfunc)SbkPySide_QtCore_QTextStream_NumberFlag___xor__,
    /*nb_or*/                   (binaryfunc)SbkPySide_QtCore_QTextStream_NumberFlag___or__,
    /*nb_coerce*/               0,
    /*nb_int*/                  0,
    /*nb_long*/                 0,
    /*nb_float*/                0,
    /*nb_oct*/                  0,
    /*nb_hex*/                  0,
    /*nb_inplace_add*/          0,
    /*nb_inplace_subtract*/     0,
    /*nb_inplace_multiply*/     0,
    /*nb_inplace_divide*/       0,
    /*nb_inplace_remainder*/    0,
    /*nb_inplace_power*/        0,
    /*nb_inplace_lshift*/       0,
    /*nb_inplace_rshift*/       0,
    /*nb_inplace_and*/          0,
    /*nb_inplace_xor*/          0,
    /*nb_inplace_or*/           0,
    /*nb_floor_divide*/         0,
    /*nb_true_divide*/          0,
    /*nb_inplace_floor_divide*/ 0,
    /*nb_inplace_true_divide*/  0,
    /*nb_index*/                0
};


// forward declaration of new function
static PyTypeObject SbkPySide_QtCore_QTextStream_NumberFlags_Type = {
    PyObject_HEAD_INIT(&PyType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "NumberFlags",
    /*tp_basicsize*/        0,
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        &SbkPySide_QtCore_QTextStream_NumberFlag_as_number,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT | Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              PyInt_Type.tp_new,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};



void init_QTextStream(PyObject* module)
{
    SbkPySide_QtCoreTypes[SBK_QTEXTSTREAM_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QTextStream_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QTextStream_Type);
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QTextStream_Type, &Shiboken::callCppDestructor<QTextStream >);
    Py_INCREF((PyObject*)&Sbk_QTextStream_Type); //Incref due the 'PyModule_AddObject' steals the reference.
    if (PyType_Ready((PyTypeObject*)&Sbk_QTextStream_Type) < 0)
        return;

    // Fill type discovery information

    Shiboken::ObjectType::setOriginalName(&Sbk_QTextStream_Type, "QTextStream*");
    PyModule_AddObject(module, "QTextStream",
        ((PyObject*)&Sbk_QTextStream_Type));

    // Initialize enums
    PyObject* enumItem;

    // init enum: RealNumberNotation
    PyTypeObject* SbkPySide_QtCore_QTextStream_RealNumberNotation = Shiboken::Enum::newType("PySide.QtCore.QTextStream.RealNumberNotation");
    SbkPySide_QtCoreTypes[SBK_QTEXTSTREAM_REALNUMBERNOTATION_IDX] = SbkPySide_QtCore_QTextStream_RealNumberNotation;
    if (PyType_Ready(SbkPySide_QtCore_QTextStream_RealNumberNotation) < 0)
        return;
    PyDict_SetItemString(Sbk_QTextStream_Type.super.ht_type.tp_dict,
            "RealNumberNotation",((PyObject*)SbkPySide_QtCore_QTextStream_RealNumberNotation));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QTextStream_RealNumberNotation,(long) QTextStream::SmartNotation, "SmartNotation");
    PyDict_SetItemString(Sbk_QTextStream_Type.super.ht_type.tp_dict,"SmartNotation", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QTextStream_RealNumberNotation->tp_dict,"SmartNotation", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QTextStream_RealNumberNotation,(long) QTextStream::FixedNotation, "FixedNotation");
    PyDict_SetItemString(Sbk_QTextStream_Type.super.ht_type.tp_dict,"FixedNotation", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QTextStream_RealNumberNotation->tp_dict,"FixedNotation", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QTextStream_RealNumberNotation,(long) QTextStream::ScientificNotation, "ScientificNotation");
    PyDict_SetItemString(Sbk_QTextStream_Type.super.ht_type.tp_dict,"ScientificNotation", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QTextStream_RealNumberNotation->tp_dict,"ScientificNotation", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QTextStream::RealNumberNotation");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::RealNumberNotation");
    // end of enum RealNumberNotation

    // init enum: NumberFlag
    PyTypeObject* SbkPySide_QtCore_QTextStream_NumberFlag = Shiboken::Enum::newType("PySide.QtCore.QTextStream.NumberFlag");
    SbkPySide_QtCore_QTextStream_NumberFlag->tp_as_number = &SbkPySide_QtCore_QTextStream_NumberFlag_as_number;
    SbkPySide_QtCoreTypes[SBK_QTEXTSTREAM_NUMBERFLAG_IDX] = SbkPySide_QtCore_QTextStream_NumberFlag;
    if (PyType_Ready(SbkPySide_QtCore_QTextStream_NumberFlag) < 0)
        return;
    PyDict_SetItemString(Sbk_QTextStream_Type.super.ht_type.tp_dict,
            "NumberFlag",((PyObject*)SbkPySide_QtCore_QTextStream_NumberFlag));

    // init flags class: QFlags<QTextStream::NumberFlag>
    SbkPySide_QtCoreTypes[SBK_QFLAGS_QTEXTSTREAM_NUMBERFLAG__IDX] = &SbkPySide_QtCore_QTextStream_NumberFlags_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtCore_QTextStream_NumberFlags_Type) < 0)
        return;
    PyDict_SetItemString(Sbk_QTextStream_Type.super.ht_type.tp_dict,
            "NumberFlags",((PyObject*)&SbkPySide_QtCore_QTextStream_NumberFlags_Type));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QTextStream_NumberFlag,(long) QTextStream::ShowBase, "ShowBase");
    PyDict_SetItemString(Sbk_QTextStream_Type.super.ht_type.tp_dict,"ShowBase", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QTextStream_NumberFlag->tp_dict,"ShowBase", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QTextStream_NumberFlag,(long) QTextStream::ForcePoint, "ForcePoint");
    PyDict_SetItemString(Sbk_QTextStream_Type.super.ht_type.tp_dict,"ForcePoint", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QTextStream_NumberFlag->tp_dict,"ForcePoint", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QTextStream_NumberFlag,(long) QTextStream::ForceSign, "ForceSign");
    PyDict_SetItemString(Sbk_QTextStream_Type.super.ht_type.tp_dict,"ForceSign", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QTextStream_NumberFlag->tp_dict,"ForceSign", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QTextStream_NumberFlag,(long) QTextStream::UppercaseBase, "UppercaseBase");
    PyDict_SetItemString(Sbk_QTextStream_Type.super.ht_type.tp_dict,"UppercaseBase", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QTextStream_NumberFlag->tp_dict,"UppercaseBase", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QTextStream_NumberFlag,(long) QTextStream::UppercaseDigits, "UppercaseDigits");
    PyDict_SetItemString(Sbk_QTextStream_Type.super.ht_type.tp_dict,"UppercaseDigits", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QTextStream_NumberFlag->tp_dict,"UppercaseDigits", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QTextStream::NumberFlag");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::NumberFlag");
    // end of enum NumberFlag

    // init enum: FieldAlignment
    PyTypeObject* SbkPySide_QtCore_QTextStream_FieldAlignment = Shiboken::Enum::newType("PySide.QtCore.QTextStream.FieldAlignment");
    SbkPySide_QtCoreTypes[SBK_QTEXTSTREAM_FIELDALIGNMENT_IDX] = SbkPySide_QtCore_QTextStream_FieldAlignment;
    if (PyType_Ready(SbkPySide_QtCore_QTextStream_FieldAlignment) < 0)
        return;
    PyDict_SetItemString(Sbk_QTextStream_Type.super.ht_type.tp_dict,
            "FieldAlignment",((PyObject*)SbkPySide_QtCore_QTextStream_FieldAlignment));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QTextStream_FieldAlignment,(long) QTextStream::AlignLeft, "AlignLeft");
    PyDict_SetItemString(Sbk_QTextStream_Type.super.ht_type.tp_dict,"AlignLeft", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QTextStream_FieldAlignment->tp_dict,"AlignLeft", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QTextStream_FieldAlignment,(long) QTextStream::AlignRight, "AlignRight");
    PyDict_SetItemString(Sbk_QTextStream_Type.super.ht_type.tp_dict,"AlignRight", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QTextStream_FieldAlignment->tp_dict,"AlignRight", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QTextStream_FieldAlignment,(long) QTextStream::AlignCenter, "AlignCenter");
    PyDict_SetItemString(Sbk_QTextStream_Type.super.ht_type.tp_dict,"AlignCenter", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QTextStream_FieldAlignment->tp_dict,"AlignCenter", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QTextStream_FieldAlignment,(long) QTextStream::AlignAccountingStyle, "AlignAccountingStyle");
    PyDict_SetItemString(Sbk_QTextStream_Type.super.ht_type.tp_dict,"AlignAccountingStyle", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QTextStream_FieldAlignment->tp_dict,"AlignAccountingStyle", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QTextStream::FieldAlignment");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::FieldAlignment");
    // end of enum FieldAlignment

    // init enum: Status
    PyTypeObject* SbkPySide_QtCore_QTextStream_Status = Shiboken::Enum::newType("PySide.QtCore.QTextStream.Status");
    SbkPySide_QtCoreTypes[SBK_QTEXTSTREAM_STATUS_IDX] = SbkPySide_QtCore_QTextStream_Status;
    if (PyType_Ready(SbkPySide_QtCore_QTextStream_Status) < 0)
        return;
    PyDict_SetItemString(Sbk_QTextStream_Type.super.ht_type.tp_dict,
            "Status",((PyObject*)SbkPySide_QtCore_QTextStream_Status));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QTextStream_Status,(long) QTextStream::Ok, "Ok");
    PyDict_SetItemString(Sbk_QTextStream_Type.super.ht_type.tp_dict,"Ok", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QTextStream_Status->tp_dict,"Ok", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QTextStream_Status,(long) QTextStream::ReadPastEnd, "ReadPastEnd");
    PyDict_SetItemString(Sbk_QTextStream_Type.super.ht_type.tp_dict,"ReadPastEnd", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QTextStream_Status->tp_dict,"ReadPastEnd", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QTextStream_Status,(long) QTextStream::ReadCorruptData, "ReadCorruptData");
    PyDict_SetItemString(Sbk_QTextStream_Type.super.ht_type.tp_dict,"ReadCorruptData", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QTextStream_Status->tp_dict,"ReadCorruptData", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QTextStream::Status");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::Status");
    // end of enum Status


    Shiboken::TypeResolver::createObjectTypeResolver<QTextStream >("QTextStream*");
    Shiboken::TypeResolver::createObjectTypeResolver<QTextStream >(typeid(QTextStream).name());
    Shiboken::TypeResolver::createObjectTypeResolver<QTextStream >(typeid(QTextStreamWrapper).name());
    qRegisterMetaType< ::QTextStream* >("QTextStream*");
    qRegisterMetaType< ::QTextStream::RealNumberNotation >("QTextStream::RealNumberNotation");
    qRegisterMetaType< ::QTextStream::NumberFlag >("QTextStream::NumberFlag");
    qRegisterMetaType< ::QTextStream::NumberFlags >("QTextStream::NumberFlags");
    qRegisterMetaType< ::QTextStream::FieldAlignment >("QTextStream::FieldAlignment");
    qRegisterMetaType< ::QTextStream::Status >("QTextStream::Status");
}

