/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include "pyside_qtdeclarative_python.h"

#include "qdeclarativecomponent_wrapper.h"

// Extra includes
#include <QList>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qdeclarativecomponent.h>
#include <qdeclarativecontext.h>
#include <qdeclarativeengine.h>
#include <qdeclarativeerror.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qthread.h>
#include <qurl.h>


// Native ---------------------------------------------------------

QDeclarativeComponentWrapper::QDeclarativeComponentWrapper(QDeclarativeEngine * arg__1, QObject * parent) : QDeclarativeComponent(arg__1, parent) {
    // ... middle
}

QDeclarativeComponentWrapper::QDeclarativeComponentWrapper(QDeclarativeEngine * arg__1, const QString & fileName, QObject * parent) : QDeclarativeComponent(arg__1, fileName, parent) {
    // ... middle
}

QDeclarativeComponentWrapper::QDeclarativeComponentWrapper(QDeclarativeEngine * arg__1, const QUrl & url, QObject * parent) : QDeclarativeComponent(arg__1, url, parent) {
    // ... middle
}

QObject * QDeclarativeComponentWrapper::beginCreate(QDeclarativeContext * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return 0;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "beginCreate"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QDeclarativeComponent::beginCreate(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QDeclarativeContext * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return 0;
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QObject * >::isConvertible(pyResult);
    typeIsValid = typeIsValid || (pyResult == Py_None);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QDeclarativeComponent.beginCreate", Shiboken::SbkType<QObject >()->tp_name, pyResult->ob_type->tp_name);
        return 0;
    }
    QObject * cppResult(Shiboken::Converter< ::QObject * >::toCpp(pyResult));
    return cppResult;
}

void QDeclarativeComponentWrapper::childEvent(QChildEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "childEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::childEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QChildEvent * >::toPython(arg__1)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QDeclarativeComponentWrapper::completeCreate()
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "completeCreate"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QDeclarativeComponent::completeCreate();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QDeclarativeComponentWrapper::connectNotify(const char * signal)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "connectNotify"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::connectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

QObject * QDeclarativeComponentWrapper::create(QDeclarativeContext * context)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return 0;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "create"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QDeclarativeComponent::create(context);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QDeclarativeContext * >::toPython(context)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return 0;
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QObject * >::isConvertible(pyResult);
    typeIsValid = typeIsValid || (pyResult == Py_None);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QDeclarativeComponent.create", Shiboken::SbkType<QObject >()->tp_name, pyResult->ob_type->tp_name);
        return 0;
    }
    QObject * cppResult(Shiboken::Converter< ::QObject * >::toCpp(pyResult));
    return cppResult;
}

void QDeclarativeComponentWrapper::customEvent(QEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "customEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::customEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QEvent * >::toPython(arg__1)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QDeclarativeComponentWrapper::disconnectNotify(const char * signal)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "disconnectNotify"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::disconnectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

bool QDeclarativeComponentWrapper::event(QEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return bool(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "event"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::event(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QEvent * >::toPython(arg__1)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QDeclarativeComponent.event", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
    return cppResult;
}

bool QDeclarativeComponentWrapper::eventFilter(QObject * arg__1, QEvent * arg__2)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return bool(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "eventFilter"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::eventFilter(arg__1, arg__2);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter< ::QObject * >::toPython(arg__1),
        Shiboken::Converter< ::QEvent * >::toPython(arg__2)
    ));
    bool invalidadeArg2 = PyTuple_GET_ITEM(pyargs, 1)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QDeclarativeComponent.eventFilter", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    if (invalidadeArg2)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 1));
    return cppResult;
}

void QDeclarativeComponentWrapper::timerEvent(QTimerEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "timerEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::timerEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QTimerEvent * >::toPython(arg__1)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

const QMetaObject* QDeclarativeComponentWrapper::metaObject() const
{
    SbkObject* pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    return reinterpret_cast<QMetaObject*>(Shiboken::Object::getTypeUserData(pySelf));
}

int QDeclarativeComponentWrapper::qt_metacall(QMetaObject::Call call, int id, void** args)
{
    int result = QDeclarativeComponent::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

QDeclarativeComponentWrapper::~QDeclarativeComponentWrapper()
{
    SbkObject* wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QDeclarativeComponent_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QDeclarativeComponent >()))
        return -1;

    QDeclarativeComponentWrapper* cptr = 0;
    int overloadId = -1;
    const char* argNames[] = {"parent"};
    const QMetaObject* metaObject;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths
    if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtDeclarative.QDeclarativeComponent(): not enough arguments");
        return -1;
    }

    if (!PyArg_ParseTuple(args, "|OOO:QDeclarativeComponent", &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return -1;

    // Overloaded function decisor
    // 0: QDeclarativeComponent(QDeclarativeEngine*,QObject*)
    // 1: QDeclarativeComponent(QDeclarativeEngine*,QString,QObject*)
    // 2: QDeclarativeComponent(QDeclarativeEngine*,QUrl,QObject*)
    if (Shiboken::Converter< ::QDeclarativeEngine * >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // QDeclarativeComponent(QDeclarativeEngine*,QObject*)
        } else if (Shiboken::Converter< ::QObject * >::isConvertible(pyargs[1])) {
            overloadId = 0; // QDeclarativeComponent(QDeclarativeEngine*,QObject*)
        } else if (Shiboken::Converter< QString >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 1; // QDeclarativeComponent(QDeclarativeEngine*,QString,QObject*)
            } else if (Shiboken::Converter< ::QObject * >::isConvertible(pyargs[2])) {
                overloadId = 1; // QDeclarativeComponent(QDeclarativeEngine*,QString,QObject*)
            }
        } else if (Shiboken::Converter< ::QUrl >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 2; // QDeclarativeComponent(QDeclarativeEngine*,QUrl,QObject*)
            } else if (Shiboken::Converter< ::QObject * >::isConvertible(pyargs[2])) {
                overloadId = 2; // QDeclarativeComponent(QDeclarativeEngine*,QUrl,QObject*)
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QDeclarativeComponent_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QDeclarativeComponent(QDeclarativeEngine*,QObject*)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "parent");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "parent";
                        else if (Shiboken::Converter< ::QObject * >::isConvertible(value))
                            pyargs[1] = value;
                        else
                            goto Sbk_QDeclarativeComponent_Init_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtDeclarative.QDeclarativeComponent(): got multiple values for keyword argument '%s'", errorArgName);
                        return -1;
                    }
                }
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QDeclarativeEngine * cppArg0 = Shiboken::Converter<QDeclarativeEngine * >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return -1;
                QObject * cppArg1 = pyargs[1] ? Shiboken::Converter<QObject * >::toCpp(pyargs[1]) : 0;

                if(!PyErr_Occurred()) {
                    // QDeclarativeComponent(QDeclarativeEngine*,QObject*)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QDeclarativeComponentWrapper(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    Shiboken::Object::setParent(pyargs[1], self);
                }
                break;
            }
            case 1: // QDeclarativeComponent(QDeclarativeEngine*,QString,QObject*)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "parent");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "parent";
                        else if (Shiboken::Converter< ::QObject * >::isConvertible(value))
                            pyargs[2] = value;
                        else
                            goto Sbk_QDeclarativeComponent_Init_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtDeclarative.QDeclarativeComponent(): got multiple values for keyword argument '%s'", errorArgName);
                        return -1;
                    }
                }
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QDeclarativeEngine * cppArg0 = Shiboken::Converter<QDeclarativeEngine * >::toCpp(pyargs[0]);
                QString cppArg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);
                if (!Shiboken::Object::isValid(pyargs[2]))
                    return -1;
                QObject * cppArg2 = pyargs[2] ? Shiboken::Converter<QObject * >::toCpp(pyargs[2]) : 0;

                if(!PyErr_Occurred()) {
                    // QDeclarativeComponent(QDeclarativeEngine*,QString,QObject*)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QDeclarativeComponentWrapper(cppArg0, cppArg1, cppArg2);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    Shiboken::Object::setParent(pyargs[2], self);
                }
                break;
            }
            case 2: // QDeclarativeComponent(QDeclarativeEngine*,QUrl,QObject*)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "parent");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "parent";
                        else if (Shiboken::Converter< ::QObject * >::isConvertible(value))
                            pyargs[2] = value;
                        else
                            goto Sbk_QDeclarativeComponent_Init_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtDeclarative.QDeclarativeComponent(): got multiple values for keyword argument '%s'", errorArgName);
                        return -1;
                    }
                }
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QDeclarativeEngine * cppArg0 = Shiboken::Converter<QDeclarativeEngine * >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return -1;
                QUrl cppArg1 = Shiboken::Converter<QUrl >::toCpp(pyargs[1]);
                if (!Shiboken::Object::isValid(pyargs[2]))
                    return -1;
                QObject * cppArg2 = pyargs[2] ? Shiboken::Converter<QObject * >::toCpp(pyargs[2]) : 0;

                if(!PyErr_Occurred()) {
                    // QDeclarativeComponent(QDeclarativeEngine*,QUrl,QObject*)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QDeclarativeComponentWrapper(cppArg0, cppArg1, cppArg2);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    Shiboken::Object::setParent(pyargs[2], self);
                }
                break;
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QDeclarativeComponent >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QDeclarativeComponent_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    metaObject = cptr->metaObject(); // <- init python qt properties
    if (kwds && !PySide::fillQtProperties(self, metaObject, kwds, argNames, 1))
        return -1;


    return 1;

    Sbk_QDeclarativeComponent_Init_TypeError:
        const char* overloads[] = {"PySide.QtDeclarative.QDeclarativeEngine, PySide.QtCore.QObject = None", "PySide.QtDeclarative.QDeclarativeEngine, QString, PySide.QtCore.QObject = None", "PySide.QtDeclarative.QDeclarativeEngine, PySide.QtCore.QUrl, PySide.QtCore.QObject = None", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtDeclarative.QDeclarativeComponent", overloads);
        return -1;
}

static PyObject* Sbk_QDeclarativeComponentFunc_beginCreate(PyObject* self, PyObject* arg)
{
    QDeclarativeComponent* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDeclarativeComponent* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: beginCreate(QDeclarativeContext*)
    if (Shiboken::Converter< ::QDeclarativeContext * >::isConvertible(arg)) {
        overloadId = 0; // beginCreate(QDeclarativeContext*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QDeclarativeComponentFunc_beginCreate_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QDeclarativeContext * cppArg0 = Shiboken::Converter<QDeclarativeContext * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // beginCreate(QDeclarativeContext*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QObject * cppResult = (Shiboken::Object::isUserType(self) ? cppSelf->::QDeclarativeComponent::beginCreate(cppArg0) : cppSelf->beginCreate(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QObject * >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QDeclarativeComponentFunc_beginCreate_TypeError:
        const char* overloads[] = {"PySide.QtDeclarative.QDeclarativeContext", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtDeclarative.QDeclarativeComponent.beginCreate", overloads);
        return 0;
}

static PyObject* Sbk_QDeclarativeComponentFunc_completeCreate(PyObject* self)
{
    QDeclarativeComponent* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDeclarativeComponent* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // completeCreate()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QDeclarativeComponent::completeCreate() : cppSelf->completeCreate());
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QDeclarativeComponentFunc_create(PyObject* self, PyObject* args, PyObject* kwds)
{
    QDeclarativeComponent* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDeclarativeComponent* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtDeclarative.QDeclarativeComponent.create(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:create", &(pyargs[0])))
        return 0;


    // Overloaded function decisor
    // 0: create(QDeclarativeContext*)
    if (numArgs == 0) {
        overloadId = 0; // create(QDeclarativeContext*)
    } else if (Shiboken::Converter< ::QDeclarativeContext * >::isConvertible(pyargs[0])) {
        overloadId = 0; // create(QDeclarativeContext*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QDeclarativeComponentFunc_create_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "context");
                if (value) {
                    if (pyargs[0])
                        errorArgName = "context";
                    else if (Shiboken::Converter< ::QDeclarativeContext * >::isConvertible(value))
                        pyargs[0] = value;
                    else
                        goto Sbk_QDeclarativeComponentFunc_create_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtDeclarative.QDeclarativeComponent.create(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QDeclarativeContext * cppArg0 = pyargs[0] ? Shiboken::Converter<QDeclarativeContext * >::toCpp(pyargs[0]) : 0;

            if(!PyErr_Occurred()) {
                // create(QDeclarativeContext*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QObject * cppResult = (Shiboken::Object::isUserType(self) ? cppSelf->::QDeclarativeComponent::create(cppArg0) : cppSelf->create(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QObject * >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QDeclarativeComponentFunc_create_TypeError:
        const char* overloads[] = {"PySide.QtDeclarative.QDeclarativeContext = None", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtDeclarative.QDeclarativeComponent.create", overloads);
        return 0;
}

static PyObject* Sbk_QDeclarativeComponentFunc_creationContext(PyObject* self)
{
    QDeclarativeComponent* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDeclarativeComponent* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // creationContext()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QDeclarativeContext * cppResult = const_cast<const QDeclarativeComponent*>(cppSelf)->creationContext();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QDeclarativeContext * >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QDeclarativeComponentFunc_errorString(PyObject* self)
{
    QDeclarativeComponent* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDeclarativeComponent* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // errorString()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = const_cast<const QDeclarativeComponent*>(cppSelf)->errorString();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QDeclarativeComponentFunc_errors(PyObject* self)
{
    QDeclarativeComponent* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDeclarativeComponent* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // errors()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QList<QDeclarativeError > cppResult = const_cast<const QDeclarativeComponent*>(cppSelf)->errors();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QList<QDeclarativeError > >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QDeclarativeComponentFunc_isError(PyObject* self)
{
    QDeclarativeComponent* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDeclarativeComponent* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isError()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QDeclarativeComponent*>(cppSelf)->isError();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QDeclarativeComponentFunc_isLoading(PyObject* self)
{
    QDeclarativeComponent* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDeclarativeComponent* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isLoading()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QDeclarativeComponent*>(cppSelf)->isLoading();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QDeclarativeComponentFunc_isNull(PyObject* self)
{
    QDeclarativeComponent* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDeclarativeComponent* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isNull()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QDeclarativeComponent*>(cppSelf)->isNull();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QDeclarativeComponentFunc_isReady(PyObject* self)
{
    QDeclarativeComponent* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDeclarativeComponent* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isReady()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QDeclarativeComponent*>(cppSelf)->isReady();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QDeclarativeComponentFunc_loadUrl(PyObject* self, PyObject* arg)
{
    QDeclarativeComponent* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDeclarativeComponent* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: loadUrl(QUrl)
    if (Shiboken::Converter< ::QUrl >::isConvertible(arg)) {
        overloadId = 0; // loadUrl(QUrl)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QDeclarativeComponentFunc_loadUrl_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QUrl cppArg0 = Shiboken::Converter<QUrl >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // loadUrl(QUrl)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->loadUrl(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QDeclarativeComponentFunc_loadUrl_TypeError:
        const char* overloads[] = {"PySide.QtCore.QUrl", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtDeclarative.QDeclarativeComponent.loadUrl", overloads);
        return 0;
}

static PyObject* Sbk_QDeclarativeComponentFunc_progress(PyObject* self)
{
    QDeclarativeComponent* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDeclarativeComponent* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // progress()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                qreal cppResult = const_cast<const QDeclarativeComponent*>(cppSelf)->progress();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< double >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QDeclarativeComponentFunc_setData(PyObject* self, PyObject* args)
{
    QDeclarativeComponent* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDeclarativeComponent* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setData", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setData(QByteArray,QUrl)
    if (numArgs == 2 && Shiboken::Converter< ::QByteArray >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QUrl >::isConvertible(pyargs[1])) {
        overloadId = 0; // setData(QByteArray,QUrl)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QDeclarativeComponentFunc_setData_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QByteArray cppArg0 = Shiboken::Converter<QByteArray >::toCpp(pyargs[0]);
            if (!Shiboken::Object::isValid(pyargs[1]))
                return 0;
            QUrl cppArg1 = Shiboken::Converter<QUrl >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // setData(QByteArray,QUrl)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setData(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QDeclarativeComponentFunc_setData_TypeError:
        const char* overloads[] = {"PySide.QtCore.QByteArray, PySide.QtCore.QUrl", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtDeclarative.QDeclarativeComponent.setData", overloads);
        return 0;
}

static PyObject* Sbk_QDeclarativeComponentFunc_status(PyObject* self)
{
    QDeclarativeComponent* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDeclarativeComponent* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // status()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QDeclarativeComponent::Status cppResult = const_cast<const QDeclarativeComponent*>(cppSelf)->status();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QDeclarativeComponent::Status >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QDeclarativeComponentFunc_url(PyObject* self)
{
    QDeclarativeComponent* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDeclarativeComponent* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // url()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QUrl cppResult = const_cast<const QDeclarativeComponent*>(cppSelf)->url();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QUrl >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef Sbk_QDeclarativeComponent_methods[] = {
    {"beginCreate", (PyCFunction)Sbk_QDeclarativeComponentFunc_beginCreate, METH_O},
    {"completeCreate", (PyCFunction)Sbk_QDeclarativeComponentFunc_completeCreate, METH_NOARGS},
    {"create", (PyCFunction)Sbk_QDeclarativeComponentFunc_create, METH_VARARGS|METH_KEYWORDS},
    {"creationContext", (PyCFunction)Sbk_QDeclarativeComponentFunc_creationContext, METH_NOARGS},
    {"errorString", (PyCFunction)Sbk_QDeclarativeComponentFunc_errorString, METH_NOARGS},
    {"errors", (PyCFunction)Sbk_QDeclarativeComponentFunc_errors, METH_NOARGS},
    {"isError", (PyCFunction)Sbk_QDeclarativeComponentFunc_isError, METH_NOARGS},
    {"isLoading", (PyCFunction)Sbk_QDeclarativeComponentFunc_isLoading, METH_NOARGS},
    {"isNull", (PyCFunction)Sbk_QDeclarativeComponentFunc_isNull, METH_NOARGS},
    {"isReady", (PyCFunction)Sbk_QDeclarativeComponentFunc_isReady, METH_NOARGS},
    {"loadUrl", (PyCFunction)Sbk_QDeclarativeComponentFunc_loadUrl, METH_O},
    {"progress", (PyCFunction)Sbk_QDeclarativeComponentFunc_progress, METH_NOARGS},
    {"setData", (PyCFunction)Sbk_QDeclarativeComponentFunc_setData, METH_VARARGS},
    {"status", (PyCFunction)Sbk_QDeclarativeComponentFunc_status, METH_NOARGS},
    {"url", (PyCFunction)Sbk_QDeclarativeComponentFunc_url, METH_NOARGS},

    {0} // Sentinel
};

static int Sbk_QDeclarativeComponent___nb_bool(PyObject* pyObj)
{
    if (!Shiboken::Object::isValid(pyObj))
        return -1;
    const ::QDeclarativeComponent* cppSelf = Shiboken::Converter< ::QDeclarativeComponent*>::toCpp(pyObj);
    int result;
    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
    result = !cppSelf->isNull();
    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
    return result;
}

// type has number operators
static PyNumberMethods Sbk_QDeclarativeComponent_as_number = {
    /*nb_add*/                  (binaryfunc)0,
    /*nb_subtract*/             (binaryfunc)0,
    /*nb_multiply*/             (binaryfunc)0,
    /*nb_divide*/               (binaryfunc)0,
    /*nb_remainder*/            (binaryfunc)0,
    /*nb_divmod*/               0,
    /*nb_power*/                0,
    /*nb_negative*/             (unaryfunc)0,
    /*nb_positive*/             (unaryfunc)0,
    /*nb_absolute*/             0,
    /*nb_nonzero*/              Sbk_QDeclarativeComponent___nb_bool,
    /*nb_invert*/               (unaryfunc)0,
    /*nb_lshift*/               (binaryfunc)0,
    /*nb_rshift*/               (binaryfunc)0,
    /*nb_and*/                  (binaryfunc)0,
    /*nb_xor*/                  (binaryfunc)0,
    /*nb_or*/                   (binaryfunc)0,
    /*nb_coerce*/               0,
    /*nb_int*/                  0,
    /*nb_long*/                 0,
    /*nb_float*/                0,
    /*nb_oct*/                  0,
    /*nb_hex*/                  0,
    /*nb_inplace_add*/          (binaryfunc)0,
    /*nb_inplace_subtract*/     (binaryfunc)0,
    /*nb_inplace_multiply*/     (binaryfunc)0,
    /*nb_inplace_divide*/       (binaryfunc)0,
    /*nb_inplace_remainder*/    (binaryfunc)0,
    /*nb_inplace_power*/        0,
    /*nb_inplace_lshift*/       (binaryfunc)0,
    /*nb_inplace_rshift*/       (binaryfunc)0,
    /*nb_inplace_and*/          (binaryfunc)0,
    /*nb_inplace_xor*/          (binaryfunc)0,
    /*nb_inplace_or*/           (binaryfunc)0,
    /*nb_floor_divide*/         0,
    /*nb_true_divide*/          (binaryfunc)0,
    /*nb_inplace_floor_divide*/ 0,
    /*nb_inplace_true_divide*/  0,
    /*nb_index*/                0
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QDeclarativeComponent_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtDeclarative.QDeclarativeComponent",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        &Sbk_QDeclarativeComponent_as_number,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QDeclarativeComponent_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QDeclarativeComponent_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern

static SbkObjectType* Sbk_QDeclarativeComponent_typeDiscovery(void* cptr, SbkObjectType* instanceType)
{
    if (instanceType == reinterpret_cast<SbkObjectType*>(Shiboken::SbkType<QObject >()) && dynamic_cast<QDeclarativeComponent*>(reinterpret_cast<QObject*>(cptr)))
        return &Sbk_QDeclarativeComponent_Type;
    return 0;
}


void init_QDeclarativeComponent(PyObject* module)
{
    SbkPySide_QtDeclarativeTypes[SBK_QDECLARATIVECOMPONENT_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QDeclarativeComponent_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QDeclarativeComponent_Type);
    Shiboken::ObjectType::setSubTypeInitHook(&Sbk_QDeclarativeComponent_Type, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(&Sbk_QDeclarativeComponent_Type, &QDeclarativeComponent::staticMetaObject);    Sbk_QDeclarativeComponent_Type.super.ht_type.tp_base = SbkPySide_QtCoreTypes[SBK_QOBJECT_IDX];
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QDeclarativeComponent_Type, &Shiboken::callCppDestructor<QDeclarativeComponent >);
    Py_INCREF((PyObject*)&Sbk_QDeclarativeComponent_Type); //Incref due the 'PyModule_AddObject' steals the reference.
    if (PyType_Ready((PyTypeObject*)&Sbk_QDeclarativeComponent_Type) < 0)
        return;

    // Fill type discovery information
    Shiboken::ObjectType::setTypeDiscoveryFunction(&Sbk_QDeclarativeComponent_Type, &Sbk_QDeclarativeComponent_typeDiscovery);
    Shiboken::BindingManager& bm = Shiboken::BindingManager::instance();
    bm.addClassInheritance(reinterpret_cast<SbkObjectType*>(SbkPySide_QtCoreTypes[SBK_QOBJECT_IDX]), &Sbk_QDeclarativeComponent_Type);

    Shiboken::ObjectType::setOriginalName(&Sbk_QDeclarativeComponent_Type, "QDeclarativeComponent*");
    PyModule_AddObject(module, "QDeclarativeComponent",
        ((PyObject*)&Sbk_QDeclarativeComponent_Type));

    // Initialize enums
    PyObject* enumItem;

    // init enum: Status
    PyTypeObject* SbkPySide_QtDeclarative_QDeclarativeComponent_Status = Shiboken::Enum::newType("PySide.QtDeclarative.QDeclarativeComponent.Status");
    SbkPySide_QtDeclarativeTypes[SBK_QDECLARATIVECOMPONENT_STATUS_IDX] = SbkPySide_QtDeclarative_QDeclarativeComponent_Status;
    if (PyType_Ready(SbkPySide_QtDeclarative_QDeclarativeComponent_Status) < 0)
        return;
    PyDict_SetItemString(Sbk_QDeclarativeComponent_Type.super.ht_type.tp_dict,
            "Status",((PyObject*)SbkPySide_QtDeclarative_QDeclarativeComponent_Status));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtDeclarative_QDeclarativeComponent_Status,(long) QDeclarativeComponent::Null, "Null");
    PyDict_SetItemString(Sbk_QDeclarativeComponent_Type.super.ht_type.tp_dict,"Null", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtDeclarative_QDeclarativeComponent_Status->tp_dict,"Null", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtDeclarative_QDeclarativeComponent_Status,(long) QDeclarativeComponent::Ready, "Ready");
    PyDict_SetItemString(Sbk_QDeclarativeComponent_Type.super.ht_type.tp_dict,"Ready", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtDeclarative_QDeclarativeComponent_Status->tp_dict,"Ready", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtDeclarative_QDeclarativeComponent_Status,(long) QDeclarativeComponent::Loading, "Loading");
    PyDict_SetItemString(Sbk_QDeclarativeComponent_Type.super.ht_type.tp_dict,"Loading", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtDeclarative_QDeclarativeComponent_Status->tp_dict,"Loading", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtDeclarative_QDeclarativeComponent_Status,(long) QDeclarativeComponent::Error, "Error");
    PyDict_SetItemString(Sbk_QDeclarativeComponent_Type.super.ht_type.tp_dict,"Error", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtDeclarative_QDeclarativeComponent_Status->tp_dict,"Error", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QDeclarativeComponent::Status");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::Status");
    // end of enum Status

    // Initialize signals
    PySideSignal* signal_item;

    signal_item = PySide::Signal::newObject("progressChanged", "qreal", NULL);
    PySide::Signal::addSignalToWrapper(&Sbk_QDeclarativeComponent_Type, "progressChanged", signal_item);
    Py_DECREF((PyObject*) signal_item);
    signal_item = PySide::Signal::newObject("statusChanged", "QDeclarativeComponent::Status", NULL);
    PySide::Signal::addSignalToWrapper(&Sbk_QDeclarativeComponent_Type, "statusChanged", signal_item);
    Py_DECREF((PyObject*) signal_item);


    Shiboken::TypeResolver::createObjectTypeResolver<QDeclarativeComponent >("QDeclarativeComponent*");
    Shiboken::TypeResolver::createObjectTypeResolver<QDeclarativeComponent >(typeid(QDeclarativeComponent).name());
    Shiboken::TypeResolver::createObjectTypeResolver<QDeclarativeComponent >(typeid(QDeclarativeComponentWrapper).name());
    qRegisterMetaType< ::QDeclarativeComponent* >("QDeclarativeComponent*");
    qRegisterMetaType< ::QDeclarativeComponent::Status >("QDeclarativeComponent::Status");
}

