/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtdeclarative_python.h"

#include "qdeclarativenetworkaccessmanagerfactory_wrapper.h"

// Extra includes
#include <qnetworkaccessmanager.h>
#include <qobject.h>


// Native ---------------------------------------------------------

QDeclarativeNetworkAccessManagerFactoryWrapper::QDeclarativeNetworkAccessManagerFactoryWrapper() : QDeclarativeNetworkAccessManagerFactory() {
    // ... middle
}

QNetworkAccessManager * QDeclarativeNetworkAccessManagerFactoryWrapper::create(QObject * parent)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return 0;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "create"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QDeclarativeNetworkAccessManagerFactory.create()' not implemented.");
        return 0;
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QObject * >::toPython(parent)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return 0;
    }
    bool invalidadeArg0 = pyResult->ob_refcnt == 1;
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QNetworkAccessManager * >::isConvertible(pyResult);
    typeIsValid = typeIsValid || (pyResult == Py_None);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QDeclarativeNetworkAccessManagerFactory.create", Shiboken::SbkType<QNetworkAccessManager >()->tp_name, pyResult->ob_type->tp_name);
        return 0;
    }
    QNetworkAccessManager * cppResult(Shiboken::Converter< ::QNetworkAccessManager * >::toCpp(pyResult));
    if (invalidadeArg0)
        Shiboken::Object::releaseOwnership(pyResult.object());
    return cppResult;
}

QDeclarativeNetworkAccessManagerFactoryWrapper::~QDeclarativeNetworkAccessManagerFactoryWrapper()
{
    SbkObject* wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QDeclarativeNetworkAccessManagerFactory_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QDeclarativeNetworkAccessManagerFactory >()))
        return -1;

    QDeclarativeNetworkAccessManagerFactoryWrapper* cptr = 0;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);
    SbkObjectType* type = reinterpret_cast<SbkObjectType*>(self->ob_type);
    SbkObjectType* myType = reinterpret_cast<SbkObjectType*>(SbkPySide_QtDeclarativeTypes[SBK_QDECLARATIVENETWORKACCESSMANAGERFACTORY_IDX]);
    if (type == myType) {
        PyErr_SetString(PyExc_NotImplementedError,
            "'QDeclarativeNetworkAccessManagerFactory' represents a C++ abstract class and cannot be instantiated");
        return -1;
    }


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // QDeclarativeNetworkAccessManagerFactory()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new QDeclarativeNetworkAccessManagerFactoryWrapper();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QDeclarativeNetworkAccessManagerFactory >(), cptr)) {
        delete cptr;
        return -1;
    }
    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject* Sbk_QDeclarativeNetworkAccessManagerFactoryFunc_create(PyObject* self, PyObject* arg)
{
    QDeclarativeNetworkAccessManagerFactory* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDeclarativeNetworkAccessManagerFactory* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: create(QObject*)
    if (Shiboken::Converter< ::QObject * >::isConvertible(arg)) {
        overloadId = 0; // create(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QDeclarativeNetworkAccessManagerFactoryFunc_create_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QObject * cppArg0 = Shiboken::Converter<QObject * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // create(QObject*)
                if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject*>(self))) {
                    PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QDeclarativeNetworkAccessManagerFactory.create()' not implemented.");
                    return 0;
                }
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QNetworkAccessManager * cppResult = cppSelf->create(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QNetworkAccessManager * >::toPython(cppResult);

                // Ownership transferences.
                Shiboken::Object::invalidate(pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QDeclarativeNetworkAccessManagerFactoryFunc_create_TypeError:
        const char* overloads[] = {"PySide.QtCore.QObject", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtDeclarative.QDeclarativeNetworkAccessManagerFactory.create", overloads);
        return 0;
}

static PyMethodDef Sbk_QDeclarativeNetworkAccessManagerFactory_methods[] = {
    {"create", (PyCFunction)Sbk_QDeclarativeNetworkAccessManagerFactoryFunc_create, METH_O},

    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QDeclarativeNetworkAccessManagerFactory_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtDeclarative.QDeclarativeNetworkAccessManagerFactory",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QDeclarativeNetworkAccessManagerFactory_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&SbkObject_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QDeclarativeNetworkAccessManagerFactory_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern


void init_QDeclarativeNetworkAccessManagerFactory(PyObject* module)
{
    SbkPySide_QtDeclarativeTypes[SBK_QDECLARATIVENETWORKACCESSMANAGERFACTORY_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QDeclarativeNetworkAccessManagerFactory_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QDeclarativeNetworkAccessManagerFactory_Type);
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QDeclarativeNetworkAccessManagerFactory_Type, &Shiboken::callCppDestructor<QDeclarativeNetworkAccessManagerFactory >);
    Py_INCREF((PyObject*)&Sbk_QDeclarativeNetworkAccessManagerFactory_Type); //Incref due the 'PyModule_AddObject' steals the reference.
    if (PyType_Ready((PyTypeObject*)&Sbk_QDeclarativeNetworkAccessManagerFactory_Type) < 0)
        return;

    // Fill type discovery information

    Shiboken::ObjectType::setOriginalName(&Sbk_QDeclarativeNetworkAccessManagerFactory_Type, "QDeclarativeNetworkAccessManagerFactory*");
    PyModule_AddObject(module, "QDeclarativeNetworkAccessManagerFactory",
        ((PyObject*)&Sbk_QDeclarativeNetworkAccessManagerFactory_Type));


    Shiboken::TypeResolver::createObjectTypeResolver<QDeclarativeNetworkAccessManagerFactory >("QDeclarativeNetworkAccessManagerFactory*");
    Shiboken::TypeResolver::createObjectTypeResolver<QDeclarativeNetworkAccessManagerFactory >("QDeclarativeNetworkAccessManagerFactory$ConcreteWrapper*");
    Shiboken::TypeResolver::createObjectTypeResolver<QDeclarativeNetworkAccessManagerFactory >(typeid(QDeclarativeNetworkAccessManagerFactory).name());
    Shiboken::TypeResolver::createObjectTypeResolver<QDeclarativeNetworkAccessManagerFactory >(typeid(QDeclarativeNetworkAccessManagerFactoryWrapper).name());
}

