/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtgui_python.h"

#include "qbrush_wrapper.h"

// Extra includes
#include <QPixmap>
#include <qbrush.h>
#include <qcolor.h>
#include <qdatastream.h>
#include <qimage.h>
#include <qmatrix.h>
#include <qpixmap.h>
#include <qtransform.h>



// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QBrush_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QBrush >()))
        return -1;

    QBrush* cptr = 0;
    int overloadId = -1;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);

    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);

    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QBrush(): too many arguments");
        return -1;
    }

    if (!PyArg_ParseTuple(args, "|OO:QBrush", &(pyargs[0]), &(pyargs[1])))
        return -1;

    // Overloaded function decisor
    // 0: QBrush()
    // 1: QBrush(Qt::BrushStyle)
    // 2: QBrush(Qt::GlobalColor,Qt::BrushStyle)
    // 3: QBrush(Qt::GlobalColor,QPixmap)
    // 4: QBrush(QBrush)
    // 5: QBrush(QColor,Qt::BrushStyle)
    // 6: QBrush(QColor,QPixmap)
    // 7: QBrush(QGradient)
    // 8: QBrush(QImage)
    // 9: QBrush(QPixmap)
    if (numArgs == 0) {
        overloadId = 0; // QBrush()
    } else if (numArgs == 1 && Shiboken::Converter< ::QImage >::isConvertible(pyargs[0])) {
        overloadId = 8; // QBrush(QImage)
    } else if (numArgs == 1 && Shiboken::Converter< ::QPixmap >::isConvertible(pyargs[0])) {
        overloadId = 9; // QBrush(QPixmap)
    } else if (numArgs == 1 && Shiboken::Converter< ::QGradient >::isConvertible(pyargs[0])) {
        overloadId = 7; // QBrush(QGradient)
    } else if (Shiboken::Converter< ::Qt::GlobalColor >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 2; // QBrush(Qt::GlobalColor,Qt::BrushStyle)
        } else if (numArgs == 2 && Shiboken::Converter< ::QPixmap >::isConvertible(pyargs[1])) {
            overloadId = 3; // QBrush(Qt::GlobalColor,QPixmap)
        } else if (Shiboken::Converter< ::Qt::BrushStyle >::isConvertible(pyargs[1])) {
            overloadId = 2; // QBrush(Qt::GlobalColor,Qt::BrushStyle)
        }
    } else if (numArgs == 1 && Shiboken::Converter< ::Qt::BrushStyle >::isConvertible(pyargs[0])) {
        overloadId = 1; // QBrush(Qt::BrushStyle)
    } else if (Shiboken::Converter< ::QColor >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 5; // QBrush(QColor,Qt::BrushStyle)
        } else if (numArgs == 2 && Shiboken::Converter< ::QPixmap >::isConvertible(pyargs[1])) {
            overloadId = 6; // QBrush(QColor,QPixmap)
        } else if (Shiboken::Converter< ::Qt::BrushStyle >::isConvertible(pyargs[1])) {
            overloadId = 5; // QBrush(QColor,Qt::BrushStyle)
        }
    } else if (numArgs == 1 && Shiboken::Converter< ::QBrush >::isConvertible(pyargs[0])) {
        overloadId = 4; // QBrush(QBrush)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QBrush_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QBrush()
            {

                if(!PyErr_Occurred()) {
                    // QBrush()
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QBrush();
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // QBrush(Qt::BrushStyle)
            {
                Qt::BrushStyle cppArg0 = Shiboken::Converter<Qt::BrushStyle >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QBrush(Qt::BrushStyle)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QBrush(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 2: // QBrush(Qt::GlobalColor,Qt::BrushStyle)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "bs");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "bs";
                        else if (Shiboken::Converter< ::Qt::BrushStyle >::isConvertible(value))
                            pyargs[1] = value;
                        else
                            goto Sbk_QBrush_Init_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QBrush(): got multiple values for keyword argument '%s'", errorArgName);
                        return -1;
                    }
                }
                Qt::GlobalColor cppArg0 = Shiboken::Converter<Qt::GlobalColor >::toCpp(pyargs[0]);
                Qt::BrushStyle cppArg1 = pyargs[1] ? Shiboken::Converter<Qt::BrushStyle >::toCpp(pyargs[1]) : Qt::SolidPattern;

                if(!PyErr_Occurred()) {
                    // QBrush(Qt::GlobalColor,Qt::BrushStyle)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QBrush(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 3: // QBrush(Qt::GlobalColor,QPixmap)
            {
                Qt::GlobalColor cppArg0 = Shiboken::Converter<Qt::GlobalColor >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return -1;
                QPixmap cppArg1 = Shiboken::Converter<QPixmap >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // QBrush(Qt::GlobalColor,QPixmap)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QBrush(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 4: // QBrush(QBrush)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QBrush cppArg0 = Shiboken::Converter<QBrush >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QBrush(QBrush)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QBrush(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 5: // QBrush(QColor,Qt::BrushStyle)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "bs");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "bs";
                        else if (Shiboken::Converter< ::Qt::BrushStyle >::isConvertible(value))
                            pyargs[1] = value;
                        else
                            goto Sbk_QBrush_Init_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QBrush(): got multiple values for keyword argument '%s'", errorArgName);
                        return -1;
                    }
                }
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QColor cppArg0 = Shiboken::Converter<QColor >::toCpp(pyargs[0]);
                Qt::BrushStyle cppArg1 = pyargs[1] ? Shiboken::Converter<Qt::BrushStyle >::toCpp(pyargs[1]) : Qt::SolidPattern;

                if(!PyErr_Occurred()) {
                    // QBrush(QColor,Qt::BrushStyle)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QBrush(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 6: // QBrush(QColor,QPixmap)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QColor cppArg0 = Shiboken::Converter<QColor >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return -1;
                QPixmap cppArg1 = Shiboken::Converter<QPixmap >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // QBrush(QColor,QPixmap)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QBrush(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 7: // QBrush(QGradient)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QGradient cppArg0 = Shiboken::Converter<QGradient >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QBrush(QGradient)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QBrush(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 8: // QBrush(QImage)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QImage cppArg0 = Shiboken::Converter<QImage >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QBrush(QImage)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QBrush(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 9: // QBrush(QPixmap)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QPixmap cppArg0 = Shiboken::Converter<QPixmap >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QBrush(QPixmap)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QBrush(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QBrush >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QBrush_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QBrush_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtCore.Qt.BrushStyle", "PySide.QtCore.Qt.GlobalColor, PySide.QtCore.Qt.BrushStyle = Qt.SolidPattern", "PySide.QtCore.Qt.GlobalColor, PySide.QtGui.QPixmap", "PySide.QtGui.QBrush", "PySide.QtGui.QColor, PySide.QtCore.Qt.BrushStyle = Qt.SolidPattern", "PySide.QtGui.QColor, PySide.QtGui.QPixmap", "PySide.QtGui.QGradient", "PySide.QtGui.QImage", "PySide.QtGui.QPixmap", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QBrush", overloads);
        return -1;
}

static PyObject* Sbk_QBrushFunc_color(PyObject* self)
{
    QBrush* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QBrush* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // color()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                const QColor & cppResult = const_cast<const QBrush*>(cppSelf)->color();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QColor >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QBrushFunc_gradient(PyObject* self)
{
    QBrush* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QBrush* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // gradient()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                const QGradient * cppResult = const_cast<const QBrush*>(cppSelf)->gradient();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QGradient * >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QBrushFunc_isOpaque(PyObject* self)
{
    QBrush* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QBrush* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isOpaque()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QBrush*>(cppSelf)->isOpaque();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QBrushFunc_matrix(PyObject* self)
{
    QBrush* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QBrush* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // matrix()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                const QMatrix & cppResult = const_cast<const QBrush*>(cppSelf)->matrix();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QMatrix >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QBrushFunc_setColor(PyObject* self, PyObject* arg)
{
    QBrush* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QBrush* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setColor(Qt::GlobalColor)
    // 1: setColor(QColor)
    if (Shiboken::Converter< ::Qt::GlobalColor >::isConvertible(arg)) {
        overloadId = 0; // setColor(Qt::GlobalColor)
    } else if (Shiboken::Converter< ::QColor >::isConvertible(arg)) {
        overloadId = 1; // setColor(QColor)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QBrushFunc_setColor_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // setColor(Qt::GlobalColor)
            {
                Qt::GlobalColor cppArg0 = Shiboken::Converter<Qt::GlobalColor >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // setColor(Qt::GlobalColor)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setColor(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // setColor(QColor)
            {
                if (!Shiboken::Object::isValid(arg))
                    return 0;
                QColor cppArg0 = Shiboken::Converter<QColor >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // setColor(QColor)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setColor(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QBrushFunc_setColor_TypeError:
        const char* overloads[] = {"PySide.QtCore.Qt.GlobalColor", "PySide.QtGui.QColor", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QBrush.setColor", overloads);
        return 0;
}

static PyObject* Sbk_QBrushFunc_setMatrix(PyObject* self, PyObject* arg)
{
    QBrush* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QBrush* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setMatrix(QMatrix)
    if (Shiboken::Converter< ::QMatrix >::isConvertible(arg)) {
        overloadId = 0; // setMatrix(QMatrix)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QBrushFunc_setMatrix_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QMatrix cppArg0 = Shiboken::Converter<QMatrix >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setMatrix(QMatrix)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setMatrix(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QBrushFunc_setMatrix_TypeError:
        const char* overloads[] = {"PySide.QtGui.QMatrix", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QBrush.setMatrix", overloads);
        return 0;
}

static PyObject* Sbk_QBrushFunc_setStyle(PyObject* self, PyObject* arg)
{
    QBrush* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QBrush* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setStyle(Qt::BrushStyle)
    if (Shiboken::Converter< ::Qt::BrushStyle >::isConvertible(arg)) {
        overloadId = 0; // setStyle(Qt::BrushStyle)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QBrushFunc_setStyle_TypeError;

    // Call function/method
    {
        {
            Qt::BrushStyle cppArg0 = Shiboken::Converter<Qt::BrushStyle >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setStyle(Qt::BrushStyle)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setStyle(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QBrushFunc_setStyle_TypeError:
        const char* overloads[] = {"PySide.QtCore.Qt.BrushStyle", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QBrush.setStyle", overloads);
        return 0;
}

static PyObject* Sbk_QBrushFunc_setTexture(PyObject* self, PyObject* arg)
{
    QBrush* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QBrush* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setTexture(QPixmap)
    if (Shiboken::Converter< ::QPixmap >::isConvertible(arg)) {
        overloadId = 0; // setTexture(QPixmap)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QBrushFunc_setTexture_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QPixmap cppArg0 = Shiboken::Converter<QPixmap >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setTexture(QPixmap)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setTexture(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QBrushFunc_setTexture_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPixmap", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QBrush.setTexture", overloads);
        return 0;
}

static PyObject* Sbk_QBrushFunc_setTextureImage(PyObject* self, PyObject* arg)
{
    QBrush* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QBrush* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setTextureImage(QImage)
    if (Shiboken::Converter< ::QImage >::isConvertible(arg)) {
        overloadId = 0; // setTextureImage(QImage)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QBrushFunc_setTextureImage_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QImage cppArg0 = Shiboken::Converter<QImage >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setTextureImage(QImage)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setTextureImage(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QBrushFunc_setTextureImage_TypeError:
        const char* overloads[] = {"PySide.QtGui.QImage", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QBrush.setTextureImage", overloads);
        return 0;
}

static PyObject* Sbk_QBrushFunc_setTransform(PyObject* self, PyObject* arg)
{
    QBrush* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QBrush* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setTransform(QTransform)
    if (Shiboken::Converter< ::QTransform >::isConvertible(arg)) {
        overloadId = 0; // setTransform(QTransform)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QBrushFunc_setTransform_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QTransform cppArg0 = Shiboken::Converter<QTransform >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setTransform(QTransform)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setTransform(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QBrushFunc_setTransform_TypeError:
        const char* overloads[] = {"PySide.QtGui.QTransform", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QBrush.setTransform", overloads);
        return 0;
}

static PyObject* Sbk_QBrushFunc_style(PyObject* self)
{
    QBrush* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QBrush* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // style()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                Qt::BrushStyle cppResult = const_cast<const QBrush*>(cppSelf)->style();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::Qt::BrushStyle >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QBrushFunc_texture(PyObject* self)
{
    QBrush* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QBrush* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // texture()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QPixmap cppResult = const_cast<const QBrush*>(cppSelf)->texture();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QPixmap >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QBrushFunc_textureImage(PyObject* self)
{
    QBrush* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QBrush* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // textureImage()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QImage cppResult = const_cast<const QBrush*>(cppSelf)->textureImage();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QImage >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QBrushFunc_transform(PyObject* self)
{
    QBrush* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QBrush* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // transform()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QTransform cppResult = const_cast<const QBrush*>(cppSelf)->transform();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QTransform >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject *Sbk_QBrush___copy__(PyObject *self)
{
        QBrush* cppSelf = 0;
        if (!Shiboken::Object::isValid(self))
            return 0;
        cppSelf = Shiboken::Converter<QBrush*>::toCpp(self);
        PyObject* pyResult = 0;
        QBrush* copy = new QBrush(*cppSelf);
        pyResult = Shiboken::Converter<QBrush*>::toPython(copy);
        Shiboken::Object::getOwnership(pyResult);

        if (PyErr_Occurred() || !pyResult) {
            Py_XDECREF(pyResult);
            return 0;
        }
        return pyResult;
}

static PyMethodDef Sbk_QBrush_methods[] = {
    {"color", (PyCFunction)Sbk_QBrushFunc_color, METH_NOARGS},
    {"gradient", (PyCFunction)Sbk_QBrushFunc_gradient, METH_NOARGS},
    {"isOpaque", (PyCFunction)Sbk_QBrushFunc_isOpaque, METH_NOARGS},
    {"matrix", (PyCFunction)Sbk_QBrushFunc_matrix, METH_NOARGS},
    {"setColor", (PyCFunction)Sbk_QBrushFunc_setColor, METH_O},
    {"setMatrix", (PyCFunction)Sbk_QBrushFunc_setMatrix, METH_O},
    {"setStyle", (PyCFunction)Sbk_QBrushFunc_setStyle, METH_O},
    {"setTexture", (PyCFunction)Sbk_QBrushFunc_setTexture, METH_O},
    {"setTextureImage", (PyCFunction)Sbk_QBrushFunc_setTextureImage, METH_O},
    {"setTransform", (PyCFunction)Sbk_QBrushFunc_setTransform, METH_O},
    {"style", (PyCFunction)Sbk_QBrushFunc_style, METH_NOARGS},
    {"texture", (PyCFunction)Sbk_QBrushFunc_texture, METH_NOARGS},
    {"textureImage", (PyCFunction)Sbk_QBrushFunc_textureImage, METH_NOARGS},
    {"transform", (PyCFunction)Sbk_QBrushFunc_transform, METH_NOARGS},

    {"__copy__", (PyCFunction)Sbk_QBrush___copy__, METH_NOARGS},
    {0} // Sentinel
};

static PyObject* Sbk_QBrushFunc___lshift__(PyObject* self, PyObject* arg)
{
    QBrush* cppSelf = 0;
    bool isReverse = Shiboken::Converter< ::QBrush >::checkType(arg) && !Shiboken::Converter< ::QBrush >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QBrush* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && Shiboken::Object::checkType(arg)
        && !PyObject_TypeCheck(arg, self->ob_type)
        && PyObject_HasAttrString(arg, const_cast<char*>("__rlshift__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(arg, const_cast<char*>("__rlshift__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator<<(QDataStream&,QBrush)
    if (isReverse && Shiboken::Converter< ::QDataStream & >::isConvertible(arg)) {
        overloadId = 0; // operator<<(QDataStream&,QBrush)
    }

    if (isReverse && overloadId == -1) {
        PyErr_SetString(PyExc_NotImplementedError, "reverse operator not implemented.");
        return 0;
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QBrushFunc___lshift___TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QDataStream & cppArg0 = Shiboken::Converter<QDataStream & >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // operator<<(QDataStream&,QBrush) [reverse operator]
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QDataStream & cppResult = (cppArg0) << (*cppSelf);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QDataStream & >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    } // End of "if (!pyResult)"


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QBrushFunc___lshift___TypeError:
        const char* overloads[] = {"PySide.QtCore.QDataStream", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QBrush.__lshift__", overloads);
        return 0;
}

static PyObject* Sbk_QBrushFunc___rshift__(PyObject* self, PyObject* arg)
{
    QBrush* cppSelf = 0;
    bool isReverse = Shiboken::Converter< ::QBrush >::checkType(arg) && !Shiboken::Converter< ::QBrush >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QBrush* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && Shiboken::Object::checkType(arg)
        && !PyObject_TypeCheck(arg, self->ob_type)
        && PyObject_HasAttrString(arg, const_cast<char*>("__rrshift__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(arg, const_cast<char*>("__rrshift__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator>>(QDataStream&,QBrush&)
    if (isReverse && Shiboken::Converter< ::QDataStream & >::isConvertible(arg)) {
        overloadId = 0; // operator>>(QDataStream&,QBrush&)
    }

    if (isReverse && overloadId == -1) {
        PyErr_SetString(PyExc_NotImplementedError, "reverse operator not implemented.");
        return 0;
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QBrushFunc___rshift___TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QDataStream & cppArg0 = Shiboken::Converter<QDataStream & >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // operator>>(QDataStream&,QBrush&) [reverse operator]
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QDataStream & cppResult = (cppArg0) >> (*cppSelf);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QDataStream & >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    } // End of "if (!pyResult)"


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QBrushFunc___rshift___TypeError:
        const char* overloads[] = {"PySide.QtCore.QDataStream", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QBrush.__rshift__", overloads);
        return 0;
}

// type has number operators
static PyNumberMethods Sbk_QBrush_as_number = {
    /*nb_add*/                  (binaryfunc)0,
    /*nb_subtract*/             (binaryfunc)0,
    /*nb_multiply*/             (binaryfunc)0,
    /*nb_divide*/               (binaryfunc)0,
    /*nb_remainder*/            (binaryfunc)0,
    /*nb_divmod*/               0,
    /*nb_power*/                0,
    /*nb_negative*/             (unaryfunc)0,
    /*nb_positive*/             (unaryfunc)0,
    /*nb_absolute*/             0,
    /*nb_nonzero*/              0,
    /*nb_invert*/               (unaryfunc)0,
    /*nb_lshift*/               (binaryfunc)Sbk_QBrushFunc___lshift__,
    /*nb_rshift*/               (binaryfunc)Sbk_QBrushFunc___rshift__,
    /*nb_and*/                  (binaryfunc)0,
    /*nb_xor*/                  (binaryfunc)0,
    /*nb_or*/                   (binaryfunc)0,
    /*nb_coerce*/               0,
    /*nb_int*/                  0,
    /*nb_long*/                 0,
    /*nb_float*/                0,
    /*nb_oct*/                  0,
    /*nb_hex*/                  0,
    /*nb_inplace_add*/          (binaryfunc)0,
    /*nb_inplace_subtract*/     (binaryfunc)0,
    /*nb_inplace_multiply*/     (binaryfunc)0,
    /*nb_inplace_divide*/       (binaryfunc)0,
    /*nb_inplace_remainder*/    (binaryfunc)0,
    /*nb_inplace_power*/        0,
    /*nb_inplace_lshift*/       (binaryfunc)0,
    /*nb_inplace_rshift*/       (binaryfunc)0,
    /*nb_inplace_and*/          (binaryfunc)0,
    /*nb_inplace_xor*/          (binaryfunc)0,
    /*nb_inplace_or*/           (binaryfunc)0,
    /*nb_floor_divide*/         0,
    /*nb_true_divide*/          (binaryfunc)0,
    /*nb_inplace_floor_divide*/ 0,
    /*nb_inplace_true_divide*/  0,
    /*nb_index*/                0
};

// Rich comparison
static PyObject* Sbk_QBrush_richcompare(PyObject* self, PyObject* arg, int op)
{
    PyObject* pyResult = 0;
    QBrush& cppSelf = *Shiboken::Converter< QBrush* >::toCpp(self);

    switch (op) {
        case Py_NE:
            if (Shiboken::Converter< ::QBrush >::isConvertible(arg)) {
                // operator!=(const QBrush & b) const
                QBrush cppArg0 = Shiboken::Converter< ::QBrush >::toCpp(arg);
                pyResult = Shiboken::Converter< bool >::toPython(cppSelf != cppArg0);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_EQ:
            if (Shiboken::Converter< ::QBrush >::isConvertible(arg)) {
                // operator==(const QBrush & b) const
                QBrush cppArg0 = Shiboken::Converter< ::QBrush >::toCpp(arg);
                pyResult = Shiboken::Converter< bool >::toPython(cppSelf == cppArg0);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            goto Sbk_QBrush_RichComparison_TypeError;
    }

    if (pyResult && !PyErr_Occurred())
        return pyResult;
    Sbk_QBrush_RichComparison_TypeError:
    PyErr_SetString(PyExc_NotImplementedError, "operator not implemented.");
    return 0;

}

} // extern "C"

extern "C"
{
static PyObject* Sbk_QBrush__repr__(PyObject* pyObj)
{
    QBuffer buffer;
    buffer.open(QBuffer::ReadWrite);
    QDebug dbg(&buffer);
    dbg << Shiboken::Converter< ::QBrush >::toCpp(pyObj);
    buffer.close();
    return PyString_FromFormat("<PySide.QtGui.%s at %p>", buffer.data().constData(), pyObj);
}
} // extern C

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QBrush_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QBrush",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Sbk_QBrush__repr__,
    /*tp_as_number*/        &Sbk_QBrush_as_number,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      Sbk_QBrush_richcompare,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QBrush_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&SbkObject_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QBrush_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern


void init_QBrush(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QBRUSH_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QBrush_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QBrush_Type);
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QBrush_Type, &Shiboken::callCppDestructor<QBrush >);
    Py_INCREF((PyObject*)&Sbk_QBrush_Type); //Incref due the 'PyModule_AddObject' steals the reference.
    if (PyType_Ready((PyTypeObject*)&Sbk_QBrush_Type) < 0)
        return;

    Shiboken::ObjectType::setOriginalName(&Sbk_QBrush_Type, "QBrush");
    PyModule_AddObject(module, "QBrush",
        ((PyObject*)&Sbk_QBrush_Type));


    Shiboken::TypeResolver::createValueTypeResolver<QBrush >("QBrush");
    Shiboken::TypeResolver::createObjectTypeResolver<QBrush >("QBrush*");
    Shiboken::TypeResolver::createValueTypeResolver<QBrush >(typeid(QBrush).name());
    qRegisterMetaType< ::QBrush >("QBrush");
}

