/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <set>
#include "pyside_qtgui_python.h"

#include "qfiledialog_wrapper.h"

// Extra includes
#include <QAbstractProxyModel>
#include <QList>
#include <QStringList>
#include <QUrl>
#include <qabstractitemdelegate.h>
#include <qabstractproxymodel.h>
#include <qaction.h>
#include <qbitmap.h>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qcursor.h>
#include <qdir.h>
#include <qevent.h>
#include <qfiledialog.h>
#include <qfileiconprovider.h>
#include <qfont.h>
#include <qfontinfo.h>
#include <qfontmetrics.h>
#include <qgraphicseffect.h>
#include <qgraphicsproxywidget.h>
#include <qicon.h>
#include <qinputcontext.h>
#include <qkeysequence.h>
#include <qlayout.h>
#include <qlocale.h>
#include <qmargins.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qpaintdevice.h>
#include <qpaintengine.h>
#include <qpainter.h>
#include <qpalette.h>
#include <qpoint.h>
#include <qrect.h>
#include <qregion.h>
#include <qsize.h>
#include <qsizepolicy.h>
#include <qstyle.h>
#include <qurl.h>
#include <qwidget.h>
#include <qx11info_x11.h>


// Native ---------------------------------------------------------

QFileDialogWrapper::QFileDialogWrapper(QWidget * parent, QFlags<Qt::WindowType> f) : QFileDialog(parent, f) {
    // ... middle
}

QFileDialogWrapper::QFileDialogWrapper(QWidget * parent, const QString & caption, const QString & directory, const QString & filter) : QFileDialog(parent, caption, directory, filter) {
    // ... middle
}

void QFileDialogWrapper::accept()
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "accept"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QFileDialog::accept();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QFileDialogWrapper::actionEvent(QActionEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "actionEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::actionEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QActionEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QFileDialogWrapper::changeEvent(QEvent * e)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "changeEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QFileDialog::changeEvent(e);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QEvent * >::toPython(e)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QFileDialogWrapper::childEvent(QChildEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "childEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::childEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QChildEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QFileDialogWrapper::closeEvent(QCloseEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "closeEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QDialog::closeEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QCloseEvent * >::toPython(arg__1)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QFileDialogWrapper::connectNotify(const char * signal)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "connectNotify"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::connectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QFileDialogWrapper::contextMenuEvent(QContextMenuEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "contextMenuEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QDialog::contextMenuEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QContextMenuEvent * >::toPython(arg__1)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QFileDialogWrapper::customEvent(QEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "customEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::customEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

int QFileDialogWrapper::devType() const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return int(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "devType"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::devType();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return int(0);
    }
    // Check return type
    bool typeIsValid = PyInt_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QFileDialog.devType", "int", pyResult->ob_type->tp_name);
        return int(0);
    }
    int cppResult(Shiboken::Converter< int >::toCpp(pyResult));
    return cppResult;
}

void QFileDialogWrapper::disconnectNotify(const char * signal)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "disconnectNotify"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::disconnectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QFileDialogWrapper::done(int result)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "done"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QFileDialog::done(result);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(i)",
        result
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QFileDialogWrapper::dragEnterEvent(QDragEnterEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "dragEnterEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::dragEnterEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QDragEnterEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QFileDialogWrapper::dragLeaveEvent(QDragLeaveEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "dragLeaveEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::dragLeaveEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QDragLeaveEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QFileDialogWrapper::dragMoveEvent(QDragMoveEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "dragMoveEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::dragMoveEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QDragMoveEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QFileDialogWrapper::dropEvent(QDropEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "dropEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::dropEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QDropEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QFileDialogWrapper::enterEvent(QEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "enterEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::enterEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

bool QFileDialogWrapper::event(QEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return bool(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "event"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::event(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QFileDialog.event", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    return cppResult;
}

bool QFileDialogWrapper::eventFilter(QObject * arg__1, QEvent * arg__2)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return bool(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "eventFilter"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QDialog::eventFilter(arg__1, arg__2);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter< ::QObject * >::toPython(arg__1),
        Shiboken::Converter< ::QEvent * >::toPython(arg__2)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QFileDialog.eventFilter", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    return cppResult;
}

void QFileDialogWrapper::focusInEvent(QFocusEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "focusInEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::focusInEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QFocusEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

bool QFileDialogWrapper::focusNextPrevChild(bool next)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return bool(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "focusNextPrevChild"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::focusNextPrevChild(next);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< bool >::toPython(next)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QFileDialog.focusNextPrevChild", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    return cppResult;
}

void QFileDialogWrapper::focusOutEvent(QFocusEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "focusOutEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::focusOutEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QFocusEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

int QFileDialogWrapper::heightForWidth(int arg__1) const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return int(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "heightForWidth"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::heightForWidth(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(i)",
        arg__1
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return int(0);
    }
    // Check return type
    bool typeIsValid = PyInt_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QFileDialog.heightForWidth", "int", pyResult->ob_type->tp_name);
        return int(0);
    }
    int cppResult(Shiboken::Converter< int >::toCpp(pyResult));
    return cppResult;
}

void QFileDialogWrapper::hideEvent(QHideEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "hideEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::hideEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QHideEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QFileDialogWrapper::inputMethodEvent(QInputMethodEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "inputMethodEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::inputMethodEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QInputMethodEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

QVariant QFileDialogWrapper::inputMethodQuery(Qt::InputMethodQuery arg__1) const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return QVariant(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "inputMethodQuery"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::inputMethodQuery(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::Qt::InputMethodQuery >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QVariant(0);
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< QVariant >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QFileDialog.inputMethodQuery", "QVariant", pyResult->ob_type->tp_name);
        return QVariant(0);
    }
    QVariant cppResult(Shiboken::Converter< QVariant >::toCpp(pyResult));
    return cppResult;
}

void QFileDialogWrapper::keyPressEvent(QKeyEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "keyPressEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QDialog::keyPressEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QKeyEvent * >::toPython(arg__1)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QFileDialogWrapper::keyReleaseEvent(QKeyEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "keyReleaseEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::keyReleaseEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QKeyEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QFileDialogWrapper::languageChange()
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "languageChange"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::languageChange();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QFileDialogWrapper::leaveEvent(QEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "leaveEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::leaveEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

int QFileDialogWrapper::metric(QPaintDevice::PaintDeviceMetric arg__1) const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return int(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "metric"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::metric(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QPaintDevice::PaintDeviceMetric >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return int(0);
    }
    // Check return type
    bool typeIsValid = PyInt_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QFileDialog.metric", "int", pyResult->ob_type->tp_name);
        return int(0);
    }
    int cppResult(Shiboken::Converter< int >::toCpp(pyResult));
    return cppResult;
}

QSize QFileDialogWrapper::minimumSizeHint() const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return QSize();
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "minimumSizeHint"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QDialog::minimumSizeHint();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QSize();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QSize >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QFileDialog.minimumSizeHint", Shiboken::SbkType<QSize >()->tp_name, pyResult->ob_type->tp_name);
        return QSize();
    }
    QSize cppResult(Shiboken::Converter< ::QSize >::toCpp(pyResult));
    return cppResult;
}

void QFileDialogWrapper::mouseDoubleClickEvent(QMouseEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "mouseDoubleClickEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::mouseDoubleClickEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QMouseEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QFileDialogWrapper::mouseMoveEvent(QMouseEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "mouseMoveEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::mouseMoveEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QMouseEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QFileDialogWrapper::mousePressEvent(QMouseEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "mousePressEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::mousePressEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QMouseEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QFileDialogWrapper::mouseReleaseEvent(QMouseEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "mouseReleaseEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::mouseReleaseEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QMouseEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QFileDialogWrapper::moveEvent(QMoveEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "moveEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::moveEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QMoveEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

QPaintEngine * QFileDialogWrapper::paintEngine() const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return 0;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "paintEngine"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::paintEngine();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return 0;
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QPaintEngine * >::isConvertible(pyResult);
    typeIsValid = typeIsValid || (pyResult == Py_None);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QFileDialog.paintEngine", Shiboken::SbkType<QPaintEngine >()->tp_name, pyResult->ob_type->tp_name);
        return 0;
    }
    QPaintEngine * cppResult(Shiboken::Converter< ::QPaintEngine * >::toCpp(pyResult));
    return cppResult;
}

void QFileDialogWrapper::paintEvent(QPaintEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "paintEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::paintEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QPaintEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QFileDialogWrapper::reject()
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "reject"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QDialog::reject();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QFileDialogWrapper::resizeEvent(QResizeEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "resizeEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QDialog::resizeEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QResizeEvent * >::toPython(arg__1)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QFileDialogWrapper::setVisible(bool visible)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "setVisible"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QFileDialog::setVisible(visible);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< bool >::toPython(visible)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QFileDialogWrapper::showEvent(QShowEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "showEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QDialog::showEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QShowEvent * >::toPython(arg__1)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

QSize QFileDialogWrapper::sizeHint() const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return QSize();
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "sizeHint"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QDialog::sizeHint();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QSize();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QSize >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QFileDialog.sizeHint", Shiboken::SbkType<QSize >()->tp_name, pyResult->ob_type->tp_name);
        return QSize();
    }
    QSize cppResult(Shiboken::Converter< ::QSize >::toCpp(pyResult));
    return cppResult;
}

void QFileDialogWrapper::tabletEvent(QTabletEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "tabletEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::tabletEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QTabletEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QFileDialogWrapper::timerEvent(QTimerEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "timerEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::timerEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QTimerEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QFileDialogWrapper::wheelEvent(QWheelEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "wheelEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::wheelEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QWheelEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

const QMetaObject* QFileDialogWrapper::metaObject() const
{
    SbkObject* pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    return reinterpret_cast<QMetaObject*>(Shiboken::Object::getTypeUserData(pySelf));
}

int QFileDialogWrapper::qt_metacall(QMetaObject::Call call, int id, void** args)
{
    int result = QFileDialog::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

QFileDialogWrapper::~QFileDialogWrapper()
{
    SbkObject* wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QFileDialog_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QFileDialog >()))
        return -1;

    QFileDialogWrapper* cptr = 0;
    int overloadId = -1;
    const char* argNames[] = {"caption", "directory", "filter", "parent"};
    const QMetaObject* metaObject;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths


    if (!PyArg_ParseTuple(args, "|OOOO:QFileDialog", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return -1;

    // Overloaded function decisor
    // 0: QFileDialog(QWidget*,QFlags<Qt::WindowType>)
    // 1: QFileDialog(QWidget*,QString,QString,QString)
    if (numArgs == 0) {
        overloadId = 1; // QFileDialog(QWidget*,QString,QString,QString)
    } else if (Shiboken::Converter< ::QWidget * >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 1; // QFileDialog(QWidget*,QString,QString,QString)
        } else if (Shiboken::Converter< QString >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 1; // QFileDialog(QWidget*,QString,QString,QString)
            } else if (Shiboken::Converter< QString >::isConvertible(pyargs[2])) {
                if (numArgs == 3) {
                    overloadId = 1; // QFileDialog(QWidget*,QString,QString,QString)
                } else if (Shiboken::Converter< QString >::isConvertible(pyargs[3])) {
                    overloadId = 1; // QFileDialog(QWidget*,QString,QString,QString)
                }
            }
        } else if (numArgs == 2 && Shiboken::Converter< ::QFlags<Qt::WindowType> >::isConvertible(pyargs[1])) {
            overloadId = 0; // QFileDialog(QWidget*,QFlags<Qt::WindowType>)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QFileDialog_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QFileDialog(QWidget*,QFlags<Qt::WindowType>)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QWidget * cppArg0 = Shiboken::Converter<QWidget * >::toCpp(pyargs[0]);
                QFlags<Qt::WindowType> cppArg1 = Shiboken::Converter<QFlags<Qt::WindowType> >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // QFileDialog(QWidget*,QFlags<Qt::WindowType>)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QFileDialogWrapper(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    Shiboken::Object::setParent(pyargs[0], self);
                }
                break;
            }
            case 1: // QFileDialog(QWidget*,QString,QString,QString)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "parent");
                    if (value) {
                        if (pyargs[0])
                            errorArgName = "parent";
                        else if (Shiboken::Converter< ::QWidget * >::isConvertible(value))
                            pyargs[0] = value;
                        else
                            goto Sbk_QFileDialog_Init_TypeError;
                    }
                    value = PyDict_GetItemString(kwds, "caption");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "caption";
                        else if (Shiboken::Converter< QString >::isConvertible(value))
                            pyargs[1] = value;
                        else
                            goto Sbk_QFileDialog_Init_TypeError;
                    }
                    value = PyDict_GetItemString(kwds, "directory");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "directory";
                        else if (Shiboken::Converter< QString >::isConvertible(value))
                            pyargs[2] = value;
                        else
                            goto Sbk_QFileDialog_Init_TypeError;
                    }
                    value = PyDict_GetItemString(kwds, "filter");
                    if (value) {
                        if (pyargs[3])
                            errorArgName = "filter";
                        else if (Shiboken::Converter< QString >::isConvertible(value))
                            pyargs[3] = value;
                        else
                            goto Sbk_QFileDialog_Init_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QFileDialog(): got multiple values for keyword argument '%s'", errorArgName);
                        return -1;
                    }
                }
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QWidget * cppArg0 = pyargs[0] ? Shiboken::Converter<QWidget * >::toCpp(pyargs[0]) : 0;
                QString cppArg1 = pyargs[1] ? Shiboken::Converter<QString >::toCpp(pyargs[1]) : QString();
                QString cppArg2 = pyargs[2] ? Shiboken::Converter<QString >::toCpp(pyargs[2]) : QString();
                QString cppArg3 = pyargs[3] ? Shiboken::Converter<QString >::toCpp(pyargs[3]) : QString();

                if(!PyErr_Occurred()) {
                    // QFileDialog(QWidget*,QString,QString,QString)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QFileDialogWrapper(cppArg0, cppArg1, cppArg2, cppArg3);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    Shiboken::Object::setParent(pyargs[0], self);
                }
                break;
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QFileDialog >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QFileDialog_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    metaObject = cptr->metaObject(); // <- init python qt properties
    if (kwds && !PySide::fillQtProperties(self, metaObject, kwds, argNames, 4))
        return -1;


    return 1;

    Sbk_QFileDialog_Init_TypeError:
        const char* overloads[] = {"PySide.QtGui.QWidget, PySide.QtCore.Qt.WindowFlags", "PySide.QtGui.QWidget = None, QString = QString(), QString = QString(), QString = QString()", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QFileDialog", overloads);
        return -1;
}

static PyObject* Sbk_QFileDialogFunc_accept(PyObject* self)
{
    QFileDialog* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFileDialog* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // accept()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QFileDialog::accept() : cppSelf->accept());
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QFileDialogFunc_acceptMode(PyObject* self)
{
    QFileDialog* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFileDialog* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // acceptMode()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QFileDialog::AcceptMode cppResult = const_cast<const QFileDialog*>(cppSelf)->acceptMode();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QFileDialog::AcceptMode >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QFileDialogFunc_changeEvent(PyObject* self, PyObject* arg)
{
    QFileDialog* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFileDialog* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: changeEvent(QEvent*)
    if (Shiboken::Converter< ::QEvent * >::isConvertible(arg)) {
        overloadId = 0; // changeEvent(QEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QFileDialogFunc_changeEvent_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QEvent * cppArg0 = Shiboken::Converter<QEvent * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // changeEvent(QEvent*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QFileDialog::changeEvent(cppArg0) : cppSelf->changeEvent(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QFileDialogFunc_changeEvent_TypeError:
        const char* overloads[] = {"PySide.QtCore.QEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QFileDialog.changeEvent", overloads);
        return 0;
}

static PyObject* Sbk_QFileDialogFunc_confirmOverwrite(PyObject* self)
{
    QFileDialog* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFileDialog* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // confirmOverwrite()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QFileDialog*>(cppSelf)->confirmOverwrite();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QFileDialogFunc_defaultSuffix(PyObject* self)
{
    QFileDialog* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFileDialog* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // defaultSuffix()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = const_cast<const QFileDialog*>(cppSelf)->defaultSuffix();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QFileDialogFunc_directory(PyObject* self)
{
    QFileDialog* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFileDialog* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // directory()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QDir cppResult = const_cast<const QFileDialog*>(cppSelf)->directory();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QDir >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QFileDialogFunc_done(PyObject* self, PyObject* arg)
{
    QFileDialog* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFileDialog* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: done(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // done(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QFileDialogFunc_done_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // done(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QFileDialog::done(cppArg0) : cppSelf->done(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QFileDialogFunc_done_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QFileDialog.done", overloads);
        return 0;
}

static PyObject* Sbk_QFileDialogFunc_fileMode(PyObject* self)
{
    QFileDialog* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFileDialog* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // fileMode()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QFileDialog::FileMode cppResult = const_cast<const QFileDialog*>(cppSelf)->fileMode();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QFileDialog::FileMode >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QFileDialogFunc_filter(PyObject* self)
{
    QFileDialog* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFileDialog* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // filter()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QFlags<QDir::Filter> cppResult = const_cast<const QFileDialog*>(cppSelf)->filter();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QFlags<QDir::Filter> >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QFileDialogFunc_filters(PyObject* self)
{
    QFileDialog* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFileDialog* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // filters()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QStringList cppResult = const_cast<const QFileDialog*>(cppSelf)->filters();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QStringList >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QFileDialogFunc_getExistingDirectory(PyObject* self, PyObject* args, PyObject* kwds)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 4) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QFileDialog.getExistingDirectory(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOOO:getExistingDirectory", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return 0;


    // Overloaded function decisor
    // 0: getExistingDirectory(QWidget*,QString,QString,QFlags<QFileDialog::Option>)
    if (numArgs == 0) {
        overloadId = 0; // getExistingDirectory(QWidget*,QString,QString,QFlags<QFileDialog::Option>)
    } else if (Shiboken::Converter< ::QWidget * >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // getExistingDirectory(QWidget*,QString,QString,QFlags<QFileDialog::Option>)
        } else if (Shiboken::Converter< QString >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 0; // getExistingDirectory(QWidget*,QString,QString,QFlags<QFileDialog::Option>)
            } else if (Shiboken::Converter< QString >::isConvertible(pyargs[2])) {
                if (numArgs == 3) {
                    overloadId = 0; // getExistingDirectory(QWidget*,QString,QString,QFlags<QFileDialog::Option>)
                } else if (Shiboken::Converter< ::QFlags<QFileDialog::Option> >::isConvertible(pyargs[3])) {
                    overloadId = 0; // getExistingDirectory(QWidget*,QString,QString,QFlags<QFileDialog::Option>)
                }
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QFileDialogFunc_getExistingDirectory_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "parent");
                if (value) {
                    if (pyargs[0])
                        errorArgName = "parent";
                    else if (Shiboken::Converter< ::QWidget * >::isConvertible(value))
                        pyargs[0] = value;
                    else
                        goto Sbk_QFileDialogFunc_getExistingDirectory_TypeError;
                }
                value = PyDict_GetItemString(kwds, "caption");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "caption";
                    else if (Shiboken::Converter< QString >::isConvertible(value))
                        pyargs[1] = value;
                    else
                        goto Sbk_QFileDialogFunc_getExistingDirectory_TypeError;
                }
                value = PyDict_GetItemString(kwds, "dir");
                if (value) {
                    if (pyargs[2])
                        errorArgName = "dir";
                    else if (Shiboken::Converter< QString >::isConvertible(value))
                        pyargs[2] = value;
                    else
                        goto Sbk_QFileDialogFunc_getExistingDirectory_TypeError;
                }
                value = PyDict_GetItemString(kwds, "options");
                if (value) {
                    if (pyargs[3])
                        errorArgName = "options";
                    else if (Shiboken::Converter< ::QFlags<QFileDialog::Option> >::isConvertible(value))
                        pyargs[3] = value;
                    else
                        goto Sbk_QFileDialogFunc_getExistingDirectory_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QFileDialog.getExistingDirectory(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QWidget * cppArg0 = pyargs[0] ? Shiboken::Converter<QWidget * >::toCpp(pyargs[0]) : 0;
            QString cppArg1 = pyargs[1] ? Shiboken::Converter<QString >::toCpp(pyargs[1]) : QString();
            QString cppArg2 = pyargs[2] ? Shiboken::Converter<QString >::toCpp(pyargs[2]) : QString();
            QFlags<QFileDialog::Option> cppArg3 = pyargs[3] ? Shiboken::Converter<QFlags<QFileDialog::Option> >::toCpp(pyargs[3]) : QFileDialog::ShowDirsOnly;

            if(!PyErr_Occurred()) {
                // getExistingDirectory(QWidget*,QString,QString,QFlags<QFileDialog::Option>)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = QFileDialog::getExistingDirectory(cppArg0, cppArg1, cppArg2, cppArg3);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QFileDialogFunc_getExistingDirectory_TypeError:
        const char* overloads[] = {"PySide.QtGui.QWidget = None, QString = QString(), QString = QString(), PySide.QtGui.QFileDialog.Options = QFileDialog.ShowDirsOnly", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QFileDialog.getExistingDirectory", overloads);
        return 0;
}

static PyObject* Sbk_QFileDialogFunc_getOpenFileName(PyObject* self, PyObject* args, PyObject* kwds)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 6) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QFileDialog.getOpenFileName(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOOOOO:getOpenFileName", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3]), &(pyargs[4]), &(pyargs[5])))
        return 0;


    // Overloaded function decisor
    // 0: getOpenFileName(QWidget*,QString,QString,QString,QString*,QFlags<QFileDialog::Option>)
    if (numArgs == 0) {
        overloadId = 0; // getOpenFileName(QWidget*,QString,QString,QString,QString*,QFlags<QFileDialog::Option>)
    } else if (Shiboken::Converter< ::QWidget * >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // getOpenFileName(QWidget*,QString,QString,QString,QString*,QFlags<QFileDialog::Option>)
        } else if (Shiboken::Converter< QString >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 0; // getOpenFileName(QWidget*,QString,QString,QString,QString*,QFlags<QFileDialog::Option>)
            } else if (Shiboken::Converter< QString >::isConvertible(pyargs[2])) {
                if (numArgs == 3) {
                    overloadId = 0; // getOpenFileName(QWidget*,QString,QString,QString,QString*,QFlags<QFileDialog::Option>)
                } else if (Shiboken::Converter< QString >::isConvertible(pyargs[3])) {
                    if (numArgs == 4) {
                        overloadId = 0; // getOpenFileName(QWidget*,QString,QString,QString,QString*,QFlags<QFileDialog::Option>)
                    } else if (Shiboken::Converter< ::QString >::checkType(pyargs[4])) {
                        if (numArgs == 5) {
                            overloadId = 0; // getOpenFileName(QWidget*,QString,QString,QString,QString*,QFlags<QFileDialog::Option>)
                        } else if (Shiboken::Converter< ::QFlags<QFileDialog::Option> >::isConvertible(pyargs[5])) {
                            overloadId = 0; // getOpenFileName(QWidget*,QString,QString,QString,QString*,QFlags<QFileDialog::Option>)
                        }
                    }
                }
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QFileDialogFunc_getOpenFileName_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "parent");
                if (value) {
                    if (pyargs[0])
                        errorArgName = "parent";
                    else if (Shiboken::Converter< ::QWidget * >::isConvertible(value))
                        pyargs[0] = value;
                    else
                        goto Sbk_QFileDialogFunc_getOpenFileName_TypeError;
                }
                value = PyDict_GetItemString(kwds, "caption");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "caption";
                    else if (Shiboken::Converter< QString >::isConvertible(value))
                        pyargs[1] = value;
                    else
                        goto Sbk_QFileDialogFunc_getOpenFileName_TypeError;
                }
                value = PyDict_GetItemString(kwds, "dir");
                if (value) {
                    if (pyargs[2])
                        errorArgName = "dir";
                    else if (Shiboken::Converter< QString >::isConvertible(value))
                        pyargs[2] = value;
                    else
                        goto Sbk_QFileDialogFunc_getOpenFileName_TypeError;
                }
                value = PyDict_GetItemString(kwds, "filter");
                if (value) {
                    if (pyargs[3])
                        errorArgName = "filter";
                    else if (Shiboken::Converter< QString >::isConvertible(value))
                        pyargs[3] = value;
                    else
                        goto Sbk_QFileDialogFunc_getOpenFileName_TypeError;
                }
                value = PyDict_GetItemString(kwds, "selectedFilter");
                if (value) {
                    if (pyargs[4])
                        errorArgName = "selectedFilter";
                    else if (Shiboken::Converter< ::QString * >::isConvertible(value))
                        pyargs[4] = value;
                    else
                        goto Sbk_QFileDialogFunc_getOpenFileName_TypeError;
                }
                value = PyDict_GetItemString(kwds, "options");
                if (value) {
                    if (pyargs[5])
                        errorArgName = "options";
                    else if (Shiboken::Converter< ::QFlags<QFileDialog::Option> >::isConvertible(value))
                        pyargs[5] = value;
                    else
                        goto Sbk_QFileDialogFunc_getOpenFileName_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QFileDialog.getOpenFileName(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QWidget * cppArg0 = pyargs[0] ? Shiboken::Converter<QWidget * >::toCpp(pyargs[0]) : 0;
            QString cppArg1 = pyargs[1] ? Shiboken::Converter<QString >::toCpp(pyargs[1]) : QString();
            QString cppArg2 = pyargs[2] ? Shiboken::Converter<QString >::toCpp(pyargs[2]) : QString();
            QString cppArg3 = pyargs[3] ? Shiboken::Converter<QString >::toCpp(pyargs[3]) : QString();
            QString cppArg4 = pyargs[4] ? Shiboken::Converter<QString >::toCpp(pyargs[4]) : QString();
            QFlags<QFileDialog::Option> cppArg5 = pyargs[5] ? Shiboken::Converter<QFlags<QFileDialog::Option> >::toCpp(pyargs[5]) : QFlags<QFileDialog::Option>(0);

            if(!PyErr_Occurred()) {
                // getOpenFileName(QWidget*,QString,QString,QString,QString*,QFlags<QFileDialog::Option>)


                // Begin code injection

                // TEMPLATE - return_for_QFileDialog - START
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString retval_ = QFileDialog::getOpenFileName(cppArg0, cppArg1, cppArg2, cppArg3, &cppArg4, cppArg5);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::makeTuple(retval_, cppArg4);
                // TEMPLATE - return_for_QFileDialog - END

                // End of code injection
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QFileDialogFunc_getOpenFileName_TypeError:
        const char* overloads[] = {"PySide.QtGui.QWidget = None, QString = QString(), QString = QString(), QString = QString(), QString = QString(), PySide.QtGui.QFileDialog.Options = 0", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QFileDialog.getOpenFileName", overloads);
        return 0;
}

static PyObject* Sbk_QFileDialogFunc_getOpenFileNames(PyObject* self, PyObject* args, PyObject* kwds)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 6) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QFileDialog.getOpenFileNames(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOOOOO:getOpenFileNames", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3]), &(pyargs[4]), &(pyargs[5])))
        return 0;


    // Overloaded function decisor
    // 0: getOpenFileNames(QWidget*,QString,QString,QString,QString*,QFlags<QFileDialog::Option>)
    if (numArgs == 0) {
        overloadId = 0; // getOpenFileNames(QWidget*,QString,QString,QString,QString*,QFlags<QFileDialog::Option>)
    } else if (Shiboken::Converter< ::QWidget * >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // getOpenFileNames(QWidget*,QString,QString,QString,QString*,QFlags<QFileDialog::Option>)
        } else if (Shiboken::Converter< QString >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 0; // getOpenFileNames(QWidget*,QString,QString,QString,QString*,QFlags<QFileDialog::Option>)
            } else if (Shiboken::Converter< QString >::isConvertible(pyargs[2])) {
                if (numArgs == 3) {
                    overloadId = 0; // getOpenFileNames(QWidget*,QString,QString,QString,QString*,QFlags<QFileDialog::Option>)
                } else if (Shiboken::Converter< QString >::isConvertible(pyargs[3])) {
                    if (numArgs == 4) {
                        overloadId = 0; // getOpenFileNames(QWidget*,QString,QString,QString,QString*,QFlags<QFileDialog::Option>)
                    } else if (Shiboken::Converter< ::QString >::checkType(pyargs[4])) {
                        if (numArgs == 5) {
                            overloadId = 0; // getOpenFileNames(QWidget*,QString,QString,QString,QString*,QFlags<QFileDialog::Option>)
                        } else if (Shiboken::Converter< ::QFlags<QFileDialog::Option> >::isConvertible(pyargs[5])) {
                            overloadId = 0; // getOpenFileNames(QWidget*,QString,QString,QString,QString*,QFlags<QFileDialog::Option>)
                        }
                    }
                }
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QFileDialogFunc_getOpenFileNames_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "parent");
                if (value) {
                    if (pyargs[0])
                        errorArgName = "parent";
                    else if (Shiboken::Converter< ::QWidget * >::isConvertible(value))
                        pyargs[0] = value;
                    else
                        goto Sbk_QFileDialogFunc_getOpenFileNames_TypeError;
                }
                value = PyDict_GetItemString(kwds, "caption");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "caption";
                    else if (Shiboken::Converter< QString >::isConvertible(value))
                        pyargs[1] = value;
                    else
                        goto Sbk_QFileDialogFunc_getOpenFileNames_TypeError;
                }
                value = PyDict_GetItemString(kwds, "dir");
                if (value) {
                    if (pyargs[2])
                        errorArgName = "dir";
                    else if (Shiboken::Converter< QString >::isConvertible(value))
                        pyargs[2] = value;
                    else
                        goto Sbk_QFileDialogFunc_getOpenFileNames_TypeError;
                }
                value = PyDict_GetItemString(kwds, "filter");
                if (value) {
                    if (pyargs[3])
                        errorArgName = "filter";
                    else if (Shiboken::Converter< QString >::isConvertible(value))
                        pyargs[3] = value;
                    else
                        goto Sbk_QFileDialogFunc_getOpenFileNames_TypeError;
                }
                value = PyDict_GetItemString(kwds, "selectedFilter");
                if (value) {
                    if (pyargs[4])
                        errorArgName = "selectedFilter";
                    else if (Shiboken::Converter< ::QString * >::isConvertible(value))
                        pyargs[4] = value;
                    else
                        goto Sbk_QFileDialogFunc_getOpenFileNames_TypeError;
                }
                value = PyDict_GetItemString(kwds, "options");
                if (value) {
                    if (pyargs[5])
                        errorArgName = "options";
                    else if (Shiboken::Converter< ::QFlags<QFileDialog::Option> >::isConvertible(value))
                        pyargs[5] = value;
                    else
                        goto Sbk_QFileDialogFunc_getOpenFileNames_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QFileDialog.getOpenFileNames(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QWidget * cppArg0 = pyargs[0] ? Shiboken::Converter<QWidget * >::toCpp(pyargs[0]) : 0;
            QString cppArg1 = pyargs[1] ? Shiboken::Converter<QString >::toCpp(pyargs[1]) : QString();
            QString cppArg2 = pyargs[2] ? Shiboken::Converter<QString >::toCpp(pyargs[2]) : QString();
            QString cppArg3 = pyargs[3] ? Shiboken::Converter<QString >::toCpp(pyargs[3]) : QString();
            QString cppArg4 = pyargs[4] ? Shiboken::Converter<QString >::toCpp(pyargs[4]) : QString();
            QFlags<QFileDialog::Option> cppArg5 = pyargs[5] ? Shiboken::Converter<QFlags<QFileDialog::Option> >::toCpp(pyargs[5]) : QFlags<QFileDialog::Option>(0);

            if(!PyErr_Occurred()) {
                // getOpenFileNames(QWidget*,QString,QString,QString,QString*,QFlags<QFileDialog::Option>)


                // Begin code injection

                // TEMPLATE - return_for_QFileDialog - START
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QStringList retval_ = QFileDialog::getOpenFileNames(cppArg0, cppArg1, cppArg2, cppArg3, &cppArg4, cppArg5);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::makeTuple(retval_, cppArg4);
                // TEMPLATE - return_for_QFileDialog - END

                // End of code injection
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QFileDialogFunc_getOpenFileNames_TypeError:
        const char* overloads[] = {"PySide.QtGui.QWidget = None, QString = QString(), QString = QString(), QString = QString(), QString = QString(), PySide.QtGui.QFileDialog.Options = 0", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QFileDialog.getOpenFileNames", overloads);
        return 0;
}

static PyObject* Sbk_QFileDialogFunc_getSaveFileName(PyObject* self, PyObject* args, PyObject* kwds)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 6) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QFileDialog.getSaveFileName(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOOOOO:getSaveFileName", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3]), &(pyargs[4]), &(pyargs[5])))
        return 0;


    // Overloaded function decisor
    // 0: getSaveFileName(QWidget*,QString,QString,QString,QString*,QFlags<QFileDialog::Option>)
    if (numArgs == 0) {
        overloadId = 0; // getSaveFileName(QWidget*,QString,QString,QString,QString*,QFlags<QFileDialog::Option>)
    } else if (Shiboken::Converter< ::QWidget * >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // getSaveFileName(QWidget*,QString,QString,QString,QString*,QFlags<QFileDialog::Option>)
        } else if (Shiboken::Converter< QString >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 0; // getSaveFileName(QWidget*,QString,QString,QString,QString*,QFlags<QFileDialog::Option>)
            } else if (Shiboken::Converter< QString >::isConvertible(pyargs[2])) {
                if (numArgs == 3) {
                    overloadId = 0; // getSaveFileName(QWidget*,QString,QString,QString,QString*,QFlags<QFileDialog::Option>)
                } else if (Shiboken::Converter< QString >::isConvertible(pyargs[3])) {
                    if (numArgs == 4) {
                        overloadId = 0; // getSaveFileName(QWidget*,QString,QString,QString,QString*,QFlags<QFileDialog::Option>)
                    } else if (Shiboken::Converter< ::QString >::checkType(pyargs[4])) {
                        if (numArgs == 5) {
                            overloadId = 0; // getSaveFileName(QWidget*,QString,QString,QString,QString*,QFlags<QFileDialog::Option>)
                        } else if (Shiboken::Converter< ::QFlags<QFileDialog::Option> >::isConvertible(pyargs[5])) {
                            overloadId = 0; // getSaveFileName(QWidget*,QString,QString,QString,QString*,QFlags<QFileDialog::Option>)
                        }
                    }
                }
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QFileDialogFunc_getSaveFileName_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "parent");
                if (value) {
                    if (pyargs[0])
                        errorArgName = "parent";
                    else if (Shiboken::Converter< ::QWidget * >::isConvertible(value))
                        pyargs[0] = value;
                    else
                        goto Sbk_QFileDialogFunc_getSaveFileName_TypeError;
                }
                value = PyDict_GetItemString(kwds, "caption");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "caption";
                    else if (Shiboken::Converter< QString >::isConvertible(value))
                        pyargs[1] = value;
                    else
                        goto Sbk_QFileDialogFunc_getSaveFileName_TypeError;
                }
                value = PyDict_GetItemString(kwds, "dir");
                if (value) {
                    if (pyargs[2])
                        errorArgName = "dir";
                    else if (Shiboken::Converter< QString >::isConvertible(value))
                        pyargs[2] = value;
                    else
                        goto Sbk_QFileDialogFunc_getSaveFileName_TypeError;
                }
                value = PyDict_GetItemString(kwds, "filter");
                if (value) {
                    if (pyargs[3])
                        errorArgName = "filter";
                    else if (Shiboken::Converter< QString >::isConvertible(value))
                        pyargs[3] = value;
                    else
                        goto Sbk_QFileDialogFunc_getSaveFileName_TypeError;
                }
                value = PyDict_GetItemString(kwds, "selectedFilter");
                if (value) {
                    if (pyargs[4])
                        errorArgName = "selectedFilter";
                    else if (Shiboken::Converter< ::QString * >::isConvertible(value))
                        pyargs[4] = value;
                    else
                        goto Sbk_QFileDialogFunc_getSaveFileName_TypeError;
                }
                value = PyDict_GetItemString(kwds, "options");
                if (value) {
                    if (pyargs[5])
                        errorArgName = "options";
                    else if (Shiboken::Converter< ::QFlags<QFileDialog::Option> >::isConvertible(value))
                        pyargs[5] = value;
                    else
                        goto Sbk_QFileDialogFunc_getSaveFileName_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QFileDialog.getSaveFileName(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QWidget * cppArg0 = pyargs[0] ? Shiboken::Converter<QWidget * >::toCpp(pyargs[0]) : 0;
            QString cppArg1 = pyargs[1] ? Shiboken::Converter<QString >::toCpp(pyargs[1]) : QString();
            QString cppArg2 = pyargs[2] ? Shiboken::Converter<QString >::toCpp(pyargs[2]) : QString();
            QString cppArg3 = pyargs[3] ? Shiboken::Converter<QString >::toCpp(pyargs[3]) : QString();
            QString cppArg4 = pyargs[4] ? Shiboken::Converter<QString >::toCpp(pyargs[4]) : QString();
            QFlags<QFileDialog::Option> cppArg5 = pyargs[5] ? Shiboken::Converter<QFlags<QFileDialog::Option> >::toCpp(pyargs[5]) : QFlags<QFileDialog::Option>(0);

            if(!PyErr_Occurred()) {
                // getSaveFileName(QWidget*,QString,QString,QString,QString*,QFlags<QFileDialog::Option>)


                // Begin code injection

                // TEMPLATE - return_for_QFileDialog - START
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString retval_ = QFileDialog::getSaveFileName(cppArg0, cppArg1, cppArg2, cppArg3, &cppArg4, cppArg5);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::makeTuple(retval_, cppArg4);
                // TEMPLATE - return_for_QFileDialog - END

                // End of code injection
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QFileDialogFunc_getSaveFileName_TypeError:
        const char* overloads[] = {"PySide.QtGui.QWidget = None, QString = QString(), QString = QString(), QString = QString(), QString = QString(), PySide.QtGui.QFileDialog.Options = 0", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QFileDialog.getSaveFileName", overloads);
        return 0;
}

static PyObject* Sbk_QFileDialogFunc_history(PyObject* self)
{
    QFileDialog* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFileDialog* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // history()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QStringList cppResult = const_cast<const QFileDialog*>(cppSelf)->history();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QStringList >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QFileDialogFunc_iconProvider(PyObject* self)
{
    QFileDialog* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFileDialog* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // iconProvider()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QFileIconProvider * cppResult = const_cast<const QFileDialog*>(cppSelf)->iconProvider();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QFileIconProvider * >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QFileDialogFunc_isNameFilterDetailsVisible(PyObject* self)
{
    QFileDialog* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFileDialog* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isNameFilterDetailsVisible()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QFileDialog*>(cppSelf)->isNameFilterDetailsVisible();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QFileDialogFunc_isReadOnly(PyObject* self)
{
    QFileDialog* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFileDialog* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isReadOnly()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QFileDialog*>(cppSelf)->isReadOnly();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QFileDialogFunc_itemDelegate(PyObject* self)
{
    QFileDialog* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFileDialog* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // itemDelegate()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QAbstractItemDelegate * cppResult = const_cast<const QFileDialog*>(cppSelf)->itemDelegate();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QAbstractItemDelegate * >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QFileDialogFunc_labelText(PyObject* self, PyObject* arg)
{
    QFileDialog* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFileDialog* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: labelText(QFileDialog::DialogLabel)const
    if (Shiboken::Converter< ::QFileDialog::DialogLabel >::isConvertible(arg)) {
        overloadId = 0; // labelText(QFileDialog::DialogLabel)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QFileDialogFunc_labelText_TypeError;

    // Call function/method
    {
        {
            QFileDialog::DialogLabel cppArg0 = Shiboken::Converter<QFileDialog::DialogLabel >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // labelText(QFileDialog::DialogLabel)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = const_cast<const QFileDialog*>(cppSelf)->labelText(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QFileDialogFunc_labelText_TypeError:
        const char* overloads[] = {"PySide.QtGui.QFileDialog.DialogLabel", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QFileDialog.labelText", overloads);
        return 0;
}

static PyObject* Sbk_QFileDialogFunc_nameFilters(PyObject* self)
{
    QFileDialog* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFileDialog* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // nameFilters()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QStringList cppResult = const_cast<const QFileDialog*>(cppSelf)->nameFilters();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QStringList >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QFileDialogFunc_open(PyObject* self, PyObject* args)
{
    QFileDialog* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFileDialog* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs == 1)
        goto Sbk_QFileDialogFunc_open_TypeError;

    if (!PyArg_UnpackTuple(args, "open", 0, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: open()
    // 1: open(QObject*,const char*)
    if (numArgs == 0) {
        overloadId = 0; // open()
    } else if (numArgs == 2 && Shiboken::Converter< ::QObject * >::isConvertible(pyargs[0]) && Shiboken::Converter< const char * >::isConvertible(pyargs[1])) {
        overloadId = 1; // open(QObject*,const char*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QFileDialogFunc_open_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // open()
            {

                if(!PyErr_Occurred()) {
                    // open()
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->open();
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // open(QObject*,const char*)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QObject * cppArg0 = Shiboken::Converter<QObject * >::toCpp(pyargs[0]);
                const char * cppArg1 = Shiboken::Converter<const char * >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // open(QObject*,const char*)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->open(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QFileDialogFunc_open_TypeError:
        const char* overloads[] = {"", "PySide.QtCore.QObject, str", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QFileDialog.open", overloads);
        return 0;
}

static PyObject* Sbk_QFileDialogFunc_options(PyObject* self)
{
    QFileDialog* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFileDialog* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // options()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QFlags<QFileDialog::Option> cppResult = const_cast<const QFileDialog*>(cppSelf)->options();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QFlags<QFileDialog::Option> >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QFileDialogFunc_proxyModel(PyObject* self)
{
    QFileDialog* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFileDialog* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // proxyModel()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QAbstractProxyModel * cppResult = const_cast<const QFileDialog*>(cppSelf)->proxyModel();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QAbstractProxyModel * >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QFileDialogFunc_resolveSymlinks(PyObject* self)
{
    QFileDialog* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFileDialog* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // resolveSymlinks()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QFileDialog*>(cppSelf)->resolveSymlinks();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QFileDialogFunc_restoreState(PyObject* self, PyObject* arg)
{
    QFileDialog* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFileDialog* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: restoreState(QByteArray)
    if (Shiboken::Converter< ::QByteArray >::isConvertible(arg)) {
        overloadId = 0; // restoreState(QByteArray)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QFileDialogFunc_restoreState_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QByteArray cppArg0 = Shiboken::Converter<QByteArray >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // restoreState(QByteArray)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->restoreState(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QFileDialogFunc_restoreState_TypeError:
        const char* overloads[] = {"PySide.QtCore.QByteArray", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QFileDialog.restoreState", overloads);
        return 0;
}

static PyObject* Sbk_QFileDialogFunc_saveState(PyObject* self)
{
    QFileDialog* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFileDialog* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // saveState()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QByteArray cppResult = const_cast<const QFileDialog*>(cppSelf)->saveState();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QByteArray >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QFileDialogFunc_selectFile(PyObject* self, PyObject* arg)
{
    QFileDialog* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFileDialog* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: selectFile(QString)
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // selectFile(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QFileDialogFunc_selectFile_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // selectFile(QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->selectFile(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QFileDialogFunc_selectFile_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QFileDialog.selectFile", overloads);
        return 0;
}

static PyObject* Sbk_QFileDialogFunc_selectFilter(PyObject* self, PyObject* arg)
{
    QFileDialog* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFileDialog* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: selectFilter(QString)
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // selectFilter(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QFileDialogFunc_selectFilter_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // selectFilter(QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->selectFilter(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QFileDialogFunc_selectFilter_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QFileDialog.selectFilter", overloads);
        return 0;
}

static PyObject* Sbk_QFileDialogFunc_selectNameFilter(PyObject* self, PyObject* arg)
{
    QFileDialog* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFileDialog* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: selectNameFilter(QString)
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // selectNameFilter(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QFileDialogFunc_selectNameFilter_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // selectNameFilter(QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->selectNameFilter(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QFileDialogFunc_selectNameFilter_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QFileDialog.selectNameFilter", overloads);
        return 0;
}

static PyObject* Sbk_QFileDialogFunc_selectedFiles(PyObject* self)
{
    QFileDialog* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFileDialog* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // selectedFiles()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QStringList cppResult = const_cast<const QFileDialog*>(cppSelf)->selectedFiles();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QStringList >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QFileDialogFunc_selectedFilter(PyObject* self)
{
    QFileDialog* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFileDialog* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // selectedFilter()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = const_cast<const QFileDialog*>(cppSelf)->selectedFilter();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QFileDialogFunc_selectedNameFilter(PyObject* self)
{
    QFileDialog* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFileDialog* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // selectedNameFilter()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = const_cast<const QFileDialog*>(cppSelf)->selectedNameFilter();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QFileDialogFunc_setAcceptMode(PyObject* self, PyObject* arg)
{
    QFileDialog* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFileDialog* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setAcceptMode(QFileDialog::AcceptMode)
    if (Shiboken::Converter< ::QFileDialog::AcceptMode >::isConvertible(arg)) {
        overloadId = 0; // setAcceptMode(QFileDialog::AcceptMode)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QFileDialogFunc_setAcceptMode_TypeError;

    // Call function/method
    {
        {
            QFileDialog::AcceptMode cppArg0 = Shiboken::Converter<QFileDialog::AcceptMode >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setAcceptMode(QFileDialog::AcceptMode)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setAcceptMode(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QFileDialogFunc_setAcceptMode_TypeError:
        const char* overloads[] = {"PySide.QtGui.QFileDialog.AcceptMode", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QFileDialog.setAcceptMode", overloads);
        return 0;
}

static PyObject* Sbk_QFileDialogFunc_setConfirmOverwrite(PyObject* self, PyObject* arg)
{
    QFileDialog* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFileDialog* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setConfirmOverwrite(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setConfirmOverwrite(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QFileDialogFunc_setConfirmOverwrite_TypeError;

    // Call function/method
    {
        {
            bool cppArg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setConfirmOverwrite(bool)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setConfirmOverwrite(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QFileDialogFunc_setConfirmOverwrite_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QFileDialog.setConfirmOverwrite", overloads);
        return 0;
}

static PyObject* Sbk_QFileDialogFunc_setDefaultSuffix(PyObject* self, PyObject* arg)
{
    QFileDialog* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFileDialog* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setDefaultSuffix(QString)
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // setDefaultSuffix(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QFileDialogFunc_setDefaultSuffix_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setDefaultSuffix(QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setDefaultSuffix(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QFileDialogFunc_setDefaultSuffix_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QFileDialog.setDefaultSuffix", overloads);
        return 0;
}

static PyObject* Sbk_QFileDialogFunc_setDirectory(PyObject* self, PyObject* arg)
{
    QFileDialog* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFileDialog* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setDirectory(QDir)
    // 1: setDirectory(QString)
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 1; // setDirectory(QString)
    } else if (Shiboken::Converter< ::QDir >::isConvertible(arg)) {
        overloadId = 0; // setDirectory(QDir)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QFileDialogFunc_setDirectory_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // setDirectory(QDir)
            {
                if (!Shiboken::Object::isValid(arg))
                    return 0;
                QDir cppArg0 = Shiboken::Converter<QDir >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // setDirectory(QDir)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setDirectory(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // setDirectory(QString)
            {
                QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // setDirectory(QString)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setDirectory(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QFileDialogFunc_setDirectory_TypeError:
        const char* overloads[] = {"PySide.QtCore.QDir", "QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QFileDialog.setDirectory", overloads);
        return 0;
}

static PyObject* Sbk_QFileDialogFunc_setFileMode(PyObject* self, PyObject* arg)
{
    QFileDialog* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFileDialog* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setFileMode(QFileDialog::FileMode)
    if (Shiboken::Converter< ::QFileDialog::FileMode >::isConvertible(arg)) {
        overloadId = 0; // setFileMode(QFileDialog::FileMode)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QFileDialogFunc_setFileMode_TypeError;

    // Call function/method
    {
        {
            QFileDialog::FileMode cppArg0 = Shiboken::Converter<QFileDialog::FileMode >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setFileMode(QFileDialog::FileMode)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setFileMode(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QFileDialogFunc_setFileMode_TypeError:
        const char* overloads[] = {"PySide.QtGui.QFileDialog.FileMode", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QFileDialog.setFileMode", overloads);
        return 0;
}

static PyObject* Sbk_QFileDialogFunc_setFilter(PyObject* self, PyObject* arg)
{
    QFileDialog* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFileDialog* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setFilter(QFlags<QDir::Filter>)
    // 1: setFilter(QString)
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 1; // setFilter(QString)
    } else if (Shiboken::Converter< ::QFlags<QDir::Filter> >::isConvertible(arg)) {
        overloadId = 0; // setFilter(QFlags<QDir::Filter>)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QFileDialogFunc_setFilter_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // setFilter(QFlags<QDir::Filter>)
            {
                QFlags<QDir::Filter> cppArg0 = Shiboken::Converter<QFlags<QDir::Filter> >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // setFilter(QFlags<QDir::Filter>)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setFilter(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // setFilter(QString)
            {
                QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // setFilter(QString)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setFilter(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QFileDialogFunc_setFilter_TypeError:
        const char* overloads[] = {"PySide.QtCore.QDir.Filters", "QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QFileDialog.setFilter", overloads);
        return 0;
}

static PyObject* Sbk_QFileDialogFunc_setFilters(PyObject* self, PyObject* arg)
{
    QFileDialog* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFileDialog* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setFilters(QStringList)
    if (Shiboken::Converter< ::QStringList >::isConvertible(arg)) {
        overloadId = 0; // setFilters(QStringList)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QFileDialogFunc_setFilters_TypeError;

    // Call function/method
    {
        {
            QStringList cppArg0 = Shiboken::Converter<QStringList >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setFilters(QStringList)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setFilters(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QFileDialogFunc_setFilters_TypeError:
        const char* overloads[] = {"list", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QFileDialog.setFilters", overloads);
        return 0;
}

static PyObject* Sbk_QFileDialogFunc_setHistory(PyObject* self, PyObject* arg)
{
    QFileDialog* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFileDialog* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setHistory(QStringList)
    if (Shiboken::Converter< ::QStringList >::isConvertible(arg)) {
        overloadId = 0; // setHistory(QStringList)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QFileDialogFunc_setHistory_TypeError;

    // Call function/method
    {
        {
            QStringList cppArg0 = Shiboken::Converter<QStringList >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setHistory(QStringList)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setHistory(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QFileDialogFunc_setHistory_TypeError:
        const char* overloads[] = {"list", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QFileDialog.setHistory", overloads);
        return 0;
}

static PyObject* Sbk_QFileDialogFunc_setIconProvider(PyObject* self, PyObject* arg)
{
    QFileDialog* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFileDialog* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setIconProvider(QFileIconProvider*)
    if (Shiboken::Converter< ::QFileIconProvider * >::isConvertible(arg)) {
        overloadId = 0; // setIconProvider(QFileIconProvider*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QFileDialogFunc_setIconProvider_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QFileIconProvider * cppArg0 = Shiboken::Converter<QFileIconProvider * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setIconProvider(QFileIconProvider*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setIconProvider(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                Shiboken::Object::setParent(self, arg);
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QFileDialogFunc_setIconProvider_TypeError:
        const char* overloads[] = {"PySide.QtGui.QFileIconProvider", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QFileDialog.setIconProvider", overloads);
        return 0;
}

static PyObject* Sbk_QFileDialogFunc_setItemDelegate(PyObject* self, PyObject* arg)
{
    QFileDialog* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFileDialog* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setItemDelegate(QAbstractItemDelegate*)
    if (Shiboken::Converter< ::QAbstractItemDelegate * >::isConvertible(arg)) {
        overloadId = 0; // setItemDelegate(QAbstractItemDelegate*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QFileDialogFunc_setItemDelegate_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QAbstractItemDelegate * cppArg0 = Shiboken::Converter<QAbstractItemDelegate * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setItemDelegate(QAbstractItemDelegate*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setItemDelegate(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                Shiboken::Object::keepReference(reinterpret_cast<SbkObject*>(self), "setItemDelegate(QAbstractItemDelegate*)1", arg);
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QFileDialogFunc_setItemDelegate_TypeError:
        const char* overloads[] = {"PySide.QtGui.QAbstractItemDelegate", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QFileDialog.setItemDelegate", overloads);
        return 0;
}

static PyObject* Sbk_QFileDialogFunc_setLabelText(PyObject* self, PyObject* args)
{
    QFileDialog* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFileDialog* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setLabelText", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setLabelText(QFileDialog::DialogLabel,QString)
    if (numArgs == 2 && Shiboken::Converter< ::QFileDialog::DialogLabel >::isConvertible(pyargs[0]) && Shiboken::Converter< QString >::isConvertible(pyargs[1])) {
        overloadId = 0; // setLabelText(QFileDialog::DialogLabel,QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QFileDialogFunc_setLabelText_TypeError;

    // Call function/method
    {
        {
            QFileDialog::DialogLabel cppArg0 = Shiboken::Converter<QFileDialog::DialogLabel >::toCpp(pyargs[0]);
            QString cppArg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // setLabelText(QFileDialog::DialogLabel,QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setLabelText(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QFileDialogFunc_setLabelText_TypeError:
        const char* overloads[] = {"PySide.QtGui.QFileDialog.DialogLabel, QString", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QFileDialog.setLabelText", overloads);
        return 0;
}

static PyObject* Sbk_QFileDialogFunc_setNameFilter(PyObject* self, PyObject* arg)
{
    QFileDialog* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFileDialog* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setNameFilter(QString)
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // setNameFilter(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QFileDialogFunc_setNameFilter_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setNameFilter(QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setNameFilter(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QFileDialogFunc_setNameFilter_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QFileDialog.setNameFilter", overloads);
        return 0;
}

static PyObject* Sbk_QFileDialogFunc_setNameFilterDetailsVisible(PyObject* self, PyObject* arg)
{
    QFileDialog* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFileDialog* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setNameFilterDetailsVisible(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setNameFilterDetailsVisible(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QFileDialogFunc_setNameFilterDetailsVisible_TypeError;

    // Call function/method
    {
        {
            bool cppArg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setNameFilterDetailsVisible(bool)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setNameFilterDetailsVisible(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QFileDialogFunc_setNameFilterDetailsVisible_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QFileDialog.setNameFilterDetailsVisible", overloads);
        return 0;
}

static PyObject* Sbk_QFileDialogFunc_setNameFilters(PyObject* self, PyObject* arg)
{
    QFileDialog* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFileDialog* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setNameFilters(QStringList)
    if (Shiboken::Converter< ::QStringList >::isConvertible(arg)) {
        overloadId = 0; // setNameFilters(QStringList)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QFileDialogFunc_setNameFilters_TypeError;

    // Call function/method
    {
        {
            QStringList cppArg0 = Shiboken::Converter<QStringList >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setNameFilters(QStringList)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setNameFilters(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QFileDialogFunc_setNameFilters_TypeError:
        const char* overloads[] = {"list", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QFileDialog.setNameFilters", overloads);
        return 0;
}

static PyObject* Sbk_QFileDialogFunc_setOption(PyObject* self, PyObject* args, PyObject* kwds)
{
    QFileDialog* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFileDialog* >::toCpp(self);

    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QFileDialog.setOption(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QFileDialog.setOption(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:setOption", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setOption(QFileDialog::Option,bool)
    if (Shiboken::Converter< ::QFileDialog::Option >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // setOption(QFileDialog::Option,bool)
        } else if (SbkNumber_Check(pyargs[1])) {
            overloadId = 0; // setOption(QFileDialog::Option,bool)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QFileDialogFunc_setOption_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "on");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "on";
                    else if (SbkNumber_Check(value))
                        pyargs[1] = value;
                    else
                        goto Sbk_QFileDialogFunc_setOption_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QFileDialog.setOption(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QFileDialog::Option cppArg0 = Shiboken::Converter<QFileDialog::Option >::toCpp(pyargs[0]);
            bool cppArg1 = pyargs[1] ? Shiboken::Converter<bool >::toCpp(pyargs[1]) : true;

            if(!PyErr_Occurred()) {
                // setOption(QFileDialog::Option,bool)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setOption(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QFileDialogFunc_setOption_TypeError:
        const char* overloads[] = {"PySide.QtGui.QFileDialog.Option, bool = true", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QFileDialog.setOption", overloads);
        return 0;
}

static PyObject* Sbk_QFileDialogFunc_setOptions(PyObject* self, PyObject* arg)
{
    QFileDialog* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFileDialog* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setOptions(QFlags<QFileDialog::Option>)
    if (Shiboken::Converter< ::QFlags<QFileDialog::Option> >::isConvertible(arg)) {
        overloadId = 0; // setOptions(QFlags<QFileDialog::Option>)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QFileDialogFunc_setOptions_TypeError;

    // Call function/method
    {
        {
            QFlags<QFileDialog::Option> cppArg0 = Shiboken::Converter<QFlags<QFileDialog::Option> >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setOptions(QFlags<QFileDialog::Option>)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setOptions(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QFileDialogFunc_setOptions_TypeError:
        const char* overloads[] = {"PySide.QtGui.QFileDialog.Options", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QFileDialog.setOptions", overloads);
        return 0;
}

static PyObject* Sbk_QFileDialogFunc_setProxyModel(PyObject* self, PyObject* arg)
{
    QFileDialog* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFileDialog* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setProxyModel(QAbstractProxyModel*)
    if (Shiboken::Converter< ::QAbstractProxyModel * >::isConvertible(arg)) {
        overloadId = 0; // setProxyModel(QAbstractProxyModel*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QFileDialogFunc_setProxyModel_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QAbstractProxyModel * cppArg0 = Shiboken::Converter<QAbstractProxyModel * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setProxyModel(QAbstractProxyModel*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setProxyModel(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QFileDialogFunc_setProxyModel_TypeError:
        const char* overloads[] = {"PySide.QtGui.QAbstractProxyModel", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QFileDialog.setProxyModel", overloads);
        return 0;
}

static PyObject* Sbk_QFileDialogFunc_setReadOnly(PyObject* self, PyObject* arg)
{
    QFileDialog* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFileDialog* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setReadOnly(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setReadOnly(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QFileDialogFunc_setReadOnly_TypeError;

    // Call function/method
    {
        {
            bool cppArg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setReadOnly(bool)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setReadOnly(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QFileDialogFunc_setReadOnly_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QFileDialog.setReadOnly", overloads);
        return 0;
}

static PyObject* Sbk_QFileDialogFunc_setResolveSymlinks(PyObject* self, PyObject* arg)
{
    QFileDialog* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFileDialog* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setResolveSymlinks(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setResolveSymlinks(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QFileDialogFunc_setResolveSymlinks_TypeError;

    // Call function/method
    {
        {
            bool cppArg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setResolveSymlinks(bool)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setResolveSymlinks(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QFileDialogFunc_setResolveSymlinks_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QFileDialog.setResolveSymlinks", overloads);
        return 0;
}

static PyObject* Sbk_QFileDialogFunc_setSidebarUrls(PyObject* self, PyObject* arg)
{
    QFileDialog* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFileDialog* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setSidebarUrls(QList<QUrl>)
    if (Shiboken::Converter< ::QList<QUrl > >::isConvertible(arg)) {
        overloadId = 0; // setSidebarUrls(QList<QUrl>)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QFileDialogFunc_setSidebarUrls_TypeError;

    // Call function/method
    {
        {
            QList<QUrl > cppArg0 = Shiboken::Converter<QList<QUrl > >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setSidebarUrls(QList<QUrl>)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setSidebarUrls(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QFileDialogFunc_setSidebarUrls_TypeError:
        const char* overloads[] = {"list", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QFileDialog.setSidebarUrls", overloads);
        return 0;
}

static PyObject* Sbk_QFileDialogFunc_setViewMode(PyObject* self, PyObject* arg)
{
    QFileDialog* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFileDialog* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setViewMode(QFileDialog::ViewMode)
    if (Shiboken::Converter< ::QFileDialog::ViewMode >::isConvertible(arg)) {
        overloadId = 0; // setViewMode(QFileDialog::ViewMode)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QFileDialogFunc_setViewMode_TypeError;

    // Call function/method
    {
        {
            QFileDialog::ViewMode cppArg0 = Shiboken::Converter<QFileDialog::ViewMode >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setViewMode(QFileDialog::ViewMode)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setViewMode(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QFileDialogFunc_setViewMode_TypeError:
        const char* overloads[] = {"PySide.QtGui.QFileDialog.ViewMode", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QFileDialog.setViewMode", overloads);
        return 0;
}

static PyObject* Sbk_QFileDialogFunc_setVisible(PyObject* self, PyObject* arg)
{
    QFileDialog* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFileDialog* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setVisible(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setVisible(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QFileDialogFunc_setVisible_TypeError;

    // Call function/method
    {
        {
            bool cppArg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setVisible(bool)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QFileDialog::setVisible(cppArg0) : cppSelf->setVisible(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QFileDialogFunc_setVisible_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QFileDialog.setVisible", overloads);
        return 0;
}

static PyObject* Sbk_QFileDialogFunc_sidebarUrls(PyObject* self)
{
    QFileDialog* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFileDialog* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // sidebarUrls()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QList<QUrl > cppResult = const_cast<const QFileDialog*>(cppSelf)->sidebarUrls();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QList<QUrl > >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QFileDialogFunc_testOption(PyObject* self, PyObject* arg)
{
    QFileDialog* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFileDialog* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: testOption(QFileDialog::Option)const
    if (Shiboken::Converter< ::QFileDialog::Option >::isConvertible(arg)) {
        overloadId = 0; // testOption(QFileDialog::Option)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QFileDialogFunc_testOption_TypeError;

    // Call function/method
    {
        {
            QFileDialog::Option cppArg0 = Shiboken::Converter<QFileDialog::Option >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // testOption(QFileDialog::Option)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QFileDialog*>(cppSelf)->testOption(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QFileDialogFunc_testOption_TypeError:
        const char* overloads[] = {"PySide.QtGui.QFileDialog.Option", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QFileDialog.testOption", overloads);
        return 0;
}

static PyObject* Sbk_QFileDialogFunc_viewMode(PyObject* self)
{
    QFileDialog* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFileDialog* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // viewMode()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QFileDialog::ViewMode cppResult = const_cast<const QFileDialog*>(cppSelf)->viewMode();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QFileDialog::ViewMode >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef Sbk_QFileDialog_methods[] = {
    {"accept", (PyCFunction)Sbk_QFileDialogFunc_accept, METH_NOARGS},
    {"acceptMode", (PyCFunction)Sbk_QFileDialogFunc_acceptMode, METH_NOARGS},
    {"changeEvent", (PyCFunction)Sbk_QFileDialogFunc_changeEvent, METH_O},
    {"confirmOverwrite", (PyCFunction)Sbk_QFileDialogFunc_confirmOverwrite, METH_NOARGS},
    {"defaultSuffix", (PyCFunction)Sbk_QFileDialogFunc_defaultSuffix, METH_NOARGS},
    {"directory", (PyCFunction)Sbk_QFileDialogFunc_directory, METH_NOARGS},
    {"done", (PyCFunction)Sbk_QFileDialogFunc_done, METH_O},
    {"fileMode", (PyCFunction)Sbk_QFileDialogFunc_fileMode, METH_NOARGS},
    {"filter", (PyCFunction)Sbk_QFileDialogFunc_filter, METH_NOARGS},
    {"filters", (PyCFunction)Sbk_QFileDialogFunc_filters, METH_NOARGS},
    {"getExistingDirectory", (PyCFunction)Sbk_QFileDialogFunc_getExistingDirectory, METH_VARARGS|METH_KEYWORDS|METH_STATIC},
    {"getOpenFileName", (PyCFunction)Sbk_QFileDialogFunc_getOpenFileName, METH_VARARGS|METH_KEYWORDS|METH_STATIC},
    {"getOpenFileNames", (PyCFunction)Sbk_QFileDialogFunc_getOpenFileNames, METH_VARARGS|METH_KEYWORDS|METH_STATIC},
    {"getSaveFileName", (PyCFunction)Sbk_QFileDialogFunc_getSaveFileName, METH_VARARGS|METH_KEYWORDS|METH_STATIC},
    {"history", (PyCFunction)Sbk_QFileDialogFunc_history, METH_NOARGS},
    {"iconProvider", (PyCFunction)Sbk_QFileDialogFunc_iconProvider, METH_NOARGS},
    {"isNameFilterDetailsVisible", (PyCFunction)Sbk_QFileDialogFunc_isNameFilterDetailsVisible, METH_NOARGS},
    {"isReadOnly", (PyCFunction)Sbk_QFileDialogFunc_isReadOnly, METH_NOARGS},
    {"itemDelegate", (PyCFunction)Sbk_QFileDialogFunc_itemDelegate, METH_NOARGS},
    {"labelText", (PyCFunction)Sbk_QFileDialogFunc_labelText, METH_O},
    {"nameFilters", (PyCFunction)Sbk_QFileDialogFunc_nameFilters, METH_NOARGS},
    {"open", (PyCFunction)Sbk_QFileDialogFunc_open, METH_VARARGS},
    {"options", (PyCFunction)Sbk_QFileDialogFunc_options, METH_NOARGS},
    {"proxyModel", (PyCFunction)Sbk_QFileDialogFunc_proxyModel, METH_NOARGS},
    {"resolveSymlinks", (PyCFunction)Sbk_QFileDialogFunc_resolveSymlinks, METH_NOARGS},
    {"restoreState", (PyCFunction)Sbk_QFileDialogFunc_restoreState, METH_O},
    {"saveState", (PyCFunction)Sbk_QFileDialogFunc_saveState, METH_NOARGS},
    {"selectFile", (PyCFunction)Sbk_QFileDialogFunc_selectFile, METH_O},
    {"selectFilter", (PyCFunction)Sbk_QFileDialogFunc_selectFilter, METH_O},
    {"selectNameFilter", (PyCFunction)Sbk_QFileDialogFunc_selectNameFilter, METH_O},
    {"selectedFiles", (PyCFunction)Sbk_QFileDialogFunc_selectedFiles, METH_NOARGS},
    {"selectedFilter", (PyCFunction)Sbk_QFileDialogFunc_selectedFilter, METH_NOARGS},
    {"selectedNameFilter", (PyCFunction)Sbk_QFileDialogFunc_selectedNameFilter, METH_NOARGS},
    {"setAcceptMode", (PyCFunction)Sbk_QFileDialogFunc_setAcceptMode, METH_O},
    {"setConfirmOverwrite", (PyCFunction)Sbk_QFileDialogFunc_setConfirmOverwrite, METH_O},
    {"setDefaultSuffix", (PyCFunction)Sbk_QFileDialogFunc_setDefaultSuffix, METH_O},
    {"setDirectory", (PyCFunction)Sbk_QFileDialogFunc_setDirectory, METH_O},
    {"setFileMode", (PyCFunction)Sbk_QFileDialogFunc_setFileMode, METH_O},
    {"setFilter", (PyCFunction)Sbk_QFileDialogFunc_setFilter, METH_O},
    {"setFilters", (PyCFunction)Sbk_QFileDialogFunc_setFilters, METH_O},
    {"setHistory", (PyCFunction)Sbk_QFileDialogFunc_setHistory, METH_O},
    {"setIconProvider", (PyCFunction)Sbk_QFileDialogFunc_setIconProvider, METH_O},
    {"setItemDelegate", (PyCFunction)Sbk_QFileDialogFunc_setItemDelegate, METH_O},
    {"setLabelText", (PyCFunction)Sbk_QFileDialogFunc_setLabelText, METH_VARARGS},
    {"setNameFilter", (PyCFunction)Sbk_QFileDialogFunc_setNameFilter, METH_O},
    {"setNameFilterDetailsVisible", (PyCFunction)Sbk_QFileDialogFunc_setNameFilterDetailsVisible, METH_O},
    {"setNameFilters", (PyCFunction)Sbk_QFileDialogFunc_setNameFilters, METH_O},
    {"setOption", (PyCFunction)Sbk_QFileDialogFunc_setOption, METH_VARARGS|METH_KEYWORDS},
    {"setOptions", (PyCFunction)Sbk_QFileDialogFunc_setOptions, METH_O},
    {"setProxyModel", (PyCFunction)Sbk_QFileDialogFunc_setProxyModel, METH_O},
    {"setReadOnly", (PyCFunction)Sbk_QFileDialogFunc_setReadOnly, METH_O},
    {"setResolveSymlinks", (PyCFunction)Sbk_QFileDialogFunc_setResolveSymlinks, METH_O},
    {"setSidebarUrls", (PyCFunction)Sbk_QFileDialogFunc_setSidebarUrls, METH_O},
    {"setViewMode", (PyCFunction)Sbk_QFileDialogFunc_setViewMode, METH_O},
    {"setVisible", (PyCFunction)Sbk_QFileDialogFunc_setVisible, METH_O},
    {"sidebarUrls", (PyCFunction)Sbk_QFileDialogFunc_sidebarUrls, METH_NOARGS},
    {"testOption", (PyCFunction)Sbk_QFileDialogFunc_testOption, METH_O},
    {"viewMode", (PyCFunction)Sbk_QFileDialogFunc_viewMode, METH_NOARGS},

    {0} // Sentinel
};

} // extern "C"

static void* Sbk_QFileDialogSpecialCastFunction(void* obj, SbkObjectType* desiredType)
{
    QFileDialog* me = reinterpret_cast<QFileDialog*>(obj);
    if (desiredType == reinterpret_cast<SbkObjectType*>(SbkPySide_QtGuiTypes[SBK_QDIALOG_IDX]))
        return static_cast<QDialog*>(me);
    else if (desiredType == reinterpret_cast<SbkObjectType*>(SbkPySide_QtGuiTypes[SBK_QWIDGET_IDX]))
        return static_cast<QWidget*>(me);
    else if (desiredType == reinterpret_cast<SbkObjectType*>(SbkPySide_QtCoreTypes[SBK_QOBJECT_IDX]))
        return static_cast<QObject*>(me);
    else if (desiredType == reinterpret_cast<SbkObjectType*>(SbkPySide_QtGuiTypes[SBK_QPAINTDEVICE_IDX]))
        return static_cast<QPaintDevice*>(me);
    return me;
}


// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QFileDialog_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QFileDialog",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QFileDialog_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QFileDialog_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern

static SbkObjectType* Sbk_QFileDialog_typeDiscovery(void* cptr, SbkObjectType* instanceType)
{
    if (instanceType == reinterpret_cast<SbkObjectType*>(Shiboken::SbkType<QObject >()) && dynamic_cast<QFileDialog*>(reinterpret_cast<QObject*>(cptr)))
        return &Sbk_QFileDialog_Type;
    if (instanceType == reinterpret_cast<SbkObjectType*>(Shiboken::SbkType<QPaintDevice >()) && dynamic_cast<QFileDialog*>(reinterpret_cast<QPaintDevice*>(cptr)))
        return &Sbk_QFileDialog_Type;
    return 0;
}

PyObject* SbkPySide_QtGui_QFileDialog_Option___and__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QFileDialog::Options >::toPython(
        Shiboken::Converter<QFileDialog::Options>::toCpp(self)
        & Shiboken::Converter< QFileDialog::Options >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtGui_QFileDialog_Option___or__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QFileDialog::Options >::toPython(
        Shiboken::Converter<QFileDialog::Options>::toCpp(self)
        | Shiboken::Converter< QFileDialog::Options >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtGui_QFileDialog_Option___xor__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QFileDialog::Options >::toPython(
        Shiboken::Converter<QFileDialog::Options>::toCpp(self)
        ^ Shiboken::Converter< QFileDialog::Options >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtGui_QFileDialog_Option___invert__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QFileDialog::Options >::toPython(
        ~Shiboken::Converter<QFileDialog::Options >::toCpp(self)
    );
}


static PyNumberMethods SbkPySide_QtGui_QFileDialog_Option_as_number = {
    /*nb_add*/                  0,
    /*nb_subtract*/             0,
    /*nb_multiply*/             0,
    /*nb_divide*/               0,
    /*nb_remainder*/            0,
    /*nb_divmod*/               0,
    /*nb_power*/                0,
    /*nb_negative*/             0,
    /*nb_positive*/             0,
    /*nb_absolute*/             0,
    /*nb_nonzero*/              0,
    /*nb_invert*/               (unaryfunc)SbkPySide_QtGui_QFileDialog_Option___invert__,
    /*nb_lshift*/               0,
    /*nb_rshift*/               0,
    /*nb_and*/                  (binaryfunc)SbkPySide_QtGui_QFileDialog_Option___and__,
    /*nb_xor*/                  (binaryfunc)SbkPySide_QtGui_QFileDialog_Option___xor__,
    /*nb_or*/                   (binaryfunc)SbkPySide_QtGui_QFileDialog_Option___or__,
    /*nb_coerce*/               0,
    /*nb_int*/                  0,
    /*nb_long*/                 0,
    /*nb_float*/                0,
    /*nb_oct*/                  0,
    /*nb_hex*/                  0,
    /*nb_inplace_add*/          0,
    /*nb_inplace_subtract*/     0,
    /*nb_inplace_multiply*/     0,
    /*nb_inplace_divide*/       0,
    /*nb_inplace_remainder*/    0,
    /*nb_inplace_power*/        0,
    /*nb_inplace_lshift*/       0,
    /*nb_inplace_rshift*/       0,
    /*nb_inplace_and*/          0,
    /*nb_inplace_xor*/          0,
    /*nb_inplace_or*/           0,
    /*nb_floor_divide*/         0,
    /*nb_true_divide*/          0,
    /*nb_inplace_floor_divide*/ 0,
    /*nb_inplace_true_divide*/  0,
    /*nb_index*/                0
};


// forward declaration of new function
static PyTypeObject SbkPySide_QtGui_QFileDialog_Options_Type = {
    PyObject_HEAD_INIT(&PyType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "Options",
    /*tp_basicsize*/        0,
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        &SbkPySide_QtGui_QFileDialog_Option_as_number,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT | Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              PyInt_Type.tp_new,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};



void init_QFileDialog(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QFILEDIALOG_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QFileDialog_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QFileDialog_Type);
    Shiboken::ObjectType::setSubTypeInitHook(&Sbk_QFileDialog_Type, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(&Sbk_QFileDialog_Type, &QFileDialog::staticMetaObject);    Sbk_QFileDialog_Type.super.ht_type.tp_base = SbkPySide_QtGuiTypes[SBK_QDIALOG_IDX];
    MultipleInheritanceInitFunction func;
    func = Shiboken::ObjectType::getMultipleIheritanceFunction(reinterpret_cast<SbkObjectType*>(SbkPySide_QtGuiTypes[SBK_QWIDGET_IDX]));
    Shiboken::ObjectType::setMultipleIheritanceFunction(&Sbk_QFileDialog_Type, func);
    Shiboken::ObjectType::setCastFunction(&Sbk_QFileDialog_Type, &Sbk_QFileDialogSpecialCastFunction);
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QFileDialog_Type, &Shiboken::callCppDestructor<QFileDialog >);
    Py_INCREF((PyObject*)&Sbk_QFileDialog_Type); //Incref due the 'PyModule_AddObject' steals the reference.
    if (PyType_Ready((PyTypeObject*)&Sbk_QFileDialog_Type) < 0)
        return;

    // Fill type discovery information
    Shiboken::ObjectType::setTypeDiscoveryFunction(&Sbk_QFileDialog_Type, &Sbk_QFileDialog_typeDiscovery);
    Shiboken::BindingManager& bm = Shiboken::BindingManager::instance();
    bm.addClassInheritance(reinterpret_cast<SbkObjectType*>(SbkPySide_QtGuiTypes[SBK_QDIALOG_IDX]), &Sbk_QFileDialog_Type);

    Shiboken::ObjectType::setOriginalName(&Sbk_QFileDialog_Type, "QFileDialog*");
    PyModule_AddObject(module, "QFileDialog",
        ((PyObject*)&Sbk_QFileDialog_Type));

    // Initialize enums
    PyObject* enumItem;

    // init enum: FileMode
    PyTypeObject* SbkPySide_QtGui_QFileDialog_FileMode = Shiboken::Enum::newType("PySide.QtGui.QFileDialog.FileMode");
    SbkPySide_QtGuiTypes[SBK_QFILEDIALOG_FILEMODE_IDX] = SbkPySide_QtGui_QFileDialog_FileMode;
    if (PyType_Ready(SbkPySide_QtGui_QFileDialog_FileMode) < 0)
        return;
    PyDict_SetItemString(Sbk_QFileDialog_Type.super.ht_type.tp_dict,
            "FileMode",((PyObject*)SbkPySide_QtGui_QFileDialog_FileMode));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QFileDialog_FileMode,(long) QFileDialog::AnyFile, "AnyFile");
    PyDict_SetItemString(Sbk_QFileDialog_Type.super.ht_type.tp_dict,"AnyFile", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QFileDialog_FileMode->tp_dict,"AnyFile", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QFileDialog_FileMode,(long) QFileDialog::ExistingFile, "ExistingFile");
    PyDict_SetItemString(Sbk_QFileDialog_Type.super.ht_type.tp_dict,"ExistingFile", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QFileDialog_FileMode->tp_dict,"ExistingFile", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QFileDialog_FileMode,(long) QFileDialog::Directory, "Directory");
    PyDict_SetItemString(Sbk_QFileDialog_Type.super.ht_type.tp_dict,"Directory", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QFileDialog_FileMode->tp_dict,"Directory", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QFileDialog_FileMode,(long) QFileDialog::ExistingFiles, "ExistingFiles");
    PyDict_SetItemString(Sbk_QFileDialog_Type.super.ht_type.tp_dict,"ExistingFiles", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QFileDialog_FileMode->tp_dict,"ExistingFiles", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QFileDialog_FileMode,(long) QFileDialog::DirectoryOnly, "DirectoryOnly");
    PyDict_SetItemString(Sbk_QFileDialog_Type.super.ht_type.tp_dict,"DirectoryOnly", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QFileDialog_FileMode->tp_dict,"DirectoryOnly", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QFileDialog::FileMode");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::FileMode");
    // end of enum FileMode

    // init enum: Option
    PyTypeObject* SbkPySide_QtGui_QFileDialog_Option = Shiboken::Enum::newType("PySide.QtGui.QFileDialog.Option");
    SbkPySide_QtGui_QFileDialog_Option->tp_as_number = &SbkPySide_QtGui_QFileDialog_Option_as_number;
    SbkPySide_QtGuiTypes[SBK_QFILEDIALOG_OPTION_IDX] = SbkPySide_QtGui_QFileDialog_Option;
    if (PyType_Ready(SbkPySide_QtGui_QFileDialog_Option) < 0)
        return;
    PyDict_SetItemString(Sbk_QFileDialog_Type.super.ht_type.tp_dict,
            "Option",((PyObject*)SbkPySide_QtGui_QFileDialog_Option));

    // init flags class: QFlags<QFileDialog::Option>
    SbkPySide_QtGuiTypes[SBK_QFLAGS_QFILEDIALOG_OPTION__IDX] = &SbkPySide_QtGui_QFileDialog_Options_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtGui_QFileDialog_Options_Type) < 0)
        return;
    PyDict_SetItemString(Sbk_QFileDialog_Type.super.ht_type.tp_dict,
            "Options",((PyObject*)&SbkPySide_QtGui_QFileDialog_Options_Type));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QFileDialog_Option,(long) QFileDialog::ShowDirsOnly, "ShowDirsOnly");
    PyDict_SetItemString(Sbk_QFileDialog_Type.super.ht_type.tp_dict,"ShowDirsOnly", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QFileDialog_Option->tp_dict,"ShowDirsOnly", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QFileDialog_Option,(long) QFileDialog::DontResolveSymlinks, "DontResolveSymlinks");
    PyDict_SetItemString(Sbk_QFileDialog_Type.super.ht_type.tp_dict,"DontResolveSymlinks", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QFileDialog_Option->tp_dict,"DontResolveSymlinks", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QFileDialog_Option,(long) QFileDialog::DontConfirmOverwrite, "DontConfirmOverwrite");
    PyDict_SetItemString(Sbk_QFileDialog_Type.super.ht_type.tp_dict,"DontConfirmOverwrite", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QFileDialog_Option->tp_dict,"DontConfirmOverwrite", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QFileDialog_Option,(long) QFileDialog::DontUseSheet, "DontUseSheet");
    PyDict_SetItemString(Sbk_QFileDialog_Type.super.ht_type.tp_dict,"DontUseSheet", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QFileDialog_Option->tp_dict,"DontUseSheet", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QFileDialog_Option,(long) QFileDialog::DontUseNativeDialog, "DontUseNativeDialog");
    PyDict_SetItemString(Sbk_QFileDialog_Type.super.ht_type.tp_dict,"DontUseNativeDialog", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QFileDialog_Option->tp_dict,"DontUseNativeDialog", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QFileDialog_Option,(long) QFileDialog::ReadOnly, "ReadOnly");
    PyDict_SetItemString(Sbk_QFileDialog_Type.super.ht_type.tp_dict,"ReadOnly", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QFileDialog_Option->tp_dict,"ReadOnly", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QFileDialog_Option,(long) QFileDialog::HideNameFilterDetails, "HideNameFilterDetails");
    PyDict_SetItemString(Sbk_QFileDialog_Type.super.ht_type.tp_dict,"HideNameFilterDetails", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QFileDialog_Option->tp_dict,"HideNameFilterDetails", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QFileDialog::Option");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::Option");
    // end of enum Option

    // init enum: DialogLabel
    PyTypeObject* SbkPySide_QtGui_QFileDialog_DialogLabel = Shiboken::Enum::newType("PySide.QtGui.QFileDialog.DialogLabel");
    SbkPySide_QtGuiTypes[SBK_QFILEDIALOG_DIALOGLABEL_IDX] = SbkPySide_QtGui_QFileDialog_DialogLabel;
    if (PyType_Ready(SbkPySide_QtGui_QFileDialog_DialogLabel) < 0)
        return;
    PyDict_SetItemString(Sbk_QFileDialog_Type.super.ht_type.tp_dict,
            "DialogLabel",((PyObject*)SbkPySide_QtGui_QFileDialog_DialogLabel));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QFileDialog_DialogLabel,(long) QFileDialog::LookIn, "LookIn");
    PyDict_SetItemString(Sbk_QFileDialog_Type.super.ht_type.tp_dict,"LookIn", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QFileDialog_DialogLabel->tp_dict,"LookIn", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QFileDialog_DialogLabel,(long) QFileDialog::FileName, "FileName");
    PyDict_SetItemString(Sbk_QFileDialog_Type.super.ht_type.tp_dict,"FileName", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QFileDialog_DialogLabel->tp_dict,"FileName", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QFileDialog_DialogLabel,(long) QFileDialog::FileType, "FileType");
    PyDict_SetItemString(Sbk_QFileDialog_Type.super.ht_type.tp_dict,"FileType", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QFileDialog_DialogLabel->tp_dict,"FileType", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QFileDialog_DialogLabel,(long) QFileDialog::Accept, "Accept");
    PyDict_SetItemString(Sbk_QFileDialog_Type.super.ht_type.tp_dict,"Accept", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QFileDialog_DialogLabel->tp_dict,"Accept", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QFileDialog_DialogLabel,(long) QFileDialog::Reject, "Reject");
    PyDict_SetItemString(Sbk_QFileDialog_Type.super.ht_type.tp_dict,"Reject", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QFileDialog_DialogLabel->tp_dict,"Reject", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QFileDialog::DialogLabel");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::DialogLabel");
    // end of enum DialogLabel

    // init enum: ViewMode
    PyTypeObject* SbkPySide_QtGui_QFileDialog_ViewMode = Shiboken::Enum::newType("PySide.QtGui.QFileDialog.ViewMode");
    SbkPySide_QtGuiTypes[SBK_QFILEDIALOG_VIEWMODE_IDX] = SbkPySide_QtGui_QFileDialog_ViewMode;
    if (PyType_Ready(SbkPySide_QtGui_QFileDialog_ViewMode) < 0)
        return;
    PyDict_SetItemString(Sbk_QFileDialog_Type.super.ht_type.tp_dict,
            "ViewMode",((PyObject*)SbkPySide_QtGui_QFileDialog_ViewMode));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QFileDialog_ViewMode,(long) QFileDialog::Detail, "Detail");
    PyDict_SetItemString(Sbk_QFileDialog_Type.super.ht_type.tp_dict,"Detail", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QFileDialog_ViewMode->tp_dict,"Detail", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QFileDialog_ViewMode,(long) QFileDialog::List, "List");
    PyDict_SetItemString(Sbk_QFileDialog_Type.super.ht_type.tp_dict,"List", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QFileDialog_ViewMode->tp_dict,"List", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QFileDialog::ViewMode");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::ViewMode");
    // end of enum ViewMode

    // init enum: AcceptMode
    PyTypeObject* SbkPySide_QtGui_QFileDialog_AcceptMode = Shiboken::Enum::newType("PySide.QtGui.QFileDialog.AcceptMode");
    SbkPySide_QtGuiTypes[SBK_QFILEDIALOG_ACCEPTMODE_IDX] = SbkPySide_QtGui_QFileDialog_AcceptMode;
    if (PyType_Ready(SbkPySide_QtGui_QFileDialog_AcceptMode) < 0)
        return;
    PyDict_SetItemString(Sbk_QFileDialog_Type.super.ht_type.tp_dict,
            "AcceptMode",((PyObject*)SbkPySide_QtGui_QFileDialog_AcceptMode));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QFileDialog_AcceptMode,(long) QFileDialog::AcceptOpen, "AcceptOpen");
    PyDict_SetItemString(Sbk_QFileDialog_Type.super.ht_type.tp_dict,"AcceptOpen", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QFileDialog_AcceptMode->tp_dict,"AcceptOpen", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QFileDialog_AcceptMode,(long) QFileDialog::AcceptSave, "AcceptSave");
    PyDict_SetItemString(Sbk_QFileDialog_Type.super.ht_type.tp_dict,"AcceptSave", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QFileDialog_AcceptMode->tp_dict,"AcceptSave", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QFileDialog::AcceptMode");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::AcceptMode");
    // end of enum AcceptMode

    // Initialize signals
    PySideSignal* signal_item;

    signal_item = PySide::Signal::newObject("directoryEntered", "QString", NULL);
    PySide::Signal::addSignalToWrapper(&Sbk_QFileDialog_Type, "directoryEntered", signal_item);
    Py_DECREF((PyObject*) signal_item);
    signal_item = PySide::Signal::newObject("filesSelected", "QStringList", NULL);
    PySide::Signal::addSignalToWrapper(&Sbk_QFileDialog_Type, "filesSelected", signal_item);
    Py_DECREF((PyObject*) signal_item);
    signal_item = PySide::Signal::newObject("filterSelected", "QString", NULL);
    PySide::Signal::addSignalToWrapper(&Sbk_QFileDialog_Type, "filterSelected", signal_item);
    Py_DECREF((PyObject*) signal_item);
    signal_item = PySide::Signal::newObject("fileSelected", "QString", NULL);
    PySide::Signal::addSignalToWrapper(&Sbk_QFileDialog_Type, "fileSelected", signal_item);
    Py_DECREF((PyObject*) signal_item);
    signal_item = PySide::Signal::newObject("currentChanged", "QString", NULL);
    PySide::Signal::addSignalToWrapper(&Sbk_QFileDialog_Type, "currentChanged", signal_item);
    Py_DECREF((PyObject*) signal_item);


    Shiboken::TypeResolver::createObjectTypeResolver<QFileDialog >("QFileDialog*");
    Shiboken::TypeResolver::createObjectTypeResolver<QFileDialog >(typeid(QFileDialog).name());
    Shiboken::TypeResolver::createObjectTypeResolver<QFileDialog >(typeid(QFileDialogWrapper).name());
    qRegisterMetaType< ::QFileDialog* >("QFileDialog*");
    qRegisterMetaType< ::QFileDialog::FileMode >("QFileDialog::FileMode");
    qRegisterMetaType< ::QFileDialog::Option >("QFileDialog::Option");
    qRegisterMetaType< ::QFileDialog::Options >("QFileDialog::Options");
    qRegisterMetaType< ::QFileDialog::DialogLabel >("QFileDialog::DialogLabel");
    qRegisterMetaType< ::QFileDialog::ViewMode >("QFileDialog::ViewMode");
    qRegisterMetaType< ::QFileDialog::AcceptMode >("QFileDialog::AcceptMode");
}

