/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtgui_python.h"

#include "qfont_wrapper.h"

// Extra includes
#include <QStringList>
#include <qdatastream.h>
#include <qfont.h>
#include <qpaintdevice.h>



// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QFont_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QFont >()))
        return -1;

    QFont* cptr = 0;
    int overloadId = -1;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);

    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);

    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 4) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QFont(): too many arguments");
        return -1;
    }

    if (!PyArg_ParseTuple(args, "|OOOO:QFont", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return -1;

    // Overloaded function decisor
    // 0: QFont()
    // 1: QFont(QFont)
    // 2: QFont(QFont,QPaintDevice*)
    // 3: QFont(QString,int,int,bool)
    if (numArgs == 0) {
        overloadId = 0; // QFont()
    } else if (Shiboken::Converter< QString >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 3; // QFont(QString,int,int,bool)
        } else if (SbkNumber_Check(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 3; // QFont(QString,int,int,bool)
            } else if (SbkNumber_Check(pyargs[2])) {
                if (numArgs == 3) {
                    overloadId = 3; // QFont(QString,int,int,bool)
                } else if (SbkNumber_Check(pyargs[3])) {
                    overloadId = 3; // QFont(QString,int,int,bool)
                }
            }
        }
    } else if (Shiboken::Converter< ::QFont >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 1; // QFont(QFont)
        } else if (numArgs == 2 && Shiboken::Converter< ::QPaintDevice * >::isConvertible(pyargs[1])) {
            overloadId = 2; // QFont(QFont,QPaintDevice*)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QFont_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QFont()
            {

                if(!PyErr_Occurred()) {
                    // QFont()
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QFont();
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // QFont(QFont)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QFont cppArg0 = Shiboken::Converter<QFont >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QFont(QFont)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QFont(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 2: // QFont(QFont,QPaintDevice*)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QFont cppArg0 = Shiboken::Converter<QFont >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return -1;
                QPaintDevice * cppArg1 = Shiboken::Converter<QPaintDevice * >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // QFont(QFont,QPaintDevice*)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QFont(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 3: // QFont(QString,int,int,bool)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "pointSize");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "pointSize";
                        else if (SbkNumber_Check(value))
                            pyargs[1] = value;
                        else
                            goto Sbk_QFont_Init_TypeError;
                    }
                    value = PyDict_GetItemString(kwds, "weight");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "weight";
                        else if (SbkNumber_Check(value))
                            pyargs[2] = value;
                        else
                            goto Sbk_QFont_Init_TypeError;
                    }
                    value = PyDict_GetItemString(kwds, "italic");
                    if (value) {
                        if (pyargs[3])
                            errorArgName = "italic";
                        else if (SbkNumber_Check(value))
                            pyargs[3] = value;
                        else
                            goto Sbk_QFont_Init_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QFont(): got multiple values for keyword argument '%s'", errorArgName);
                        return -1;
                    }
                }
                QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                int cppArg1 = pyargs[1] ? Shiboken::Converter<int >::toCpp(pyargs[1]) : -1;
                int cppArg2 = pyargs[2] ? Shiboken::Converter<int >::toCpp(pyargs[2]) : -1;
                bool cppArg3 = pyargs[3] ? Shiboken::Converter<bool >::toCpp(pyargs[3]) : false;

                if(!PyErr_Occurred()) {
                    // QFont(QString,int,int,bool)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QFont(cppArg0, cppArg1, cppArg2, cppArg3);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QFont >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QFont_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QFont_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtGui.QFont", "PySide.QtGui.QFont, PySide.QtGui.QPaintDevice", "QString, int = -1, int = -1, bool = false", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QFont", overloads);
        return -1;
}

static PyObject* Sbk_QFontFunc_bold(PyObject* self)
{
    QFont* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFont* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // bold()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QFont*>(cppSelf)->bold();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QFontFunc_cacheStatistics(PyObject* self)
{

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // cacheStatistics()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QFont::cacheStatistics();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QFontFunc_capitalization(PyObject* self)
{
    QFont* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFont* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // capitalization()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QFont::Capitalization cppResult = const_cast<const QFont*>(cppSelf)->capitalization();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QFont::Capitalization >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QFontFunc_cleanup(PyObject* self)
{

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // cleanup()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QFont::cleanup();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QFontFunc_defaultFamily(PyObject* self)
{
    QFont* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFont* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // defaultFamily()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = const_cast<const QFont*>(cppSelf)->defaultFamily();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QFontFunc_exactMatch(PyObject* self)
{
    QFont* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFont* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // exactMatch()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QFont*>(cppSelf)->exactMatch();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QFontFunc_family(PyObject* self)
{
    QFont* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFont* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // family()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = const_cast<const QFont*>(cppSelf)->family();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QFontFunc_fixedPitch(PyObject* self)
{
    QFont* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFont* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // fixedPitch()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QFont*>(cppSelf)->fixedPitch();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QFontFunc_fromString(PyObject* self, PyObject* arg)
{
    QFont* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFont* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: fromString(QString)
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // fromString(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QFontFunc_fromString_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // fromString(QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->fromString(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QFontFunc_fromString_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QFont.fromString", overloads);
        return 0;
}

static PyObject* Sbk_QFontFunc_handle(PyObject* self)
{
    QFont* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFont* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // handle()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                Qt::HANDLE cppResult = const_cast<const QFont*>(cppSelf)->handle();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< Qt::HANDLE >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QFontFunc_initialize(PyObject* self)
{

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // initialize()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QFont::initialize();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QFontFunc_insertSubstitution(PyObject* self, PyObject* args)
{
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "insertSubstitution", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: insertSubstitution(QString,QString)
    if (numArgs == 2 && Shiboken::Converter< QString >::isConvertible(pyargs[0]) && Shiboken::Converter< QString >::isConvertible(pyargs[1])) {
        overloadId = 0; // insertSubstitution(QString,QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QFontFunc_insertSubstitution_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            QString cppArg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // insertSubstitution(QString,QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QFont::insertSubstitution(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QFontFunc_insertSubstitution_TypeError:
        const char* overloads[] = {"QString, QString", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QFont.insertSubstitution", overloads);
        return 0;
}

static PyObject* Sbk_QFontFunc_insertSubstitutions(PyObject* self, PyObject* args)
{
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "insertSubstitutions", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: insertSubstitutions(QString,QStringList)
    if (numArgs == 2 && Shiboken::Converter< QString >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QStringList >::isConvertible(pyargs[1])) {
        overloadId = 0; // insertSubstitutions(QString,QStringList)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QFontFunc_insertSubstitutions_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            QStringList cppArg1 = Shiboken::Converter<QStringList >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // insertSubstitutions(QString,QStringList)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QFont::insertSubstitutions(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QFontFunc_insertSubstitutions_TypeError:
        const char* overloads[] = {"QString, list", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QFont.insertSubstitutions", overloads);
        return 0;
}

static PyObject* Sbk_QFontFunc_isCopyOf(PyObject* self, PyObject* arg)
{
    QFont* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFont* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: isCopyOf(QFont)const
    if (Shiboken::Converter< ::QFont >::isConvertible(arg)) {
        overloadId = 0; // isCopyOf(QFont)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QFontFunc_isCopyOf_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QFont cppArg0 = Shiboken::Converter<QFont >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // isCopyOf(QFont)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QFont*>(cppSelf)->isCopyOf(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QFontFunc_isCopyOf_TypeError:
        const char* overloads[] = {"PySide.QtGui.QFont", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QFont.isCopyOf", overloads);
        return 0;
}

static PyObject* Sbk_QFontFunc_italic(PyObject* self)
{
    QFont* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFont* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // italic()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QFont*>(cppSelf)->italic();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QFontFunc_kerning(PyObject* self)
{
    QFont* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFont* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // kerning()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QFont*>(cppSelf)->kerning();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QFontFunc_key(PyObject* self)
{
    QFont* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFont* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // key()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = const_cast<const QFont*>(cppSelf)->key();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QFontFunc_lastResortFamily(PyObject* self)
{
    QFont* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFont* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // lastResortFamily()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = const_cast<const QFont*>(cppSelf)->lastResortFamily();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QFontFunc_lastResortFont(PyObject* self)
{
    QFont* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFont* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // lastResortFont()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = const_cast<const QFont*>(cppSelf)->lastResortFont();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QFontFunc_letterSpacing(PyObject* self)
{
    QFont* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFont* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // letterSpacing()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                qreal cppResult = const_cast<const QFont*>(cppSelf)->letterSpacing();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< double >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QFontFunc_letterSpacingType(PyObject* self)
{
    QFont* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFont* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // letterSpacingType()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QFont::SpacingType cppResult = const_cast<const QFont*>(cppSelf)->letterSpacingType();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QFont::SpacingType >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QFontFunc_overline(PyObject* self)
{
    QFont* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFont* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // overline()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QFont*>(cppSelf)->overline();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QFontFunc_pixelSize(PyObject* self)
{
    QFont* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFont* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // pixelSize()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QFont*>(cppSelf)->pixelSize();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QFontFunc_pointSize(PyObject* self)
{
    QFont* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFont* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // pointSize()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QFont*>(cppSelf)->pointSize();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QFontFunc_pointSizeF(PyObject* self)
{
    QFont* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFont* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // pointSizeF()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                qreal cppResult = const_cast<const QFont*>(cppSelf)->pointSizeF();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< double >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QFontFunc_rawMode(PyObject* self)
{
    QFont* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFont* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // rawMode()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QFont*>(cppSelf)->rawMode();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QFontFunc_rawName(PyObject* self)
{
    QFont* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFont* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // rawName()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = const_cast<const QFont*>(cppSelf)->rawName();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QFontFunc_removeSubstitution(PyObject* self, PyObject* arg)
{
    int overloadId = -1;

    // Overloaded function decisor
    // 0: removeSubstitution(QString)
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // removeSubstitution(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QFontFunc_removeSubstitution_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // removeSubstitution(QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QFont::removeSubstitution(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QFontFunc_removeSubstitution_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QFont.removeSubstitution", overloads);
        return 0;
}

static PyObject* Sbk_QFontFunc_resolve(PyObject* self, PyObject* args)
{
    QFont* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFont* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "resolve", 0, 1, &(pyargs[0])))
        return 0;


    // Overloaded function decisor
    // 0: resolve()const
    // 1: resolve(QFont)const
    // 2: resolve(uint)
    if (numArgs == 0) {
        overloadId = 0; // resolve()const
    } else if (numArgs == 1 && SbkNumber_Check(pyargs[0])) {
        overloadId = 2; // resolve(uint)
    } else if (numArgs == 1 && Shiboken::Converter< ::QFont >::isConvertible(pyargs[0])) {
        overloadId = 1; // resolve(QFont)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QFontFunc_resolve_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // resolve()const
            {

                if(!PyErr_Occurred()) {
                    // resolve()const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    uint cppResult = const_cast<const QFont*>(cppSelf)->resolve();
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< unsigned int >::toPython(cppResult);
                }
                break;
            }
            case 1: // resolve(QFont)const
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QFont cppArg0 = Shiboken::Converter<QFont >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // resolve(QFont)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QFont cppResult = const_cast<const QFont*>(cppSelf)->resolve(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QFont >::toPython(cppResult);
                }
                break;
            }
            case 2: // resolve(uint)
            {
                uint cppArg0 = Shiboken::Converter<uint >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // resolve(uint)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->resolve(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Py_None;
                    Py_INCREF(Py_None);
                }
                break;
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QFontFunc_resolve_TypeError:
        const char* overloads[] = {"", "PySide.QtGui.QFont", "unsigned int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QFont.resolve", overloads);
        return 0;
}

static PyObject* Sbk_QFontFunc_setBold(PyObject* self, PyObject* arg)
{
    QFont* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFont* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setBold(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setBold(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QFontFunc_setBold_TypeError;

    // Call function/method
    {
        {
            bool cppArg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setBold(bool)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setBold(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QFontFunc_setBold_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QFont.setBold", overloads);
        return 0;
}

static PyObject* Sbk_QFontFunc_setCapitalization(PyObject* self, PyObject* arg)
{
    QFont* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFont* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setCapitalization(QFont::Capitalization)
    if (Shiboken::Converter< ::QFont::Capitalization >::isConvertible(arg)) {
        overloadId = 0; // setCapitalization(QFont::Capitalization)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QFontFunc_setCapitalization_TypeError;

    // Call function/method
    {
        {
            QFont::Capitalization cppArg0 = Shiboken::Converter<QFont::Capitalization >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setCapitalization(QFont::Capitalization)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setCapitalization(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QFontFunc_setCapitalization_TypeError:
        const char* overloads[] = {"PySide.QtGui.QFont.Capitalization", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QFont.setCapitalization", overloads);
        return 0;
}

static PyObject* Sbk_QFontFunc_setFamily(PyObject* self, PyObject* arg)
{
    QFont* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFont* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setFamily(QString)
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // setFamily(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QFontFunc_setFamily_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setFamily(QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setFamily(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QFontFunc_setFamily_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QFont.setFamily", overloads);
        return 0;
}

static PyObject* Sbk_QFontFunc_setFixedPitch(PyObject* self, PyObject* arg)
{
    QFont* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFont* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setFixedPitch(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setFixedPitch(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QFontFunc_setFixedPitch_TypeError;

    // Call function/method
    {
        {
            bool cppArg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setFixedPitch(bool)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setFixedPitch(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QFontFunc_setFixedPitch_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QFont.setFixedPitch", overloads);
        return 0;
}

static PyObject* Sbk_QFontFunc_setItalic(PyObject* self, PyObject* arg)
{
    QFont* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFont* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setItalic(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setItalic(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QFontFunc_setItalic_TypeError;

    // Call function/method
    {
        {
            bool cppArg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setItalic(bool)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setItalic(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QFontFunc_setItalic_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QFont.setItalic", overloads);
        return 0;
}

static PyObject* Sbk_QFontFunc_setKerning(PyObject* self, PyObject* arg)
{
    QFont* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFont* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setKerning(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setKerning(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QFontFunc_setKerning_TypeError;

    // Call function/method
    {
        {
            bool cppArg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setKerning(bool)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setKerning(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QFontFunc_setKerning_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QFont.setKerning", overloads);
        return 0;
}

static PyObject* Sbk_QFontFunc_setLetterSpacing(PyObject* self, PyObject* args)
{
    QFont* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFont* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setLetterSpacing", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setLetterSpacing(QFont::SpacingType,qreal)
    if (numArgs == 2 && Shiboken::Converter< ::QFont::SpacingType >::isConvertible(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 0; // setLetterSpacing(QFont::SpacingType,qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QFontFunc_setLetterSpacing_TypeError;

    // Call function/method
    {
        {
            QFont::SpacingType cppArg0 = Shiboken::Converter<QFont::SpacingType >::toCpp(pyargs[0]);
            qreal cppArg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // setLetterSpacing(QFont::SpacingType,qreal)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setLetterSpacing(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QFontFunc_setLetterSpacing_TypeError:
        const char* overloads[] = {"PySide.QtGui.QFont.SpacingType, float", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QFont.setLetterSpacing", overloads);
        return 0;
}

static PyObject* Sbk_QFontFunc_setOverline(PyObject* self, PyObject* arg)
{
    QFont* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFont* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setOverline(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setOverline(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QFontFunc_setOverline_TypeError;

    // Call function/method
    {
        {
            bool cppArg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setOverline(bool)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setOverline(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QFontFunc_setOverline_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QFont.setOverline", overloads);
        return 0;
}

static PyObject* Sbk_QFontFunc_setPixelSize(PyObject* self, PyObject* arg)
{
    QFont* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFont* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setPixelSize(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setPixelSize(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QFontFunc_setPixelSize_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setPixelSize(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setPixelSize(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QFontFunc_setPixelSize_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QFont.setPixelSize", overloads);
        return 0;
}

static PyObject* Sbk_QFontFunc_setPointSize(PyObject* self, PyObject* arg)
{
    QFont* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFont* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setPointSize(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setPointSize(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QFontFunc_setPointSize_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setPointSize(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setPointSize(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QFontFunc_setPointSize_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QFont.setPointSize", overloads);
        return 0;
}

static PyObject* Sbk_QFontFunc_setPointSizeF(PyObject* self, PyObject* arg)
{
    QFont* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFont* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setPointSizeF(qreal)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setPointSizeF(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QFontFunc_setPointSizeF_TypeError;

    // Call function/method
    {
        {
            qreal cppArg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setPointSizeF(qreal)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setPointSizeF(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QFontFunc_setPointSizeF_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QFont.setPointSizeF", overloads);
        return 0;
}

static PyObject* Sbk_QFontFunc_setRawMode(PyObject* self, PyObject* arg)
{
    QFont* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFont* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setRawMode(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setRawMode(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QFontFunc_setRawMode_TypeError;

    // Call function/method
    {
        {
            bool cppArg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setRawMode(bool)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setRawMode(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QFontFunc_setRawMode_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QFont.setRawMode", overloads);
        return 0;
}

static PyObject* Sbk_QFontFunc_setRawName(PyObject* self, PyObject* arg)
{
    QFont* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFont* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setRawName(QString)
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // setRawName(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QFontFunc_setRawName_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setRawName(QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setRawName(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QFontFunc_setRawName_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QFont.setRawName", overloads);
        return 0;
}

static PyObject* Sbk_QFontFunc_setStretch(PyObject* self, PyObject* arg)
{
    QFont* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFont* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setStretch(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setStretch(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QFontFunc_setStretch_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setStretch(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setStretch(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QFontFunc_setStretch_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QFont.setStretch", overloads);
        return 0;
}

static PyObject* Sbk_QFontFunc_setStrikeOut(PyObject* self, PyObject* arg)
{
    QFont* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFont* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setStrikeOut(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setStrikeOut(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QFontFunc_setStrikeOut_TypeError;

    // Call function/method
    {
        {
            bool cppArg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setStrikeOut(bool)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setStrikeOut(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QFontFunc_setStrikeOut_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QFont.setStrikeOut", overloads);
        return 0;
}

static PyObject* Sbk_QFontFunc_setStyle(PyObject* self, PyObject* arg)
{
    QFont* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFont* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setStyle(QFont::Style)
    if (Shiboken::Converter< ::QFont::Style >::isConvertible(arg)) {
        overloadId = 0; // setStyle(QFont::Style)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QFontFunc_setStyle_TypeError;

    // Call function/method
    {
        {
            QFont::Style cppArg0 = Shiboken::Converter<QFont::Style >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setStyle(QFont::Style)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setStyle(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QFontFunc_setStyle_TypeError:
        const char* overloads[] = {"PySide.QtGui.QFont.Style", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QFont.setStyle", overloads);
        return 0;
}

static PyObject* Sbk_QFontFunc_setStyleHint(PyObject* self, PyObject* args, PyObject* kwds)
{
    QFont* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFont* >::toCpp(self);

    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QFont.setStyleHint(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QFont.setStyleHint(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:setStyleHint", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setStyleHint(QFont::StyleHint,QFont::StyleStrategy)
    if (Shiboken::Converter< ::QFont::StyleHint >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // setStyleHint(QFont::StyleHint,QFont::StyleStrategy)
        } else if (Shiboken::Converter< ::QFont::StyleStrategy >::isConvertible(pyargs[1])) {
            overloadId = 0; // setStyleHint(QFont::StyleHint,QFont::StyleStrategy)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QFontFunc_setStyleHint_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "strategy");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "strategy";
                    else if (Shiboken::Converter< ::QFont::StyleStrategy >::isConvertible(value))
                        pyargs[1] = value;
                    else
                        goto Sbk_QFontFunc_setStyleHint_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QFont.setStyleHint(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QFont::StyleHint cppArg0 = Shiboken::Converter<QFont::StyleHint >::toCpp(pyargs[0]);
            QFont::StyleStrategy cppArg1 = pyargs[1] ? Shiboken::Converter<QFont::StyleStrategy >::toCpp(pyargs[1]) : QFont::PreferDefault;

            if(!PyErr_Occurred()) {
                // setStyleHint(QFont::StyleHint,QFont::StyleStrategy)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setStyleHint(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QFontFunc_setStyleHint_TypeError:
        const char* overloads[] = {"PySide.QtGui.QFont.StyleHint, PySide.QtGui.QFont.StyleStrategy = PreferDefault", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QFont.setStyleHint", overloads);
        return 0;
}

static PyObject* Sbk_QFontFunc_setStyleStrategy(PyObject* self, PyObject* arg)
{
    QFont* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFont* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setStyleStrategy(QFont::StyleStrategy)
    if (Shiboken::Converter< ::QFont::StyleStrategy >::isConvertible(arg)) {
        overloadId = 0; // setStyleStrategy(QFont::StyleStrategy)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QFontFunc_setStyleStrategy_TypeError;

    // Call function/method
    {
        {
            QFont::StyleStrategy cppArg0 = Shiboken::Converter<QFont::StyleStrategy >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setStyleStrategy(QFont::StyleStrategy)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setStyleStrategy(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QFontFunc_setStyleStrategy_TypeError:
        const char* overloads[] = {"PySide.QtGui.QFont.StyleStrategy", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QFont.setStyleStrategy", overloads);
        return 0;
}

static PyObject* Sbk_QFontFunc_setUnderline(PyObject* self, PyObject* arg)
{
    QFont* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFont* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setUnderline(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setUnderline(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QFontFunc_setUnderline_TypeError;

    // Call function/method
    {
        {
            bool cppArg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setUnderline(bool)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setUnderline(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QFontFunc_setUnderline_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QFont.setUnderline", overloads);
        return 0;
}

static PyObject* Sbk_QFontFunc_setWeight(PyObject* self, PyObject* arg)
{
    QFont* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFont* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setWeight(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setWeight(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QFontFunc_setWeight_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setWeight(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setWeight(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QFontFunc_setWeight_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QFont.setWeight", overloads);
        return 0;
}

static PyObject* Sbk_QFontFunc_setWordSpacing(PyObject* self, PyObject* arg)
{
    QFont* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFont* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setWordSpacing(qreal)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setWordSpacing(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QFontFunc_setWordSpacing_TypeError;

    // Call function/method
    {
        {
            qreal cppArg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setWordSpacing(qreal)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setWordSpacing(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QFontFunc_setWordSpacing_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QFont.setWordSpacing", overloads);
        return 0;
}

static PyObject* Sbk_QFontFunc_stretch(PyObject* self)
{
    QFont* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFont* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // stretch()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QFont*>(cppSelf)->stretch();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QFontFunc_strikeOut(PyObject* self)
{
    QFont* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFont* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // strikeOut()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QFont*>(cppSelf)->strikeOut();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QFontFunc_style(PyObject* self)
{
    QFont* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFont* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // style()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QFont::Style cppResult = const_cast<const QFont*>(cppSelf)->style();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QFont::Style >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QFontFunc_styleHint(PyObject* self)
{
    QFont* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFont* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // styleHint()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QFont::StyleHint cppResult = const_cast<const QFont*>(cppSelf)->styleHint();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QFont::StyleHint >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QFontFunc_styleStrategy(PyObject* self)
{
    QFont* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFont* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // styleStrategy()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QFont::StyleStrategy cppResult = const_cast<const QFont*>(cppSelf)->styleStrategy();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QFont::StyleStrategy >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QFontFunc_substitute(PyObject* self, PyObject* arg)
{
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: substitute(QString)
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // substitute(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QFontFunc_substitute_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // substitute(QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = QFont::substitute(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QFontFunc_substitute_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QFont.substitute", overloads);
        return 0;
}

static PyObject* Sbk_QFontFunc_substitutes(PyObject* self, PyObject* arg)
{
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: substitutes(QString)
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // substitutes(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QFontFunc_substitutes_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // substitutes(QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QStringList cppResult = QFont::substitutes(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QStringList >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QFontFunc_substitutes_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QFont.substitutes", overloads);
        return 0;
}

static PyObject* Sbk_QFontFunc_substitutions(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // substitutions()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QStringList cppResult = QFont::substitutions();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QStringList >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QFontFunc_toString(PyObject* self)
{
    QFont* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFont* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // toString()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = const_cast<const QFont*>(cppSelf)->toString();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QFontFunc_underline(PyObject* self)
{
    QFont* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFont* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // underline()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QFont*>(cppSelf)->underline();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QFontFunc_weight(PyObject* self)
{
    QFont* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFont* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // weight()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QFont*>(cppSelf)->weight();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QFontFunc_wordSpacing(PyObject* self)
{
    QFont* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFont* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // wordSpacing()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                qreal cppResult = const_cast<const QFont*>(cppSelf)->wordSpacing();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< double >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject *Sbk_QFont___copy__(PyObject *self)
{
        QFont* cppSelf = 0;
        if (!Shiboken::Object::isValid(self))
            return 0;
        cppSelf = Shiboken::Converter<QFont*>::toCpp(self);
        PyObject* pyResult = 0;
        QFont* copy = new QFont(*cppSelf);
        pyResult = Shiboken::Converter<QFont*>::toPython(copy);
        Shiboken::Object::getOwnership(pyResult);

        if (PyErr_Occurred() || !pyResult) {
            Py_XDECREF(pyResult);
            return 0;
        }
        return pyResult;
}

static PyMethodDef Sbk_QFont_methods[] = {
    {"bold", (PyCFunction)Sbk_QFontFunc_bold, METH_NOARGS},
    {"cacheStatistics", (PyCFunction)Sbk_QFontFunc_cacheStatistics, METH_NOARGS|METH_STATIC},
    {"capitalization", (PyCFunction)Sbk_QFontFunc_capitalization, METH_NOARGS},
    {"cleanup", (PyCFunction)Sbk_QFontFunc_cleanup, METH_NOARGS|METH_STATIC},
    {"defaultFamily", (PyCFunction)Sbk_QFontFunc_defaultFamily, METH_NOARGS},
    {"exactMatch", (PyCFunction)Sbk_QFontFunc_exactMatch, METH_NOARGS},
    {"family", (PyCFunction)Sbk_QFontFunc_family, METH_NOARGS},
    {"fixedPitch", (PyCFunction)Sbk_QFontFunc_fixedPitch, METH_NOARGS},
    {"fromString", (PyCFunction)Sbk_QFontFunc_fromString, METH_O},
    {"handle", (PyCFunction)Sbk_QFontFunc_handle, METH_NOARGS},
    {"initialize", (PyCFunction)Sbk_QFontFunc_initialize, METH_NOARGS|METH_STATIC},
    {"insertSubstitution", (PyCFunction)Sbk_QFontFunc_insertSubstitution, METH_VARARGS|METH_STATIC},
    {"insertSubstitutions", (PyCFunction)Sbk_QFontFunc_insertSubstitutions, METH_VARARGS|METH_STATIC},
    {"isCopyOf", (PyCFunction)Sbk_QFontFunc_isCopyOf, METH_O},
    {"italic", (PyCFunction)Sbk_QFontFunc_italic, METH_NOARGS},
    {"kerning", (PyCFunction)Sbk_QFontFunc_kerning, METH_NOARGS},
    {"key", (PyCFunction)Sbk_QFontFunc_key, METH_NOARGS},
    {"lastResortFamily", (PyCFunction)Sbk_QFontFunc_lastResortFamily, METH_NOARGS},
    {"lastResortFont", (PyCFunction)Sbk_QFontFunc_lastResortFont, METH_NOARGS},
    {"letterSpacing", (PyCFunction)Sbk_QFontFunc_letterSpacing, METH_NOARGS},
    {"letterSpacingType", (PyCFunction)Sbk_QFontFunc_letterSpacingType, METH_NOARGS},
    {"overline", (PyCFunction)Sbk_QFontFunc_overline, METH_NOARGS},
    {"pixelSize", (PyCFunction)Sbk_QFontFunc_pixelSize, METH_NOARGS},
    {"pointSize", (PyCFunction)Sbk_QFontFunc_pointSize, METH_NOARGS},
    {"pointSizeF", (PyCFunction)Sbk_QFontFunc_pointSizeF, METH_NOARGS},
    {"rawMode", (PyCFunction)Sbk_QFontFunc_rawMode, METH_NOARGS},
    {"rawName", (PyCFunction)Sbk_QFontFunc_rawName, METH_NOARGS},
    {"removeSubstitution", (PyCFunction)Sbk_QFontFunc_removeSubstitution, METH_O|METH_STATIC},
    {"resolve", (PyCFunction)Sbk_QFontFunc_resolve, METH_VARARGS},
    {"setBold", (PyCFunction)Sbk_QFontFunc_setBold, METH_O},
    {"setCapitalization", (PyCFunction)Sbk_QFontFunc_setCapitalization, METH_O},
    {"setFamily", (PyCFunction)Sbk_QFontFunc_setFamily, METH_O},
    {"setFixedPitch", (PyCFunction)Sbk_QFontFunc_setFixedPitch, METH_O},
    {"setItalic", (PyCFunction)Sbk_QFontFunc_setItalic, METH_O},
    {"setKerning", (PyCFunction)Sbk_QFontFunc_setKerning, METH_O},
    {"setLetterSpacing", (PyCFunction)Sbk_QFontFunc_setLetterSpacing, METH_VARARGS},
    {"setOverline", (PyCFunction)Sbk_QFontFunc_setOverline, METH_O},
    {"setPixelSize", (PyCFunction)Sbk_QFontFunc_setPixelSize, METH_O},
    {"setPointSize", (PyCFunction)Sbk_QFontFunc_setPointSize, METH_O},
    {"setPointSizeF", (PyCFunction)Sbk_QFontFunc_setPointSizeF, METH_O},
    {"setRawMode", (PyCFunction)Sbk_QFontFunc_setRawMode, METH_O},
    {"setRawName", (PyCFunction)Sbk_QFontFunc_setRawName, METH_O},
    {"setStretch", (PyCFunction)Sbk_QFontFunc_setStretch, METH_O},
    {"setStrikeOut", (PyCFunction)Sbk_QFontFunc_setStrikeOut, METH_O},
    {"setStyle", (PyCFunction)Sbk_QFontFunc_setStyle, METH_O},
    {"setStyleHint", (PyCFunction)Sbk_QFontFunc_setStyleHint, METH_VARARGS|METH_KEYWORDS},
    {"setStyleStrategy", (PyCFunction)Sbk_QFontFunc_setStyleStrategy, METH_O},
    {"setUnderline", (PyCFunction)Sbk_QFontFunc_setUnderline, METH_O},
    {"setWeight", (PyCFunction)Sbk_QFontFunc_setWeight, METH_O},
    {"setWordSpacing", (PyCFunction)Sbk_QFontFunc_setWordSpacing, METH_O},
    {"stretch", (PyCFunction)Sbk_QFontFunc_stretch, METH_NOARGS},
    {"strikeOut", (PyCFunction)Sbk_QFontFunc_strikeOut, METH_NOARGS},
    {"style", (PyCFunction)Sbk_QFontFunc_style, METH_NOARGS},
    {"styleHint", (PyCFunction)Sbk_QFontFunc_styleHint, METH_NOARGS},
    {"styleStrategy", (PyCFunction)Sbk_QFontFunc_styleStrategy, METH_NOARGS},
    {"substitute", (PyCFunction)Sbk_QFontFunc_substitute, METH_O|METH_STATIC},
    {"substitutes", (PyCFunction)Sbk_QFontFunc_substitutes, METH_O|METH_STATIC},
    {"substitutions", (PyCFunction)Sbk_QFontFunc_substitutions, METH_NOARGS|METH_STATIC},
    {"toString", (PyCFunction)Sbk_QFontFunc_toString, METH_NOARGS},
    {"underline", (PyCFunction)Sbk_QFontFunc_underline, METH_NOARGS},
    {"weight", (PyCFunction)Sbk_QFontFunc_weight, METH_NOARGS},
    {"wordSpacing", (PyCFunction)Sbk_QFontFunc_wordSpacing, METH_NOARGS},

    {"__copy__", (PyCFunction)Sbk_QFont___copy__, METH_NOARGS},
    {0} // Sentinel
};

static PyObject* Sbk_QFontFunc___lshift__(PyObject* self, PyObject* arg)
{
    QFont* cppSelf = 0;
    bool isReverse = Shiboken::Converter< ::QFont >::checkType(arg) && !Shiboken::Converter< ::QFont >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFont* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && Shiboken::Object::checkType(arg)
        && !PyObject_TypeCheck(arg, self->ob_type)
        && PyObject_HasAttrString(arg, const_cast<char*>("__rlshift__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(arg, const_cast<char*>("__rlshift__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator<<(QDataStream&,QFont)
    if (isReverse && Shiboken::Converter< ::QDataStream & >::isConvertible(arg)) {
        overloadId = 0; // operator<<(QDataStream&,QFont)
    }

    if (isReverse && overloadId == -1) {
        PyErr_SetString(PyExc_NotImplementedError, "reverse operator not implemented.");
        return 0;
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QFontFunc___lshift___TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QDataStream & cppArg0 = Shiboken::Converter<QDataStream & >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // operator<<(QDataStream&,QFont) [reverse operator]
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QDataStream & cppResult = (cppArg0) << (*cppSelf);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QDataStream & >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    } // End of "if (!pyResult)"


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QFontFunc___lshift___TypeError:
        const char* overloads[] = {"PySide.QtCore.QDataStream", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QFont.__lshift__", overloads);
        return 0;
}

static PyObject* Sbk_QFontFunc___rshift__(PyObject* self, PyObject* arg)
{
    QFont* cppSelf = 0;
    bool isReverse = Shiboken::Converter< ::QFont >::checkType(arg) && !Shiboken::Converter< ::QFont >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFont* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && Shiboken::Object::checkType(arg)
        && !PyObject_TypeCheck(arg, self->ob_type)
        && PyObject_HasAttrString(arg, const_cast<char*>("__rrshift__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(arg, const_cast<char*>("__rrshift__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator>>(QDataStream&,QFont&)
    if (isReverse && Shiboken::Converter< ::QDataStream & >::isConvertible(arg)) {
        overloadId = 0; // operator>>(QDataStream&,QFont&)
    }

    if (isReverse && overloadId == -1) {
        PyErr_SetString(PyExc_NotImplementedError, "reverse operator not implemented.");
        return 0;
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QFontFunc___rshift___TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QDataStream & cppArg0 = Shiboken::Converter<QDataStream & >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // operator>>(QDataStream&,QFont&) [reverse operator]
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QDataStream & cppResult = (cppArg0) >> (*cppSelf);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QDataStream & >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    } // End of "if (!pyResult)"


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QFontFunc___rshift___TypeError:
        const char* overloads[] = {"PySide.QtCore.QDataStream", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QFont.__rshift__", overloads);
        return 0;
}

// type has number operators
static PyNumberMethods Sbk_QFont_as_number = {
    /*nb_add*/                  (binaryfunc)0,
    /*nb_subtract*/             (binaryfunc)0,
    /*nb_multiply*/             (binaryfunc)0,
    /*nb_divide*/               (binaryfunc)0,
    /*nb_remainder*/            (binaryfunc)0,
    /*nb_divmod*/               0,
    /*nb_power*/                0,
    /*nb_negative*/             (unaryfunc)0,
    /*nb_positive*/             (unaryfunc)0,
    /*nb_absolute*/             0,
    /*nb_nonzero*/              0,
    /*nb_invert*/               (unaryfunc)0,
    /*nb_lshift*/               (binaryfunc)Sbk_QFontFunc___lshift__,
    /*nb_rshift*/               (binaryfunc)Sbk_QFontFunc___rshift__,
    /*nb_and*/                  (binaryfunc)0,
    /*nb_xor*/                  (binaryfunc)0,
    /*nb_or*/                   (binaryfunc)0,
    /*nb_coerce*/               0,
    /*nb_int*/                  0,
    /*nb_long*/                 0,
    /*nb_float*/                0,
    /*nb_oct*/                  0,
    /*nb_hex*/                  0,
    /*nb_inplace_add*/          (binaryfunc)0,
    /*nb_inplace_subtract*/     (binaryfunc)0,
    /*nb_inplace_multiply*/     (binaryfunc)0,
    /*nb_inplace_divide*/       (binaryfunc)0,
    /*nb_inplace_remainder*/    (binaryfunc)0,
    /*nb_inplace_power*/        0,
    /*nb_inplace_lshift*/       (binaryfunc)0,
    /*nb_inplace_rshift*/       (binaryfunc)0,
    /*nb_inplace_and*/          (binaryfunc)0,
    /*nb_inplace_xor*/          (binaryfunc)0,
    /*nb_inplace_or*/           (binaryfunc)0,
    /*nb_floor_divide*/         0,
    /*nb_true_divide*/          (binaryfunc)0,
    /*nb_inplace_floor_divide*/ 0,
    /*nb_inplace_true_divide*/  0,
    /*nb_index*/                0
};

// Rich comparison
static PyObject* Sbk_QFont_richcompare(PyObject* self, PyObject* arg, int op)
{
    PyObject* pyResult = 0;
    QFont& cppSelf = *Shiboken::Converter< QFont* >::toCpp(self);

    switch (op) {
        case Py_NE:
            if (Shiboken::Converter< ::QFont >::isConvertible(arg)) {
                // operator!=(const QFont & arg__1) const
                QFont cppArg0 = Shiboken::Converter< ::QFont >::toCpp(arg);
                pyResult = Shiboken::Converter< bool >::toPython(cppSelf != cppArg0);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_LT:
            if (Shiboken::Converter< ::QFont >::isConvertible(arg)) {
                // operator<(const QFont & arg__1) const
                QFont cppArg0 = Shiboken::Converter< ::QFont >::toCpp(arg);
                pyResult = Shiboken::Converter< bool >::toPython(cppSelf < cppArg0);
            } else {
                goto Sbk_QFont_RichComparison_TypeError;
            }

            break;
        case Py_EQ:
            if (Shiboken::Converter< ::QFont >::isConvertible(arg)) {
                // operator==(const QFont & arg__1) const
                QFont cppArg0 = Shiboken::Converter< ::QFont >::toCpp(arg);
                pyResult = Shiboken::Converter< bool >::toPython(cppSelf == cppArg0);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            goto Sbk_QFont_RichComparison_TypeError;
    }

    if (pyResult && !PyErr_Occurred())
        return pyResult;
    Sbk_QFont_RichComparison_TypeError:
    PyErr_SetString(PyExc_NotImplementedError, "operator not implemented.");
    return 0;

}

} // extern "C"

extern "C"
{
static PyObject* Sbk_QFont__repr__(PyObject* pyObj)
{
    QBuffer buffer;
    buffer.open(QBuffer::ReadWrite);
    QDebug dbg(&buffer);
    dbg << Shiboken::Converter< ::QFont >::toCpp(pyObj);
    buffer.close();
    return PyString_FromFormat("<PySide.QtGui.%s at %p>", buffer.data().constData(), pyObj);
}
} // extern C

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QFont_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QFont",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Sbk_QFont__repr__,
    /*tp_as_number*/        &Sbk_QFont_as_number,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      Sbk_QFont_richcompare,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QFont_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&SbkObject_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QFont_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern


void init_QFont(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QFONT_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QFont_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QFont_Type);
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QFont_Type, &Shiboken::callCppDestructor<QFont >);
    Py_INCREF((PyObject*)&Sbk_QFont_Type); //Incref due the 'PyModule_AddObject' steals the reference.
    if (PyType_Ready((PyTypeObject*)&Sbk_QFont_Type) < 0)
        return;

    Shiboken::ObjectType::setOriginalName(&Sbk_QFont_Type, "QFont");
    PyModule_AddObject(module, "QFont",
        ((PyObject*)&Sbk_QFont_Type));

    // Initialize enums
    PyObject* enumItem;

    // init enum: StyleStrategy
    PyTypeObject* SbkPySide_QtGui_QFont_StyleStrategy = Shiboken::Enum::newType("PySide.QtGui.QFont.StyleStrategy");
    SbkPySide_QtGuiTypes[SBK_QFONT_STYLESTRATEGY_IDX] = SbkPySide_QtGui_QFont_StyleStrategy;
    if (PyType_Ready(SbkPySide_QtGui_QFont_StyleStrategy) < 0)
        return;
    PyDict_SetItemString(Sbk_QFont_Type.super.ht_type.tp_dict,
            "StyleStrategy",((PyObject*)SbkPySide_QtGui_QFont_StyleStrategy));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QFont_StyleStrategy,(long) QFont::PreferDefault, "PreferDefault");
    PyDict_SetItemString(Sbk_QFont_Type.super.ht_type.tp_dict,"PreferDefault", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QFont_StyleStrategy->tp_dict,"PreferDefault", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QFont_StyleStrategy,(long) QFont::PreferBitmap, "PreferBitmap");
    PyDict_SetItemString(Sbk_QFont_Type.super.ht_type.tp_dict,"PreferBitmap", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QFont_StyleStrategy->tp_dict,"PreferBitmap", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QFont_StyleStrategy,(long) QFont::PreferDevice, "PreferDevice");
    PyDict_SetItemString(Sbk_QFont_Type.super.ht_type.tp_dict,"PreferDevice", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QFont_StyleStrategy->tp_dict,"PreferDevice", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QFont_StyleStrategy,(long) QFont::PreferOutline, "PreferOutline");
    PyDict_SetItemString(Sbk_QFont_Type.super.ht_type.tp_dict,"PreferOutline", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QFont_StyleStrategy->tp_dict,"PreferOutline", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QFont_StyleStrategy,(long) QFont::ForceOutline, "ForceOutline");
    PyDict_SetItemString(Sbk_QFont_Type.super.ht_type.tp_dict,"ForceOutline", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QFont_StyleStrategy->tp_dict,"ForceOutline", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QFont_StyleStrategy,(long) QFont::PreferMatch, "PreferMatch");
    PyDict_SetItemString(Sbk_QFont_Type.super.ht_type.tp_dict,"PreferMatch", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QFont_StyleStrategy->tp_dict,"PreferMatch", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QFont_StyleStrategy,(long) QFont::PreferQuality, "PreferQuality");
    PyDict_SetItemString(Sbk_QFont_Type.super.ht_type.tp_dict,"PreferQuality", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QFont_StyleStrategy->tp_dict,"PreferQuality", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QFont_StyleStrategy,(long) QFont::PreferAntialias, "PreferAntialias");
    PyDict_SetItemString(Sbk_QFont_Type.super.ht_type.tp_dict,"PreferAntialias", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QFont_StyleStrategy->tp_dict,"PreferAntialias", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QFont_StyleStrategy,(long) QFont::NoAntialias, "NoAntialias");
    PyDict_SetItemString(Sbk_QFont_Type.super.ht_type.tp_dict,"NoAntialias", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QFont_StyleStrategy->tp_dict,"NoAntialias", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QFont_StyleStrategy,(long) QFont::OpenGLCompatible, "OpenGLCompatible");
    PyDict_SetItemString(Sbk_QFont_Type.super.ht_type.tp_dict,"OpenGLCompatible", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QFont_StyleStrategy->tp_dict,"OpenGLCompatible", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QFont_StyleStrategy,(long) QFont::ForceIntegerMetrics, "ForceIntegerMetrics");
    PyDict_SetItemString(Sbk_QFont_Type.super.ht_type.tp_dict,"ForceIntegerMetrics", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QFont_StyleStrategy->tp_dict,"ForceIntegerMetrics", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QFont_StyleStrategy,(long) QFont::NoFontMerging, "NoFontMerging");
    PyDict_SetItemString(Sbk_QFont_Type.super.ht_type.tp_dict,"NoFontMerging", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QFont_StyleStrategy->tp_dict,"NoFontMerging", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QFont::StyleStrategy");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::StyleStrategy");
    // end of enum StyleStrategy

    // init enum: SpacingType
    PyTypeObject* SbkPySide_QtGui_QFont_SpacingType = Shiboken::Enum::newType("PySide.QtGui.QFont.SpacingType");
    SbkPySide_QtGuiTypes[SBK_QFONT_SPACINGTYPE_IDX] = SbkPySide_QtGui_QFont_SpacingType;
    if (PyType_Ready(SbkPySide_QtGui_QFont_SpacingType) < 0)
        return;
    PyDict_SetItemString(Sbk_QFont_Type.super.ht_type.tp_dict,
            "SpacingType",((PyObject*)SbkPySide_QtGui_QFont_SpacingType));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QFont_SpacingType,(long) QFont::PercentageSpacing, "PercentageSpacing");
    PyDict_SetItemString(Sbk_QFont_Type.super.ht_type.tp_dict,"PercentageSpacing", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QFont_SpacingType->tp_dict,"PercentageSpacing", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QFont_SpacingType,(long) QFont::AbsoluteSpacing, "AbsoluteSpacing");
    PyDict_SetItemString(Sbk_QFont_Type.super.ht_type.tp_dict,"AbsoluteSpacing", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QFont_SpacingType->tp_dict,"AbsoluteSpacing", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QFont::SpacingType");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::SpacingType");
    // end of enum SpacingType

    // init enum: StyleHint
    PyTypeObject* SbkPySide_QtGui_QFont_StyleHint = Shiboken::Enum::newType("PySide.QtGui.QFont.StyleHint");
    SbkPySide_QtGuiTypes[SBK_QFONT_STYLEHINT_IDX] = SbkPySide_QtGui_QFont_StyleHint;
    if (PyType_Ready(SbkPySide_QtGui_QFont_StyleHint) < 0)
        return;
    PyDict_SetItemString(Sbk_QFont_Type.super.ht_type.tp_dict,
            "StyleHint",((PyObject*)SbkPySide_QtGui_QFont_StyleHint));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QFont_StyleHint,(long) QFont::Helvetica, "Helvetica");
    PyDict_SetItemString(Sbk_QFont_Type.super.ht_type.tp_dict,"Helvetica", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QFont_StyleHint->tp_dict,"Helvetica", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QFont_StyleHint,(long) QFont::SansSerif, "SansSerif");
    PyDict_SetItemString(Sbk_QFont_Type.super.ht_type.tp_dict,"SansSerif", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QFont_StyleHint->tp_dict,"SansSerif", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QFont_StyleHint,(long) QFont::Times, "Times");
    PyDict_SetItemString(Sbk_QFont_Type.super.ht_type.tp_dict,"Times", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QFont_StyleHint->tp_dict,"Times", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QFont_StyleHint,(long) QFont::Serif, "Serif");
    PyDict_SetItemString(Sbk_QFont_Type.super.ht_type.tp_dict,"Serif", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QFont_StyleHint->tp_dict,"Serif", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QFont_StyleHint,(long) QFont::Courier, "Courier");
    PyDict_SetItemString(Sbk_QFont_Type.super.ht_type.tp_dict,"Courier", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QFont_StyleHint->tp_dict,"Courier", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QFont_StyleHint,(long) QFont::TypeWriter, "TypeWriter");
    PyDict_SetItemString(Sbk_QFont_Type.super.ht_type.tp_dict,"TypeWriter", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QFont_StyleHint->tp_dict,"TypeWriter", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QFont_StyleHint,(long) QFont::OldEnglish, "OldEnglish");
    PyDict_SetItemString(Sbk_QFont_Type.super.ht_type.tp_dict,"OldEnglish", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QFont_StyleHint->tp_dict,"OldEnglish", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QFont_StyleHint,(long) QFont::Decorative, "Decorative");
    PyDict_SetItemString(Sbk_QFont_Type.super.ht_type.tp_dict,"Decorative", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QFont_StyleHint->tp_dict,"Decorative", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QFont_StyleHint,(long) QFont::System, "System");
    PyDict_SetItemString(Sbk_QFont_Type.super.ht_type.tp_dict,"System", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QFont_StyleHint->tp_dict,"System", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QFont_StyleHint,(long) QFont::AnyStyle, "AnyStyle");
    PyDict_SetItemString(Sbk_QFont_Type.super.ht_type.tp_dict,"AnyStyle", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QFont_StyleHint->tp_dict,"AnyStyle", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QFont_StyleHint,(long) QFont::Cursive, "Cursive");
    PyDict_SetItemString(Sbk_QFont_Type.super.ht_type.tp_dict,"Cursive", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QFont_StyleHint->tp_dict,"Cursive", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QFont_StyleHint,(long) QFont::Monospace, "Monospace");
    PyDict_SetItemString(Sbk_QFont_Type.super.ht_type.tp_dict,"Monospace", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QFont_StyleHint->tp_dict,"Monospace", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QFont_StyleHint,(long) QFont::Fantasy, "Fantasy");
    PyDict_SetItemString(Sbk_QFont_Type.super.ht_type.tp_dict,"Fantasy", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QFont_StyleHint->tp_dict,"Fantasy", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QFont::StyleHint");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::StyleHint");
    // end of enum StyleHint

    // init enum: Weight
    PyTypeObject* SbkPySide_QtGui_QFont_Weight = Shiboken::Enum::newType("PySide.QtGui.QFont.Weight");
    SbkPySide_QtGuiTypes[SBK_QFONT_WEIGHT_IDX] = SbkPySide_QtGui_QFont_Weight;
    if (PyType_Ready(SbkPySide_QtGui_QFont_Weight) < 0)
        return;
    PyDict_SetItemString(Sbk_QFont_Type.super.ht_type.tp_dict,
            "Weight",((PyObject*)SbkPySide_QtGui_QFont_Weight));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QFont_Weight,(long) QFont::Light, "Light");
    PyDict_SetItemString(Sbk_QFont_Type.super.ht_type.tp_dict,"Light", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QFont_Weight->tp_dict,"Light", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QFont_Weight,(long) QFont::Normal, "Normal");
    PyDict_SetItemString(Sbk_QFont_Type.super.ht_type.tp_dict,"Normal", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QFont_Weight->tp_dict,"Normal", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QFont_Weight,(long) QFont::DemiBold, "DemiBold");
    PyDict_SetItemString(Sbk_QFont_Type.super.ht_type.tp_dict,"DemiBold", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QFont_Weight->tp_dict,"DemiBold", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QFont_Weight,(long) QFont::Bold, "Bold");
    PyDict_SetItemString(Sbk_QFont_Type.super.ht_type.tp_dict,"Bold", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QFont_Weight->tp_dict,"Bold", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QFont_Weight,(long) QFont::Black, "Black");
    PyDict_SetItemString(Sbk_QFont_Type.super.ht_type.tp_dict,"Black", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QFont_Weight->tp_dict,"Black", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QFont::Weight");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::Weight");
    // end of enum Weight

    // init enum: Capitalization
    PyTypeObject* SbkPySide_QtGui_QFont_Capitalization = Shiboken::Enum::newType("PySide.QtGui.QFont.Capitalization");
    SbkPySide_QtGuiTypes[SBK_QFONT_CAPITALIZATION_IDX] = SbkPySide_QtGui_QFont_Capitalization;
    if (PyType_Ready(SbkPySide_QtGui_QFont_Capitalization) < 0)
        return;
    PyDict_SetItemString(Sbk_QFont_Type.super.ht_type.tp_dict,
            "Capitalization",((PyObject*)SbkPySide_QtGui_QFont_Capitalization));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QFont_Capitalization,(long) QFont::MixedCase, "MixedCase");
    PyDict_SetItemString(Sbk_QFont_Type.super.ht_type.tp_dict,"MixedCase", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QFont_Capitalization->tp_dict,"MixedCase", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QFont_Capitalization,(long) QFont::AllUppercase, "AllUppercase");
    PyDict_SetItemString(Sbk_QFont_Type.super.ht_type.tp_dict,"AllUppercase", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QFont_Capitalization->tp_dict,"AllUppercase", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QFont_Capitalization,(long) QFont::AllLowercase, "AllLowercase");
    PyDict_SetItemString(Sbk_QFont_Type.super.ht_type.tp_dict,"AllLowercase", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QFont_Capitalization->tp_dict,"AllLowercase", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QFont_Capitalization,(long) QFont::SmallCaps, "SmallCaps");
    PyDict_SetItemString(Sbk_QFont_Type.super.ht_type.tp_dict,"SmallCaps", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QFont_Capitalization->tp_dict,"SmallCaps", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QFont_Capitalization,(long) QFont::Capitalize, "Capitalize");
    PyDict_SetItemString(Sbk_QFont_Type.super.ht_type.tp_dict,"Capitalize", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QFont_Capitalization->tp_dict,"Capitalize", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QFont::Capitalization");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::Capitalization");
    // end of enum Capitalization

    // init enum: Stretch
    PyTypeObject* SbkPySide_QtGui_QFont_Stretch = Shiboken::Enum::newType("PySide.QtGui.QFont.Stretch");
    SbkPySide_QtGuiTypes[SBK_QFONT_STRETCH_IDX] = SbkPySide_QtGui_QFont_Stretch;
    if (PyType_Ready(SbkPySide_QtGui_QFont_Stretch) < 0)
        return;
    PyDict_SetItemString(Sbk_QFont_Type.super.ht_type.tp_dict,
            "Stretch",((PyObject*)SbkPySide_QtGui_QFont_Stretch));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QFont_Stretch,(long) QFont::UltraCondensed, "UltraCondensed");
    PyDict_SetItemString(Sbk_QFont_Type.super.ht_type.tp_dict,"UltraCondensed", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QFont_Stretch->tp_dict,"UltraCondensed", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QFont_Stretch,(long) QFont::ExtraCondensed, "ExtraCondensed");
    PyDict_SetItemString(Sbk_QFont_Type.super.ht_type.tp_dict,"ExtraCondensed", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QFont_Stretch->tp_dict,"ExtraCondensed", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QFont_Stretch,(long) QFont::Condensed, "Condensed");
    PyDict_SetItemString(Sbk_QFont_Type.super.ht_type.tp_dict,"Condensed", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QFont_Stretch->tp_dict,"Condensed", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QFont_Stretch,(long) QFont::SemiCondensed, "SemiCondensed");
    PyDict_SetItemString(Sbk_QFont_Type.super.ht_type.tp_dict,"SemiCondensed", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QFont_Stretch->tp_dict,"SemiCondensed", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QFont_Stretch,(long) QFont::Unstretched, "Unstretched");
    PyDict_SetItemString(Sbk_QFont_Type.super.ht_type.tp_dict,"Unstretched", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QFont_Stretch->tp_dict,"Unstretched", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QFont_Stretch,(long) QFont::SemiExpanded, "SemiExpanded");
    PyDict_SetItemString(Sbk_QFont_Type.super.ht_type.tp_dict,"SemiExpanded", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QFont_Stretch->tp_dict,"SemiExpanded", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QFont_Stretch,(long) QFont::Expanded, "Expanded");
    PyDict_SetItemString(Sbk_QFont_Type.super.ht_type.tp_dict,"Expanded", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QFont_Stretch->tp_dict,"Expanded", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QFont_Stretch,(long) QFont::ExtraExpanded, "ExtraExpanded");
    PyDict_SetItemString(Sbk_QFont_Type.super.ht_type.tp_dict,"ExtraExpanded", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QFont_Stretch->tp_dict,"ExtraExpanded", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QFont_Stretch,(long) QFont::UltraExpanded, "UltraExpanded");
    PyDict_SetItemString(Sbk_QFont_Type.super.ht_type.tp_dict,"UltraExpanded", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QFont_Stretch->tp_dict,"UltraExpanded", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QFont::Stretch");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::Stretch");
    // end of enum Stretch

    // init enum: Style
    PyTypeObject* SbkPySide_QtGui_QFont_Style = Shiboken::Enum::newType("PySide.QtGui.QFont.Style");
    SbkPySide_QtGuiTypes[SBK_QFONT_STYLE_IDX] = SbkPySide_QtGui_QFont_Style;
    if (PyType_Ready(SbkPySide_QtGui_QFont_Style) < 0)
        return;
    PyDict_SetItemString(Sbk_QFont_Type.super.ht_type.tp_dict,
            "Style",((PyObject*)SbkPySide_QtGui_QFont_Style));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QFont_Style,(long) QFont::StyleNormal, "StyleNormal");
    PyDict_SetItemString(Sbk_QFont_Type.super.ht_type.tp_dict,"StyleNormal", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QFont_Style->tp_dict,"StyleNormal", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QFont_Style,(long) QFont::StyleItalic, "StyleItalic");
    PyDict_SetItemString(Sbk_QFont_Type.super.ht_type.tp_dict,"StyleItalic", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QFont_Style->tp_dict,"StyleItalic", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QFont_Style,(long) QFont::StyleOblique, "StyleOblique");
    PyDict_SetItemString(Sbk_QFont_Type.super.ht_type.tp_dict,"StyleOblique", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QFont_Style->tp_dict,"StyleOblique", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QFont::Style");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::Style");
    // end of enum Style


    Shiboken::TypeResolver::createValueTypeResolver<QFont >("QFont");
    Shiboken::TypeResolver::createObjectTypeResolver<QFont >("QFont*");
    Shiboken::TypeResolver::createValueTypeResolver<QFont >(typeid(QFont).name());
    qRegisterMetaType< ::QFont >("QFont");
    qRegisterMetaType< ::QFont::StyleStrategy >("QFont::StyleStrategy");
    qRegisterMetaType< ::QFont::SpacingType >("QFont::SpacingType");
    qRegisterMetaType< ::QFont::StyleHint >("QFont::StyleHint");
    qRegisterMetaType< ::QFont::Weight >("QFont::Weight");
    qRegisterMetaType< ::QFont::Capitalization >("QFont::Capitalization");
    qRegisterMetaType< ::QFont::Stretch >("QFont::Stretch");
    qRegisterMetaType< ::QFont::Style >("QFont::Style");
}

