/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtgui_python.h"

#include "qgraphicsscenehoverevent_wrapper.h"

// Extra includes
#include <qgraphicssceneevent.h>
#include <qpoint.h>
#include <qwidget.h>


// Native ---------------------------------------------------------

QGraphicsSceneHoverEventWrapper::QGraphicsSceneHoverEventWrapper(QEvent::Type type) : QGraphicsSceneHoverEvent(type) {
    // ... middle
}

QGraphicsSceneHoverEventWrapper::~QGraphicsSceneHoverEventWrapper()
{
    SbkObject* wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QGraphicsSceneHoverEvent_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QGraphicsSceneHoverEvent >()))
        return -1;

    QGraphicsSceneHoverEventWrapper* cptr = 0;
    int overloadId = -1;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);

    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);

    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QGraphicsSceneHoverEvent(): too many arguments");
        return -1;
    }

    if (!PyArg_ParseTuple(args, "|O:QGraphicsSceneHoverEvent", &(pyargs[0])))
        return -1;

    // Overloaded function decisor
    // 0: QGraphicsSceneHoverEvent(QEvent::Type)
    if (numArgs == 0) {
        overloadId = 0; // QGraphicsSceneHoverEvent(QEvent::Type)
    } else if (Shiboken::Converter< ::QEvent::Type >::isConvertible(pyargs[0])) {
        overloadId = 0; // QGraphicsSceneHoverEvent(QEvent::Type)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGraphicsSceneHoverEvent_Init_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "type");
                if (value) {
                    if (pyargs[0])
                        errorArgName = "type";
                    else if (Shiboken::Converter< ::QEvent::Type >::isConvertible(value))
                        pyargs[0] = value;
                    else
                        goto Sbk_QGraphicsSceneHoverEvent_Init_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QGraphicsSceneHoverEvent(): got multiple values for keyword argument '%s'", errorArgName);
                    return -1;
                }
            }
            QEvent::Type cppArg0 = pyargs[0] ? Shiboken::Converter<QEvent::Type >::toCpp(pyargs[0]) : QEvent::None;

            if(!PyErr_Occurred()) {
                // QGraphicsSceneHoverEvent(QEvent::Type)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new QGraphicsSceneHoverEventWrapper(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QGraphicsSceneHoverEvent >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QGraphicsSceneHoverEvent_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QGraphicsSceneHoverEvent_Init_TypeError:
        const char* overloads[] = {"PySide.QtCore.QEvent.Type = None", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QGraphicsSceneHoverEvent", overloads);
        return -1;
}

static PyObject* Sbk_QGraphicsSceneHoverEventFunc_lastPos(PyObject* self)
{
    QGraphicsSceneHoverEvent* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsSceneHoverEvent* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // lastPos()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QPointF cppResult = const_cast<const QGraphicsSceneHoverEvent*>(cppSelf)->lastPos();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QPointF >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QGraphicsSceneHoverEventFunc_lastScenePos(PyObject* self)
{
    QGraphicsSceneHoverEvent* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsSceneHoverEvent* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // lastScenePos()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QPointF cppResult = const_cast<const QGraphicsSceneHoverEvent*>(cppSelf)->lastScenePos();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QPointF >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QGraphicsSceneHoverEventFunc_lastScreenPos(PyObject* self)
{
    QGraphicsSceneHoverEvent* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsSceneHoverEvent* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // lastScreenPos()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QPoint cppResult = const_cast<const QGraphicsSceneHoverEvent*>(cppSelf)->lastScreenPos();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QPoint >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QGraphicsSceneHoverEventFunc_modifiers(PyObject* self)
{
    QGraphicsSceneHoverEvent* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsSceneHoverEvent* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // modifiers()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QFlags<Qt::KeyboardModifier> cppResult = const_cast<const QGraphicsSceneHoverEvent*>(cppSelf)->modifiers();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QFlags<Qt::KeyboardModifier> >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QGraphicsSceneHoverEventFunc_pos(PyObject* self)
{
    QGraphicsSceneHoverEvent* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsSceneHoverEvent* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // pos()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QPointF cppResult = const_cast<const QGraphicsSceneHoverEvent*>(cppSelf)->pos();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QPointF >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QGraphicsSceneHoverEventFunc_scenePos(PyObject* self)
{
    QGraphicsSceneHoverEvent* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsSceneHoverEvent* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // scenePos()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QPointF cppResult = const_cast<const QGraphicsSceneHoverEvent*>(cppSelf)->scenePos();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QPointF >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QGraphicsSceneHoverEventFunc_screenPos(PyObject* self)
{
    QGraphicsSceneHoverEvent* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsSceneHoverEvent* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // screenPos()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QPoint cppResult = const_cast<const QGraphicsSceneHoverEvent*>(cppSelf)->screenPos();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QPoint >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QGraphicsSceneHoverEventFunc_setLastPos(PyObject* self, PyObject* arg)
{
    QGraphicsSceneHoverEvent* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsSceneHoverEvent* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setLastPos(QPointF)
    if (Shiboken::Converter< ::QPointF >::isConvertible(arg)) {
        overloadId = 0; // setLastPos(QPointF)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGraphicsSceneHoverEventFunc_setLastPos_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QPointF cppArg0 = Shiboken::Converter<QPointF >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setLastPos(QPointF)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setLastPos(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGraphicsSceneHoverEventFunc_setLastPos_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPointF", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsSceneHoverEvent.setLastPos", overloads);
        return 0;
}

static PyObject* Sbk_QGraphicsSceneHoverEventFunc_setLastScenePos(PyObject* self, PyObject* arg)
{
    QGraphicsSceneHoverEvent* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsSceneHoverEvent* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setLastScenePos(QPointF)
    if (Shiboken::Converter< ::QPointF >::isConvertible(arg)) {
        overloadId = 0; // setLastScenePos(QPointF)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGraphicsSceneHoverEventFunc_setLastScenePos_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QPointF cppArg0 = Shiboken::Converter<QPointF >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setLastScenePos(QPointF)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setLastScenePos(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGraphicsSceneHoverEventFunc_setLastScenePos_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPointF", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsSceneHoverEvent.setLastScenePos", overloads);
        return 0;
}

static PyObject* Sbk_QGraphicsSceneHoverEventFunc_setLastScreenPos(PyObject* self, PyObject* arg)
{
    QGraphicsSceneHoverEvent* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsSceneHoverEvent* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setLastScreenPos(QPoint)
    if (Shiboken::Converter< ::QPoint >::isConvertible(arg)) {
        overloadId = 0; // setLastScreenPos(QPoint)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGraphicsSceneHoverEventFunc_setLastScreenPos_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QPoint cppArg0 = Shiboken::Converter<QPoint >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setLastScreenPos(QPoint)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setLastScreenPos(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGraphicsSceneHoverEventFunc_setLastScreenPos_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPoint", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsSceneHoverEvent.setLastScreenPos", overloads);
        return 0;
}

static PyObject* Sbk_QGraphicsSceneHoverEventFunc_setModifiers(PyObject* self, PyObject* arg)
{
    QGraphicsSceneHoverEvent* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsSceneHoverEvent* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setModifiers(QFlags<Qt::KeyboardModifier>)
    if (Shiboken::Converter< ::QFlags<Qt::KeyboardModifier> >::isConvertible(arg)) {
        overloadId = 0; // setModifiers(QFlags<Qt::KeyboardModifier>)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGraphicsSceneHoverEventFunc_setModifiers_TypeError;

    // Call function/method
    {
        {
            QFlags<Qt::KeyboardModifier> cppArg0 = Shiboken::Converter<QFlags<Qt::KeyboardModifier> >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setModifiers(QFlags<Qt::KeyboardModifier>)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setModifiers(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGraphicsSceneHoverEventFunc_setModifiers_TypeError:
        const char* overloads[] = {"PySide.QtCore.Qt.KeyboardModifiers", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsSceneHoverEvent.setModifiers", overloads);
        return 0;
}

static PyObject* Sbk_QGraphicsSceneHoverEventFunc_setPos(PyObject* self, PyObject* arg)
{
    QGraphicsSceneHoverEvent* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsSceneHoverEvent* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setPos(QPointF)
    if (Shiboken::Converter< ::QPointF >::isConvertible(arg)) {
        overloadId = 0; // setPos(QPointF)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGraphicsSceneHoverEventFunc_setPos_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QPointF cppArg0 = Shiboken::Converter<QPointF >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setPos(QPointF)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setPos(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGraphicsSceneHoverEventFunc_setPos_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPointF", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsSceneHoverEvent.setPos", overloads);
        return 0;
}

static PyObject* Sbk_QGraphicsSceneHoverEventFunc_setScenePos(PyObject* self, PyObject* arg)
{
    QGraphicsSceneHoverEvent* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsSceneHoverEvent* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setScenePos(QPointF)
    if (Shiboken::Converter< ::QPointF >::isConvertible(arg)) {
        overloadId = 0; // setScenePos(QPointF)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGraphicsSceneHoverEventFunc_setScenePos_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QPointF cppArg0 = Shiboken::Converter<QPointF >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setScenePos(QPointF)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setScenePos(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGraphicsSceneHoverEventFunc_setScenePos_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPointF", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsSceneHoverEvent.setScenePos", overloads);
        return 0;
}

static PyObject* Sbk_QGraphicsSceneHoverEventFunc_setScreenPos(PyObject* self, PyObject* arg)
{
    QGraphicsSceneHoverEvent* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsSceneHoverEvent* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setScreenPos(QPoint)
    if (Shiboken::Converter< ::QPoint >::isConvertible(arg)) {
        overloadId = 0; // setScreenPos(QPoint)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGraphicsSceneHoverEventFunc_setScreenPos_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QPoint cppArg0 = Shiboken::Converter<QPoint >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setScreenPos(QPoint)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setScreenPos(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGraphicsSceneHoverEventFunc_setScreenPos_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPoint", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsSceneHoverEvent.setScreenPos", overloads);
        return 0;
}

static PyMethodDef Sbk_QGraphicsSceneHoverEvent_methods[] = {
    {"lastPos", (PyCFunction)Sbk_QGraphicsSceneHoverEventFunc_lastPos, METH_NOARGS},
    {"lastScenePos", (PyCFunction)Sbk_QGraphicsSceneHoverEventFunc_lastScenePos, METH_NOARGS},
    {"lastScreenPos", (PyCFunction)Sbk_QGraphicsSceneHoverEventFunc_lastScreenPos, METH_NOARGS},
    {"modifiers", (PyCFunction)Sbk_QGraphicsSceneHoverEventFunc_modifiers, METH_NOARGS},
    {"pos", (PyCFunction)Sbk_QGraphicsSceneHoverEventFunc_pos, METH_NOARGS},
    {"scenePos", (PyCFunction)Sbk_QGraphicsSceneHoverEventFunc_scenePos, METH_NOARGS},
    {"screenPos", (PyCFunction)Sbk_QGraphicsSceneHoverEventFunc_screenPos, METH_NOARGS},
    {"setLastPos", (PyCFunction)Sbk_QGraphicsSceneHoverEventFunc_setLastPos, METH_O},
    {"setLastScenePos", (PyCFunction)Sbk_QGraphicsSceneHoverEventFunc_setLastScenePos, METH_O},
    {"setLastScreenPos", (PyCFunction)Sbk_QGraphicsSceneHoverEventFunc_setLastScreenPos, METH_O},
    {"setModifiers", (PyCFunction)Sbk_QGraphicsSceneHoverEventFunc_setModifiers, METH_O},
    {"setPos", (PyCFunction)Sbk_QGraphicsSceneHoverEventFunc_setPos, METH_O},
    {"setScenePos", (PyCFunction)Sbk_QGraphicsSceneHoverEventFunc_setScenePos, METH_O},
    {"setScreenPos", (PyCFunction)Sbk_QGraphicsSceneHoverEventFunc_setScreenPos, METH_O},

    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QGraphicsSceneHoverEvent_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QGraphicsSceneHoverEvent",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QGraphicsSceneHoverEvent_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QGraphicsSceneHoverEvent_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern

static SbkObjectType* Sbk_QGraphicsSceneHoverEvent_typeDiscovery(void* cptr, SbkObjectType* instanceType)
{
     if ( reinterpret_cast<QGraphicsSceneHoverEvent*>(cptr)->type() == QEvent::GraphicsSceneHoverEnter ||  reinterpret_cast<QGraphicsSceneHoverEvent*>(cptr)->type() == QEvent::GraphicsSceneHoverLeave ||  reinterpret_cast<QGraphicsSceneHoverEvent*>(cptr)->type() == QEvent::GraphicsSceneHoverMove)
        return &Sbk_QGraphicsSceneHoverEvent_Type;
    return 0;
}


void init_QGraphicsSceneHoverEvent(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QGRAPHICSSCENEHOVEREVENT_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QGraphicsSceneHoverEvent_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QGraphicsSceneHoverEvent_Type);
    Sbk_QGraphicsSceneHoverEvent_Type.super.ht_type.tp_base = SbkPySide_QtGuiTypes[SBK_QGRAPHICSSCENEEVENT_IDX];
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QGraphicsSceneHoverEvent_Type, &Shiboken::callCppDestructor<QGraphicsSceneHoverEvent >);
    Py_INCREF((PyObject*)&Sbk_QGraphicsSceneHoverEvent_Type); //Incref due the 'PyModule_AddObject' steals the reference.
    if (PyType_Ready((PyTypeObject*)&Sbk_QGraphicsSceneHoverEvent_Type) < 0)
        return;

    // Fill type discovery information
    Shiboken::ObjectType::setTypeDiscoveryFunction(&Sbk_QGraphicsSceneHoverEvent_Type, &Sbk_QGraphicsSceneHoverEvent_typeDiscovery);
    Shiboken::BindingManager& bm = Shiboken::BindingManager::instance();
    bm.addClassInheritance(reinterpret_cast<SbkObjectType*>(SbkPySide_QtGuiTypes[SBK_QGRAPHICSSCENEEVENT_IDX]), &Sbk_QGraphicsSceneHoverEvent_Type);

    Shiboken::ObjectType::setOriginalName(&Sbk_QGraphicsSceneHoverEvent_Type, "QGraphicsSceneHoverEvent*");
    PyModule_AddObject(module, "QGraphicsSceneHoverEvent",
        ((PyObject*)&Sbk_QGraphicsSceneHoverEvent_Type));


    Shiboken::TypeResolver::createObjectTypeResolver<QGraphicsSceneHoverEvent >("QGraphicsSceneHoverEvent*");
    Shiboken::TypeResolver::createObjectTypeResolver<QGraphicsSceneHoverEvent >(typeid(QGraphicsSceneHoverEvent).name());
    Shiboken::TypeResolver::createObjectTypeResolver<QGraphicsSceneHoverEvent >(typeid(QGraphicsSceneHoverEventWrapper).name());
    qRegisterMetaType< ::QGraphicsSceneHoverEvent* >("QGraphicsSceneHoverEvent*");
}

