/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtgui_python.h"

#include "qgraphicssceneresizeevent_wrapper.h"

// Extra includes
#include <qgraphicssceneevent.h>
#include <qsize.h>
#include <qwidget.h>


// Native ---------------------------------------------------------

QGraphicsSceneResizeEventWrapper::QGraphicsSceneResizeEventWrapper() : QGraphicsSceneResizeEvent() {
    // ... middle
}

QGraphicsSceneResizeEventWrapper::~QGraphicsSceneResizeEventWrapper()
{
    SbkObject* wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QGraphicsSceneResizeEvent_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QGraphicsSceneResizeEvent >()))
        return -1;

    QGraphicsSceneResizeEventWrapper* cptr = 0;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // QGraphicsSceneResizeEvent()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new QGraphicsSceneResizeEventWrapper();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QGraphicsSceneResizeEvent >(), cptr)) {
        delete cptr;
        return -1;
    }
    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject* Sbk_QGraphicsSceneResizeEventFunc_newSize(PyObject* self)
{
    QGraphicsSceneResizeEvent* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsSceneResizeEvent* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // newSize()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QSizeF cppResult = const_cast<const QGraphicsSceneResizeEvent*>(cppSelf)->newSize();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QSizeF >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QGraphicsSceneResizeEventFunc_oldSize(PyObject* self)
{
    QGraphicsSceneResizeEvent* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsSceneResizeEvent* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // oldSize()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QSizeF cppResult = const_cast<const QGraphicsSceneResizeEvent*>(cppSelf)->oldSize();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QSizeF >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QGraphicsSceneResizeEventFunc_setNewSize(PyObject* self, PyObject* arg)
{
    QGraphicsSceneResizeEvent* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsSceneResizeEvent* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setNewSize(QSizeF)
    if (Shiboken::Converter< ::QSizeF >::isConvertible(arg)) {
        overloadId = 0; // setNewSize(QSizeF)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGraphicsSceneResizeEventFunc_setNewSize_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QSizeF cppArg0 = Shiboken::Converter<QSizeF >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setNewSize(QSizeF)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setNewSize(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGraphicsSceneResizeEventFunc_setNewSize_TypeError:
        const char* overloads[] = {"PySide.QtCore.QSizeF", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsSceneResizeEvent.setNewSize", overloads);
        return 0;
}

static PyObject* Sbk_QGraphicsSceneResizeEventFunc_setOldSize(PyObject* self, PyObject* arg)
{
    QGraphicsSceneResizeEvent* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsSceneResizeEvent* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setOldSize(QSizeF)
    if (Shiboken::Converter< ::QSizeF >::isConvertible(arg)) {
        overloadId = 0; // setOldSize(QSizeF)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGraphicsSceneResizeEventFunc_setOldSize_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QSizeF cppArg0 = Shiboken::Converter<QSizeF >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setOldSize(QSizeF)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setOldSize(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGraphicsSceneResizeEventFunc_setOldSize_TypeError:
        const char* overloads[] = {"PySide.QtCore.QSizeF", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsSceneResizeEvent.setOldSize", overloads);
        return 0;
}

static PyMethodDef Sbk_QGraphicsSceneResizeEvent_methods[] = {
    {"newSize", (PyCFunction)Sbk_QGraphicsSceneResizeEventFunc_newSize, METH_NOARGS},
    {"oldSize", (PyCFunction)Sbk_QGraphicsSceneResizeEventFunc_oldSize, METH_NOARGS},
    {"setNewSize", (PyCFunction)Sbk_QGraphicsSceneResizeEventFunc_setNewSize, METH_O},
    {"setOldSize", (PyCFunction)Sbk_QGraphicsSceneResizeEventFunc_setOldSize, METH_O},

    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QGraphicsSceneResizeEvent_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QGraphicsSceneResizeEvent",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QGraphicsSceneResizeEvent_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QGraphicsSceneResizeEvent_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern

static SbkObjectType* Sbk_QGraphicsSceneResizeEvent_typeDiscovery(void* cptr, SbkObjectType* instanceType)
{
     if ( reinterpret_cast<QGraphicsSceneResizeEvent*>(cptr)->type() == QEvent::GraphicsSceneResize)
        return &Sbk_QGraphicsSceneResizeEvent_Type;
    return 0;
}


void init_QGraphicsSceneResizeEvent(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QGRAPHICSSCENERESIZEEVENT_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QGraphicsSceneResizeEvent_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QGraphicsSceneResizeEvent_Type);
    Sbk_QGraphicsSceneResizeEvent_Type.super.ht_type.tp_base = SbkPySide_QtGuiTypes[SBK_QGRAPHICSSCENEEVENT_IDX];
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QGraphicsSceneResizeEvent_Type, &Shiboken::callCppDestructor<QGraphicsSceneResizeEvent >);
    Py_INCREF((PyObject*)&Sbk_QGraphicsSceneResizeEvent_Type); //Incref due the 'PyModule_AddObject' steals the reference.
    if (PyType_Ready((PyTypeObject*)&Sbk_QGraphicsSceneResizeEvent_Type) < 0)
        return;

    // Fill type discovery information
    Shiboken::ObjectType::setTypeDiscoveryFunction(&Sbk_QGraphicsSceneResizeEvent_Type, &Sbk_QGraphicsSceneResizeEvent_typeDiscovery);
    Shiboken::BindingManager& bm = Shiboken::BindingManager::instance();
    bm.addClassInheritance(reinterpret_cast<SbkObjectType*>(SbkPySide_QtGuiTypes[SBK_QGRAPHICSSCENEEVENT_IDX]), &Sbk_QGraphicsSceneResizeEvent_Type);

    Shiboken::ObjectType::setOriginalName(&Sbk_QGraphicsSceneResizeEvent_Type, "QGraphicsSceneResizeEvent*");
    PyModule_AddObject(module, "QGraphicsSceneResizeEvent",
        ((PyObject*)&Sbk_QGraphicsSceneResizeEvent_Type));


    Shiboken::TypeResolver::createObjectTypeResolver<QGraphicsSceneResizeEvent >("QGraphicsSceneResizeEvent*");
    Shiboken::TypeResolver::createObjectTypeResolver<QGraphicsSceneResizeEvent >(typeid(QGraphicsSceneResizeEvent).name());
    Shiboken::TypeResolver::createObjectTypeResolver<QGraphicsSceneResizeEvent >(typeid(QGraphicsSceneResizeEventWrapper).name());
    qRegisterMetaType< ::QGraphicsSceneResizeEvent* >("QGraphicsSceneResizeEvent*");
}

