/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtgui_python.h"

#include "qimagereader_wrapper.h"

// Extra includes
#include <QColor>
#include <QImage>
#include <QList>
#include <QRect>
#include <QSize>
#include <QStringList>
#include <qbytearray.h>
#include <qcolor.h>
#include <qimage.h>
#include <qimagereader.h>
#include <qiodevice.h>
#include <qrect.h>
#include <qsize.h>



// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QImageReader_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QImageReader >()))
        return -1;

    QImageReader* cptr = 0;
    int overloadId = -1;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);

    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);

    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QImageReader(): too many arguments");
        return -1;
    }

    if (!PyArg_ParseTuple(args, "|OO:QImageReader", &(pyargs[0]), &(pyargs[1])))
        return -1;

    // Overloaded function decisor
    // 0: QImageReader()
    // 1: QImageReader(QIODevice*,QByteArray)
    // 2: QImageReader(QString,QByteArray)
    if (numArgs == 0) {
        overloadId = 0; // QImageReader()
    } else if (Shiboken::Converter< ::QIODevice * >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 1; // QImageReader(QIODevice*,QByteArray)
        } else if (Shiboken::Converter< ::QByteArray >::isConvertible(pyargs[1])) {
            overloadId = 1; // QImageReader(QIODevice*,QByteArray)
        }
    } else if (Shiboken::Converter< QString >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 2; // QImageReader(QString,QByteArray)
        } else if (Shiboken::Converter< ::QByteArray >::isConvertible(pyargs[1])) {
            overloadId = 2; // QImageReader(QString,QByteArray)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QImageReader_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QImageReader()
            {

                if(!PyErr_Occurred()) {
                    // QImageReader()
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QImageReader();
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // QImageReader(QIODevice*,QByteArray)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "format");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "format";
                        else if (Shiboken::Converter< ::QByteArray >::isConvertible(value))
                            pyargs[1] = value;
                        else
                            goto Sbk_QImageReader_Init_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QImageReader(): got multiple values for keyword argument '%s'", errorArgName);
                        return -1;
                    }
                }
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QIODevice * cppArg0 = Shiboken::Converter<QIODevice * >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return -1;
                QByteArray cppArg1_tmp = QByteArray();
                QByteArray cppArg1 = pyargs[1] ? Shiboken::Converter<QByteArray >::toCpp(pyargs[1]) : cppArg1_tmp;

                if(!PyErr_Occurred()) {
                    // QImageReader(QIODevice*,QByteArray)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QImageReader(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 2: // QImageReader(QString,QByteArray)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "format");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "format";
                        else if (Shiboken::Converter< ::QByteArray >::isConvertible(value))
                            pyargs[1] = value;
                        else
                            goto Sbk_QImageReader_Init_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QImageReader(): got multiple values for keyword argument '%s'", errorArgName);
                        return -1;
                    }
                }
                QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return -1;
                QByteArray cppArg1_tmp = QByteArray();
                QByteArray cppArg1 = pyargs[1] ? Shiboken::Converter<QByteArray >::toCpp(pyargs[1]) : cppArg1_tmp;

                if(!PyErr_Occurred()) {
                    // QImageReader(QString,QByteArray)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QImageReader(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QImageReader >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QImageReader_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QImageReader_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtCore.QIODevice, PySide.QtCore.QByteArray = QByteArray()", "QString, PySide.QtCore.QByteArray = QByteArray()", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QImageReader", overloads);
        return -1;
}

static PyObject* Sbk_QImageReaderFunc_autoDetectImageFormat(PyObject* self)
{
    QImageReader* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QImageReader* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // autoDetectImageFormat()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QImageReader*>(cppSelf)->autoDetectImageFormat();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QImageReaderFunc_backgroundColor(PyObject* self)
{
    QImageReader* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QImageReader* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // backgroundColor()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QColor cppResult = const_cast<const QImageReader*>(cppSelf)->backgroundColor();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QColor >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QImageReaderFunc_canRead(PyObject* self)
{
    QImageReader* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QImageReader* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // canRead()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QImageReader*>(cppSelf)->canRead();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QImageReaderFunc_clipRect(PyObject* self)
{
    QImageReader* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QImageReader* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // clipRect()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QRect cppResult = const_cast<const QImageReader*>(cppSelf)->clipRect();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QRect >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QImageReaderFunc_currentImageNumber(PyObject* self)
{
    QImageReader* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QImageReader* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // currentImageNumber()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QImageReader*>(cppSelf)->currentImageNumber();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QImageReaderFunc_currentImageRect(PyObject* self)
{
    QImageReader* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QImageReader* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // currentImageRect()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QRect cppResult = const_cast<const QImageReader*>(cppSelf)->currentImageRect();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QRect >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QImageReaderFunc_decideFormatFromContent(PyObject* self)
{
    QImageReader* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QImageReader* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // decideFormatFromContent()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QImageReader*>(cppSelf)->decideFormatFromContent();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QImageReaderFunc_device(PyObject* self)
{
    QImageReader* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QImageReader* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // device()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QIODevice * cppResult = const_cast<const QImageReader*>(cppSelf)->device();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QIODevice * >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QImageReaderFunc_error(PyObject* self)
{
    QImageReader* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QImageReader* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // error()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QImageReader::ImageReaderError cppResult = const_cast<const QImageReader*>(cppSelf)->error();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QImageReader::ImageReaderError >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QImageReaderFunc_errorString(PyObject* self)
{
    QImageReader* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QImageReader* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // errorString()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = const_cast<const QImageReader*>(cppSelf)->errorString();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QImageReaderFunc_fileName(PyObject* self)
{
    QImageReader* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QImageReader* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // fileName()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = const_cast<const QImageReader*>(cppSelf)->fileName();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QImageReaderFunc_format(PyObject* self)
{
    QImageReader* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QImageReader* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // format()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QByteArray cppResult = const_cast<const QImageReader*>(cppSelf)->format();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QByteArray >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QImageReaderFunc_imageCount(PyObject* self)
{
    QImageReader* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QImageReader* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // imageCount()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QImageReader*>(cppSelf)->imageCount();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QImageReaderFunc_imageFormat(PyObject* self, PyObject* args)
{
    QImageReader* cppSelf = 0;
    if (self) {
        if (!Shiboken::Object::isValid(self))
            return 0;
        cppSelf = Shiboken::Converter< QImageReader* >::toCpp(self);
    }

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "imageFormat", 0, 1, &(pyargs[0])))
        return 0;


    // Overloaded function decisor
    // 0: imageFormat()const
    // 1: imageFormat(QIODevice*)
    // 2: imageFormat(QString)
    if (numArgs == 0) {
        overloadId = 0; // imageFormat()const
    } else if (numArgs == 1 && Shiboken::Converter< ::QIODevice * >::isConvertible(pyargs[0])) {
        overloadId = 1; // imageFormat(QIODevice*)
    } else if (numArgs == 1 && Shiboken::Converter< QString >::isConvertible(pyargs[0])) {
        overloadId = 2; // imageFormat(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QImageReaderFunc_imageFormat_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // imageFormat()const
            {

                if(!PyErr_Occurred()) {
                    // imageFormat()const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QImage::Format cppResult = const_cast<const QImageReader*>(cppSelf)->imageFormat();
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QImage::Format >::toPython(cppResult);
                }
                break;
            }
            case 1: // imageFormat(QIODevice*)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QIODevice * cppArg0 = Shiboken::Converter<QIODevice * >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // imageFormat(QIODevice*)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QByteArray cppResult = QImageReader::imageFormat(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QByteArray >::toPython(cppResult);
                }
                break;
            }
            case 2: // imageFormat(QString)
            {
                QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // imageFormat(QString)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QByteArray cppResult = QImageReader::imageFormat(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QByteArray >::toPython(cppResult);
                }
                break;
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QImageReaderFunc_imageFormat_TypeError:
        const char* overloads[] = {"", "PySide.QtCore.QIODevice", "QString", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QImageReader.imageFormat", overloads);
        return 0;
}

static PyObject* Sbk_QImageReaderFunc_jumpToImage(PyObject* self, PyObject* arg)
{
    QImageReader* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QImageReader* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: jumpToImage(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // jumpToImage(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QImageReaderFunc_jumpToImage_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // jumpToImage(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->jumpToImage(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QImageReaderFunc_jumpToImage_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QImageReader.jumpToImage", overloads);
        return 0;
}

static PyObject* Sbk_QImageReaderFunc_jumpToNextImage(PyObject* self)
{
    QImageReader* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QImageReader* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // jumpToNextImage()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->jumpToNextImage();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QImageReaderFunc_loopCount(PyObject* self)
{
    QImageReader* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QImageReader* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // loopCount()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QImageReader*>(cppSelf)->loopCount();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QImageReaderFunc_nextImageDelay(PyObject* self)
{
    QImageReader* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QImageReader* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // nextImageDelay()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QImageReader*>(cppSelf)->nextImageDelay();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QImageReaderFunc_quality(PyObject* self)
{
    QImageReader* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QImageReader* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // quality()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QImageReader*>(cppSelf)->quality();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QImageReaderFunc_read(PyObject* self)
{
    QImageReader* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QImageReader* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // read()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QImage cppResult = cppSelf->read();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QImage >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QImageReaderFunc_scaledClipRect(PyObject* self)
{
    QImageReader* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QImageReader* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // scaledClipRect()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QRect cppResult = const_cast<const QImageReader*>(cppSelf)->scaledClipRect();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QRect >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QImageReaderFunc_scaledSize(PyObject* self)
{
    QImageReader* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QImageReader* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // scaledSize()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QSize cppResult = const_cast<const QImageReader*>(cppSelf)->scaledSize();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QSize >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QImageReaderFunc_setAutoDetectImageFormat(PyObject* self, PyObject* arg)
{
    QImageReader* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QImageReader* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setAutoDetectImageFormat(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setAutoDetectImageFormat(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QImageReaderFunc_setAutoDetectImageFormat_TypeError;

    // Call function/method
    {
        {
            bool cppArg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setAutoDetectImageFormat(bool)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setAutoDetectImageFormat(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QImageReaderFunc_setAutoDetectImageFormat_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QImageReader.setAutoDetectImageFormat", overloads);
        return 0;
}

static PyObject* Sbk_QImageReaderFunc_setBackgroundColor(PyObject* self, PyObject* arg)
{
    QImageReader* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QImageReader* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setBackgroundColor(QColor)
    if (Shiboken::Converter< ::QColor >::isConvertible(arg)) {
        overloadId = 0; // setBackgroundColor(QColor)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QImageReaderFunc_setBackgroundColor_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QColor cppArg0 = Shiboken::Converter<QColor >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setBackgroundColor(QColor)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setBackgroundColor(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QImageReaderFunc_setBackgroundColor_TypeError:
        const char* overloads[] = {"PySide.QtGui.QColor", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QImageReader.setBackgroundColor", overloads);
        return 0;
}

static PyObject* Sbk_QImageReaderFunc_setClipRect(PyObject* self, PyObject* arg)
{
    QImageReader* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QImageReader* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setClipRect(QRect)
    if (Shiboken::Converter< ::QRect >::isConvertible(arg)) {
        overloadId = 0; // setClipRect(QRect)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QImageReaderFunc_setClipRect_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QRect cppArg0 = Shiboken::Converter<QRect >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setClipRect(QRect)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setClipRect(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QImageReaderFunc_setClipRect_TypeError:
        const char* overloads[] = {"PySide.QtCore.QRect", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QImageReader.setClipRect", overloads);
        return 0;
}

static PyObject* Sbk_QImageReaderFunc_setDecideFormatFromContent(PyObject* self, PyObject* arg)
{
    QImageReader* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QImageReader* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setDecideFormatFromContent(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setDecideFormatFromContent(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QImageReaderFunc_setDecideFormatFromContent_TypeError;

    // Call function/method
    {
        {
            bool cppArg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setDecideFormatFromContent(bool)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setDecideFormatFromContent(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QImageReaderFunc_setDecideFormatFromContent_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QImageReader.setDecideFormatFromContent", overloads);
        return 0;
}

static PyObject* Sbk_QImageReaderFunc_setDevice(PyObject* self, PyObject* arg)
{
    QImageReader* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QImageReader* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setDevice(QIODevice*)
    if (Shiboken::Converter< ::QIODevice * >::isConvertible(arg)) {
        overloadId = 0; // setDevice(QIODevice*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QImageReaderFunc_setDevice_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QIODevice * cppArg0 = Shiboken::Converter<QIODevice * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setDevice(QIODevice*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setDevice(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                Shiboken::Object::setParent(self, arg);
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QImageReaderFunc_setDevice_TypeError:
        const char* overloads[] = {"PySide.QtCore.QIODevice", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QImageReader.setDevice", overloads);
        return 0;
}

static PyObject* Sbk_QImageReaderFunc_setFileName(PyObject* self, PyObject* arg)
{
    QImageReader* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QImageReader* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setFileName(QString)
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // setFileName(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QImageReaderFunc_setFileName_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setFileName(QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setFileName(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QImageReaderFunc_setFileName_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QImageReader.setFileName", overloads);
        return 0;
}

static PyObject* Sbk_QImageReaderFunc_setFormat(PyObject* self, PyObject* arg)
{
    QImageReader* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QImageReader* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setFormat(QByteArray)
    if (Shiboken::Converter< ::QByteArray >::isConvertible(arg)) {
        overloadId = 0; // setFormat(QByteArray)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QImageReaderFunc_setFormat_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QByteArray cppArg0 = Shiboken::Converter<QByteArray >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setFormat(QByteArray)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setFormat(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QImageReaderFunc_setFormat_TypeError:
        const char* overloads[] = {"PySide.QtCore.QByteArray", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QImageReader.setFormat", overloads);
        return 0;
}

static PyObject* Sbk_QImageReaderFunc_setQuality(PyObject* self, PyObject* arg)
{
    QImageReader* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QImageReader* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setQuality(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setQuality(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QImageReaderFunc_setQuality_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setQuality(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setQuality(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QImageReaderFunc_setQuality_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QImageReader.setQuality", overloads);
        return 0;
}

static PyObject* Sbk_QImageReaderFunc_setScaledClipRect(PyObject* self, PyObject* arg)
{
    QImageReader* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QImageReader* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setScaledClipRect(QRect)
    if (Shiboken::Converter< ::QRect >::isConvertible(arg)) {
        overloadId = 0; // setScaledClipRect(QRect)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QImageReaderFunc_setScaledClipRect_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QRect cppArg0 = Shiboken::Converter<QRect >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setScaledClipRect(QRect)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setScaledClipRect(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QImageReaderFunc_setScaledClipRect_TypeError:
        const char* overloads[] = {"PySide.QtCore.QRect", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QImageReader.setScaledClipRect", overloads);
        return 0;
}

static PyObject* Sbk_QImageReaderFunc_setScaledSize(PyObject* self, PyObject* arg)
{
    QImageReader* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QImageReader* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setScaledSize(QSize)
    if (Shiboken::Converter< ::QSize >::isConvertible(arg)) {
        overloadId = 0; // setScaledSize(QSize)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QImageReaderFunc_setScaledSize_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QSize cppArg0 = Shiboken::Converter<QSize >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setScaledSize(QSize)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setScaledSize(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QImageReaderFunc_setScaledSize_TypeError:
        const char* overloads[] = {"PySide.QtCore.QSize", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QImageReader.setScaledSize", overloads);
        return 0;
}

static PyObject* Sbk_QImageReaderFunc_size(PyObject* self)
{
    QImageReader* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QImageReader* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // size()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QSize cppResult = const_cast<const QImageReader*>(cppSelf)->size();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QSize >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QImageReaderFunc_supportedImageFormats(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // supportedImageFormats()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QList<QByteArray > cppResult = QImageReader::supportedImageFormats();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QList<QByteArray > >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QImageReaderFunc_supportsAnimation(PyObject* self)
{
    QImageReader* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QImageReader* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // supportsAnimation()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QImageReader*>(cppSelf)->supportsAnimation();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QImageReaderFunc_supportsOption(PyObject* self, PyObject* arg)
{
    QImageReader* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QImageReader* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: supportsOption(QImageIOHandler::ImageOption)const
    if (Shiboken::Converter< ::QImageIOHandler::ImageOption >::isConvertible(arg)) {
        overloadId = 0; // supportsOption(QImageIOHandler::ImageOption)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QImageReaderFunc_supportsOption_TypeError;

    // Call function/method
    {
        {
            QImageIOHandler::ImageOption cppArg0 = Shiboken::Converter<QImageIOHandler::ImageOption >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // supportsOption(QImageIOHandler::ImageOption)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QImageReader*>(cppSelf)->supportsOption(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QImageReaderFunc_supportsOption_TypeError:
        const char* overloads[] = {"PySide.QtGui.QImageIOHandler.ImageOption", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QImageReader.supportsOption", overloads);
        return 0;
}

static PyObject* Sbk_QImageReaderFunc_text(PyObject* self, PyObject* arg)
{
    QImageReader* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QImageReader* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: text(QString)const
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // text(QString)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QImageReaderFunc_text_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // text(QString)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = const_cast<const QImageReader*>(cppSelf)->text(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QImageReaderFunc_text_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QImageReader.text", overloads);
        return 0;
}

static PyObject* Sbk_QImageReaderFunc_textKeys(PyObject* self)
{
    QImageReader* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QImageReader* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // textKeys()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QStringList cppResult = const_cast<const QImageReader*>(cppSelf)->textKeys();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QStringList >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef Sbk_QImageReaderMethod_imageFormat = {
    "imageFormat", (PyCFunction)Sbk_QImageReaderFunc_imageFormat, METH_VARARGS|METH_STATIC
};

static PyMethodDef Sbk_QImageReader_methods[] = {
    {"autoDetectImageFormat", (PyCFunction)Sbk_QImageReaderFunc_autoDetectImageFormat, METH_NOARGS},
    {"backgroundColor", (PyCFunction)Sbk_QImageReaderFunc_backgroundColor, METH_NOARGS},
    {"canRead", (PyCFunction)Sbk_QImageReaderFunc_canRead, METH_NOARGS},
    {"clipRect", (PyCFunction)Sbk_QImageReaderFunc_clipRect, METH_NOARGS},
    {"currentImageNumber", (PyCFunction)Sbk_QImageReaderFunc_currentImageNumber, METH_NOARGS},
    {"currentImageRect", (PyCFunction)Sbk_QImageReaderFunc_currentImageRect, METH_NOARGS},
    {"decideFormatFromContent", (PyCFunction)Sbk_QImageReaderFunc_decideFormatFromContent, METH_NOARGS},
    {"device", (PyCFunction)Sbk_QImageReaderFunc_device, METH_NOARGS},
    {"error", (PyCFunction)Sbk_QImageReaderFunc_error, METH_NOARGS},
    {"errorString", (PyCFunction)Sbk_QImageReaderFunc_errorString, METH_NOARGS},
    {"fileName", (PyCFunction)Sbk_QImageReaderFunc_fileName, METH_NOARGS},
    {"format", (PyCFunction)Sbk_QImageReaderFunc_format, METH_NOARGS},
    {"imageCount", (PyCFunction)Sbk_QImageReaderFunc_imageCount, METH_NOARGS},
    Sbk_QImageReaderMethod_imageFormat,
    {"jumpToImage", (PyCFunction)Sbk_QImageReaderFunc_jumpToImage, METH_O},
    {"jumpToNextImage", (PyCFunction)Sbk_QImageReaderFunc_jumpToNextImage, METH_NOARGS},
    {"loopCount", (PyCFunction)Sbk_QImageReaderFunc_loopCount, METH_NOARGS},
    {"nextImageDelay", (PyCFunction)Sbk_QImageReaderFunc_nextImageDelay, METH_NOARGS},
    {"quality", (PyCFunction)Sbk_QImageReaderFunc_quality, METH_NOARGS},
    {"read", (PyCFunction)Sbk_QImageReaderFunc_read, METH_NOARGS},
    {"scaledClipRect", (PyCFunction)Sbk_QImageReaderFunc_scaledClipRect, METH_NOARGS},
    {"scaledSize", (PyCFunction)Sbk_QImageReaderFunc_scaledSize, METH_NOARGS},
    {"setAutoDetectImageFormat", (PyCFunction)Sbk_QImageReaderFunc_setAutoDetectImageFormat, METH_O},
    {"setBackgroundColor", (PyCFunction)Sbk_QImageReaderFunc_setBackgroundColor, METH_O},
    {"setClipRect", (PyCFunction)Sbk_QImageReaderFunc_setClipRect, METH_O},
    {"setDecideFormatFromContent", (PyCFunction)Sbk_QImageReaderFunc_setDecideFormatFromContent, METH_O},
    {"setDevice", (PyCFunction)Sbk_QImageReaderFunc_setDevice, METH_O},
    {"setFileName", (PyCFunction)Sbk_QImageReaderFunc_setFileName, METH_O},
    {"setFormat", (PyCFunction)Sbk_QImageReaderFunc_setFormat, METH_O},
    {"setQuality", (PyCFunction)Sbk_QImageReaderFunc_setQuality, METH_O},
    {"setScaledClipRect", (PyCFunction)Sbk_QImageReaderFunc_setScaledClipRect, METH_O},
    {"setScaledSize", (PyCFunction)Sbk_QImageReaderFunc_setScaledSize, METH_O},
    {"size", (PyCFunction)Sbk_QImageReaderFunc_size, METH_NOARGS},
    {"supportedImageFormats", (PyCFunction)Sbk_QImageReaderFunc_supportedImageFormats, METH_NOARGS|METH_STATIC},
    {"supportsAnimation", (PyCFunction)Sbk_QImageReaderFunc_supportsAnimation, METH_NOARGS},
    {"supportsOption", (PyCFunction)Sbk_QImageReaderFunc_supportsOption, METH_O},
    {"text", (PyCFunction)Sbk_QImageReaderFunc_text, METH_O},
    {"textKeys", (PyCFunction)Sbk_QImageReaderFunc_textKeys, METH_NOARGS},

    {0} // Sentinel
};

static PyObject* Sbk_QImageReader_getattro(PyObject* self, PyObject* name)
{
    if (self) {
        if (reinterpret_cast<SbkObject*>(self)->ob_dict) {
            PyObject* meth = PyDict_GetItem(reinterpret_cast<SbkObject*>(self)->ob_dict, name);
            if (meth) {
                Py_INCREF(meth);
                return meth;
            }
        }
        const char* cname = PyString_AS_STRING(name);
        if (strcmp(cname, "imageFormat") == 0)
            return PyCFunction_NewEx(&Sbk_QImageReaderMethod_imageFormat, self, 0);
    }
    return PyObject_GenericGetAttr(self, name);
}

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QImageReader_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QImageReader",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         Sbk_QImageReader_getattro,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QImageReader_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&SbkObject_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QImageReader_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern


void init_QImageReader(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QIMAGEREADER_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QImageReader_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QImageReader_Type);
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QImageReader_Type, &Shiboken::callCppDestructor<QImageReader >);
    Py_INCREF((PyObject*)&Sbk_QImageReader_Type); //Incref due the 'PyModule_AddObject' steals the reference.
    if (PyType_Ready((PyTypeObject*)&Sbk_QImageReader_Type) < 0)
        return;

    Shiboken::ObjectType::setOriginalName(&Sbk_QImageReader_Type, "QImageReader*");
    PyModule_AddObject(module, "QImageReader",
        ((PyObject*)&Sbk_QImageReader_Type));

    // Initialize enums
    PyObject* enumItem;

    // init enum: ImageReaderError
    PyTypeObject* SbkPySide_QtGui_QImageReader_ImageReaderError = Shiboken::Enum::newType("PySide.QtGui.QImageReader.ImageReaderError");
    SbkPySide_QtGuiTypes[SBK_QIMAGEREADER_IMAGEREADERERROR_IDX] = SbkPySide_QtGui_QImageReader_ImageReaderError;
    if (PyType_Ready(SbkPySide_QtGui_QImageReader_ImageReaderError) < 0)
        return;
    PyDict_SetItemString(Sbk_QImageReader_Type.super.ht_type.tp_dict,
            "ImageReaderError",((PyObject*)SbkPySide_QtGui_QImageReader_ImageReaderError));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QImageReader_ImageReaderError,(long) QImageReader::UnknownError, "UnknownError");
    PyDict_SetItemString(Sbk_QImageReader_Type.super.ht_type.tp_dict,"UnknownError", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QImageReader_ImageReaderError->tp_dict,"UnknownError", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QImageReader_ImageReaderError,(long) QImageReader::FileNotFoundError, "FileNotFoundError");
    PyDict_SetItemString(Sbk_QImageReader_Type.super.ht_type.tp_dict,"FileNotFoundError", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QImageReader_ImageReaderError->tp_dict,"FileNotFoundError", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QImageReader_ImageReaderError,(long) QImageReader::DeviceError, "DeviceError");
    PyDict_SetItemString(Sbk_QImageReader_Type.super.ht_type.tp_dict,"DeviceError", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QImageReader_ImageReaderError->tp_dict,"DeviceError", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QImageReader_ImageReaderError,(long) QImageReader::UnsupportedFormatError, "UnsupportedFormatError");
    PyDict_SetItemString(Sbk_QImageReader_Type.super.ht_type.tp_dict,"UnsupportedFormatError", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QImageReader_ImageReaderError->tp_dict,"UnsupportedFormatError", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QImageReader_ImageReaderError,(long) QImageReader::InvalidDataError, "InvalidDataError");
    PyDict_SetItemString(Sbk_QImageReader_Type.super.ht_type.tp_dict,"InvalidDataError", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QImageReader_ImageReaderError->tp_dict,"InvalidDataError", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QImageReader::ImageReaderError");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::ImageReaderError");
    // end of enum ImageReaderError


    Shiboken::TypeResolver::createObjectTypeResolver<QImageReader >("QImageReader*");
    Shiboken::TypeResolver::createObjectTypeResolver<QImageReader >(typeid(QImageReader).name());
    qRegisterMetaType< ::QImageReader* >("QImageReader*");
    qRegisterMetaType< ::QImageReader::ImageReaderError >("QImageReader::ImageReaderError");
}

