/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtgui_python.h"

#include "qpainterpath_wrapper.h"
#include "qpainterpath_element_wrapper.h"

// Extra includes
#include <QList>
#include <QPainterPath>
#include <qdatastream.h>
#include <qfont.h>
#include <qmatrix.h>
#include <qpainterpath.h>
#include <qpoint.h>
#include <qpolygon.h>
#include <qrect.h>
#include <qregion.h>
#include <qtransform.h>



// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QPainterPath_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QPainterPath >()))
        return -1;

    QPainterPath* cptr = 0;
    int overloadId = -1;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QPainterPath", 0, 1, &(pyargs[0])))
        return -1;

    // Overloaded function decisor
    // 0: QPainterPath()
    // 1: QPainterPath(QPainterPath)
    // 2: QPainterPath(QPointF)
    if (numArgs == 0) {
        overloadId = 0; // QPainterPath()
    } else if (numArgs == 1 && Shiboken::Converter< ::QPointF >::isConvertible(pyargs[0])) {
        overloadId = 2; // QPainterPath(QPointF)
    } else if (numArgs == 1 && Shiboken::Converter< ::QPainterPath >::isConvertible(pyargs[0])) {
        overloadId = 1; // QPainterPath(QPainterPath)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPainterPath_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QPainterPath()
            {

                if(!PyErr_Occurred()) {
                    // QPainterPath()
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QPainterPath();
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // QPainterPath(QPainterPath)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QPainterPath cppArg0 = Shiboken::Converter<QPainterPath >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QPainterPath(QPainterPath)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QPainterPath(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 2: // QPainterPath(QPointF)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QPointF cppArg0 = Shiboken::Converter<QPointF >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QPainterPath(QPointF)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QPainterPath(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QPainterPath >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QPainterPath_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QPainterPath_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtGui.QPainterPath", "PySide.QtCore.QPointF", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPainterPath", overloads);
        return -1;
}

static PyObject* Sbk_QPainterPathFunc_addEllipse(PyObject* self, PyObject* args)
{
    QPainterPath* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPainterPath* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs == 2)
        goto Sbk_QPainterPathFunc_addEllipse_TypeError;

    if (!PyArg_UnpackTuple(args, "addEllipse", 1, 4, &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return 0;


    // Overloaded function decisor
    // 0: addEllipse(QPointF,qreal,qreal)
    // 1: addEllipse(QRectF)
    // 2: addEllipse(qreal,qreal,qreal,qreal)
    if (numArgs == 4 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2]) && SbkNumber_Check(pyargs[3])) {
        overloadId = 2; // addEllipse(qreal,qreal,qreal,qreal)
    } else if (numArgs == 1 && Shiboken::Converter< ::QRectF >::isConvertible(pyargs[0])) {
        overloadId = 1; // addEllipse(QRectF)
    } else if (numArgs == 3 && Shiboken::Converter< ::QPointF >::isConvertible(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
        overloadId = 0; // addEllipse(QPointF,qreal,qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPainterPathFunc_addEllipse_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // addEllipse(QPointF,qreal,qreal)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QPointF cppArg0 = Shiboken::Converter<QPointF >::toCpp(pyargs[0]);
                qreal cppArg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);
                qreal cppArg2 = Shiboken::Converter<qreal >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                    // addEllipse(QPointF,qreal,qreal)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->addEllipse(cppArg0, cppArg1, cppArg2);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // addEllipse(QRectF)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QRectF cppArg0 = Shiboken::Converter<QRectF >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // addEllipse(QRectF)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->addEllipse(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 2: // addEllipse(qreal,qreal,qreal,qreal)
            {
                qreal cppArg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
                qreal cppArg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);
                qreal cppArg2 = Shiboken::Converter<qreal >::toCpp(pyargs[2]);
                qreal cppArg3 = Shiboken::Converter<qreal >::toCpp(pyargs[3]);

                if(!PyErr_Occurred()) {
                    // addEllipse(qreal,qreal,qreal,qreal)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->addEllipse(cppArg0, cppArg1, cppArg2, cppArg3);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QPainterPathFunc_addEllipse_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPointF, float, float", "PySide.QtCore.QRectF", "float, float, float, float", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPainterPath.addEllipse", overloads);
        return 0;
}

static PyObject* Sbk_QPainterPathFunc_addPath(PyObject* self, PyObject* arg)
{
    QPainterPath* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPainterPath* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: addPath(QPainterPath)
    if (Shiboken::Converter< ::QPainterPath >::isConvertible(arg)) {
        overloadId = 0; // addPath(QPainterPath)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPainterPathFunc_addPath_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QPainterPath cppArg0 = Shiboken::Converter<QPainterPath >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // addPath(QPainterPath)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->addPath(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QPainterPathFunc_addPath_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPainterPath", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPainterPath.addPath", overloads);
        return 0;
}

static PyObject* Sbk_QPainterPathFunc_addPolygon(PyObject* self, PyObject* arg)
{
    QPainterPath* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPainterPath* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: addPolygon(QPolygonF)
    if (Shiboken::Converter< ::QPolygonF >::isConvertible(arg)) {
        overloadId = 0; // addPolygon(QPolygonF)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPainterPathFunc_addPolygon_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QPolygonF cppArg0 = Shiboken::Converter<QPolygonF >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // addPolygon(QPolygonF)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->addPolygon(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QPainterPathFunc_addPolygon_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPolygonF", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPainterPath.addPolygon", overloads);
        return 0;
}

static PyObject* Sbk_QPainterPathFunc_addRect(PyObject* self, PyObject* args)
{
    QPainterPath* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPainterPath* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs == 2 || numArgs == 3)
        goto Sbk_QPainterPathFunc_addRect_TypeError;

    if (!PyArg_UnpackTuple(args, "addRect", 1, 4, &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return 0;


    // Overloaded function decisor
    // 0: addRect(QRectF)
    // 1: addRect(qreal,qreal,qreal,qreal)
    if (numArgs == 4 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2]) && SbkNumber_Check(pyargs[3])) {
        overloadId = 1; // addRect(qreal,qreal,qreal,qreal)
    } else if (numArgs == 1 && Shiboken::Converter< ::QRectF >::isConvertible(pyargs[0])) {
        overloadId = 0; // addRect(QRectF)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPainterPathFunc_addRect_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // addRect(QRectF)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QRectF cppArg0 = Shiboken::Converter<QRectF >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // addRect(QRectF)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->addRect(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // addRect(qreal,qreal,qreal,qreal)
            {
                qreal cppArg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
                qreal cppArg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);
                qreal cppArg2 = Shiboken::Converter<qreal >::toCpp(pyargs[2]);
                qreal cppArg3 = Shiboken::Converter<qreal >::toCpp(pyargs[3]);

                if(!PyErr_Occurred()) {
                    // addRect(qreal,qreal,qreal,qreal)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->addRect(cppArg0, cppArg1, cppArg2, cppArg3);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QPainterPathFunc_addRect_TypeError:
        const char* overloads[] = {"PySide.QtCore.QRectF", "float, float, float, float", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPainterPath.addRect", overloads);
        return 0;
}

static PyObject* Sbk_QPainterPathFunc_addRegion(PyObject* self, PyObject* arg)
{
    QPainterPath* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPainterPath* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: addRegion(QRegion)
    if (Shiboken::Converter< ::QRegion >::isConvertible(arg)) {
        overloadId = 0; // addRegion(QRegion)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPainterPathFunc_addRegion_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QRegion cppArg0 = Shiboken::Converter<QRegion >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // addRegion(QRegion)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->addRegion(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QPainterPathFunc_addRegion_TypeError:
        const char* overloads[] = {"PySide.QtGui.QRegion", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPainterPath.addRegion", overloads);
        return 0;
}

static PyObject* Sbk_QPainterPathFunc_addRoundRect(PyObject* self, PyObject* args)
{
    QPainterPath* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPainterPath* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs == 4)
        goto Sbk_QPainterPathFunc_addRoundRect_TypeError;

    if (!PyArg_UnpackTuple(args, "addRoundRect", 2, 6, &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3]), &(pyargs[4]), &(pyargs[5])))
        return 0;


    // Overloaded function decisor
    // 0: addRoundRect(QRectF,int)
    // 1: addRoundRect(QRectF,int,int)
    // 2: addRoundRect(qreal,qreal,qreal,qreal,int)
    // 3: addRoundRect(qreal,qreal,qreal,qreal,int,int)
    if (numArgs >= 5 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2]) && SbkNumber_Check(pyargs[3]) && SbkNumber_Check(pyargs[4])) {
        if (numArgs == 5) {
            overloadId = 2; // addRoundRect(qreal,qreal,qreal,qreal,int)
        } else if (numArgs == 6 && SbkNumber_Check(pyargs[5])) {
            overloadId = 3; // addRoundRect(qreal,qreal,qreal,qreal,int,int)
        }
    } else if (numArgs >= 2 && Shiboken::Converter< ::QRectF >::isConvertible(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        if (numArgs == 2) {
            overloadId = 0; // addRoundRect(QRectF,int)
        } else if (numArgs == 3 && SbkNumber_Check(pyargs[2])) {
            overloadId = 1; // addRoundRect(QRectF,int,int)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPainterPathFunc_addRoundRect_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // addRoundRect(QRectF,int)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QRectF cppArg0 = Shiboken::Converter<QRectF >::toCpp(pyargs[0]);
                int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // addRoundRect(QRectF,int)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->addRoundRect(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // addRoundRect(QRectF,int,int)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QRectF cppArg0 = Shiboken::Converter<QRectF >::toCpp(pyargs[0]);
                int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                int cppArg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                    // addRoundRect(QRectF,int,int)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->addRoundRect(cppArg0, cppArg1, cppArg2);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 2: // addRoundRect(qreal,qreal,qreal,qreal,int)
            {
                qreal cppArg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
                qreal cppArg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);
                qreal cppArg2 = Shiboken::Converter<qreal >::toCpp(pyargs[2]);
                qreal cppArg3 = Shiboken::Converter<qreal >::toCpp(pyargs[3]);
                int cppArg4 = Shiboken::Converter<int >::toCpp(pyargs[4]);

                if(!PyErr_Occurred()) {
                    // addRoundRect(qreal,qreal,qreal,qreal,int)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->addRoundRect(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 3: // addRoundRect(qreal,qreal,qreal,qreal,int,int)
            {
                qreal cppArg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
                qreal cppArg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);
                qreal cppArg2 = Shiboken::Converter<qreal >::toCpp(pyargs[2]);
                qreal cppArg3 = Shiboken::Converter<qreal >::toCpp(pyargs[3]);
                int cppArg4 = Shiboken::Converter<int >::toCpp(pyargs[4]);
                int cppArg5 = Shiboken::Converter<int >::toCpp(pyargs[5]);

                if(!PyErr_Occurred()) {
                    // addRoundRect(qreal,qreal,qreal,qreal,int,int)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->addRoundRect(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QPainterPathFunc_addRoundRect_TypeError:
        const char* overloads[] = {"PySide.QtCore.QRectF, int", "PySide.QtCore.QRectF, int, int", "float, float, float, float, int", "float, float, float, float, int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPainterPath.addRoundRect", overloads);
        return 0;
}

static PyObject* Sbk_QPainterPathFunc_addRoundedRect(PyObject* self, PyObject* args, PyObject* kwds)
{
    QPainterPath* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPainterPath* >::toCpp(self);

    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 7) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QPainterPath.addRoundedRect(): too many arguments");
        return 0;
    } else if (numArgs < 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QPainterPath.addRoundedRect(): not enough arguments");
        return 0;
    } else if (numArgs == 5)
        goto Sbk_QPainterPathFunc_addRoundedRect_TypeError;

    if (!PyArg_ParseTuple(args, "|OOOOOOO:addRoundedRect", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3]), &(pyargs[4]), &(pyargs[5]), &(pyargs[6])))
        return 0;


    // Overloaded function decisor
    // 0: addRoundedRect(QRectF,qreal,qreal,Qt::SizeMode)
    // 1: addRoundedRect(qreal,qreal,qreal,qreal,qreal,qreal,Qt::SizeMode)
    if (numArgs >= 6 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2]) && SbkNumber_Check(pyargs[3]) && SbkNumber_Check(pyargs[4]) && SbkNumber_Check(pyargs[5])) {
        if (numArgs == 6) {
            overloadId = 1; // addRoundedRect(qreal,qreal,qreal,qreal,qreal,qreal,Qt::SizeMode)
        } else if (Shiboken::Converter< ::Qt::SizeMode >::isConvertible(pyargs[6])) {
            overloadId = 1; // addRoundedRect(qreal,qreal,qreal,qreal,qreal,qreal,Qt::SizeMode)
        }
    } else if (numArgs >= 3 && Shiboken::Converter< ::QRectF >::isConvertible(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
        if (numArgs == 3) {
            overloadId = 0; // addRoundedRect(QRectF,qreal,qreal,Qt::SizeMode)
        } else if (Shiboken::Converter< ::Qt::SizeMode >::isConvertible(pyargs[3])) {
            overloadId = 0; // addRoundedRect(QRectF,qreal,qreal,Qt::SizeMode)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPainterPathFunc_addRoundedRect_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // addRoundedRect(QRectF,qreal,qreal,Qt::SizeMode)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "mode");
                    if (value) {
                        if (pyargs[3])
                            errorArgName = "mode";
                        else if (Shiboken::Converter< ::Qt::SizeMode >::isConvertible(value))
                            pyargs[3] = value;
                        else
                            goto Sbk_QPainterPathFunc_addRoundedRect_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QPainterPath.addRoundedRect(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QRectF cppArg0 = Shiboken::Converter<QRectF >::toCpp(pyargs[0]);
                qreal cppArg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);
                qreal cppArg2 = Shiboken::Converter<qreal >::toCpp(pyargs[2]);
                Qt::SizeMode cppArg3 = pyargs[3] ? Shiboken::Converter<Qt::SizeMode >::toCpp(pyargs[3]) : Qt::AbsoluteSize;

                if(!PyErr_Occurred()) {
                    // addRoundedRect(QRectF,qreal,qreal,Qt::SizeMode)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->addRoundedRect(cppArg0, cppArg1, cppArg2, cppArg3);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // addRoundedRect(qreal,qreal,qreal,qreal,qreal,qreal,Qt::SizeMode)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "mode");
                    if (value) {
                        if (pyargs[6])
                            errorArgName = "mode";
                        else if (Shiboken::Converter< ::Qt::SizeMode >::isConvertible(value))
                            pyargs[6] = value;
                        else
                            goto Sbk_QPainterPathFunc_addRoundedRect_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QPainterPath.addRoundedRect(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                qreal cppArg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
                qreal cppArg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);
                qreal cppArg2 = Shiboken::Converter<qreal >::toCpp(pyargs[2]);
                qreal cppArg3 = Shiboken::Converter<qreal >::toCpp(pyargs[3]);
                qreal cppArg4 = Shiboken::Converter<qreal >::toCpp(pyargs[4]);
                qreal cppArg5 = Shiboken::Converter<qreal >::toCpp(pyargs[5]);
                Qt::SizeMode cppArg6 = pyargs[6] ? Shiboken::Converter<Qt::SizeMode >::toCpp(pyargs[6]) : Qt::AbsoluteSize;

                if(!PyErr_Occurred()) {
                    // addRoundedRect(qreal,qreal,qreal,qreal,qreal,qreal,Qt::SizeMode)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->addRoundedRect(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5, cppArg6);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QPainterPathFunc_addRoundedRect_TypeError:
        const char* overloads[] = {"PySide.QtCore.QRectF, float, float, PySide.QtCore.Qt.SizeMode = Qt.AbsoluteSize", "float, float, float, float, float, float, PySide.QtCore.Qt.SizeMode = Qt.AbsoluteSize", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPainterPath.addRoundedRect", overloads);
        return 0;
}

static PyObject* Sbk_QPainterPathFunc_addText(PyObject* self, PyObject* args)
{
    QPainterPath* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPainterPath* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "addText", 3, 4, &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return 0;


    // Overloaded function decisor
    // 0: addText(QPointF,QFont,QString)
    // 1: addText(qreal,qreal,QFont,QString)
    if (numArgs == 4 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && Shiboken::Converter< ::QFont >::isConvertible(pyargs[2]) && Shiboken::Converter< QString >::isConvertible(pyargs[3])) {
        overloadId = 1; // addText(qreal,qreal,QFont,QString)
    } else if (numArgs == 3 && Shiboken::Converter< ::QPointF >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QFont >::isConvertible(pyargs[1]) && Shiboken::Converter< QString >::isConvertible(pyargs[2])) {
        overloadId = 0; // addText(QPointF,QFont,QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPainterPathFunc_addText_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // addText(QPointF,QFont,QString)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QPointF cppArg0 = Shiboken::Converter<QPointF >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return 0;
                QFont cppArg1 = Shiboken::Converter<QFont >::toCpp(pyargs[1]);
                QString cppArg2 = Shiboken::Converter<QString >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                    // addText(QPointF,QFont,QString)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->addText(cppArg0, cppArg1, cppArg2);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // addText(qreal,qreal,QFont,QString)
            {
                qreal cppArg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
                qreal cppArg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);
                if (!Shiboken::Object::isValid(pyargs[2]))
                    return 0;
                QFont cppArg2 = Shiboken::Converter<QFont >::toCpp(pyargs[2]);
                QString cppArg3 = Shiboken::Converter<QString >::toCpp(pyargs[3]);

                if(!PyErr_Occurred()) {
                    // addText(qreal,qreal,QFont,QString)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->addText(cppArg0, cppArg1, cppArg2, cppArg3);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QPainterPathFunc_addText_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPointF, PySide.QtGui.QFont, QString", "float, float, PySide.QtGui.QFont, QString", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPainterPath.addText", overloads);
        return 0;
}

static PyObject* Sbk_QPainterPathFunc_angleAtPercent(PyObject* self, PyObject* arg)
{
    QPainterPath* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPainterPath* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: angleAtPercent(qreal)const
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // angleAtPercent(qreal)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPainterPathFunc_angleAtPercent_TypeError;

    // Call function/method
    {
        {
            qreal cppArg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // angleAtPercent(qreal)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                qreal cppResult = const_cast<const QPainterPath*>(cppSelf)->angleAtPercent(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< double >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QPainterPathFunc_angleAtPercent_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPainterPath.angleAtPercent", overloads);
        return 0;
}

static PyObject* Sbk_QPainterPathFunc_arcMoveTo(PyObject* self, PyObject* args)
{
    QPainterPath* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPainterPath* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs == 3 || numArgs == 4)
        goto Sbk_QPainterPathFunc_arcMoveTo_TypeError;

    if (!PyArg_UnpackTuple(args, "arcMoveTo", 2, 5, &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3]), &(pyargs[4])))
        return 0;


    // Overloaded function decisor
    // 0: arcMoveTo(QRectF,qreal)
    // 1: arcMoveTo(qreal,qreal,qreal,qreal,qreal)
    if (numArgs == 5 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2]) && SbkNumber_Check(pyargs[3]) && SbkNumber_Check(pyargs[4])) {
        overloadId = 1; // arcMoveTo(qreal,qreal,qreal,qreal,qreal)
    } else if (numArgs == 2 && Shiboken::Converter< ::QRectF >::isConvertible(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 0; // arcMoveTo(QRectF,qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPainterPathFunc_arcMoveTo_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // arcMoveTo(QRectF,qreal)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QRectF cppArg0 = Shiboken::Converter<QRectF >::toCpp(pyargs[0]);
                qreal cppArg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // arcMoveTo(QRectF,qreal)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->arcMoveTo(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // arcMoveTo(qreal,qreal,qreal,qreal,qreal)
            {
                qreal cppArg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
                qreal cppArg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);
                qreal cppArg2 = Shiboken::Converter<qreal >::toCpp(pyargs[2]);
                qreal cppArg3 = Shiboken::Converter<qreal >::toCpp(pyargs[3]);
                qreal cppArg4 = Shiboken::Converter<qreal >::toCpp(pyargs[4]);

                if(!PyErr_Occurred()) {
                    // arcMoveTo(qreal,qreal,qreal,qreal,qreal)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->arcMoveTo(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QPainterPathFunc_arcMoveTo_TypeError:
        const char* overloads[] = {"PySide.QtCore.QRectF, float", "float, float, float, float, float", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPainterPath.arcMoveTo", overloads);
        return 0;
}

static PyObject* Sbk_QPainterPathFunc_arcTo(PyObject* self, PyObject* args)
{
    QPainterPath* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPainterPath* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs == 4 || numArgs == 5)
        goto Sbk_QPainterPathFunc_arcTo_TypeError;

    if (!PyArg_UnpackTuple(args, "arcTo", 3, 6, &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3]), &(pyargs[4]), &(pyargs[5])))
        return 0;


    // Overloaded function decisor
    // 0: arcTo(QRectF,qreal,qreal)
    // 1: arcTo(qreal,qreal,qreal,qreal,qreal,qreal)
    if (numArgs == 6 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2]) && SbkNumber_Check(pyargs[3]) && SbkNumber_Check(pyargs[4]) && SbkNumber_Check(pyargs[5])) {
        overloadId = 1; // arcTo(qreal,qreal,qreal,qreal,qreal,qreal)
    } else if (numArgs == 3 && Shiboken::Converter< ::QRectF >::isConvertible(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
        overloadId = 0; // arcTo(QRectF,qreal,qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPainterPathFunc_arcTo_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // arcTo(QRectF,qreal,qreal)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QRectF cppArg0 = Shiboken::Converter<QRectF >::toCpp(pyargs[0]);
                qreal cppArg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);
                qreal cppArg2 = Shiboken::Converter<qreal >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                    // arcTo(QRectF,qreal,qreal)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->arcTo(cppArg0, cppArg1, cppArg2);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // arcTo(qreal,qreal,qreal,qreal,qreal,qreal)
            {
                qreal cppArg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
                qreal cppArg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);
                qreal cppArg2 = Shiboken::Converter<qreal >::toCpp(pyargs[2]);
                qreal cppArg3 = Shiboken::Converter<qreal >::toCpp(pyargs[3]);
                qreal cppArg4 = Shiboken::Converter<qreal >::toCpp(pyargs[4]);
                qreal cppArg5 = Shiboken::Converter<qreal >::toCpp(pyargs[5]);

                if(!PyErr_Occurred()) {
                    // arcTo(qreal,qreal,qreal,qreal,qreal,qreal)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->arcTo(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QPainterPathFunc_arcTo_TypeError:
        const char* overloads[] = {"PySide.QtCore.QRectF, float, float", "float, float, float, float, float, float", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPainterPath.arcTo", overloads);
        return 0;
}

static PyObject* Sbk_QPainterPathFunc_boundingRect(PyObject* self)
{
    QPainterPath* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPainterPath* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // boundingRect()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QRectF cppResult = const_cast<const QPainterPath*>(cppSelf)->boundingRect();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QRectF >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QPainterPathFunc_closeSubpath(PyObject* self)
{
    QPainterPath* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPainterPath* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // closeSubpath()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->closeSubpath();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QPainterPathFunc_connectPath(PyObject* self, PyObject* arg)
{
    QPainterPath* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPainterPath* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: connectPath(QPainterPath)
    if (Shiboken::Converter< ::QPainterPath >::isConvertible(arg)) {
        overloadId = 0; // connectPath(QPainterPath)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPainterPathFunc_connectPath_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QPainterPath cppArg0 = Shiboken::Converter<QPainterPath >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // connectPath(QPainterPath)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->connectPath(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QPainterPathFunc_connectPath_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPainterPath", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPainterPath.connectPath", overloads);
        return 0;
}

static PyObject* Sbk_QPainterPathFunc_contains(PyObject* self, PyObject* arg)
{
    QPainterPath* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPainterPath* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: contains(QPainterPath)const
    // 1: contains(QPointF)const
    // 2: contains(QRectF)const
    if (Shiboken::Converter< ::QRectF >::isConvertible(arg)) {
        overloadId = 2; // contains(QRectF)const
    } else if (Shiboken::Converter< ::QPointF >::isConvertible(arg)) {
        overloadId = 1; // contains(QPointF)const
    } else if (Shiboken::Converter< ::QPainterPath >::isConvertible(arg)) {
        overloadId = 0; // contains(QPainterPath)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPainterPathFunc_contains_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // contains(QPainterPath)const
            {
                if (!Shiboken::Object::isValid(arg))
                    return 0;
                QPainterPath cppArg0 = Shiboken::Converter<QPainterPath >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // contains(QPainterPath)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    bool cppResult = const_cast<const QPainterPath*>(cppSelf)->contains(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< bool >::toPython(cppResult);
                }
                break;
            }
            case 1: // contains(QPointF)const
            {
                if (!Shiboken::Object::isValid(arg))
                    return 0;
                QPointF cppArg0 = Shiboken::Converter<QPointF >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // contains(QPointF)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    bool cppResult = const_cast<const QPainterPath*>(cppSelf)->contains(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< bool >::toPython(cppResult);
                }
                break;
            }
            case 2: // contains(QRectF)const
            {
                if (!Shiboken::Object::isValid(arg))
                    return 0;
                QRectF cppArg0 = Shiboken::Converter<QRectF >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // contains(QRectF)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    bool cppResult = const_cast<const QPainterPath*>(cppSelf)->contains(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< bool >::toPython(cppResult);
                }
                break;
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QPainterPathFunc_contains_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPainterPath", "PySide.QtCore.QPointF", "PySide.QtCore.QRectF", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPainterPath.contains", overloads);
        return 0;
}

static PyObject* Sbk_QPainterPathFunc_controlPointRect(PyObject* self)
{
    QPainterPath* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPainterPath* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // controlPointRect()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QRectF cppResult = const_cast<const QPainterPath*>(cppSelf)->controlPointRect();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QRectF >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QPainterPathFunc_cubicTo(PyObject* self, PyObject* args)
{
    QPainterPath* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPainterPath* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs == 4 || numArgs == 5)
        goto Sbk_QPainterPathFunc_cubicTo_TypeError;

    if (!PyArg_UnpackTuple(args, "cubicTo", 3, 6, &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3]), &(pyargs[4]), &(pyargs[5])))
        return 0;


    // Overloaded function decisor
    // 0: cubicTo(QPointF,QPointF,QPointF)
    // 1: cubicTo(qreal,qreal,qreal,qreal,qreal,qreal)
    if (numArgs == 6 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2]) && SbkNumber_Check(pyargs[3]) && SbkNumber_Check(pyargs[4]) && SbkNumber_Check(pyargs[5])) {
        overloadId = 1; // cubicTo(qreal,qreal,qreal,qreal,qreal,qreal)
    } else if (numArgs == 3 && Shiboken::Converter< ::QPointF >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QPointF >::isConvertible(pyargs[1]) && Shiboken::Converter< ::QPointF >::isConvertible(pyargs[2])) {
        overloadId = 0; // cubicTo(QPointF,QPointF,QPointF)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPainterPathFunc_cubicTo_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // cubicTo(QPointF,QPointF,QPointF)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QPointF cppArg0 = Shiboken::Converter<QPointF >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return 0;
                QPointF cppArg1 = Shiboken::Converter<QPointF >::toCpp(pyargs[1]);
                if (!Shiboken::Object::isValid(pyargs[2]))
                    return 0;
                QPointF cppArg2 = Shiboken::Converter<QPointF >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                    // cubicTo(QPointF,QPointF,QPointF)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->cubicTo(cppArg0, cppArg1, cppArg2);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // cubicTo(qreal,qreal,qreal,qreal,qreal,qreal)
            {
                qreal cppArg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
                qreal cppArg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);
                qreal cppArg2 = Shiboken::Converter<qreal >::toCpp(pyargs[2]);
                qreal cppArg3 = Shiboken::Converter<qreal >::toCpp(pyargs[3]);
                qreal cppArg4 = Shiboken::Converter<qreal >::toCpp(pyargs[4]);
                qreal cppArg5 = Shiboken::Converter<qreal >::toCpp(pyargs[5]);

                if(!PyErr_Occurred()) {
                    // cubicTo(qreal,qreal,qreal,qreal,qreal,qreal)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->cubicTo(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QPainterPathFunc_cubicTo_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPointF, PySide.QtCore.QPointF, PySide.QtCore.QPointF", "float, float, float, float, float, float", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPainterPath.cubicTo", overloads);
        return 0;
}

static PyObject* Sbk_QPainterPathFunc_currentPosition(PyObject* self)
{
    QPainterPath* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPainterPath* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // currentPosition()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QPointF cppResult = const_cast<const QPainterPath*>(cppSelf)->currentPosition();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QPointF >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QPainterPathFunc_elementAt(PyObject* self, PyObject* arg)
{
    QPainterPath* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPainterPath* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: elementAt(int)const
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // elementAt(int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPainterPathFunc_elementAt_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // elementAt(int)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                const QPainterPath::Element & cppResult = const_cast<const QPainterPath*>(cppSelf)->elementAt(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QPainterPath::Element >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QPainterPathFunc_elementAt_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPainterPath.elementAt", overloads);
        return 0;
}

static PyObject* Sbk_QPainterPathFunc_elementCount(PyObject* self)
{
    QPainterPath* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPainterPath* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // elementCount()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QPainterPath*>(cppSelf)->elementCount();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QPainterPathFunc_fillRule(PyObject* self)
{
    QPainterPath* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPainterPath* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // fillRule()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                Qt::FillRule cppResult = const_cast<const QPainterPath*>(cppSelf)->fillRule();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::Qt::FillRule >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QPainterPathFunc_intersected(PyObject* self, PyObject* arg)
{
    QPainterPath* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPainterPath* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: intersected(QPainterPath)const
    if (Shiboken::Converter< ::QPainterPath >::isConvertible(arg)) {
        overloadId = 0; // intersected(QPainterPath)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPainterPathFunc_intersected_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QPainterPath cppArg0 = Shiboken::Converter<QPainterPath >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // intersected(QPainterPath)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QPainterPath cppResult = const_cast<const QPainterPath*>(cppSelf)->intersected(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QPainterPath >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QPainterPathFunc_intersected_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPainterPath", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPainterPath.intersected", overloads);
        return 0;
}

static PyObject* Sbk_QPainterPathFunc_intersects(PyObject* self, PyObject* arg)
{
    QPainterPath* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPainterPath* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: intersects(QPainterPath)const
    // 1: intersects(QRectF)const
    if (Shiboken::Converter< ::QRectF >::isConvertible(arg)) {
        overloadId = 1; // intersects(QRectF)const
    } else if (Shiboken::Converter< ::QPainterPath >::isConvertible(arg)) {
        overloadId = 0; // intersects(QPainterPath)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPainterPathFunc_intersects_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // intersects(QPainterPath)const
            {
                if (!Shiboken::Object::isValid(arg))
                    return 0;
                QPainterPath cppArg0 = Shiboken::Converter<QPainterPath >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // intersects(QPainterPath)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    bool cppResult = const_cast<const QPainterPath*>(cppSelf)->intersects(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< bool >::toPython(cppResult);
                }
                break;
            }
            case 1: // intersects(QRectF)const
            {
                if (!Shiboken::Object::isValid(arg))
                    return 0;
                QRectF cppArg0 = Shiboken::Converter<QRectF >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // intersects(QRectF)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    bool cppResult = const_cast<const QPainterPath*>(cppSelf)->intersects(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< bool >::toPython(cppResult);
                }
                break;
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QPainterPathFunc_intersects_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPainterPath", "PySide.QtCore.QRectF", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPainterPath.intersects", overloads);
        return 0;
}

static PyObject* Sbk_QPainterPathFunc_isEmpty(PyObject* self)
{
    QPainterPath* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPainterPath* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isEmpty()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QPainterPath*>(cppSelf)->isEmpty();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QPainterPathFunc_length(PyObject* self)
{
    QPainterPath* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPainterPath* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // length()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                qreal cppResult = const_cast<const QPainterPath*>(cppSelf)->length();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< double >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QPainterPathFunc_lineTo(PyObject* self, PyObject* args)
{
    QPainterPath* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPainterPath* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "lineTo", 1, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: lineTo(QPointF)
    // 1: lineTo(qreal,qreal)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 1; // lineTo(qreal,qreal)
    } else if (numArgs == 1 && Shiboken::Converter< ::QPointF >::isConvertible(pyargs[0])) {
        overloadId = 0; // lineTo(QPointF)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPainterPathFunc_lineTo_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // lineTo(QPointF)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QPointF cppArg0 = Shiboken::Converter<QPointF >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // lineTo(QPointF)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->lineTo(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // lineTo(qreal,qreal)
            {
                qreal cppArg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
                qreal cppArg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // lineTo(qreal,qreal)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->lineTo(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QPainterPathFunc_lineTo_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPointF", "float, float", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPainterPath.lineTo", overloads);
        return 0;
}

static PyObject* Sbk_QPainterPathFunc_moveTo(PyObject* self, PyObject* args)
{
    QPainterPath* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPainterPath* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "moveTo", 1, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: moveTo(QPointF)
    // 1: moveTo(qreal,qreal)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 1; // moveTo(qreal,qreal)
    } else if (numArgs == 1 && Shiboken::Converter< ::QPointF >::isConvertible(pyargs[0])) {
        overloadId = 0; // moveTo(QPointF)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPainterPathFunc_moveTo_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // moveTo(QPointF)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QPointF cppArg0 = Shiboken::Converter<QPointF >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // moveTo(QPointF)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->moveTo(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // moveTo(qreal,qreal)
            {
                qreal cppArg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
                qreal cppArg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // moveTo(qreal,qreal)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->moveTo(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QPainterPathFunc_moveTo_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPointF", "float, float", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPainterPath.moveTo", overloads);
        return 0;
}

static PyObject* Sbk_QPainterPathFunc_percentAtLength(PyObject* self, PyObject* arg)
{
    QPainterPath* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPainterPath* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: percentAtLength(qreal)const
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // percentAtLength(qreal)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPainterPathFunc_percentAtLength_TypeError;

    // Call function/method
    {
        {
            qreal cppArg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // percentAtLength(qreal)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                qreal cppResult = const_cast<const QPainterPath*>(cppSelf)->percentAtLength(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< double >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QPainterPathFunc_percentAtLength_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPainterPath.percentAtLength", overloads);
        return 0;
}

static PyObject* Sbk_QPainterPathFunc_pointAtPercent(PyObject* self, PyObject* arg)
{
    QPainterPath* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPainterPath* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: pointAtPercent(qreal)const
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // pointAtPercent(qreal)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPainterPathFunc_pointAtPercent_TypeError;

    // Call function/method
    {
        {
            qreal cppArg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // pointAtPercent(qreal)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QPointF cppResult = const_cast<const QPainterPath*>(cppSelf)->pointAtPercent(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QPointF >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QPainterPathFunc_pointAtPercent_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPainterPath.pointAtPercent", overloads);
        return 0;
}

static PyObject* Sbk_QPainterPathFunc_quadTo(PyObject* self, PyObject* args)
{
    QPainterPath* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPainterPath* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs == 3)
        goto Sbk_QPainterPathFunc_quadTo_TypeError;

    if (!PyArg_UnpackTuple(args, "quadTo", 2, 4, &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return 0;


    // Overloaded function decisor
    // 0: quadTo(QPointF,QPointF)
    // 1: quadTo(qreal,qreal,qreal,qreal)
    if (numArgs == 4 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2]) && SbkNumber_Check(pyargs[3])) {
        overloadId = 1; // quadTo(qreal,qreal,qreal,qreal)
    } else if (numArgs == 2 && Shiboken::Converter< ::QPointF >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QPointF >::isConvertible(pyargs[1])) {
        overloadId = 0; // quadTo(QPointF,QPointF)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPainterPathFunc_quadTo_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // quadTo(QPointF,QPointF)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QPointF cppArg0 = Shiboken::Converter<QPointF >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return 0;
                QPointF cppArg1 = Shiboken::Converter<QPointF >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // quadTo(QPointF,QPointF)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->quadTo(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // quadTo(qreal,qreal,qreal,qreal)
            {
                qreal cppArg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
                qreal cppArg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);
                qreal cppArg2 = Shiboken::Converter<qreal >::toCpp(pyargs[2]);
                qreal cppArg3 = Shiboken::Converter<qreal >::toCpp(pyargs[3]);

                if(!PyErr_Occurred()) {
                    // quadTo(qreal,qreal,qreal,qreal)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->quadTo(cppArg0, cppArg1, cppArg2, cppArg3);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QPainterPathFunc_quadTo_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPointF, PySide.QtCore.QPointF", "float, float, float, float", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPainterPath.quadTo", overloads);
        return 0;
}

static PyObject* Sbk_QPainterPathFunc_setElementPositionAt(PyObject* self, PyObject* args)
{
    QPainterPath* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPainterPath* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setElementPositionAt", 3, 3, &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: setElementPositionAt(int,qreal,qreal)
    if (numArgs == 3 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
        overloadId = 0; // setElementPositionAt(int,qreal,qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPainterPathFunc_setElementPositionAt_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            qreal cppArg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);
            qreal cppArg2 = Shiboken::Converter<qreal >::toCpp(pyargs[2]);

            if(!PyErr_Occurred()) {
                // setElementPositionAt(int,qreal,qreal)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setElementPositionAt(cppArg0, cppArg1, cppArg2);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QPainterPathFunc_setElementPositionAt_TypeError:
        const char* overloads[] = {"int, float, float", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPainterPath.setElementPositionAt", overloads);
        return 0;
}

static PyObject* Sbk_QPainterPathFunc_setFillRule(PyObject* self, PyObject* arg)
{
    QPainterPath* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPainterPath* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setFillRule(Qt::FillRule)
    if (Shiboken::Converter< ::Qt::FillRule >::isConvertible(arg)) {
        overloadId = 0; // setFillRule(Qt::FillRule)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPainterPathFunc_setFillRule_TypeError;

    // Call function/method
    {
        {
            Qt::FillRule cppArg0 = Shiboken::Converter<Qt::FillRule >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setFillRule(Qt::FillRule)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setFillRule(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QPainterPathFunc_setFillRule_TypeError:
        const char* overloads[] = {"PySide.QtCore.Qt.FillRule", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPainterPath.setFillRule", overloads);
        return 0;
}

static PyObject* Sbk_QPainterPathFunc_simplified(PyObject* self)
{
    QPainterPath* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPainterPath* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // simplified()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QPainterPath cppResult = const_cast<const QPainterPath*>(cppSelf)->simplified();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QPainterPath >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QPainterPathFunc_slopeAtPercent(PyObject* self, PyObject* arg)
{
    QPainterPath* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPainterPath* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: slopeAtPercent(qreal)const
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // slopeAtPercent(qreal)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPainterPathFunc_slopeAtPercent_TypeError;

    // Call function/method
    {
        {
            qreal cppArg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // slopeAtPercent(qreal)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                qreal cppResult = const_cast<const QPainterPath*>(cppSelf)->slopeAtPercent(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< double >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QPainterPathFunc_slopeAtPercent_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPainterPath.slopeAtPercent", overloads);
        return 0;
}

static PyObject* Sbk_QPainterPathFunc_subtracted(PyObject* self, PyObject* arg)
{
    QPainterPath* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPainterPath* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: subtracted(QPainterPath)const
    if (Shiboken::Converter< ::QPainterPath >::isConvertible(arg)) {
        overloadId = 0; // subtracted(QPainterPath)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPainterPathFunc_subtracted_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QPainterPath cppArg0 = Shiboken::Converter<QPainterPath >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // subtracted(QPainterPath)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QPainterPath cppResult = const_cast<const QPainterPath*>(cppSelf)->subtracted(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QPainterPath >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QPainterPathFunc_subtracted_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPainterPath", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPainterPath.subtracted", overloads);
        return 0;
}

static PyObject* Sbk_QPainterPathFunc_subtractedInverted(PyObject* self, PyObject* arg)
{
    QPainterPath* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPainterPath* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: subtractedInverted(QPainterPath)const
    if (Shiboken::Converter< ::QPainterPath >::isConvertible(arg)) {
        overloadId = 0; // subtractedInverted(QPainterPath)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPainterPathFunc_subtractedInverted_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QPainterPath cppArg0 = Shiboken::Converter<QPainterPath >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // subtractedInverted(QPainterPath)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QPainterPath cppResult = const_cast<const QPainterPath*>(cppSelf)->subtractedInverted(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QPainterPath >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QPainterPathFunc_subtractedInverted_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPainterPath", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPainterPath.subtractedInverted", overloads);
        return 0;
}

static PyObject* Sbk_QPainterPathFunc_toFillPolygon(PyObject* self, PyObject* args, PyObject* kwds)
{
    QPainterPath* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPainterPath* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QPainterPath.toFillPolygon(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:toFillPolygon", &(pyargs[0])))
        return 0;


    // Overloaded function decisor
    // 0: toFillPolygon(QMatrix)const
    // 1: toFillPolygon(QTransform)const
    if (numArgs == 0) {
        overloadId = 0; // toFillPolygon(QMatrix)const
    } else if (numArgs == 1 && Shiboken::Converter< ::QTransform >::isConvertible(pyargs[0])) {
        overloadId = 1; // toFillPolygon(QTransform)const
    } else if (Shiboken::Converter< ::QMatrix >::isConvertible(pyargs[0])) {
        overloadId = 0; // toFillPolygon(QMatrix)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPainterPathFunc_toFillPolygon_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // toFillPolygon(QMatrix)const
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "matrix");
                    if (value) {
                        if (pyargs[0])
                            errorArgName = "matrix";
                        else if (Shiboken::Converter< ::QMatrix >::isConvertible(value))
                            pyargs[0] = value;
                        else
                            goto Sbk_QPainterPathFunc_toFillPolygon_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QPainterPath.toFillPolygon(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QMatrix cppArg0_tmp = QMatrix();
                QMatrix cppArg0 = pyargs[0] ? Shiboken::Converter<QMatrix >::toCpp(pyargs[0]) : cppArg0_tmp;

                if(!PyErr_Occurred()) {
                    // toFillPolygon(QMatrix)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QPolygonF cppResult = const_cast<const QPainterPath*>(cppSelf)->toFillPolygon(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QPolygonF >::toPython(cppResult);
                }
                break;
            }
            case 1: // toFillPolygon(QTransform)const
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QTransform cppArg0 = Shiboken::Converter<QTransform >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // toFillPolygon(QTransform)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QPolygonF cppResult = const_cast<const QPainterPath*>(cppSelf)->toFillPolygon(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QPolygonF >::toPython(cppResult);
                }
                break;
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QPainterPathFunc_toFillPolygon_TypeError:
        const char* overloads[] = {"PySide.QtGui.QMatrix = QMatrix()", "PySide.QtGui.QTransform", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPainterPath.toFillPolygon", overloads);
        return 0;
}

static PyObject* Sbk_QPainterPathFunc_toFillPolygons(PyObject* self, PyObject* args, PyObject* kwds)
{
    QPainterPath* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPainterPath* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QPainterPath.toFillPolygons(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:toFillPolygons", &(pyargs[0])))
        return 0;


    // Overloaded function decisor
    // 0: toFillPolygons(QMatrix)const
    // 1: toFillPolygons(QTransform)const
    if (numArgs == 0) {
        overloadId = 0; // toFillPolygons(QMatrix)const
    } else if (numArgs == 1 && Shiboken::Converter< ::QTransform >::isConvertible(pyargs[0])) {
        overloadId = 1; // toFillPolygons(QTransform)const
    } else if (Shiboken::Converter< ::QMatrix >::isConvertible(pyargs[0])) {
        overloadId = 0; // toFillPolygons(QMatrix)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPainterPathFunc_toFillPolygons_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // toFillPolygons(QMatrix)const
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "matrix");
                    if (value) {
                        if (pyargs[0])
                            errorArgName = "matrix";
                        else if (Shiboken::Converter< ::QMatrix >::isConvertible(value))
                            pyargs[0] = value;
                        else
                            goto Sbk_QPainterPathFunc_toFillPolygons_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QPainterPath.toFillPolygons(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QMatrix cppArg0_tmp = QMatrix();
                QMatrix cppArg0 = pyargs[0] ? Shiboken::Converter<QMatrix >::toCpp(pyargs[0]) : cppArg0_tmp;

                if(!PyErr_Occurred()) {
                    // toFillPolygons(QMatrix)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QList<QPolygonF > cppResult = const_cast<const QPainterPath*>(cppSelf)->toFillPolygons(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QList<QPolygonF > >::toPython(cppResult);
                }
                break;
            }
            case 1: // toFillPolygons(QTransform)const
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QTransform cppArg0 = Shiboken::Converter<QTransform >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // toFillPolygons(QTransform)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QList<QPolygonF > cppResult = const_cast<const QPainterPath*>(cppSelf)->toFillPolygons(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QList<QPolygonF > >::toPython(cppResult);
                }
                break;
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QPainterPathFunc_toFillPolygons_TypeError:
        const char* overloads[] = {"PySide.QtGui.QMatrix = QMatrix()", "PySide.QtGui.QTransform", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPainterPath.toFillPolygons", overloads);
        return 0;
}

static PyObject* Sbk_QPainterPathFunc_toReversed(PyObject* self)
{
    QPainterPath* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPainterPath* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // toReversed()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QPainterPath cppResult = const_cast<const QPainterPath*>(cppSelf)->toReversed();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QPainterPath >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QPainterPathFunc_toSubpathPolygons(PyObject* self, PyObject* args, PyObject* kwds)
{
    QPainterPath* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPainterPath* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QPainterPath.toSubpathPolygons(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:toSubpathPolygons", &(pyargs[0])))
        return 0;


    // Overloaded function decisor
    // 0: toSubpathPolygons(QMatrix)const
    // 1: toSubpathPolygons(QTransform)const
    if (numArgs == 0) {
        overloadId = 0; // toSubpathPolygons(QMatrix)const
    } else if (numArgs == 1 && Shiboken::Converter< ::QTransform >::isConvertible(pyargs[0])) {
        overloadId = 1; // toSubpathPolygons(QTransform)const
    } else if (Shiboken::Converter< ::QMatrix >::isConvertible(pyargs[0])) {
        overloadId = 0; // toSubpathPolygons(QMatrix)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPainterPathFunc_toSubpathPolygons_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // toSubpathPolygons(QMatrix)const
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "matrix");
                    if (value) {
                        if (pyargs[0])
                            errorArgName = "matrix";
                        else if (Shiboken::Converter< ::QMatrix >::isConvertible(value))
                            pyargs[0] = value;
                        else
                            goto Sbk_QPainterPathFunc_toSubpathPolygons_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QPainterPath.toSubpathPolygons(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QMatrix cppArg0_tmp = QMatrix();
                QMatrix cppArg0 = pyargs[0] ? Shiboken::Converter<QMatrix >::toCpp(pyargs[0]) : cppArg0_tmp;

                if(!PyErr_Occurred()) {
                    // toSubpathPolygons(QMatrix)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QList<QPolygonF > cppResult = const_cast<const QPainterPath*>(cppSelf)->toSubpathPolygons(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QList<QPolygonF > >::toPython(cppResult);
                }
                break;
            }
            case 1: // toSubpathPolygons(QTransform)const
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QTransform cppArg0 = Shiboken::Converter<QTransform >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // toSubpathPolygons(QTransform)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QList<QPolygonF > cppResult = const_cast<const QPainterPath*>(cppSelf)->toSubpathPolygons(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QList<QPolygonF > >::toPython(cppResult);
                }
                break;
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QPainterPathFunc_toSubpathPolygons_TypeError:
        const char* overloads[] = {"PySide.QtGui.QMatrix = QMatrix()", "PySide.QtGui.QTransform", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPainterPath.toSubpathPolygons", overloads);
        return 0;
}

static PyObject* Sbk_QPainterPathFunc_translate(PyObject* self, PyObject* args)
{
    QPainterPath* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPainterPath* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "translate", 1, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: translate(QPointF)
    // 1: translate(qreal,qreal)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 1; // translate(qreal,qreal)
    } else if (numArgs == 1 && Shiboken::Converter< ::QPointF >::isConvertible(pyargs[0])) {
        overloadId = 0; // translate(QPointF)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPainterPathFunc_translate_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // translate(QPointF)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QPointF cppArg0 = Shiboken::Converter<QPointF >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // translate(QPointF)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->translate(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // translate(qreal,qreal)
            {
                qreal cppArg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
                qreal cppArg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // translate(qreal,qreal)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->translate(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QPainterPathFunc_translate_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPointF", "float, float", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPainterPath.translate", overloads);
        return 0;
}

static PyObject* Sbk_QPainterPathFunc_translated(PyObject* self, PyObject* args)
{
    QPainterPath* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPainterPath* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "translated", 1, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: translated(QPointF)const
    // 1: translated(qreal,qreal)const
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 1; // translated(qreal,qreal)const
    } else if (numArgs == 1 && Shiboken::Converter< ::QPointF >::isConvertible(pyargs[0])) {
        overloadId = 0; // translated(QPointF)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPainterPathFunc_translated_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // translated(QPointF)const
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QPointF cppArg0 = Shiboken::Converter<QPointF >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // translated(QPointF)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QPainterPath cppResult = const_cast<const QPainterPath*>(cppSelf)->translated(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QPainterPath >::toPython(cppResult);
                }
                break;
            }
            case 1: // translated(qreal,qreal)const
            {
                qreal cppArg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
                qreal cppArg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // translated(qreal,qreal)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QPainterPath cppResult = const_cast<const QPainterPath*>(cppSelf)->translated(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QPainterPath >::toPython(cppResult);
                }
                break;
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QPainterPathFunc_translated_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPointF", "float, float", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPainterPath.translated", overloads);
        return 0;
}

static PyObject* Sbk_QPainterPathFunc_united(PyObject* self, PyObject* arg)
{
    QPainterPath* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPainterPath* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: united(QPainterPath)const
    if (Shiboken::Converter< ::QPainterPath >::isConvertible(arg)) {
        overloadId = 0; // united(QPainterPath)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPainterPathFunc_united_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QPainterPath cppArg0 = Shiboken::Converter<QPainterPath >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // united(QPainterPath)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QPainterPath cppResult = const_cast<const QPainterPath*>(cppSelf)->united(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QPainterPath >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QPainterPathFunc_united_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPainterPath", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPainterPath.united", overloads);
        return 0;
}

static PyObject *Sbk_QPainterPath___copy__(PyObject *self)
{
        QPainterPath* cppSelf = 0;
        if (!Shiboken::Object::isValid(self))
            return 0;
        cppSelf = Shiboken::Converter<QPainterPath*>::toCpp(self);
        PyObject* pyResult = 0;
        QPainterPath* copy = new QPainterPath(*cppSelf);
        pyResult = Shiboken::Converter<QPainterPath*>::toPython(copy);
        Shiboken::Object::getOwnership(pyResult);

        if (PyErr_Occurred() || !pyResult) {
            Py_XDECREF(pyResult);
            return 0;
        }
        return pyResult;
}

static PyMethodDef Sbk_QPainterPath_methods[] = {
    {"addEllipse", (PyCFunction)Sbk_QPainterPathFunc_addEllipse, METH_VARARGS},
    {"addPath", (PyCFunction)Sbk_QPainterPathFunc_addPath, METH_O},
    {"addPolygon", (PyCFunction)Sbk_QPainterPathFunc_addPolygon, METH_O},
    {"addRect", (PyCFunction)Sbk_QPainterPathFunc_addRect, METH_VARARGS},
    {"addRegion", (PyCFunction)Sbk_QPainterPathFunc_addRegion, METH_O},
    {"addRoundRect", (PyCFunction)Sbk_QPainterPathFunc_addRoundRect, METH_VARARGS},
    {"addRoundedRect", (PyCFunction)Sbk_QPainterPathFunc_addRoundedRect, METH_VARARGS|METH_KEYWORDS},
    {"addText", (PyCFunction)Sbk_QPainterPathFunc_addText, METH_VARARGS},
    {"angleAtPercent", (PyCFunction)Sbk_QPainterPathFunc_angleAtPercent, METH_O},
    {"arcMoveTo", (PyCFunction)Sbk_QPainterPathFunc_arcMoveTo, METH_VARARGS},
    {"arcTo", (PyCFunction)Sbk_QPainterPathFunc_arcTo, METH_VARARGS},
    {"boundingRect", (PyCFunction)Sbk_QPainterPathFunc_boundingRect, METH_NOARGS},
    {"closeSubpath", (PyCFunction)Sbk_QPainterPathFunc_closeSubpath, METH_NOARGS},
    {"connectPath", (PyCFunction)Sbk_QPainterPathFunc_connectPath, METH_O},
    {"contains", (PyCFunction)Sbk_QPainterPathFunc_contains, METH_O},
    {"controlPointRect", (PyCFunction)Sbk_QPainterPathFunc_controlPointRect, METH_NOARGS},
    {"cubicTo", (PyCFunction)Sbk_QPainterPathFunc_cubicTo, METH_VARARGS},
    {"currentPosition", (PyCFunction)Sbk_QPainterPathFunc_currentPosition, METH_NOARGS},
    {"elementAt", (PyCFunction)Sbk_QPainterPathFunc_elementAt, METH_O},
    {"elementCount", (PyCFunction)Sbk_QPainterPathFunc_elementCount, METH_NOARGS},
    {"fillRule", (PyCFunction)Sbk_QPainterPathFunc_fillRule, METH_NOARGS},
    {"intersected", (PyCFunction)Sbk_QPainterPathFunc_intersected, METH_O},
    {"intersects", (PyCFunction)Sbk_QPainterPathFunc_intersects, METH_O},
    {"isEmpty", (PyCFunction)Sbk_QPainterPathFunc_isEmpty, METH_NOARGS},
    {"length", (PyCFunction)Sbk_QPainterPathFunc_length, METH_NOARGS},
    {"lineTo", (PyCFunction)Sbk_QPainterPathFunc_lineTo, METH_VARARGS},
    {"moveTo", (PyCFunction)Sbk_QPainterPathFunc_moveTo, METH_VARARGS},
    {"percentAtLength", (PyCFunction)Sbk_QPainterPathFunc_percentAtLength, METH_O},
    {"pointAtPercent", (PyCFunction)Sbk_QPainterPathFunc_pointAtPercent, METH_O},
    {"quadTo", (PyCFunction)Sbk_QPainterPathFunc_quadTo, METH_VARARGS},
    {"setElementPositionAt", (PyCFunction)Sbk_QPainterPathFunc_setElementPositionAt, METH_VARARGS},
    {"setFillRule", (PyCFunction)Sbk_QPainterPathFunc_setFillRule, METH_O},
    {"simplified", (PyCFunction)Sbk_QPainterPathFunc_simplified, METH_NOARGS},
    {"slopeAtPercent", (PyCFunction)Sbk_QPainterPathFunc_slopeAtPercent, METH_O},
    {"subtracted", (PyCFunction)Sbk_QPainterPathFunc_subtracted, METH_O},
    {"subtractedInverted", (PyCFunction)Sbk_QPainterPathFunc_subtractedInverted, METH_O},
    {"toFillPolygon", (PyCFunction)Sbk_QPainterPathFunc_toFillPolygon, METH_VARARGS|METH_KEYWORDS},
    {"toFillPolygons", (PyCFunction)Sbk_QPainterPathFunc_toFillPolygons, METH_VARARGS|METH_KEYWORDS},
    {"toReversed", (PyCFunction)Sbk_QPainterPathFunc_toReversed, METH_NOARGS},
    {"toSubpathPolygons", (PyCFunction)Sbk_QPainterPathFunc_toSubpathPolygons, METH_VARARGS|METH_KEYWORDS},
    {"translate", (PyCFunction)Sbk_QPainterPathFunc_translate, METH_VARARGS},
    {"translated", (PyCFunction)Sbk_QPainterPathFunc_translated, METH_VARARGS},
    {"united", (PyCFunction)Sbk_QPainterPathFunc_united, METH_O},

    {"__copy__", (PyCFunction)Sbk_QPainterPath___copy__, METH_NOARGS},
    {0} // Sentinel
};

static PyObject* Sbk_QPainterPathFunc___and__(PyObject* self, PyObject* arg)
{
    QPainterPath* cppSelf = 0;
    bool isReverse = Shiboken::Converter< ::QPainterPath >::checkType(arg) && !Shiboken::Converter< ::QPainterPath >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPainterPath* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && Shiboken::Object::checkType(arg)
        && !PyObject_TypeCheck(arg, self->ob_type)
        && PyObject_HasAttrString(arg, const_cast<char*>("__rand__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(arg, const_cast<char*>("__rand__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator&(QPainterPath)const
    if (!isReverse && Shiboken::Converter< ::QPainterPath >::isConvertible(arg)) {
        overloadId = 0; // operator&(QPainterPath)const
    }

    if (isReverse && overloadId == -1) {
        PyErr_SetString(PyExc_NotImplementedError, "reverse operator not implemented.");
        return 0;
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPainterPathFunc___and___TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QPainterPath cppArg0 = Shiboken::Converter<QPainterPath >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // operator&(QPainterPath)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QPainterPath cppResult = (*cppSelf) & (cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QPainterPath >::toPython(cppResult);
            }
        }
    }


    } // End of "if (!pyResult)"


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QPainterPathFunc___and___TypeError:
        const char* overloads[] = {"PySide.QtGui.QPainterPath", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPainterPath.__and__", overloads);
        return 0;
}

static PyObject* Sbk_QPainterPathFunc___iand__(PyObject* self, PyObject* arg)
{
    QPainterPath* cppSelf = 0;
    bool isReverse = Shiboken::Converter< ::QPainterPath >::checkType(arg) && !Shiboken::Converter< ::QPainterPath >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPainterPath* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: operator&=(QPainterPath)
    if (!isReverse && Shiboken::Converter< ::QPainterPath >::isConvertible(arg)) {
        overloadId = 0; // operator&=(QPainterPath)
    }

    if (isReverse && overloadId == -1) {
        PyErr_SetString(PyExc_NotImplementedError, "reverse operator not implemented.");
        return 0;
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPainterPathFunc___iand___TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QPainterPath cppArg0 = Shiboken::Converter<QPainterPath >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // operator&=(QPainterPath)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (*cppSelf) &= (cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_INCREF(self);
    return self;

    Sbk_QPainterPathFunc___iand___TypeError:
        const char* overloads[] = {"PySide.QtGui.QPainterPath", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPainterPath.__iand__", overloads);
        return 0;
}

static PyObject* Sbk_QPainterPathFunc___mul__(PyObject* self, PyObject* arg)
{
    QPainterPath* cppSelf = 0;
    bool isReverse = Shiboken::Converter< ::QPainterPath >::checkType(arg) && !Shiboken::Converter< ::QPainterPath >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPainterPath* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && Shiboken::Object::checkType(arg)
        && !PyObject_TypeCheck(arg, self->ob_type)
        && PyObject_HasAttrString(arg, const_cast<char*>("__rmul__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(arg, const_cast<char*>("__rmul__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator*(QPainterPath,QMatrix)
    // 1: operator*(QPainterPath,QTransform)
    if (!isReverse && Shiboken::Converter< ::QTransform >::isConvertible(arg)) {
        overloadId = 1; // operator*(QPainterPath,QTransform)
    } else if (!isReverse && Shiboken::Converter< ::QMatrix >::isConvertible(arg)) {
        overloadId = 0; // operator*(QPainterPath,QMatrix)
    }

    if (isReverse && overloadId == -1) {
        PyErr_SetString(PyExc_NotImplementedError, "reverse operator not implemented.");
        return 0;
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPainterPathFunc___mul___TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // operator*(QPainterPath,QMatrix)
            {
                if (!Shiboken::Object::isValid(arg))
                    return 0;
                QMatrix cppArg0 = Shiboken::Converter<QMatrix >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // operator*(QPainterPath,QMatrix)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QPainterPath cppResult = (*cppSelf) * (cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QPainterPath >::toPython(cppResult);
                }
                break;
            }
            case 1: // operator*(QPainterPath,QTransform)
            {
                if (!Shiboken::Object::isValid(arg))
                    return 0;
                QTransform cppArg0 = Shiboken::Converter<QTransform >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // operator*(QPainterPath,QTransform)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QPainterPath cppResult = (*cppSelf) * (cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QPainterPath >::toPython(cppResult);
                }
                break;
            }
        }
    }


    } // End of "if (!pyResult)"


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QPainterPathFunc___mul___TypeError:
        const char* overloads[] = {"PySide.QtGui.QMatrix", "PySide.QtGui.QTransform", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPainterPath.__mul__", overloads);
        return 0;
}

static PyObject* Sbk_QPainterPathFunc___add__(PyObject* self, PyObject* arg)
{
    QPainterPath* cppSelf = 0;
    bool isReverse = Shiboken::Converter< ::QPainterPath >::checkType(arg) && !Shiboken::Converter< ::QPainterPath >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPainterPath* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && Shiboken::Object::checkType(arg)
        && !PyObject_TypeCheck(arg, self->ob_type)
        && PyObject_HasAttrString(arg, const_cast<char*>("__radd__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(arg, const_cast<char*>("__radd__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator+(QPainterPath)const
    if (!isReverse && Shiboken::Converter< ::QPainterPath >::isConvertible(arg)) {
        overloadId = 0; // operator+(QPainterPath)const
    }

    if (isReverse && overloadId == -1) {
        PyErr_SetString(PyExc_NotImplementedError, "reverse operator not implemented.");
        return 0;
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPainterPathFunc___add___TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QPainterPath cppArg0 = Shiboken::Converter<QPainterPath >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // operator+(QPainterPath)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QPainterPath cppResult = (*cppSelf) + (cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QPainterPath >::toPython(cppResult);
            }
        }
    }


    } // End of "if (!pyResult)"


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QPainterPathFunc___add___TypeError:
        const char* overloads[] = {"PySide.QtGui.QPainterPath", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPainterPath.__add__", overloads);
        return 0;
}

static PyObject* Sbk_QPainterPathFunc___iadd__(PyObject* self, PyObject* arg)
{
    QPainterPath* cppSelf = 0;
    bool isReverse = Shiboken::Converter< ::QPainterPath >::checkType(arg) && !Shiboken::Converter< ::QPainterPath >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPainterPath* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: operator+=(QPainterPath)
    if (!isReverse && Shiboken::Converter< ::QPainterPath >::isConvertible(arg)) {
        overloadId = 0; // operator+=(QPainterPath)
    }

    if (isReverse && overloadId == -1) {
        PyErr_SetString(PyExc_NotImplementedError, "reverse operator not implemented.");
        return 0;
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPainterPathFunc___iadd___TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QPainterPath cppArg0 = Shiboken::Converter<QPainterPath >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // operator+=(QPainterPath)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (*cppSelf) += (cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_INCREF(self);
    return self;

    Sbk_QPainterPathFunc___iadd___TypeError:
        const char* overloads[] = {"PySide.QtGui.QPainterPath", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPainterPath.__iadd__", overloads);
        return 0;
}

static PyObject* Sbk_QPainterPathFunc___sub__(PyObject* self, PyObject* arg)
{
    QPainterPath* cppSelf = 0;
    bool isReverse = Shiboken::Converter< ::QPainterPath >::checkType(arg) && !Shiboken::Converter< ::QPainterPath >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPainterPath* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && Shiboken::Object::checkType(arg)
        && !PyObject_TypeCheck(arg, self->ob_type)
        && PyObject_HasAttrString(arg, const_cast<char*>("__rsub__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(arg, const_cast<char*>("__rsub__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator-(QPainterPath)const
    if (!isReverse && Shiboken::Converter< ::QPainterPath >::isConvertible(arg)) {
        overloadId = 0; // operator-(QPainterPath)const
    }

    if (isReverse && overloadId == -1) {
        PyErr_SetString(PyExc_NotImplementedError, "reverse operator not implemented.");
        return 0;
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPainterPathFunc___sub___TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QPainterPath cppArg0 = Shiboken::Converter<QPainterPath >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // operator-(QPainterPath)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QPainterPath cppResult = (*cppSelf) - (cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QPainterPath >::toPython(cppResult);
            }
        }
    }


    } // End of "if (!pyResult)"


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QPainterPathFunc___sub___TypeError:
        const char* overloads[] = {"PySide.QtGui.QPainterPath", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPainterPath.__sub__", overloads);
        return 0;
}

static PyObject* Sbk_QPainterPathFunc___isub__(PyObject* self, PyObject* arg)
{
    QPainterPath* cppSelf = 0;
    bool isReverse = Shiboken::Converter< ::QPainterPath >::checkType(arg) && !Shiboken::Converter< ::QPainterPath >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPainterPath* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: operator-=(QPainterPath)
    if (!isReverse && Shiboken::Converter< ::QPainterPath >::isConvertible(arg)) {
        overloadId = 0; // operator-=(QPainterPath)
    }

    if (isReverse && overloadId == -1) {
        PyErr_SetString(PyExc_NotImplementedError, "reverse operator not implemented.");
        return 0;
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPainterPathFunc___isub___TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QPainterPath cppArg0 = Shiboken::Converter<QPainterPath >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // operator-=(QPainterPath)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (*cppSelf) -= (cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_INCREF(self);
    return self;

    Sbk_QPainterPathFunc___isub___TypeError:
        const char* overloads[] = {"PySide.QtGui.QPainterPath", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPainterPath.__isub__", overloads);
        return 0;
}

static PyObject* Sbk_QPainterPathFunc___lshift__(PyObject* self, PyObject* arg)
{
    QPainterPath* cppSelf = 0;
    bool isReverse = Shiboken::Converter< ::QPainterPath >::checkType(arg) && !Shiboken::Converter< ::QPainterPath >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPainterPath* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && Shiboken::Object::checkType(arg)
        && !PyObject_TypeCheck(arg, self->ob_type)
        && PyObject_HasAttrString(arg, const_cast<char*>("__rlshift__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(arg, const_cast<char*>("__rlshift__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator<<(QDataStream&,QPainterPath)
    if (isReverse && Shiboken::Converter< ::QDataStream & >::isConvertible(arg)) {
        overloadId = 0; // operator<<(QDataStream&,QPainterPath)
    }

    if (isReverse && overloadId == -1) {
        PyErr_SetString(PyExc_NotImplementedError, "reverse operator not implemented.");
        return 0;
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPainterPathFunc___lshift___TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QDataStream & cppArg0 = Shiboken::Converter<QDataStream & >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // operator<<(QDataStream&,QPainterPath) [reverse operator]
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QDataStream & cppResult = (cppArg0) << (*cppSelf);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QDataStream & >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    } // End of "if (!pyResult)"


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QPainterPathFunc___lshift___TypeError:
        const char* overloads[] = {"PySide.QtCore.QDataStream", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPainterPath.__lshift__", overloads);
        return 0;
}

static PyObject* Sbk_QPainterPathFunc___rshift__(PyObject* self, PyObject* arg)
{
    QPainterPath* cppSelf = 0;
    bool isReverse = Shiboken::Converter< ::QPainterPath >::checkType(arg) && !Shiboken::Converter< ::QPainterPath >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPainterPath* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && Shiboken::Object::checkType(arg)
        && !PyObject_TypeCheck(arg, self->ob_type)
        && PyObject_HasAttrString(arg, const_cast<char*>("__rrshift__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(arg, const_cast<char*>("__rrshift__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator>>(QDataStream&,QPainterPath&)
    if (isReverse && Shiboken::Converter< ::QDataStream & >::isConvertible(arg)) {
        overloadId = 0; // operator>>(QDataStream&,QPainterPath&)
    }

    if (isReverse && overloadId == -1) {
        PyErr_SetString(PyExc_NotImplementedError, "reverse operator not implemented.");
        return 0;
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPainterPathFunc___rshift___TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QDataStream & cppArg0 = Shiboken::Converter<QDataStream & >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // operator>>(QDataStream&,QPainterPath&) [reverse operator]
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QDataStream & cppResult = (cppArg0) >> (*cppSelf);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QDataStream & >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    } // End of "if (!pyResult)"


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QPainterPathFunc___rshift___TypeError:
        const char* overloads[] = {"PySide.QtCore.QDataStream", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPainterPath.__rshift__", overloads);
        return 0;
}

static PyObject* Sbk_QPainterPathFunc___or__(PyObject* self, PyObject* arg)
{
    QPainterPath* cppSelf = 0;
    bool isReverse = Shiboken::Converter< ::QPainterPath >::checkType(arg) && !Shiboken::Converter< ::QPainterPath >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPainterPath* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && Shiboken::Object::checkType(arg)
        && !PyObject_TypeCheck(arg, self->ob_type)
        && PyObject_HasAttrString(arg, const_cast<char*>("__ror__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(arg, const_cast<char*>("__ror__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator|(QPainterPath)const
    if (!isReverse && Shiboken::Converter< ::QPainterPath >::isConvertible(arg)) {
        overloadId = 0; // operator|(QPainterPath)const
    }

    if (isReverse && overloadId == -1) {
        PyErr_SetString(PyExc_NotImplementedError, "reverse operator not implemented.");
        return 0;
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPainterPathFunc___or___TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QPainterPath cppArg0 = Shiboken::Converter<QPainterPath >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // operator|(QPainterPath)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QPainterPath cppResult = (*cppSelf) | (cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QPainterPath >::toPython(cppResult);
            }
        }
    }


    } // End of "if (!pyResult)"


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QPainterPathFunc___or___TypeError:
        const char* overloads[] = {"PySide.QtGui.QPainterPath", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPainterPath.__or__", overloads);
        return 0;
}

static PyObject* Sbk_QPainterPathFunc___ior__(PyObject* self, PyObject* arg)
{
    QPainterPath* cppSelf = 0;
    bool isReverse = Shiboken::Converter< ::QPainterPath >::checkType(arg) && !Shiboken::Converter< ::QPainterPath >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPainterPath* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: operator|=(QPainterPath)
    if (!isReverse && Shiboken::Converter< ::QPainterPath >::isConvertible(arg)) {
        overloadId = 0; // operator|=(QPainterPath)
    }

    if (isReverse && overloadId == -1) {
        PyErr_SetString(PyExc_NotImplementedError, "reverse operator not implemented.");
        return 0;
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPainterPathFunc___ior___TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QPainterPath cppArg0 = Shiboken::Converter<QPainterPath >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // operator|=(QPainterPath)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (*cppSelf) |= (cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_INCREF(self);
    return self;

    Sbk_QPainterPathFunc___ior___TypeError:
        const char* overloads[] = {"PySide.QtGui.QPainterPath", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPainterPath.__ior__", overloads);
        return 0;
}

// type has number operators
static PyNumberMethods Sbk_QPainterPath_as_number = {
    /*nb_add*/                  (binaryfunc)Sbk_QPainterPathFunc___add__,
    /*nb_subtract*/             (binaryfunc)Sbk_QPainterPathFunc___sub__,
    /*nb_multiply*/             (binaryfunc)Sbk_QPainterPathFunc___mul__,
    /*nb_divide*/               (binaryfunc)0,
    /*nb_remainder*/            (binaryfunc)0,
    /*nb_divmod*/               0,
    /*nb_power*/                0,
    /*nb_negative*/             (unaryfunc)0,
    /*nb_positive*/             (unaryfunc)0,
    /*nb_absolute*/             0,
    /*nb_nonzero*/              0,
    /*nb_invert*/               (unaryfunc)0,
    /*nb_lshift*/               (binaryfunc)Sbk_QPainterPathFunc___lshift__,
    /*nb_rshift*/               (binaryfunc)Sbk_QPainterPathFunc___rshift__,
    /*nb_and*/                  (binaryfunc)Sbk_QPainterPathFunc___and__,
    /*nb_xor*/                  (binaryfunc)0,
    /*nb_or*/                   (binaryfunc)Sbk_QPainterPathFunc___or__,
    /*nb_coerce*/               0,
    /*nb_int*/                  0,
    /*nb_long*/                 0,
    /*nb_float*/                0,
    /*nb_oct*/                  0,
    /*nb_hex*/                  0,
    /*nb_inplace_add*/          (binaryfunc)Sbk_QPainterPathFunc___iadd__,
    /*nb_inplace_subtract*/     (binaryfunc)Sbk_QPainterPathFunc___isub__,
    /*nb_inplace_multiply*/     (binaryfunc)0,
    /*nb_inplace_divide*/       (binaryfunc)0,
    /*nb_inplace_remainder*/    (binaryfunc)0,
    /*nb_inplace_power*/        0,
    /*nb_inplace_lshift*/       (binaryfunc)0,
    /*nb_inplace_rshift*/       (binaryfunc)0,
    /*nb_inplace_and*/          (binaryfunc)Sbk_QPainterPathFunc___iand__,
    /*nb_inplace_xor*/          (binaryfunc)0,
    /*nb_inplace_or*/           (binaryfunc)Sbk_QPainterPathFunc___ior__,
    /*nb_floor_divide*/         0,
    /*nb_true_divide*/          (binaryfunc)0,
    /*nb_inplace_floor_divide*/ 0,
    /*nb_inplace_true_divide*/  0,
    /*nb_index*/                0
};

// Rich comparison
static PyObject* Sbk_QPainterPath_richcompare(PyObject* self, PyObject* arg, int op)
{
    PyObject* pyResult = 0;
    QPainterPath& cppSelf = *Shiboken::Converter< QPainterPath* >::toCpp(self);

    switch (op) {
        case Py_NE:
            if (Shiboken::Converter< ::QPainterPath >::isConvertible(arg)) {
                // operator!=(const QPainterPath & other) const
                QPainterPath cppArg0 = Shiboken::Converter< ::QPainterPath >::toCpp(arg);
                pyResult = Shiboken::Converter< bool >::toPython(cppSelf != cppArg0);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_EQ:
            if (Shiboken::Converter< ::QPainterPath >::isConvertible(arg)) {
                // operator==(const QPainterPath & other) const
                QPainterPath cppArg0 = Shiboken::Converter< ::QPainterPath >::toCpp(arg);
                pyResult = Shiboken::Converter< bool >::toPython(cppSelf == cppArg0);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            goto Sbk_QPainterPath_RichComparison_TypeError;
    }

    if (pyResult && !PyErr_Occurred())
        return pyResult;
    Sbk_QPainterPath_RichComparison_TypeError:
    PyErr_SetString(PyExc_NotImplementedError, "operator not implemented.");
    return 0;

}

} // extern "C"

extern "C"
{
static PyObject* Sbk_QPainterPath__repr__(PyObject* pyObj)
{
    QBuffer buffer;
    buffer.open(QBuffer::ReadWrite);
    QDebug dbg(&buffer);
    dbg << Shiboken::Converter< ::QPainterPath >::toCpp(pyObj);
    buffer.close();
    return PyString_FromFormat("<PySide.QtGui.%s at %p>", buffer.data().constData(), pyObj);
}
} // extern C

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QPainterPath_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QPainterPath",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Sbk_QPainterPath__repr__,
    /*tp_as_number*/        &Sbk_QPainterPath_as_number,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      Sbk_QPainterPath_richcompare,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QPainterPath_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&SbkObject_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QPainterPath_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern


void init_QPainterPath(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QPAINTERPATH_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QPainterPath_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QPainterPath_Type);
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QPainterPath_Type, &Shiboken::callCppDestructor<QPainterPath >);
    Py_INCREF((PyObject*)&Sbk_QPainterPath_Type); //Incref due the 'PyModule_AddObject' steals the reference.
    if (PyType_Ready((PyTypeObject*)&Sbk_QPainterPath_Type) < 0)
        return;

    Shiboken::ObjectType::setOriginalName(&Sbk_QPainterPath_Type, "QPainterPath");
    PyModule_AddObject(module, "QPainterPath",
        ((PyObject*)&Sbk_QPainterPath_Type));

    // Initialize enums
    PyObject* enumItem;

    // init enum: ElementType
    PyTypeObject* SbkPySide_QtGui_QPainterPath_ElementType = Shiboken::Enum::newType("PySide.QtGui.QPainterPath.ElementType");
    SbkPySide_QtGuiTypes[SBK_QPAINTERPATH_ELEMENTTYPE_IDX] = SbkPySide_QtGui_QPainterPath_ElementType;
    if (PyType_Ready(SbkPySide_QtGui_QPainterPath_ElementType) < 0)
        return;
    PyDict_SetItemString(Sbk_QPainterPath_Type.super.ht_type.tp_dict,
            "ElementType",((PyObject*)SbkPySide_QtGui_QPainterPath_ElementType));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPainterPath_ElementType,(long) QPainterPath::MoveToElement, "MoveToElement");
    PyDict_SetItemString(Sbk_QPainterPath_Type.super.ht_type.tp_dict,"MoveToElement", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPainterPath_ElementType->tp_dict,"MoveToElement", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPainterPath_ElementType,(long) QPainterPath::LineToElement, "LineToElement");
    PyDict_SetItemString(Sbk_QPainterPath_Type.super.ht_type.tp_dict,"LineToElement", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPainterPath_ElementType->tp_dict,"LineToElement", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPainterPath_ElementType,(long) QPainterPath::CurveToElement, "CurveToElement");
    PyDict_SetItemString(Sbk_QPainterPath_Type.super.ht_type.tp_dict,"CurveToElement", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPainterPath_ElementType->tp_dict,"CurveToElement", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPainterPath_ElementType,(long) QPainterPath::CurveToDataElement, "CurveToDataElement");
    PyDict_SetItemString(Sbk_QPainterPath_Type.super.ht_type.tp_dict,"CurveToDataElement", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPainterPath_ElementType->tp_dict,"CurveToDataElement", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QPainterPath::ElementType");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::ElementType");
    // end of enum ElementType


    Shiboken::TypeResolver::createValueTypeResolver<QPainterPath >("QPainterPath");
    Shiboken::TypeResolver::createObjectTypeResolver<QPainterPath >("QPainterPath*");
    Shiboken::TypeResolver::createValueTypeResolver<QPainterPath >(typeid(QPainterPath).name());
    qRegisterMetaType< ::QPainterPath >("QPainterPath");
    qRegisterMetaType< ::QPainterPath::ElementType >("QPainterPath::ElementType");
}

