/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include "pyside_qtgui_python.h"

#include "qpinchgesture_wrapper.h"

// Extra includes
#include <QList>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qpoint.h>
#include <qthread.h>


// Native ---------------------------------------------------------

QPinchGestureWrapper::QPinchGestureWrapper(QObject * parent) : QPinchGesture(parent) {
    // ... middle
}

void QPinchGestureWrapper::childEvent(QChildEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "childEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::childEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QChildEvent * >::toPython(arg__1)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QPinchGestureWrapper::connectNotify(const char * signal)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "connectNotify"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::connectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QPinchGestureWrapper::customEvent(QEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "customEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::customEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QEvent * >::toPython(arg__1)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QPinchGestureWrapper::disconnectNotify(const char * signal)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "disconnectNotify"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::disconnectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

bool QPinchGestureWrapper::event(QEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return bool(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "event"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::event(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QEvent * >::toPython(arg__1)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QPinchGesture.event", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
    return cppResult;
}

bool QPinchGestureWrapper::eventFilter(QObject * arg__1, QEvent * arg__2)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return bool(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "eventFilter"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::eventFilter(arg__1, arg__2);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter< ::QObject * >::toPython(arg__1),
        Shiboken::Converter< ::QEvent * >::toPython(arg__2)
    ));
    bool invalidadeArg2 = PyTuple_GET_ITEM(pyargs, 1)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QPinchGesture.eventFilter", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    if (invalidadeArg2)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 1));
    return cppResult;
}

void QPinchGestureWrapper::timerEvent(QTimerEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "timerEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::timerEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QTimerEvent * >::toPython(arg__1)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

const QMetaObject* QPinchGestureWrapper::metaObject() const
{
    SbkObject* pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    return reinterpret_cast<QMetaObject*>(Shiboken::Object::getTypeUserData(pySelf));
}

int QPinchGestureWrapper::qt_metacall(QMetaObject::Call call, int id, void** args)
{
    int result = QPinchGesture::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

QPinchGestureWrapper::~QPinchGestureWrapper()
{
    SbkObject* wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QPinchGesture_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QPinchGesture >()))
        return -1;

    QPinchGestureWrapper* cptr = 0;
    int overloadId = -1;
    const char* argNames[] = {"parent"};
    const QMetaObject* metaObject;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths


    if (!PyArg_ParseTuple(args, "|O:QPinchGesture", &(pyargs[0])))
        return -1;

    // Overloaded function decisor
    // 0: QPinchGesture(QObject*)
    if (numArgs == 0) {
        overloadId = 0; // QPinchGesture(QObject*)
    } else if (Shiboken::Converter< ::QObject * >::isConvertible(pyargs[0])) {
        overloadId = 0; // QPinchGesture(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPinchGesture_Init_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "parent");
                if (value) {
                    if (pyargs[0])
                        errorArgName = "parent";
                    else if (Shiboken::Converter< ::QObject * >::isConvertible(value))
                        pyargs[0] = value;
                    else
                        goto Sbk_QPinchGesture_Init_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QPinchGesture(): got multiple values for keyword argument '%s'", errorArgName);
                    return -1;
                }
            }
            if (!Shiboken::Object::isValid(pyargs[0]))
                return -1;
            QObject * cppArg0 = pyargs[0] ? Shiboken::Converter<QObject * >::toCpp(pyargs[0]) : 0;

            if(!PyErr_Occurred()) {
                // QPinchGesture(QObject*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new QPinchGestureWrapper(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                Shiboken::Object::setParent(pyargs[0], self);
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QPinchGesture >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QPinchGesture_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    metaObject = cptr->metaObject(); // <- init python qt properties
    if (kwds && !PySide::fillQtProperties(self, metaObject, kwds, argNames, 1))
        return -1;


    return 1;

    Sbk_QPinchGesture_Init_TypeError:
        const char* overloads[] = {"PySide.QtCore.QObject = None", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPinchGesture", overloads);
        return -1;
}

static PyObject* Sbk_QPinchGestureFunc_centerPoint(PyObject* self)
{
    QPinchGesture* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPinchGesture* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // centerPoint()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QPointF cppResult = const_cast<const QPinchGesture*>(cppSelf)->centerPoint();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QPointF >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QPinchGestureFunc_changeFlags(PyObject* self)
{
    QPinchGesture* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPinchGesture* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // changeFlags()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QFlags<QPinchGesture::ChangeFlag> cppResult = const_cast<const QPinchGesture*>(cppSelf)->changeFlags();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QFlags<QPinchGesture::ChangeFlag> >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QPinchGestureFunc_lastCenterPoint(PyObject* self)
{
    QPinchGesture* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPinchGesture* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // lastCenterPoint()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QPointF cppResult = const_cast<const QPinchGesture*>(cppSelf)->lastCenterPoint();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QPointF >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QPinchGestureFunc_lastRotationAngle(PyObject* self)
{
    QPinchGesture* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPinchGesture* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // lastRotationAngle()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                qreal cppResult = const_cast<const QPinchGesture*>(cppSelf)->lastRotationAngle();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< double >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QPinchGestureFunc_lastScaleFactor(PyObject* self)
{
    QPinchGesture* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPinchGesture* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // lastScaleFactor()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                qreal cppResult = const_cast<const QPinchGesture*>(cppSelf)->lastScaleFactor();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< double >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QPinchGestureFunc_rotationAngle(PyObject* self)
{
    QPinchGesture* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPinchGesture* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // rotationAngle()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                qreal cppResult = const_cast<const QPinchGesture*>(cppSelf)->rotationAngle();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< double >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QPinchGestureFunc_scaleFactor(PyObject* self)
{
    QPinchGesture* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPinchGesture* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // scaleFactor()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                qreal cppResult = const_cast<const QPinchGesture*>(cppSelf)->scaleFactor();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< double >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QPinchGestureFunc_setCenterPoint(PyObject* self, PyObject* arg)
{
    QPinchGesture* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPinchGesture* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setCenterPoint(QPointF)
    if (Shiboken::Converter< ::QPointF >::isConvertible(arg)) {
        overloadId = 0; // setCenterPoint(QPointF)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPinchGestureFunc_setCenterPoint_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QPointF cppArg0 = Shiboken::Converter<QPointF >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setCenterPoint(QPointF)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setCenterPoint(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QPinchGestureFunc_setCenterPoint_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPointF", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPinchGesture.setCenterPoint", overloads);
        return 0;
}

static PyObject* Sbk_QPinchGestureFunc_setChangeFlags(PyObject* self, PyObject* arg)
{
    QPinchGesture* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPinchGesture* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setChangeFlags(QFlags<QPinchGesture::ChangeFlag>)
    if (Shiboken::Converter< ::QFlags<QPinchGesture::ChangeFlag> >::isConvertible(arg)) {
        overloadId = 0; // setChangeFlags(QFlags<QPinchGesture::ChangeFlag>)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPinchGestureFunc_setChangeFlags_TypeError;

    // Call function/method
    {
        {
            QFlags<QPinchGesture::ChangeFlag> cppArg0 = Shiboken::Converter<QFlags<QPinchGesture::ChangeFlag> >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setChangeFlags(QFlags<QPinchGesture::ChangeFlag>)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setChangeFlags(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QPinchGestureFunc_setChangeFlags_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPinchGesture.ChangeFlags", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPinchGesture.setChangeFlags", overloads);
        return 0;
}

static PyObject* Sbk_QPinchGestureFunc_setLastCenterPoint(PyObject* self, PyObject* arg)
{
    QPinchGesture* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPinchGesture* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setLastCenterPoint(QPointF)
    if (Shiboken::Converter< ::QPointF >::isConvertible(arg)) {
        overloadId = 0; // setLastCenterPoint(QPointF)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPinchGestureFunc_setLastCenterPoint_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QPointF cppArg0 = Shiboken::Converter<QPointF >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setLastCenterPoint(QPointF)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setLastCenterPoint(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QPinchGestureFunc_setLastCenterPoint_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPointF", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPinchGesture.setLastCenterPoint", overloads);
        return 0;
}

static PyObject* Sbk_QPinchGestureFunc_setLastRotationAngle(PyObject* self, PyObject* arg)
{
    QPinchGesture* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPinchGesture* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setLastRotationAngle(qreal)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setLastRotationAngle(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPinchGestureFunc_setLastRotationAngle_TypeError;

    // Call function/method
    {
        {
            qreal cppArg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setLastRotationAngle(qreal)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setLastRotationAngle(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QPinchGestureFunc_setLastRotationAngle_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPinchGesture.setLastRotationAngle", overloads);
        return 0;
}

static PyObject* Sbk_QPinchGestureFunc_setLastScaleFactor(PyObject* self, PyObject* arg)
{
    QPinchGesture* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPinchGesture* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setLastScaleFactor(qreal)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setLastScaleFactor(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPinchGestureFunc_setLastScaleFactor_TypeError;

    // Call function/method
    {
        {
            qreal cppArg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setLastScaleFactor(qreal)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setLastScaleFactor(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QPinchGestureFunc_setLastScaleFactor_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPinchGesture.setLastScaleFactor", overloads);
        return 0;
}

static PyObject* Sbk_QPinchGestureFunc_setRotationAngle(PyObject* self, PyObject* arg)
{
    QPinchGesture* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPinchGesture* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setRotationAngle(qreal)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setRotationAngle(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPinchGestureFunc_setRotationAngle_TypeError;

    // Call function/method
    {
        {
            qreal cppArg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setRotationAngle(qreal)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setRotationAngle(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QPinchGestureFunc_setRotationAngle_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPinchGesture.setRotationAngle", overloads);
        return 0;
}

static PyObject* Sbk_QPinchGestureFunc_setScaleFactor(PyObject* self, PyObject* arg)
{
    QPinchGesture* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPinchGesture* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setScaleFactor(qreal)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setScaleFactor(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPinchGestureFunc_setScaleFactor_TypeError;

    // Call function/method
    {
        {
            qreal cppArg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setScaleFactor(qreal)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setScaleFactor(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QPinchGestureFunc_setScaleFactor_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPinchGesture.setScaleFactor", overloads);
        return 0;
}

static PyObject* Sbk_QPinchGestureFunc_setStartCenterPoint(PyObject* self, PyObject* arg)
{
    QPinchGesture* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPinchGesture* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setStartCenterPoint(QPointF)
    if (Shiboken::Converter< ::QPointF >::isConvertible(arg)) {
        overloadId = 0; // setStartCenterPoint(QPointF)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPinchGestureFunc_setStartCenterPoint_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QPointF cppArg0 = Shiboken::Converter<QPointF >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setStartCenterPoint(QPointF)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setStartCenterPoint(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QPinchGestureFunc_setStartCenterPoint_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPointF", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPinchGesture.setStartCenterPoint", overloads);
        return 0;
}

static PyObject* Sbk_QPinchGestureFunc_setTotalChangeFlags(PyObject* self, PyObject* arg)
{
    QPinchGesture* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPinchGesture* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setTotalChangeFlags(QFlags<QPinchGesture::ChangeFlag>)
    if (Shiboken::Converter< ::QFlags<QPinchGesture::ChangeFlag> >::isConvertible(arg)) {
        overloadId = 0; // setTotalChangeFlags(QFlags<QPinchGesture::ChangeFlag>)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPinchGestureFunc_setTotalChangeFlags_TypeError;

    // Call function/method
    {
        {
            QFlags<QPinchGesture::ChangeFlag> cppArg0 = Shiboken::Converter<QFlags<QPinchGesture::ChangeFlag> >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setTotalChangeFlags(QFlags<QPinchGesture::ChangeFlag>)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setTotalChangeFlags(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QPinchGestureFunc_setTotalChangeFlags_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPinchGesture.ChangeFlags", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPinchGesture.setTotalChangeFlags", overloads);
        return 0;
}

static PyObject* Sbk_QPinchGestureFunc_setTotalRotationAngle(PyObject* self, PyObject* arg)
{
    QPinchGesture* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPinchGesture* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setTotalRotationAngle(qreal)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setTotalRotationAngle(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPinchGestureFunc_setTotalRotationAngle_TypeError;

    // Call function/method
    {
        {
            qreal cppArg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setTotalRotationAngle(qreal)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setTotalRotationAngle(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QPinchGestureFunc_setTotalRotationAngle_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPinchGesture.setTotalRotationAngle", overloads);
        return 0;
}

static PyObject* Sbk_QPinchGestureFunc_setTotalScaleFactor(PyObject* self, PyObject* arg)
{
    QPinchGesture* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPinchGesture* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setTotalScaleFactor(qreal)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setTotalScaleFactor(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPinchGestureFunc_setTotalScaleFactor_TypeError;

    // Call function/method
    {
        {
            qreal cppArg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setTotalScaleFactor(qreal)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setTotalScaleFactor(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QPinchGestureFunc_setTotalScaleFactor_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPinchGesture.setTotalScaleFactor", overloads);
        return 0;
}

static PyObject* Sbk_QPinchGestureFunc_startCenterPoint(PyObject* self)
{
    QPinchGesture* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPinchGesture* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // startCenterPoint()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QPointF cppResult = const_cast<const QPinchGesture*>(cppSelf)->startCenterPoint();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QPointF >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QPinchGestureFunc_totalChangeFlags(PyObject* self)
{
    QPinchGesture* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPinchGesture* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // totalChangeFlags()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QFlags<QPinchGesture::ChangeFlag> cppResult = const_cast<const QPinchGesture*>(cppSelf)->totalChangeFlags();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QFlags<QPinchGesture::ChangeFlag> >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QPinchGestureFunc_totalRotationAngle(PyObject* self)
{
    QPinchGesture* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPinchGesture* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // totalRotationAngle()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                qreal cppResult = const_cast<const QPinchGesture*>(cppSelf)->totalRotationAngle();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< double >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QPinchGestureFunc_totalScaleFactor(PyObject* self)
{
    QPinchGesture* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPinchGesture* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // totalScaleFactor()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                qreal cppResult = const_cast<const QPinchGesture*>(cppSelf)->totalScaleFactor();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< double >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef Sbk_QPinchGesture_methods[] = {
    {"centerPoint", (PyCFunction)Sbk_QPinchGestureFunc_centerPoint, METH_NOARGS},
    {"changeFlags", (PyCFunction)Sbk_QPinchGestureFunc_changeFlags, METH_NOARGS},
    {"lastCenterPoint", (PyCFunction)Sbk_QPinchGestureFunc_lastCenterPoint, METH_NOARGS},
    {"lastRotationAngle", (PyCFunction)Sbk_QPinchGestureFunc_lastRotationAngle, METH_NOARGS},
    {"lastScaleFactor", (PyCFunction)Sbk_QPinchGestureFunc_lastScaleFactor, METH_NOARGS},
    {"rotationAngle", (PyCFunction)Sbk_QPinchGestureFunc_rotationAngle, METH_NOARGS},
    {"scaleFactor", (PyCFunction)Sbk_QPinchGestureFunc_scaleFactor, METH_NOARGS},
    {"setCenterPoint", (PyCFunction)Sbk_QPinchGestureFunc_setCenterPoint, METH_O},
    {"setChangeFlags", (PyCFunction)Sbk_QPinchGestureFunc_setChangeFlags, METH_O},
    {"setLastCenterPoint", (PyCFunction)Sbk_QPinchGestureFunc_setLastCenterPoint, METH_O},
    {"setLastRotationAngle", (PyCFunction)Sbk_QPinchGestureFunc_setLastRotationAngle, METH_O},
    {"setLastScaleFactor", (PyCFunction)Sbk_QPinchGestureFunc_setLastScaleFactor, METH_O},
    {"setRotationAngle", (PyCFunction)Sbk_QPinchGestureFunc_setRotationAngle, METH_O},
    {"setScaleFactor", (PyCFunction)Sbk_QPinchGestureFunc_setScaleFactor, METH_O},
    {"setStartCenterPoint", (PyCFunction)Sbk_QPinchGestureFunc_setStartCenterPoint, METH_O},
    {"setTotalChangeFlags", (PyCFunction)Sbk_QPinchGestureFunc_setTotalChangeFlags, METH_O},
    {"setTotalRotationAngle", (PyCFunction)Sbk_QPinchGestureFunc_setTotalRotationAngle, METH_O},
    {"setTotalScaleFactor", (PyCFunction)Sbk_QPinchGestureFunc_setTotalScaleFactor, METH_O},
    {"startCenterPoint", (PyCFunction)Sbk_QPinchGestureFunc_startCenterPoint, METH_NOARGS},
    {"totalChangeFlags", (PyCFunction)Sbk_QPinchGestureFunc_totalChangeFlags, METH_NOARGS},
    {"totalRotationAngle", (PyCFunction)Sbk_QPinchGestureFunc_totalRotationAngle, METH_NOARGS},
    {"totalScaleFactor", (PyCFunction)Sbk_QPinchGestureFunc_totalScaleFactor, METH_NOARGS},

    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QPinchGesture_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QPinchGesture",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QPinchGesture_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QPinchGesture_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern

static SbkObjectType* Sbk_QPinchGesture_typeDiscovery(void* cptr, SbkObjectType* instanceType)
{
    if (instanceType == reinterpret_cast<SbkObjectType*>(Shiboken::SbkType<QObject >()) && dynamic_cast<QPinchGesture*>(reinterpret_cast<QObject*>(cptr)))
        return &Sbk_QPinchGesture_Type;
    return 0;
}

PyObject* SbkPySide_QtGui_QPinchGesture_ChangeFlag___and__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QPinchGesture::ChangeFlags >::toPython(
        Shiboken::Converter<QPinchGesture::ChangeFlags>::toCpp(self)
        & Shiboken::Converter< QPinchGesture::ChangeFlags >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtGui_QPinchGesture_ChangeFlag___or__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QPinchGesture::ChangeFlags >::toPython(
        Shiboken::Converter<QPinchGesture::ChangeFlags>::toCpp(self)
        | Shiboken::Converter< QPinchGesture::ChangeFlags >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtGui_QPinchGesture_ChangeFlag___xor__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QPinchGesture::ChangeFlags >::toPython(
        Shiboken::Converter<QPinchGesture::ChangeFlags>::toCpp(self)
        ^ Shiboken::Converter< QPinchGesture::ChangeFlags >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtGui_QPinchGesture_ChangeFlag___invert__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QPinchGesture::ChangeFlags >::toPython(
        ~Shiboken::Converter<QPinchGesture::ChangeFlags >::toCpp(self)
    );
}


static PyNumberMethods SbkPySide_QtGui_QPinchGesture_ChangeFlag_as_number = {
    /*nb_add*/                  0,
    /*nb_subtract*/             0,
    /*nb_multiply*/             0,
    /*nb_divide*/               0,
    /*nb_remainder*/            0,
    /*nb_divmod*/               0,
    /*nb_power*/                0,
    /*nb_negative*/             0,
    /*nb_positive*/             0,
    /*nb_absolute*/             0,
    /*nb_nonzero*/              0,
    /*nb_invert*/               (unaryfunc)SbkPySide_QtGui_QPinchGesture_ChangeFlag___invert__,
    /*nb_lshift*/               0,
    /*nb_rshift*/               0,
    /*nb_and*/                  (binaryfunc)SbkPySide_QtGui_QPinchGesture_ChangeFlag___and__,
    /*nb_xor*/                  (binaryfunc)SbkPySide_QtGui_QPinchGesture_ChangeFlag___xor__,
    /*nb_or*/                   (binaryfunc)SbkPySide_QtGui_QPinchGesture_ChangeFlag___or__,
    /*nb_coerce*/               0,
    /*nb_int*/                  0,
    /*nb_long*/                 0,
    /*nb_float*/                0,
    /*nb_oct*/                  0,
    /*nb_hex*/                  0,
    /*nb_inplace_add*/          0,
    /*nb_inplace_subtract*/     0,
    /*nb_inplace_multiply*/     0,
    /*nb_inplace_divide*/       0,
    /*nb_inplace_remainder*/    0,
    /*nb_inplace_power*/        0,
    /*nb_inplace_lshift*/       0,
    /*nb_inplace_rshift*/       0,
    /*nb_inplace_and*/          0,
    /*nb_inplace_xor*/          0,
    /*nb_inplace_or*/           0,
    /*nb_floor_divide*/         0,
    /*nb_true_divide*/          0,
    /*nb_inplace_floor_divide*/ 0,
    /*nb_inplace_true_divide*/  0,
    /*nb_index*/                0
};


// forward declaration of new function
static PyTypeObject SbkPySide_QtGui_QPinchGesture_ChangeFlags_Type = {
    PyObject_HEAD_INIT(&PyType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "ChangeFlags",
    /*tp_basicsize*/        0,
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        &SbkPySide_QtGui_QPinchGesture_ChangeFlag_as_number,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT | Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              PyInt_Type.tp_new,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};



void init_QPinchGesture(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QPINCHGESTURE_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QPinchGesture_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QPinchGesture_Type);
    Shiboken::ObjectType::setSubTypeInitHook(&Sbk_QPinchGesture_Type, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(&Sbk_QPinchGesture_Type, &QPinchGesture::staticMetaObject);    Sbk_QPinchGesture_Type.super.ht_type.tp_base = SbkPySide_QtGuiTypes[SBK_QGESTURE_IDX];
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QPinchGesture_Type, &Shiboken::callCppDestructor<QPinchGesture >);
    Py_INCREF((PyObject*)&Sbk_QPinchGesture_Type); //Incref due the 'PyModule_AddObject' steals the reference.
    if (PyType_Ready((PyTypeObject*)&Sbk_QPinchGesture_Type) < 0)
        return;

    // Fill type discovery information
    Shiboken::ObjectType::setTypeDiscoveryFunction(&Sbk_QPinchGesture_Type, &Sbk_QPinchGesture_typeDiscovery);
    Shiboken::BindingManager& bm = Shiboken::BindingManager::instance();
    bm.addClassInheritance(reinterpret_cast<SbkObjectType*>(SbkPySide_QtGuiTypes[SBK_QGESTURE_IDX]), &Sbk_QPinchGesture_Type);

    Shiboken::ObjectType::setOriginalName(&Sbk_QPinchGesture_Type, "QPinchGesture*");
    PyModule_AddObject(module, "QPinchGesture",
        ((PyObject*)&Sbk_QPinchGesture_Type));

    // Initialize enums
    PyObject* enumItem;

    // init enum: ChangeFlag
    PyTypeObject* SbkPySide_QtGui_QPinchGesture_ChangeFlag = Shiboken::Enum::newType("PySide.QtGui.QPinchGesture.ChangeFlag");
    SbkPySide_QtGui_QPinchGesture_ChangeFlag->tp_as_number = &SbkPySide_QtGui_QPinchGesture_ChangeFlag_as_number;
    SbkPySide_QtGuiTypes[SBK_QPINCHGESTURE_CHANGEFLAG_IDX] = SbkPySide_QtGui_QPinchGesture_ChangeFlag;
    if (PyType_Ready(SbkPySide_QtGui_QPinchGesture_ChangeFlag) < 0)
        return;
    PyDict_SetItemString(Sbk_QPinchGesture_Type.super.ht_type.tp_dict,
            "ChangeFlag",((PyObject*)SbkPySide_QtGui_QPinchGesture_ChangeFlag));

    // init flags class: QFlags<QPinchGesture::ChangeFlag>
    SbkPySide_QtGuiTypes[SBK_QFLAGS_QPINCHGESTURE_CHANGEFLAG__IDX] = &SbkPySide_QtGui_QPinchGesture_ChangeFlags_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtGui_QPinchGesture_ChangeFlags_Type) < 0)
        return;
    PyDict_SetItemString(Sbk_QPinchGesture_Type.super.ht_type.tp_dict,
            "ChangeFlags",((PyObject*)&SbkPySide_QtGui_QPinchGesture_ChangeFlags_Type));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPinchGesture_ChangeFlag,(long) QPinchGesture::ScaleFactorChanged, "ScaleFactorChanged");
    PyDict_SetItemString(Sbk_QPinchGesture_Type.super.ht_type.tp_dict,"ScaleFactorChanged", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPinchGesture_ChangeFlag->tp_dict,"ScaleFactorChanged", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPinchGesture_ChangeFlag,(long) QPinchGesture::RotationAngleChanged, "RotationAngleChanged");
    PyDict_SetItemString(Sbk_QPinchGesture_Type.super.ht_type.tp_dict,"RotationAngleChanged", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPinchGesture_ChangeFlag->tp_dict,"RotationAngleChanged", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPinchGesture_ChangeFlag,(long) QPinchGesture::CenterPointChanged, "CenterPointChanged");
    PyDict_SetItemString(Sbk_QPinchGesture_Type.super.ht_type.tp_dict,"CenterPointChanged", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPinchGesture_ChangeFlag->tp_dict,"CenterPointChanged", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QPinchGesture::ChangeFlag");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::ChangeFlag");
    // end of enum ChangeFlag


    Shiboken::TypeResolver::createObjectTypeResolver<QPinchGesture >("QPinchGesture*");
    Shiboken::TypeResolver::createObjectTypeResolver<QPinchGesture >(typeid(QPinchGesture).name());
    Shiboken::TypeResolver::createObjectTypeResolver<QPinchGesture >(typeid(QPinchGestureWrapper).name());
    qRegisterMetaType< ::QPinchGesture* >("QPinchGesture*");
    qRegisterMetaType< ::QPinchGesture::ChangeFlag >("QPinchGesture::ChangeFlag");
    qRegisterMetaType< ::QPinchGesture::ChangeFlags >("QPinchGesture::ChangeFlags");
}

