/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtgui_python.h"

#include "qspaceritem_wrapper.h"

// Extra includes
#include <qlayout.h>
#include <qlayoutitem.h>
#include <qrect.h>
#include <qsize.h>
#include <qwidget.h>


// Native ---------------------------------------------------------

QSpacerItemWrapper::QSpacerItemWrapper(int w, int h, QSizePolicy::Policy hData, QSizePolicy::Policy vData) : QSpacerItem(w, h, hData, vData) {
    // ... middle
}

QFlags<Qt::Orientation> QSpacerItemWrapper::expandingDirections() const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return QFlags<Qt::Orientation>();
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "expandingDirections"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QSpacerItem::expandingDirections();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QFlags<Qt::Orientation>();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QFlags<Qt::Orientation> >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QSpacerItem.expandingDirections", Shiboken::SbkType<QFlags<Qt::Orientation> >()->tp_name, pyResult->ob_type->tp_name);
        return QFlags<Qt::Orientation>();
    }
    QFlags<Qt::Orientation> cppResult(Shiboken::Converter< ::QFlags<Qt::Orientation> >::toCpp(pyResult));
    return cppResult;
}

QRect QSpacerItemWrapper::geometry() const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return QRect();
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "geometry"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QSpacerItem::geometry();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QRect();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QRect >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QSpacerItem.geometry", Shiboken::SbkType<QRect >()->tp_name, pyResult->ob_type->tp_name);
        return QRect();
    }
    QRect cppResult(Shiboken::Converter< ::QRect >::toCpp(pyResult));
    return cppResult;
}

bool QSpacerItemWrapper::hasHeightForWidth() const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return bool(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "hasHeightForWidth"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QLayoutItem::hasHeightForWidth();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QSpacerItem.hasHeightForWidth", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    return cppResult;
}

int QSpacerItemWrapper::heightForWidth(int arg__1) const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return int(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "heightForWidth"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QLayoutItem::heightForWidth(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(i)",
        arg__1
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return int(0);
    }
    // Check return type
    bool typeIsValid = PyInt_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QSpacerItem.heightForWidth", "int", pyResult->ob_type->tp_name);
        return int(0);
    }
    int cppResult(Shiboken::Converter< int >::toCpp(pyResult));
    return cppResult;
}

void QSpacerItemWrapper::invalidate()
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "invalidate"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QLayoutItem::invalidate();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

bool QSpacerItemWrapper::isEmpty() const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return bool(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "isEmpty"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QSpacerItem::isEmpty();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QSpacerItem.isEmpty", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    return cppResult;
}

QLayout * QSpacerItemWrapper::layout()
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return 0;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "layout"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QLayoutItem::layout();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return 0;
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QLayout * >::isConvertible(pyResult);
    typeIsValid = typeIsValid || (pyResult == Py_None);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QSpacerItem.layout", Shiboken::SbkType<QLayout >()->tp_name, pyResult->ob_type->tp_name);
        return 0;
    }
    QLayout * cppResult(Shiboken::Converter< ::QLayout * >::toCpp(pyResult));
    return cppResult;
}

QSize QSpacerItemWrapper::maximumSize() const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return QSize();
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "maximumSize"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QSpacerItem::maximumSize();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QSize();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QSize >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QSpacerItem.maximumSize", Shiboken::SbkType<QSize >()->tp_name, pyResult->ob_type->tp_name);
        return QSize();
    }
    QSize cppResult(Shiboken::Converter< ::QSize >::toCpp(pyResult));
    return cppResult;
}

int QSpacerItemWrapper::minimumHeightForWidth(int arg__1) const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return int(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "minimumHeightForWidth"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QLayoutItem::minimumHeightForWidth(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(i)",
        arg__1
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return int(0);
    }
    // Check return type
    bool typeIsValid = PyInt_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QSpacerItem.minimumHeightForWidth", "int", pyResult->ob_type->tp_name);
        return int(0);
    }
    int cppResult(Shiboken::Converter< int >::toCpp(pyResult));
    return cppResult;
}

QSize QSpacerItemWrapper::minimumSize() const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return QSize();
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "minimumSize"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QSpacerItem::minimumSize();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QSize();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QSize >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QSpacerItem.minimumSize", Shiboken::SbkType<QSize >()->tp_name, pyResult->ob_type->tp_name);
        return QSize();
    }
    QSize cppResult(Shiboken::Converter< ::QSize >::toCpp(pyResult));
    return cppResult;
}

void QSpacerItemWrapper::setGeometry(const QRect & arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "setGeometry"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QSpacerItem::setGeometry(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QRect >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

QSize QSpacerItemWrapper::sizeHint() const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return QSize();
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "sizeHint"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QSpacerItem::sizeHint();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QSize();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QSize >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QSpacerItem.sizeHint", Shiboken::SbkType<QSize >()->tp_name, pyResult->ob_type->tp_name);
        return QSize();
    }
    QSize cppResult(Shiboken::Converter< ::QSize >::toCpp(pyResult));
    return cppResult;
}

QSpacerItem * QSpacerItemWrapper::spacerItem()
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return 0;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "spacerItem"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QSpacerItem::spacerItem();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return 0;
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QSpacerItem * >::isConvertible(pyResult);
    typeIsValid = typeIsValid || (pyResult == Py_None);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QSpacerItem.spacerItem", Shiboken::SbkType<QSpacerItem >()->tp_name, pyResult->ob_type->tp_name);
        return 0;
    }
    QSpacerItem * cppResult(Shiboken::Converter< ::QSpacerItem * >::toCpp(pyResult));
    return cppResult;
}

QWidget * QSpacerItemWrapper::widget()
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return 0;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "widget"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QLayoutItem::widget();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return 0;
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QWidget * >::isConvertible(pyResult);
    typeIsValid = typeIsValid || (pyResult == Py_None);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QSpacerItem.widget", Shiboken::SbkType<QWidget >()->tp_name, pyResult->ob_type->tp_name);
        return 0;
    }
    QWidget * cppResult(Shiboken::Converter< ::QWidget * >::toCpp(pyResult));
    return cppResult;
}

QSpacerItemWrapper::~QSpacerItemWrapper()
{
    SbkObject* wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QSpacerItem_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QSpacerItem >()))
        return -1;

    QSpacerItemWrapper* cptr = 0;
    int overloadId = -1;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);

    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);

    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 4) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QSpacerItem(): too many arguments");
        return -1;
    } else if (numArgs < 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QSpacerItem(): not enough arguments");
        return -1;
    }

    if (!PyArg_ParseTuple(args, "|OOOO:QSpacerItem", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return -1;

    // Overloaded function decisor
    // 0: QSpacerItem(int,int,QSizePolicy::Policy,QSizePolicy::Policy)
    if (numArgs >= 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        if (numArgs == 2) {
            overloadId = 0; // QSpacerItem(int,int,QSizePolicy::Policy,QSizePolicy::Policy)
        } else if (Shiboken::Converter< ::QSizePolicy::Policy >::isConvertible(pyargs[2])) {
            if (numArgs == 3) {
                overloadId = 0; // QSpacerItem(int,int,QSizePolicy::Policy,QSizePolicy::Policy)
            } else if (Shiboken::Converter< ::QSizePolicy::Policy >::isConvertible(pyargs[3])) {
                overloadId = 0; // QSpacerItem(int,int,QSizePolicy::Policy,QSizePolicy::Policy)
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QSpacerItem_Init_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "hData");
                if (value) {
                    if (pyargs[2])
                        errorArgName = "hData";
                    else if (Shiboken::Converter< ::QSizePolicy::Policy >::isConvertible(value))
                        pyargs[2] = value;
                    else
                        goto Sbk_QSpacerItem_Init_TypeError;
                }
                value = PyDict_GetItemString(kwds, "vData");
                if (value) {
                    if (pyargs[3])
                        errorArgName = "vData";
                    else if (Shiboken::Converter< ::QSizePolicy::Policy >::isConvertible(value))
                        pyargs[3] = value;
                    else
                        goto Sbk_QSpacerItem_Init_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QSpacerItem(): got multiple values for keyword argument '%s'", errorArgName);
                    return -1;
                }
            }
            int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
            QSizePolicy::Policy cppArg2 = pyargs[2] ? Shiboken::Converter<QSizePolicy::Policy >::toCpp(pyargs[2]) : QSizePolicy::Minimum;
            QSizePolicy::Policy cppArg3 = pyargs[3] ? Shiboken::Converter<QSizePolicy::Policy >::toCpp(pyargs[3]) : QSizePolicy::Minimum;

            if(!PyErr_Occurred()) {
                // QSpacerItem(int,int,QSizePolicy::Policy,QSizePolicy::Policy)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new QSpacerItemWrapper(cppArg0, cppArg1, cppArg2, cppArg3);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QSpacerItem >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QSpacerItem_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QSpacerItem_Init_TypeError:
        const char* overloads[] = {"int, int, PySide.QtGui.QSizePolicy.Policy = QSizePolicy.Minimum, PySide.QtGui.QSizePolicy.Policy = QSizePolicy.Minimum", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QSpacerItem", overloads);
        return -1;
}

static PyObject* Sbk_QSpacerItemFunc_changeSize(PyObject* self, PyObject* args, PyObject* kwds)
{
    QSpacerItem* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QSpacerItem* >::toCpp(self);

    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 4) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QSpacerItem.changeSize(): too many arguments");
        return 0;
    } else if (numArgs < 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QSpacerItem.changeSize(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOOO:changeSize", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return 0;


    // Overloaded function decisor
    // 0: changeSize(int,int,QSizePolicy::Policy,QSizePolicy::Policy)
    if (numArgs >= 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        if (numArgs == 2) {
            overloadId = 0; // changeSize(int,int,QSizePolicy::Policy,QSizePolicy::Policy)
        } else if (Shiboken::Converter< ::QSizePolicy::Policy >::isConvertible(pyargs[2])) {
            if (numArgs == 3) {
                overloadId = 0; // changeSize(int,int,QSizePolicy::Policy,QSizePolicy::Policy)
            } else if (Shiboken::Converter< ::QSizePolicy::Policy >::isConvertible(pyargs[3])) {
                overloadId = 0; // changeSize(int,int,QSizePolicy::Policy,QSizePolicy::Policy)
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QSpacerItemFunc_changeSize_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "hData");
                if (value) {
                    if (pyargs[2])
                        errorArgName = "hData";
                    else if (Shiboken::Converter< ::QSizePolicy::Policy >::isConvertible(value))
                        pyargs[2] = value;
                    else
                        goto Sbk_QSpacerItemFunc_changeSize_TypeError;
                }
                value = PyDict_GetItemString(kwds, "vData");
                if (value) {
                    if (pyargs[3])
                        errorArgName = "vData";
                    else if (Shiboken::Converter< ::QSizePolicy::Policy >::isConvertible(value))
                        pyargs[3] = value;
                    else
                        goto Sbk_QSpacerItemFunc_changeSize_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QSpacerItem.changeSize(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
            QSizePolicy::Policy cppArg2 = pyargs[2] ? Shiboken::Converter<QSizePolicy::Policy >::toCpp(pyargs[2]) : QSizePolicy::Minimum;
            QSizePolicy::Policy cppArg3 = pyargs[3] ? Shiboken::Converter<QSizePolicy::Policy >::toCpp(pyargs[3]) : QSizePolicy::Minimum;

            if(!PyErr_Occurred()) {
                // changeSize(int,int,QSizePolicy::Policy,QSizePolicy::Policy)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->changeSize(cppArg0, cppArg1, cppArg2, cppArg3);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QSpacerItemFunc_changeSize_TypeError:
        const char* overloads[] = {"int, int, PySide.QtGui.QSizePolicy.Policy = QSizePolicy.Minimum, PySide.QtGui.QSizePolicy.Policy = QSizePolicy.Minimum", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QSpacerItem.changeSize", overloads);
        return 0;
}

static PyObject* Sbk_QSpacerItemFunc_expandingDirections(PyObject* self)
{
    QSpacerItem* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QSpacerItem* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // expandingDirections()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QFlags<Qt::Orientation> cppResult = (Shiboken::Object::isUserType(self) ? const_cast<const QSpacerItem*>(cppSelf)->::QSpacerItem::expandingDirections() : const_cast<const QSpacerItem*>(cppSelf)->expandingDirections());
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QFlags<Qt::Orientation> >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QSpacerItemFunc_geometry(PyObject* self)
{
    QSpacerItem* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QSpacerItem* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // geometry()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QRect cppResult = (Shiboken::Object::isUserType(self) ? const_cast<const QSpacerItem*>(cppSelf)->::QSpacerItem::geometry() : const_cast<const QSpacerItem*>(cppSelf)->geometry());
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QRect >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QSpacerItemFunc_isEmpty(PyObject* self)
{
    QSpacerItem* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QSpacerItem* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isEmpty()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = (Shiboken::Object::isUserType(self) ? const_cast<const QSpacerItem*>(cppSelf)->::QSpacerItem::isEmpty() : const_cast<const QSpacerItem*>(cppSelf)->isEmpty());
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QSpacerItemFunc_maximumSize(PyObject* self)
{
    QSpacerItem* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QSpacerItem* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // maximumSize()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QSize cppResult = (Shiboken::Object::isUserType(self) ? const_cast<const QSpacerItem*>(cppSelf)->::QSpacerItem::maximumSize() : const_cast<const QSpacerItem*>(cppSelf)->maximumSize());
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QSize >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QSpacerItemFunc_minimumSize(PyObject* self)
{
    QSpacerItem* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QSpacerItem* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // minimumSize()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QSize cppResult = (Shiboken::Object::isUserType(self) ? const_cast<const QSpacerItem*>(cppSelf)->::QSpacerItem::minimumSize() : const_cast<const QSpacerItem*>(cppSelf)->minimumSize());
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QSize >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QSpacerItemFunc_setGeometry(PyObject* self, PyObject* arg)
{
    QSpacerItem* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QSpacerItem* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setGeometry(QRect)
    if (Shiboken::Converter< ::QRect >::isConvertible(arg)) {
        overloadId = 0; // setGeometry(QRect)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QSpacerItemFunc_setGeometry_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QRect cppArg0 = Shiboken::Converter<QRect >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setGeometry(QRect)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QSpacerItem::setGeometry(cppArg0) : cppSelf->setGeometry(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QSpacerItemFunc_setGeometry_TypeError:
        const char* overloads[] = {"PySide.QtCore.QRect", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QSpacerItem.setGeometry", overloads);
        return 0;
}

static PyObject* Sbk_QSpacerItemFunc_sizeHint(PyObject* self)
{
    QSpacerItem* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QSpacerItem* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // sizeHint()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QSize cppResult = (Shiboken::Object::isUserType(self) ? const_cast<const QSpacerItem*>(cppSelf)->::QSpacerItem::sizeHint() : const_cast<const QSpacerItem*>(cppSelf)->sizeHint());
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QSize >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QSpacerItemFunc_spacerItem(PyObject* self)
{
    QSpacerItem* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QSpacerItem* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // spacerItem()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QSpacerItem * cppResult = (Shiboken::Object::isUserType(self) ? cppSelf->::QSpacerItem::spacerItem() : cppSelf->spacerItem());
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QSpacerItem * >::toPython(cppResult);

                // Ownership transferences.
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef Sbk_QSpacerItem_methods[] = {
    {"changeSize", (PyCFunction)Sbk_QSpacerItemFunc_changeSize, METH_VARARGS|METH_KEYWORDS},
    {"expandingDirections", (PyCFunction)Sbk_QSpacerItemFunc_expandingDirections, METH_NOARGS},
    {"geometry", (PyCFunction)Sbk_QSpacerItemFunc_geometry, METH_NOARGS},
    {"isEmpty", (PyCFunction)Sbk_QSpacerItemFunc_isEmpty, METH_NOARGS},
    {"maximumSize", (PyCFunction)Sbk_QSpacerItemFunc_maximumSize, METH_NOARGS},
    {"minimumSize", (PyCFunction)Sbk_QSpacerItemFunc_minimumSize, METH_NOARGS},
    {"setGeometry", (PyCFunction)Sbk_QSpacerItemFunc_setGeometry, METH_O},
    {"sizeHint", (PyCFunction)Sbk_QSpacerItemFunc_sizeHint, METH_NOARGS},
    {"spacerItem", (PyCFunction)Sbk_QSpacerItemFunc_spacerItem, METH_NOARGS},

    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QSpacerItem_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QSpacerItem",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QSpacerItem_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QSpacerItem_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern

static SbkObjectType* Sbk_QSpacerItem_typeDiscovery(void* cptr, SbkObjectType* instanceType)
{
    if (instanceType == reinterpret_cast<SbkObjectType*>(Shiboken::SbkType<QLayoutItem >()) && dynamic_cast<QSpacerItem*>(reinterpret_cast<QLayoutItem*>(cptr)))
        return &Sbk_QSpacerItem_Type;
    return 0;
}


void init_QSpacerItem(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QSPACERITEM_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QSpacerItem_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QSpacerItem_Type);
    Sbk_QSpacerItem_Type.super.ht_type.tp_base = SbkPySide_QtGuiTypes[SBK_QLAYOUTITEM_IDX];
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QSpacerItem_Type, &Shiboken::callCppDestructor<QSpacerItem >);
    Py_INCREF((PyObject*)&Sbk_QSpacerItem_Type); //Incref due the 'PyModule_AddObject' steals the reference.
    if (PyType_Ready((PyTypeObject*)&Sbk_QSpacerItem_Type) < 0)
        return;

    // Fill type discovery information
    Shiboken::ObjectType::setTypeDiscoveryFunction(&Sbk_QSpacerItem_Type, &Sbk_QSpacerItem_typeDiscovery);
    Shiboken::BindingManager& bm = Shiboken::BindingManager::instance();
    bm.addClassInheritance(reinterpret_cast<SbkObjectType*>(SbkPySide_QtGuiTypes[SBK_QLAYOUTITEM_IDX]), &Sbk_QSpacerItem_Type);

    Shiboken::ObjectType::setOriginalName(&Sbk_QSpacerItem_Type, "QSpacerItem*");
    PyModule_AddObject(module, "QSpacerItem",
        ((PyObject*)&Sbk_QSpacerItem_Type));


    Shiboken::TypeResolver::createObjectTypeResolver<QSpacerItem >("QSpacerItem*");
    Shiboken::TypeResolver::createObjectTypeResolver<QSpacerItem >(typeid(QSpacerItem).name());
    Shiboken::TypeResolver::createObjectTypeResolver<QSpacerItem >(typeid(QSpacerItemWrapper).name());
    qRegisterMetaType< ::QSpacerItem* >("QSpacerItem*");
}

