/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtgui_python.h"

#include "qstandarditem_wrapper.h"

// Extra includes
#include <QList>
#include <qabstractitemmodel.h>
#include <qbrush.h>
#include <qdatastream.h>
#include <qfont.h>
#include <qicon.h>
#include <qsize.h>
#include <qstandarditemmodel.h>


// Native ---------------------------------------------------------

QStandardItemWrapper::QStandardItemWrapper() : QStandardItem() {
    // ... middle
}

QStandardItemWrapper::QStandardItemWrapper(const QIcon & icon, const QString & text) : QStandardItem(icon, text) {
    // ... middle
}

QStandardItemWrapper::QStandardItemWrapper(const QString & text) : QStandardItem(text) {
    // ... middle
}

QStandardItemWrapper::QStandardItemWrapper(int rows, int columns) : QStandardItem(rows, columns) {
    // ... middle
}

QStandardItem * QStandardItemWrapper::clone() const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return 0;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "clone"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QStandardItem::clone();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return 0;
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QStandardItem * >::isConvertible(pyResult);
    typeIsValid = typeIsValid || (pyResult == Py_None);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QStandardItem.clone", Shiboken::SbkType<QStandardItem >()->tp_name, pyResult->ob_type->tp_name);
        return 0;
    }
    QStandardItem * cppResult(Shiboken::Converter< ::QStandardItem * >::toCpp(pyResult));
    return cppResult;
}

QVariant QStandardItemWrapper::data(int role) const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return QVariant(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "data"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QStandardItem::data(role);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(i)",
        role
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QVariant(0);
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< QVariant >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QStandardItem.data", "QVariant", pyResult->ob_type->tp_name);
        return QVariant(0);
    }
    QVariant cppResult(Shiboken::Converter< QVariant >::toCpp(pyResult));
    return cppResult;
}

void QStandardItemWrapper::read(QDataStream & in)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "read"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QStandardItem::read(in);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QDataStream & >::toPython(in)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QStandardItemWrapper::setData(const QVariant & value, int role)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "setData"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QStandardItem::setData(value, role);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(Ni)",
        Shiboken::Converter< QVariant >::toPython(value),
        role
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

int QStandardItemWrapper::type() const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return int(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "type"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QStandardItem::type();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return int(0);
    }
    // Check return type
    bool typeIsValid = PyInt_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QStandardItem.type", "int", pyResult->ob_type->tp_name);
        return int(0);
    }
    int cppResult(Shiboken::Converter< int >::toCpp(pyResult));
    return cppResult;
}

void QStandardItemWrapper::write(QDataStream & out) const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "write"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QStandardItem::write(out);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QDataStream & >::toPython(out)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

QStandardItemWrapper::~QStandardItemWrapper()
{
    SbkObject* wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QStandardItem_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QStandardItem >()))
        return -1;

    QStandardItemWrapper* cptr = 0;
    int overloadId = -1;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);

    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);

    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QStandardItem(): too many arguments");
        return -1;
    }

    if (!PyArg_ParseTuple(args, "|OO:QStandardItem", &(pyargs[0]), &(pyargs[1])))
        return -1;

    // Overloaded function decisor
    // 0: QStandardItem()
    // 1: QStandardItem(QIcon,QString)
    // 2: QStandardItem(QStandardItem)
    // 3: QStandardItem(QString)
    // 4: QStandardItem(int,int)
    if (numArgs == 0) {
        overloadId = 0; // QStandardItem()
    } else if (SbkNumber_Check(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 4; // QStandardItem(int,int)
        } else if (SbkNumber_Check(pyargs[1])) {
            overloadId = 4; // QStandardItem(int,int)
        }
    } else if (numArgs == 1 && Shiboken::Converter< QString >::isConvertible(pyargs[0])) {
        overloadId = 3; // QStandardItem(QString)
    } else if (numArgs == 1 && Shiboken::Converter< ::QStandardItem >::isConvertible(pyargs[0])) {
        overloadId = 2; // QStandardItem(QStandardItem)
    } else if (numArgs == 2 && Shiboken::Converter< ::QIcon >::isConvertible(pyargs[0]) && Shiboken::Converter< QString >::isConvertible(pyargs[1])) {
        overloadId = 1; // QStandardItem(QIcon,QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QStandardItem_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QStandardItem()
            {

                if(!PyErr_Occurred()) {
                    // QStandardItem()
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QStandardItemWrapper();
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // QStandardItem(QIcon,QString)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QIcon cppArg0 = Shiboken::Converter<QIcon >::toCpp(pyargs[0]);
                QString cppArg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // QStandardItem(QIcon,QString)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QStandardItemWrapper(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 2: // QStandardItem(QStandardItem)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                const QStandardItem & cppArg0 = Shiboken::Converter<const QStandardItem & >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QStandardItem(QStandardItem)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QStandardItemWrapper(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 3: // QStandardItem(QString)
            {
                QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QStandardItem(QString)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QStandardItemWrapper(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 4: // QStandardItem(int,int)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "columns");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "columns";
                        else if (SbkNumber_Check(value))
                            pyargs[1] = value;
                        else
                            goto Sbk_QStandardItem_Init_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QStandardItem(): got multiple values for keyword argument '%s'", errorArgName);
                        return -1;
                    }
                }
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cppArg1 = pyargs[1] ? Shiboken::Converter<int >::toCpp(pyargs[1]) : 1;

                if(!PyErr_Occurred()) {
                    // QStandardItem(int,int)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QStandardItemWrapper(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QStandardItem >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QStandardItem_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QStandardItem_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtGui.QIcon, QString", "PySide.QtGui.QStandardItem", "QString", "int, int = 1", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QStandardItem", overloads);
        return -1;
}

static PyObject* Sbk_QStandardItemFunc_accessibleDescription(PyObject* self)
{
    QStandardItem* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QStandardItem* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // accessibleDescription()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = const_cast<const QStandardItem*>(cppSelf)->accessibleDescription();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QStandardItemFunc_accessibleText(PyObject* self)
{
    QStandardItem* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QStandardItem* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // accessibleText()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = const_cast<const QStandardItem*>(cppSelf)->accessibleText();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QStandardItemFunc_appendColumn(PyObject* self, PyObject* arg)
{
    QStandardItem* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QStandardItem* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: appendColumn(QList<QStandardItem*>)
    if (Shiboken::Converter< ::QList<QStandardItem * > >::isConvertible(arg)) {
        overloadId = 0; // appendColumn(QList<QStandardItem*>)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QStandardItemFunc_appendColumn_TypeError;

    // Call function/method
    {
        {
            QList<QStandardItem * > cppArg0 = Shiboken::Converter<QList<QStandardItem * > >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // appendColumn(QList<QStandardItem*>)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->appendColumn(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                Shiboken::Object::setParent(self, arg);
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QStandardItemFunc_appendColumn_TypeError:
        const char* overloads[] = {"list", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QStandardItem.appendColumn", overloads);
        return 0;
}

static PyObject* Sbk_QStandardItemFunc_appendRow(PyObject* self, PyObject* arg)
{
    QStandardItem* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QStandardItem* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: appendRow(QStandardItem*)
    // 1: appendRow(QList<QStandardItem*>)
    if (Shiboken::Converter< ::QStandardItem * >::isConvertible(arg)) {
        overloadId = 0; // appendRow(QStandardItem*)
    } else if (Shiboken::Converter< ::QList<QStandardItem * > >::isConvertible(arg)) {
        overloadId = 1; // appendRow(QList<QStandardItem*>)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QStandardItemFunc_appendRow_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // appendRow(QStandardItem*)
            {
                if (!Shiboken::Object::isValid(arg))
                    return 0;
                QStandardItem * cppArg0 = Shiboken::Converter<QStandardItem * >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // appendRow(QStandardItem*)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->appendRow(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    Shiboken::Object::setParent(self, arg);
                }
                break;
            }
            case 1: // appendRow(QList<QStandardItem*>)
            {
                QList<QStandardItem * > cppArg0 = Shiboken::Converter<QList<QStandardItem * > >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // appendRow(QList<QStandardItem*>)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->appendRow(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    Shiboken::Object::setParent(self, arg);
                }
                break;
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QStandardItemFunc_appendRow_TypeError:
        const char* overloads[] = {"PySide.QtGui.QStandardItem", "list", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QStandardItem.appendRow", overloads);
        return 0;
}

static PyObject* Sbk_QStandardItemFunc_appendRows(PyObject* self, PyObject* arg)
{
    QStandardItem* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QStandardItem* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: appendRows(QList<QStandardItem*>)
    if (Shiboken::Converter< ::QList<QStandardItem * > >::isConvertible(arg)) {
        overloadId = 0; // appendRows(QList<QStandardItem*>)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QStandardItemFunc_appendRows_TypeError;

    // Call function/method
    {
        {
            QList<QStandardItem * > cppArg0 = Shiboken::Converter<QList<QStandardItem * > >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // appendRows(QList<QStandardItem*>)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->appendRows(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                Shiboken::Object::setParent(self, arg);
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QStandardItemFunc_appendRows_TypeError:
        const char* overloads[] = {"list", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QStandardItem.appendRows", overloads);
        return 0;
}

static PyObject* Sbk_QStandardItemFunc_background(PyObject* self)
{
    QStandardItem* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QStandardItem* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // background()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QBrush cppResult = const_cast<const QStandardItem*>(cppSelf)->background();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QBrush >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QStandardItemFunc_checkState(PyObject* self)
{
    QStandardItem* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QStandardItem* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // checkState()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                Qt::CheckState cppResult = const_cast<const QStandardItem*>(cppSelf)->checkState();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::Qt::CheckState >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QStandardItemFunc_child(PyObject* self, PyObject* args, PyObject* kwds)
{
    QStandardItem* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QStandardItem* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QStandardItem.child(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QStandardItem.child(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:child", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: child(int,int)const
    if (SbkNumber_Check(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // child(int,int)const
        } else if (SbkNumber_Check(pyargs[1])) {
            overloadId = 0; // child(int,int)const
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QStandardItemFunc_child_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "column");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "column";
                    else if (SbkNumber_Check(value))
                        pyargs[1] = value;
                    else
                        goto Sbk_QStandardItemFunc_child_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QStandardItem.child(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            int cppArg1 = pyargs[1] ? Shiboken::Converter<int >::toCpp(pyargs[1]) : 0;

            if(!PyErr_Occurred()) {
                // child(int,int)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QStandardItem * cppResult = const_cast<const QStandardItem*>(cppSelf)->child(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QStandardItem * >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QStandardItemFunc_child_TypeError:
        const char* overloads[] = {"int, int = 0", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QStandardItem.child", overloads);
        return 0;
}

static PyObject* Sbk_QStandardItemFunc_clone(PyObject* self)
{
    QStandardItem* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QStandardItem* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // clone()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QStandardItem * cppResult = (Shiboken::Object::isUserType(self) ? const_cast<const QStandardItem*>(cppSelf)->::QStandardItem::clone() : const_cast<const QStandardItem*>(cppSelf)->clone());
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QStandardItem * >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QStandardItemFunc_column(PyObject* self)
{
    QStandardItem* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QStandardItem* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // column()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QStandardItem*>(cppSelf)->column();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QStandardItemFunc_columnCount(PyObject* self)
{
    QStandardItem* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QStandardItem* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // columnCount()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QStandardItem*>(cppSelf)->columnCount();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QStandardItemFunc_data(PyObject* self, PyObject* args, PyObject* kwds)
{
    QStandardItem* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QStandardItem* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QStandardItem.data(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:data", &(pyargs[0])))
        return 0;


    // Overloaded function decisor
    // 0: data(int)const
    if (numArgs == 0) {
        overloadId = 0; // data(int)const
    } else if (SbkNumber_Check(pyargs[0])) {
        overloadId = 0; // data(int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QStandardItemFunc_data_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "role");
                if (value) {
                    if (pyargs[0])
                        errorArgName = "role";
                    else if (SbkNumber_Check(value))
                        pyargs[0] = value;
                    else
                        goto Sbk_QStandardItemFunc_data_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QStandardItem.data(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            int cppArg0 = pyargs[0] ? Shiboken::Converter<int >::toCpp(pyargs[0]) : Qt::UserRole + 1;

            if(!PyErr_Occurred()) {
                // data(int)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QVariant cppResult = (Shiboken::Object::isUserType(self) ? const_cast<const QStandardItem*>(cppSelf)->::QStandardItem::data(cppArg0) : const_cast<const QStandardItem*>(cppSelf)->data(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QVariant >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QStandardItemFunc_data_TypeError:
        const char* overloads[] = {"int = Qt.UserRole + 1", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QStandardItem.data", overloads);
        return 0;
}

static PyObject* Sbk_QStandardItemFunc_emitDataChanged(PyObject* self)
{
    QStandardItem* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QStandardItem* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // emitDataChanged()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->emitDataChanged();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QStandardItemFunc_flags(PyObject* self)
{
    QStandardItem* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QStandardItem* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // flags()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QFlags<Qt::ItemFlag> cppResult = const_cast<const QStandardItem*>(cppSelf)->flags();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QFlags<Qt::ItemFlag> >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QStandardItemFunc_font(PyObject* self)
{
    QStandardItem* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QStandardItem* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // font()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QFont cppResult = const_cast<const QStandardItem*>(cppSelf)->font();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QFont >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QStandardItemFunc_foreground(PyObject* self)
{
    QStandardItem* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QStandardItem* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // foreground()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QBrush cppResult = const_cast<const QStandardItem*>(cppSelf)->foreground();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QBrush >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QStandardItemFunc_hasChildren(PyObject* self)
{
    QStandardItem* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QStandardItem* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // hasChildren()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QStandardItem*>(cppSelf)->hasChildren();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QStandardItemFunc_icon(PyObject* self)
{
    QStandardItem* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QStandardItem* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // icon()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QIcon cppResult = const_cast<const QStandardItem*>(cppSelf)->icon();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QIcon >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QStandardItemFunc_index(PyObject* self)
{
    QStandardItem* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QStandardItem* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // index()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QModelIndex cppResult = const_cast<const QStandardItem*>(cppSelf)->index();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QModelIndex >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QStandardItemFunc_insertColumn(PyObject* self, PyObject* args)
{
    QStandardItem* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QStandardItem* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "insertColumn", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: insertColumn(int,QList<QStandardItem*>)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && Shiboken::Converter< ::QList<QStandardItem * > >::isConvertible(pyargs[1])) {
        overloadId = 0; // insertColumn(int,QList<QStandardItem*>)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QStandardItemFunc_insertColumn_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            QList<QStandardItem * > cppArg1 = Shiboken::Converter<QList<QStandardItem * > >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // insertColumn(int,QList<QStandardItem*>)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->insertColumn(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                Shiboken::Object::setParent(self, pyargs[1]);
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QStandardItemFunc_insertColumn_TypeError:
        const char* overloads[] = {"int, list", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QStandardItem.insertColumn", overloads);
        return 0;
}

static PyObject* Sbk_QStandardItemFunc_insertColumns(PyObject* self, PyObject* args)
{
    QStandardItem* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QStandardItem* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "insertColumns", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: insertColumns(int,int)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 0; // insertColumns(int,int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QStandardItemFunc_insertColumns_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // insertColumns(int,int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->insertColumns(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QStandardItemFunc_insertColumns_TypeError:
        const char* overloads[] = {"int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QStandardItem.insertColumns", overloads);
        return 0;
}

static PyObject* Sbk_QStandardItemFunc_insertRow(PyObject* self, PyObject* args)
{
    QStandardItem* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QStandardItem* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "insertRow", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: insertRow(int,QStandardItem*)
    // 1: insertRow(int,QList<QStandardItem*>)
    if (SbkNumber_Check(pyargs[0])) {
        if (numArgs == 2 && Shiboken::Converter< ::QStandardItem * >::isConvertible(pyargs[1])) {
            overloadId = 0; // insertRow(int,QStandardItem*)
        } else if (numArgs == 2 && Shiboken::Converter< ::QList<QStandardItem * > >::isConvertible(pyargs[1])) {
            overloadId = 1; // insertRow(int,QList<QStandardItem*>)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QStandardItemFunc_insertRow_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // insertRow(int,QStandardItem*)
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return 0;
                QStandardItem * cppArg1 = Shiboken::Converter<QStandardItem * >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // insertRow(int,QStandardItem*)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->insertRow(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // insertRow(int,QList<QStandardItem*>)
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                QList<QStandardItem * > cppArg1 = Shiboken::Converter<QList<QStandardItem * > >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // insertRow(int,QList<QStandardItem*>)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->insertRow(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    Shiboken::Object::setParent(self, pyargs[1]);
                }
                break;
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QStandardItemFunc_insertRow_TypeError:
        const char* overloads[] = {"int, PySide.QtGui.QStandardItem", "int, list", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QStandardItem.insertRow", overloads);
        return 0;
}

static PyObject* Sbk_QStandardItemFunc_insertRows(PyObject* self, PyObject* args)
{
    QStandardItem* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QStandardItem* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "insertRows", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: insertRows(int,QList<QStandardItem*>)
    // 1: insertRows(int,int)
    if (SbkNumber_Check(pyargs[0])) {
        if (numArgs == 2 && SbkNumber_Check(pyargs[1])) {
            overloadId = 1; // insertRows(int,int)
        } else if (numArgs == 2 && Shiboken::Converter< ::QList<QStandardItem * > >::isConvertible(pyargs[1])) {
            overloadId = 0; // insertRows(int,QList<QStandardItem*>)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QStandardItemFunc_insertRows_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // insertRows(int,QList<QStandardItem*>)
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                QList<QStandardItem * > cppArg1 = Shiboken::Converter<QList<QStandardItem * > >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // insertRows(int,QList<QStandardItem*>)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->insertRows(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    Shiboken::Object::setParent(self, pyargs[1]);
                }
                break;
            }
            case 1: // insertRows(int,int)
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // insertRows(int,int)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->insertRows(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QStandardItemFunc_insertRows_TypeError:
        const char* overloads[] = {"int, list", "int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QStandardItem.insertRows", overloads);
        return 0;
}

static PyObject* Sbk_QStandardItemFunc_isCheckable(PyObject* self)
{
    QStandardItem* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QStandardItem* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isCheckable()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QStandardItem*>(cppSelf)->isCheckable();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QStandardItemFunc_isDragEnabled(PyObject* self)
{
    QStandardItem* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QStandardItem* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isDragEnabled()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QStandardItem*>(cppSelf)->isDragEnabled();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QStandardItemFunc_isDropEnabled(PyObject* self)
{
    QStandardItem* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QStandardItem* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isDropEnabled()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QStandardItem*>(cppSelf)->isDropEnabled();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QStandardItemFunc_isEditable(PyObject* self)
{
    QStandardItem* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QStandardItem* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isEditable()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QStandardItem*>(cppSelf)->isEditable();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QStandardItemFunc_isEnabled(PyObject* self)
{
    QStandardItem* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QStandardItem* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isEnabled()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QStandardItem*>(cppSelf)->isEnabled();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QStandardItemFunc_isSelectable(PyObject* self)
{
    QStandardItem* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QStandardItem* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isSelectable()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QStandardItem*>(cppSelf)->isSelectable();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QStandardItemFunc_isTristate(PyObject* self)
{
    QStandardItem* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QStandardItem* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isTristate()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QStandardItem*>(cppSelf)->isTristate();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QStandardItemFunc_model(PyObject* self)
{
    QStandardItem* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QStandardItem* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // model()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QStandardItemModel * cppResult = const_cast<const QStandardItem*>(cppSelf)->model();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QStandardItemModel * >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QStandardItemFunc_parent(PyObject* self)
{
    QStandardItem* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QStandardItem* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // parent()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QStandardItem * cppResult = const_cast<const QStandardItem*>(cppSelf)->parent();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QStandardItem * >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QStandardItemFunc_read(PyObject* self, PyObject* arg)
{
    QStandardItem* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QStandardItem* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: read(QDataStream&)
    if (Shiboken::Converter< ::QDataStream & >::isConvertible(arg)) {
        overloadId = 0; // read(QDataStream&)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QStandardItemFunc_read_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QDataStream & cppArg0 = Shiboken::Converter<QDataStream & >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // read(QDataStream&)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QStandardItem::read(cppArg0) : cppSelf->read(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QStandardItemFunc_read_TypeError:
        const char* overloads[] = {"PySide.QtCore.QDataStream", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QStandardItem.read", overloads);
        return 0;
}

static PyObject* Sbk_QStandardItemFunc_removeColumn(PyObject* self, PyObject* arg)
{
    QStandardItem* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QStandardItem* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: removeColumn(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // removeColumn(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QStandardItemFunc_removeColumn_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // removeColumn(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->removeColumn(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QStandardItemFunc_removeColumn_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QStandardItem.removeColumn", overloads);
        return 0;
}

static PyObject* Sbk_QStandardItemFunc_removeColumns(PyObject* self, PyObject* args)
{
    QStandardItem* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QStandardItem* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "removeColumns", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: removeColumns(int,int)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 0; // removeColumns(int,int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QStandardItemFunc_removeColumns_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // removeColumns(int,int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->removeColumns(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QStandardItemFunc_removeColumns_TypeError:
        const char* overloads[] = {"int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QStandardItem.removeColumns", overloads);
        return 0;
}

static PyObject* Sbk_QStandardItemFunc_removeRow(PyObject* self, PyObject* arg)
{
    QStandardItem* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QStandardItem* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: removeRow(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // removeRow(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QStandardItemFunc_removeRow_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // removeRow(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->removeRow(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QStandardItemFunc_removeRow_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QStandardItem.removeRow", overloads);
        return 0;
}

static PyObject* Sbk_QStandardItemFunc_removeRows(PyObject* self, PyObject* args)
{
    QStandardItem* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QStandardItem* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "removeRows", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: removeRows(int,int)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 0; // removeRows(int,int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QStandardItemFunc_removeRows_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // removeRows(int,int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->removeRows(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QStandardItemFunc_removeRows_TypeError:
        const char* overloads[] = {"int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QStandardItem.removeRows", overloads);
        return 0;
}

static PyObject* Sbk_QStandardItemFunc_row(PyObject* self)
{
    QStandardItem* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QStandardItem* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // row()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QStandardItem*>(cppSelf)->row();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QStandardItemFunc_rowCount(PyObject* self)
{
    QStandardItem* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QStandardItem* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // rowCount()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QStandardItem*>(cppSelf)->rowCount();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QStandardItemFunc_setAccessibleDescription(PyObject* self, PyObject* arg)
{
    QStandardItem* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QStandardItem* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setAccessibleDescription(QString)
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // setAccessibleDescription(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QStandardItemFunc_setAccessibleDescription_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setAccessibleDescription(QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setAccessibleDescription(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QStandardItemFunc_setAccessibleDescription_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QStandardItem.setAccessibleDescription", overloads);
        return 0;
}

static PyObject* Sbk_QStandardItemFunc_setAccessibleText(PyObject* self, PyObject* arg)
{
    QStandardItem* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QStandardItem* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setAccessibleText(QString)
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // setAccessibleText(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QStandardItemFunc_setAccessibleText_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setAccessibleText(QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setAccessibleText(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QStandardItemFunc_setAccessibleText_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QStandardItem.setAccessibleText", overloads);
        return 0;
}

static PyObject* Sbk_QStandardItemFunc_setBackground(PyObject* self, PyObject* arg)
{
    QStandardItem* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QStandardItem* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setBackground(QBrush)
    if (Shiboken::Converter< ::QBrush >::isConvertible(arg)) {
        overloadId = 0; // setBackground(QBrush)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QStandardItemFunc_setBackground_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QBrush cppArg0 = Shiboken::Converter<QBrush >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setBackground(QBrush)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setBackground(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QStandardItemFunc_setBackground_TypeError:
        const char* overloads[] = {"PySide.QtGui.QBrush", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QStandardItem.setBackground", overloads);
        return 0;
}

static PyObject* Sbk_QStandardItemFunc_setCheckState(PyObject* self, PyObject* arg)
{
    QStandardItem* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QStandardItem* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setCheckState(Qt::CheckState)
    if (Shiboken::Converter< ::Qt::CheckState >::isConvertible(arg)) {
        overloadId = 0; // setCheckState(Qt::CheckState)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QStandardItemFunc_setCheckState_TypeError;

    // Call function/method
    {
        {
            Qt::CheckState cppArg0 = Shiboken::Converter<Qt::CheckState >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setCheckState(Qt::CheckState)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setCheckState(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QStandardItemFunc_setCheckState_TypeError:
        const char* overloads[] = {"PySide.QtCore.Qt.CheckState", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QStandardItem.setCheckState", overloads);
        return 0;
}

static PyObject* Sbk_QStandardItemFunc_setCheckable(PyObject* self, PyObject* arg)
{
    QStandardItem* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QStandardItem* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setCheckable(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setCheckable(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QStandardItemFunc_setCheckable_TypeError;

    // Call function/method
    {
        {
            bool cppArg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setCheckable(bool)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setCheckable(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QStandardItemFunc_setCheckable_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QStandardItem.setCheckable", overloads);
        return 0;
}

static PyObject* Sbk_QStandardItemFunc_setChild(PyObject* self, PyObject* args)
{
    QStandardItem* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QStandardItem* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setChild", 2, 3, &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: setChild(int,QStandardItem*)
    // 1: setChild(int,int,QStandardItem*)
    if (SbkNumber_Check(pyargs[0])) {
        if (numArgs == 3 && SbkNumber_Check(pyargs[1]) && Shiboken::Converter< ::QStandardItem * >::isConvertible(pyargs[2])) {
            overloadId = 1; // setChild(int,int,QStandardItem*)
        } else if (numArgs == 2 && Shiboken::Converter< ::QStandardItem * >::isConvertible(pyargs[1])) {
            overloadId = 0; // setChild(int,QStandardItem*)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QStandardItemFunc_setChild_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // setChild(int,QStandardItem*)
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return 0;
                QStandardItem * cppArg1 = Shiboken::Converter<QStandardItem * >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // setChild(int,QStandardItem*)
                    // Begin code injection

                    // Clear parent from the old child
                    QStandardItem* _i = cppSelf->child(cppArg0);
                    if (_i) {
                        PyObject* _pyI = Shiboken::Converter<QStandardItem* >::toPython(_i);
                        Shiboken::Object::setParent(0, _pyI);
                    }

                    // End of code injection

                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setChild(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS

                    Shiboken::Object::setParent(self, pyargs[1]);
                }
                break;
            }
            case 1: // setChild(int,int,QStandardItem*)
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                if (!Shiboken::Object::isValid(pyargs[2]))
                    return 0;
                QStandardItem * cppArg2 = Shiboken::Converter<QStandardItem * >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                    // setChild(int,int,QStandardItem*)
                    // Begin code injection

                    // Clear parent from the old child
                    QStandardItem* _i = cppSelf->child(cppArg0, cppArg1);
                    if (_i) {
                        PyObject* _pyI = Shiboken::Converter<QStandardItem* >::toPython(_i);
                        Shiboken::Object::setParent(0, _pyI);
                    }

                    // End of code injection

                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setChild(cppArg0, cppArg1, cppArg2);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS

                    Shiboken::Object::setParent(self, pyargs[2]);
                }
                break;
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QStandardItemFunc_setChild_TypeError:
        const char* overloads[] = {"int, PySide.QtGui.QStandardItem", "int, int, PySide.QtGui.QStandardItem", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QStandardItem.setChild", overloads);
        return 0;
}

static PyObject* Sbk_QStandardItemFunc_setColumnCount(PyObject* self, PyObject* arg)
{
    QStandardItem* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QStandardItem* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setColumnCount(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setColumnCount(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QStandardItemFunc_setColumnCount_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setColumnCount(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setColumnCount(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QStandardItemFunc_setColumnCount_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QStandardItem.setColumnCount", overloads);
        return 0;
}

static PyObject* Sbk_QStandardItemFunc_setData(PyObject* self, PyObject* args, PyObject* kwds)
{
    QStandardItem* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QStandardItem* >::toCpp(self);

    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QStandardItem.setData(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QStandardItem.setData(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:setData", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setData(QVariant,int)
    if (Shiboken::Converter< QVariant >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // setData(QVariant,int)
        } else if (SbkNumber_Check(pyargs[1])) {
            overloadId = 0; // setData(QVariant,int)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QStandardItemFunc_setData_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "role");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "role";
                    else if (SbkNumber_Check(value))
                        pyargs[1] = value;
                    else
                        goto Sbk_QStandardItemFunc_setData_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QStandardItem.setData(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QVariant cppArg0 = Shiboken::Converter<QVariant >::toCpp(pyargs[0]);
            int cppArg1 = pyargs[1] ? Shiboken::Converter<int >::toCpp(pyargs[1]) : Qt::UserRole + 1;

            if(!PyErr_Occurred()) {
                // setData(QVariant,int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QStandardItem::setData(cppArg0, cppArg1) : cppSelf->setData(cppArg0, cppArg1));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QStandardItemFunc_setData_TypeError:
        const char* overloads[] = {"QVariant, int = Qt.UserRole + 1", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QStandardItem.setData", overloads);
        return 0;
}

static PyObject* Sbk_QStandardItemFunc_setDragEnabled(PyObject* self, PyObject* arg)
{
    QStandardItem* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QStandardItem* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setDragEnabled(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setDragEnabled(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QStandardItemFunc_setDragEnabled_TypeError;

    // Call function/method
    {
        {
            bool cppArg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setDragEnabled(bool)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setDragEnabled(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QStandardItemFunc_setDragEnabled_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QStandardItem.setDragEnabled", overloads);
        return 0;
}

static PyObject* Sbk_QStandardItemFunc_setDropEnabled(PyObject* self, PyObject* arg)
{
    QStandardItem* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QStandardItem* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setDropEnabled(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setDropEnabled(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QStandardItemFunc_setDropEnabled_TypeError;

    // Call function/method
    {
        {
            bool cppArg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setDropEnabled(bool)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setDropEnabled(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QStandardItemFunc_setDropEnabled_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QStandardItem.setDropEnabled", overloads);
        return 0;
}

static PyObject* Sbk_QStandardItemFunc_setEditable(PyObject* self, PyObject* arg)
{
    QStandardItem* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QStandardItem* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setEditable(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setEditable(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QStandardItemFunc_setEditable_TypeError;

    // Call function/method
    {
        {
            bool cppArg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setEditable(bool)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setEditable(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QStandardItemFunc_setEditable_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QStandardItem.setEditable", overloads);
        return 0;
}

static PyObject* Sbk_QStandardItemFunc_setEnabled(PyObject* self, PyObject* arg)
{
    QStandardItem* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QStandardItem* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setEnabled(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setEnabled(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QStandardItemFunc_setEnabled_TypeError;

    // Call function/method
    {
        {
            bool cppArg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setEnabled(bool)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setEnabled(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QStandardItemFunc_setEnabled_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QStandardItem.setEnabled", overloads);
        return 0;
}

static PyObject* Sbk_QStandardItemFunc_setFlags(PyObject* self, PyObject* arg)
{
    QStandardItem* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QStandardItem* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setFlags(QFlags<Qt::ItemFlag>)
    if (Shiboken::Converter< ::QFlags<Qt::ItemFlag> >::isConvertible(arg)) {
        overloadId = 0; // setFlags(QFlags<Qt::ItemFlag>)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QStandardItemFunc_setFlags_TypeError;

    // Call function/method
    {
        {
            QFlags<Qt::ItemFlag> cppArg0 = Shiboken::Converter<QFlags<Qt::ItemFlag> >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setFlags(QFlags<Qt::ItemFlag>)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setFlags(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QStandardItemFunc_setFlags_TypeError:
        const char* overloads[] = {"PySide.QtCore.Qt.ItemFlags", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QStandardItem.setFlags", overloads);
        return 0;
}

static PyObject* Sbk_QStandardItemFunc_setFont(PyObject* self, PyObject* arg)
{
    QStandardItem* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QStandardItem* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setFont(QFont)
    if (Shiboken::Converter< ::QFont >::isConvertible(arg)) {
        overloadId = 0; // setFont(QFont)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QStandardItemFunc_setFont_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QFont cppArg0 = Shiboken::Converter<QFont >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setFont(QFont)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setFont(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QStandardItemFunc_setFont_TypeError:
        const char* overloads[] = {"PySide.QtGui.QFont", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QStandardItem.setFont", overloads);
        return 0;
}

static PyObject* Sbk_QStandardItemFunc_setForeground(PyObject* self, PyObject* arg)
{
    QStandardItem* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QStandardItem* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setForeground(QBrush)
    if (Shiboken::Converter< ::QBrush >::isConvertible(arg)) {
        overloadId = 0; // setForeground(QBrush)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QStandardItemFunc_setForeground_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QBrush cppArg0 = Shiboken::Converter<QBrush >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setForeground(QBrush)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setForeground(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QStandardItemFunc_setForeground_TypeError:
        const char* overloads[] = {"PySide.QtGui.QBrush", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QStandardItem.setForeground", overloads);
        return 0;
}

static PyObject* Sbk_QStandardItemFunc_setIcon(PyObject* self, PyObject* arg)
{
    QStandardItem* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QStandardItem* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setIcon(QIcon)
    if (Shiboken::Converter< ::QIcon >::isConvertible(arg)) {
        overloadId = 0; // setIcon(QIcon)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QStandardItemFunc_setIcon_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QIcon cppArg0 = Shiboken::Converter<QIcon >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setIcon(QIcon)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setIcon(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QStandardItemFunc_setIcon_TypeError:
        const char* overloads[] = {"PySide.QtGui.QIcon", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QStandardItem.setIcon", overloads);
        return 0;
}

static PyObject* Sbk_QStandardItemFunc_setRowCount(PyObject* self, PyObject* arg)
{
    QStandardItem* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QStandardItem* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setRowCount(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setRowCount(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QStandardItemFunc_setRowCount_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setRowCount(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setRowCount(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QStandardItemFunc_setRowCount_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QStandardItem.setRowCount", overloads);
        return 0;
}

static PyObject* Sbk_QStandardItemFunc_setSelectable(PyObject* self, PyObject* arg)
{
    QStandardItem* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QStandardItem* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setSelectable(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setSelectable(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QStandardItemFunc_setSelectable_TypeError;

    // Call function/method
    {
        {
            bool cppArg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setSelectable(bool)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setSelectable(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QStandardItemFunc_setSelectable_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QStandardItem.setSelectable", overloads);
        return 0;
}

static PyObject* Sbk_QStandardItemFunc_setSizeHint(PyObject* self, PyObject* arg)
{
    QStandardItem* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QStandardItem* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setSizeHint(QSize)
    if (Shiboken::Converter< ::QSize >::isConvertible(arg)) {
        overloadId = 0; // setSizeHint(QSize)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QStandardItemFunc_setSizeHint_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QSize cppArg0 = Shiboken::Converter<QSize >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setSizeHint(QSize)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setSizeHint(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QStandardItemFunc_setSizeHint_TypeError:
        const char* overloads[] = {"PySide.QtCore.QSize", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QStandardItem.setSizeHint", overloads);
        return 0;
}

static PyObject* Sbk_QStandardItemFunc_setStatusTip(PyObject* self, PyObject* arg)
{
    QStandardItem* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QStandardItem* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setStatusTip(QString)
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // setStatusTip(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QStandardItemFunc_setStatusTip_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setStatusTip(QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setStatusTip(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QStandardItemFunc_setStatusTip_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QStandardItem.setStatusTip", overloads);
        return 0;
}

static PyObject* Sbk_QStandardItemFunc_setText(PyObject* self, PyObject* arg)
{
    QStandardItem* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QStandardItem* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setText(QString)
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // setText(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QStandardItemFunc_setText_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setText(QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setText(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QStandardItemFunc_setText_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QStandardItem.setText", overloads);
        return 0;
}

static PyObject* Sbk_QStandardItemFunc_setTextAlignment(PyObject* self, PyObject* arg)
{
    QStandardItem* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QStandardItem* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setTextAlignment(QFlags<Qt::AlignmentFlag>)
    if (Shiboken::Converter< ::QFlags<Qt::AlignmentFlag> >::isConvertible(arg)) {
        overloadId = 0; // setTextAlignment(QFlags<Qt::AlignmentFlag>)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QStandardItemFunc_setTextAlignment_TypeError;

    // Call function/method
    {
        {
            QFlags<Qt::AlignmentFlag> cppArg0 = Shiboken::Converter<QFlags<Qt::AlignmentFlag> >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setTextAlignment(QFlags<Qt::AlignmentFlag>)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setTextAlignment(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QStandardItemFunc_setTextAlignment_TypeError:
        const char* overloads[] = {"PySide.QtCore.Qt.Alignment", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QStandardItem.setTextAlignment", overloads);
        return 0;
}

static PyObject* Sbk_QStandardItemFunc_setToolTip(PyObject* self, PyObject* arg)
{
    QStandardItem* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QStandardItem* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setToolTip(QString)
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // setToolTip(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QStandardItemFunc_setToolTip_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setToolTip(QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setToolTip(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QStandardItemFunc_setToolTip_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QStandardItem.setToolTip", overloads);
        return 0;
}

static PyObject* Sbk_QStandardItemFunc_setTristate(PyObject* self, PyObject* arg)
{
    QStandardItem* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QStandardItem* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setTristate(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setTristate(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QStandardItemFunc_setTristate_TypeError;

    // Call function/method
    {
        {
            bool cppArg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setTristate(bool)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setTristate(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QStandardItemFunc_setTristate_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QStandardItem.setTristate", overloads);
        return 0;
}

static PyObject* Sbk_QStandardItemFunc_setWhatsThis(PyObject* self, PyObject* arg)
{
    QStandardItem* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QStandardItem* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setWhatsThis(QString)
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // setWhatsThis(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QStandardItemFunc_setWhatsThis_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setWhatsThis(QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setWhatsThis(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QStandardItemFunc_setWhatsThis_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QStandardItem.setWhatsThis", overloads);
        return 0;
}

static PyObject* Sbk_QStandardItemFunc_sizeHint(PyObject* self)
{
    QStandardItem* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QStandardItem* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // sizeHint()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QSize cppResult = const_cast<const QStandardItem*>(cppSelf)->sizeHint();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QSize >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QStandardItemFunc_sortChildren(PyObject* self, PyObject* args, PyObject* kwds)
{
    QStandardItem* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QStandardItem* >::toCpp(self);

    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QStandardItem.sortChildren(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QStandardItem.sortChildren(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:sortChildren", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: sortChildren(int,Qt::SortOrder)
    if (SbkNumber_Check(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // sortChildren(int,Qt::SortOrder)
        } else if (Shiboken::Converter< ::Qt::SortOrder >::isConvertible(pyargs[1])) {
            overloadId = 0; // sortChildren(int,Qt::SortOrder)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QStandardItemFunc_sortChildren_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "order");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "order";
                    else if (Shiboken::Converter< ::Qt::SortOrder >::isConvertible(value))
                        pyargs[1] = value;
                    else
                        goto Sbk_QStandardItemFunc_sortChildren_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QStandardItem.sortChildren(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            Qt::SortOrder cppArg1 = pyargs[1] ? Shiboken::Converter<Qt::SortOrder >::toCpp(pyargs[1]) : Qt::AscendingOrder;

            if(!PyErr_Occurred()) {
                // sortChildren(int,Qt::SortOrder)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->sortChildren(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QStandardItemFunc_sortChildren_TypeError:
        const char* overloads[] = {"int, PySide.QtCore.Qt.SortOrder = Qt.AscendingOrder", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QStandardItem.sortChildren", overloads);
        return 0;
}

static PyObject* Sbk_QStandardItemFunc_statusTip(PyObject* self)
{
    QStandardItem* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QStandardItem* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // statusTip()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = const_cast<const QStandardItem*>(cppSelf)->statusTip();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QStandardItemFunc_takeChild(PyObject* self, PyObject* args, PyObject* kwds)
{
    QStandardItem* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QStandardItem* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QStandardItem.takeChild(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QStandardItem.takeChild(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:takeChild", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: takeChild(int,int)
    if (SbkNumber_Check(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // takeChild(int,int)
        } else if (SbkNumber_Check(pyargs[1])) {
            overloadId = 0; // takeChild(int,int)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QStandardItemFunc_takeChild_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "column");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "column";
                    else if (SbkNumber_Check(value))
                        pyargs[1] = value;
                    else
                        goto Sbk_QStandardItemFunc_takeChild_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QStandardItem.takeChild(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            int cppArg1 = pyargs[1] ? Shiboken::Converter<int >::toCpp(pyargs[1]) : 0;

            if(!PyErr_Occurred()) {
                // takeChild(int,int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QStandardItem * cppResult = cppSelf->takeChild(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QStandardItem * >::toPython(cppResult);
                Shiboken::Object::setParent(Py_None, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QStandardItemFunc_takeChild_TypeError:
        const char* overloads[] = {"int, int = 0", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QStandardItem.takeChild", overloads);
        return 0;
}

static PyObject* Sbk_QStandardItemFunc_takeColumn(PyObject* self, PyObject* arg)
{
    QStandardItem* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QStandardItem* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: takeColumn(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // takeColumn(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QStandardItemFunc_takeColumn_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // takeColumn(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QList<QStandardItem * > cppResult = cppSelf->takeColumn(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QList<QStandardItem * > >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QStandardItemFunc_takeColumn_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QStandardItem.takeColumn", overloads);
        return 0;
}

static PyObject* Sbk_QStandardItemFunc_takeRow(PyObject* self, PyObject* arg)
{
    QStandardItem* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QStandardItem* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: takeRow(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // takeRow(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QStandardItemFunc_takeRow_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // takeRow(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QList<QStandardItem * > cppResult = cppSelf->takeRow(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QList<QStandardItem * > >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QStandardItemFunc_takeRow_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QStandardItem.takeRow", overloads);
        return 0;
}

static PyObject* Sbk_QStandardItemFunc_text(PyObject* self)
{
    QStandardItem* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QStandardItem* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // text()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = const_cast<const QStandardItem*>(cppSelf)->text();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QStandardItemFunc_textAlignment(PyObject* self)
{
    QStandardItem* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QStandardItem* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // textAlignment()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QFlags<Qt::AlignmentFlag> cppResult = const_cast<const QStandardItem*>(cppSelf)->textAlignment();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QFlags<Qt::AlignmentFlag> >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QStandardItemFunc_toolTip(PyObject* self)
{
    QStandardItem* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QStandardItem* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // toolTip()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = const_cast<const QStandardItem*>(cppSelf)->toolTip();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QStandardItemFunc_type(PyObject* self)
{
    QStandardItem* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QStandardItem* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // type()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = (Shiboken::Object::isUserType(self) ? const_cast<const QStandardItem*>(cppSelf)->::QStandardItem::type() : const_cast<const QStandardItem*>(cppSelf)->type());
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QStandardItemFunc_whatsThis(PyObject* self)
{
    QStandardItem* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QStandardItem* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // whatsThis()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = const_cast<const QStandardItem*>(cppSelf)->whatsThis();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QStandardItemFunc_write(PyObject* self, PyObject* arg)
{
    QStandardItem* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QStandardItem* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: write(QDataStream&)const
    if (Shiboken::Converter< ::QDataStream & >::isConvertible(arg)) {
        overloadId = 0; // write(QDataStream&)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QStandardItemFunc_write_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QDataStream & cppArg0 = Shiboken::Converter<QDataStream & >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // write(QDataStream&)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? const_cast<const QStandardItem*>(cppSelf)->::QStandardItem::write(cppArg0) : const_cast<const QStandardItem*>(cppSelf)->write(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QStandardItemFunc_write_TypeError:
        const char* overloads[] = {"PySide.QtCore.QDataStream", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QStandardItem.write", overloads);
        return 0;
}

static PyMethodDef Sbk_QStandardItem_methods[] = {
    {"accessibleDescription", (PyCFunction)Sbk_QStandardItemFunc_accessibleDescription, METH_NOARGS},
    {"accessibleText", (PyCFunction)Sbk_QStandardItemFunc_accessibleText, METH_NOARGS},
    {"appendColumn", (PyCFunction)Sbk_QStandardItemFunc_appendColumn, METH_O},
    {"appendRow", (PyCFunction)Sbk_QStandardItemFunc_appendRow, METH_O},
    {"appendRows", (PyCFunction)Sbk_QStandardItemFunc_appendRows, METH_O},
    {"background", (PyCFunction)Sbk_QStandardItemFunc_background, METH_NOARGS},
    {"checkState", (PyCFunction)Sbk_QStandardItemFunc_checkState, METH_NOARGS},
    {"child", (PyCFunction)Sbk_QStandardItemFunc_child, METH_VARARGS|METH_KEYWORDS},
    {"clone", (PyCFunction)Sbk_QStandardItemFunc_clone, METH_NOARGS},
    {"column", (PyCFunction)Sbk_QStandardItemFunc_column, METH_NOARGS},
    {"columnCount", (PyCFunction)Sbk_QStandardItemFunc_columnCount, METH_NOARGS},
    {"data", (PyCFunction)Sbk_QStandardItemFunc_data, METH_VARARGS|METH_KEYWORDS},
    {"emitDataChanged", (PyCFunction)Sbk_QStandardItemFunc_emitDataChanged, METH_NOARGS},
    {"flags", (PyCFunction)Sbk_QStandardItemFunc_flags, METH_NOARGS},
    {"font", (PyCFunction)Sbk_QStandardItemFunc_font, METH_NOARGS},
    {"foreground", (PyCFunction)Sbk_QStandardItemFunc_foreground, METH_NOARGS},
    {"hasChildren", (PyCFunction)Sbk_QStandardItemFunc_hasChildren, METH_NOARGS},
    {"icon", (PyCFunction)Sbk_QStandardItemFunc_icon, METH_NOARGS},
    {"index", (PyCFunction)Sbk_QStandardItemFunc_index, METH_NOARGS},
    {"insertColumn", (PyCFunction)Sbk_QStandardItemFunc_insertColumn, METH_VARARGS},
    {"insertColumns", (PyCFunction)Sbk_QStandardItemFunc_insertColumns, METH_VARARGS},
    {"insertRow", (PyCFunction)Sbk_QStandardItemFunc_insertRow, METH_VARARGS},
    {"insertRows", (PyCFunction)Sbk_QStandardItemFunc_insertRows, METH_VARARGS},
    {"isCheckable", (PyCFunction)Sbk_QStandardItemFunc_isCheckable, METH_NOARGS},
    {"isDragEnabled", (PyCFunction)Sbk_QStandardItemFunc_isDragEnabled, METH_NOARGS},
    {"isDropEnabled", (PyCFunction)Sbk_QStandardItemFunc_isDropEnabled, METH_NOARGS},
    {"isEditable", (PyCFunction)Sbk_QStandardItemFunc_isEditable, METH_NOARGS},
    {"isEnabled", (PyCFunction)Sbk_QStandardItemFunc_isEnabled, METH_NOARGS},
    {"isSelectable", (PyCFunction)Sbk_QStandardItemFunc_isSelectable, METH_NOARGS},
    {"isTristate", (PyCFunction)Sbk_QStandardItemFunc_isTristate, METH_NOARGS},
    {"model", (PyCFunction)Sbk_QStandardItemFunc_model, METH_NOARGS},
    {"parent", (PyCFunction)Sbk_QStandardItemFunc_parent, METH_NOARGS},
    {"read", (PyCFunction)Sbk_QStandardItemFunc_read, METH_O},
    {"removeColumn", (PyCFunction)Sbk_QStandardItemFunc_removeColumn, METH_O},
    {"removeColumns", (PyCFunction)Sbk_QStandardItemFunc_removeColumns, METH_VARARGS},
    {"removeRow", (PyCFunction)Sbk_QStandardItemFunc_removeRow, METH_O},
    {"removeRows", (PyCFunction)Sbk_QStandardItemFunc_removeRows, METH_VARARGS},
    {"row", (PyCFunction)Sbk_QStandardItemFunc_row, METH_NOARGS},
    {"rowCount", (PyCFunction)Sbk_QStandardItemFunc_rowCount, METH_NOARGS},
    {"setAccessibleDescription", (PyCFunction)Sbk_QStandardItemFunc_setAccessibleDescription, METH_O},
    {"setAccessibleText", (PyCFunction)Sbk_QStandardItemFunc_setAccessibleText, METH_O},
    {"setBackground", (PyCFunction)Sbk_QStandardItemFunc_setBackground, METH_O},
    {"setCheckState", (PyCFunction)Sbk_QStandardItemFunc_setCheckState, METH_O},
    {"setCheckable", (PyCFunction)Sbk_QStandardItemFunc_setCheckable, METH_O},
    {"setChild", (PyCFunction)Sbk_QStandardItemFunc_setChild, METH_VARARGS},
    {"setColumnCount", (PyCFunction)Sbk_QStandardItemFunc_setColumnCount, METH_O},
    {"setData", (PyCFunction)Sbk_QStandardItemFunc_setData, METH_VARARGS|METH_KEYWORDS},
    {"setDragEnabled", (PyCFunction)Sbk_QStandardItemFunc_setDragEnabled, METH_O},
    {"setDropEnabled", (PyCFunction)Sbk_QStandardItemFunc_setDropEnabled, METH_O},
    {"setEditable", (PyCFunction)Sbk_QStandardItemFunc_setEditable, METH_O},
    {"setEnabled", (PyCFunction)Sbk_QStandardItemFunc_setEnabled, METH_O},
    {"setFlags", (PyCFunction)Sbk_QStandardItemFunc_setFlags, METH_O},
    {"setFont", (PyCFunction)Sbk_QStandardItemFunc_setFont, METH_O},
    {"setForeground", (PyCFunction)Sbk_QStandardItemFunc_setForeground, METH_O},
    {"setIcon", (PyCFunction)Sbk_QStandardItemFunc_setIcon, METH_O},
    {"setRowCount", (PyCFunction)Sbk_QStandardItemFunc_setRowCount, METH_O},
    {"setSelectable", (PyCFunction)Sbk_QStandardItemFunc_setSelectable, METH_O},
    {"setSizeHint", (PyCFunction)Sbk_QStandardItemFunc_setSizeHint, METH_O},
    {"setStatusTip", (PyCFunction)Sbk_QStandardItemFunc_setStatusTip, METH_O},
    {"setText", (PyCFunction)Sbk_QStandardItemFunc_setText, METH_O},
    {"setTextAlignment", (PyCFunction)Sbk_QStandardItemFunc_setTextAlignment, METH_O},
    {"setToolTip", (PyCFunction)Sbk_QStandardItemFunc_setToolTip, METH_O},
    {"setTristate", (PyCFunction)Sbk_QStandardItemFunc_setTristate, METH_O},
    {"setWhatsThis", (PyCFunction)Sbk_QStandardItemFunc_setWhatsThis, METH_O},
    {"sizeHint", (PyCFunction)Sbk_QStandardItemFunc_sizeHint, METH_NOARGS},
    {"sortChildren", (PyCFunction)Sbk_QStandardItemFunc_sortChildren, METH_VARARGS|METH_KEYWORDS},
    {"statusTip", (PyCFunction)Sbk_QStandardItemFunc_statusTip, METH_NOARGS},
    {"takeChild", (PyCFunction)Sbk_QStandardItemFunc_takeChild, METH_VARARGS|METH_KEYWORDS},
    {"takeColumn", (PyCFunction)Sbk_QStandardItemFunc_takeColumn, METH_O},
    {"takeRow", (PyCFunction)Sbk_QStandardItemFunc_takeRow, METH_O},
    {"text", (PyCFunction)Sbk_QStandardItemFunc_text, METH_NOARGS},
    {"textAlignment", (PyCFunction)Sbk_QStandardItemFunc_textAlignment, METH_NOARGS},
    {"toolTip", (PyCFunction)Sbk_QStandardItemFunc_toolTip, METH_NOARGS},
    {"type", (PyCFunction)Sbk_QStandardItemFunc_type, METH_NOARGS},
    {"whatsThis", (PyCFunction)Sbk_QStandardItemFunc_whatsThis, METH_NOARGS},
    {"write", (PyCFunction)Sbk_QStandardItemFunc_write, METH_O},

    {0} // Sentinel
};

static PyObject* Sbk_QStandardItemFunc___lshift__(PyObject* self, PyObject* arg)
{
    QStandardItem* cppSelf = 0;
    bool isReverse = Shiboken::Converter< ::QStandardItem* >::checkType(arg) && !Shiboken::Converter< ::QStandardItem* >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QStandardItem* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && Shiboken::Object::checkType(arg)
        && !PyObject_TypeCheck(arg, self->ob_type)
        && PyObject_HasAttrString(arg, const_cast<char*>("__rlshift__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(arg, const_cast<char*>("__rlshift__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator<<(QDataStream&,QStandardItem)
    if (isReverse && Shiboken::Converter< ::QDataStream & >::isConvertible(arg)) {
        overloadId = 0; // operator<<(QDataStream&,QStandardItem)
    }

    if (isReverse && overloadId == -1) {
        PyErr_SetString(PyExc_NotImplementedError, "reverse operator not implemented.");
        return 0;
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QStandardItemFunc___lshift___TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QDataStream & cppArg0 = Shiboken::Converter<QDataStream & >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // operator<<(QDataStream&,QStandardItem) [reverse operator]
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QDataStream & cppResult = (cppArg0) << (*cppSelf);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QDataStream & >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    } // End of "if (!pyResult)"


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QStandardItemFunc___lshift___TypeError:
        const char* overloads[] = {"PySide.QtCore.QDataStream", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QStandardItem.__lshift__", overloads);
        return 0;
}

static PyObject* Sbk_QStandardItemFunc___rshift__(PyObject* self, PyObject* arg)
{
    QStandardItem* cppSelf = 0;
    bool isReverse = Shiboken::Converter< ::QStandardItem* >::checkType(arg) && !Shiboken::Converter< ::QStandardItem* >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QStandardItem* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && Shiboken::Object::checkType(arg)
        && !PyObject_TypeCheck(arg, self->ob_type)
        && PyObject_HasAttrString(arg, const_cast<char*>("__rrshift__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(arg, const_cast<char*>("__rrshift__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator>>(QDataStream&,QStandardItem&)
    if (isReverse && Shiboken::Converter< ::QDataStream & >::isConvertible(arg)) {
        overloadId = 0; // operator>>(QDataStream&,QStandardItem&)
    }

    if (isReverse && overloadId == -1) {
        PyErr_SetString(PyExc_NotImplementedError, "reverse operator not implemented.");
        return 0;
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QStandardItemFunc___rshift___TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QDataStream & cppArg0 = Shiboken::Converter<QDataStream & >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // operator>>(QDataStream&,QStandardItem&) [reverse operator]
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QDataStream & cppResult = (cppArg0) >> (*cppSelf);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QDataStream & >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    } // End of "if (!pyResult)"


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QStandardItemFunc___rshift___TypeError:
        const char* overloads[] = {"PySide.QtCore.QDataStream", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QStandardItem.__rshift__", overloads);
        return 0;
}

// type has number operators
static PyNumberMethods Sbk_QStandardItem_as_number = {
    /*nb_add*/                  (binaryfunc)0,
    /*nb_subtract*/             (binaryfunc)0,
    /*nb_multiply*/             (binaryfunc)0,
    /*nb_divide*/               (binaryfunc)0,
    /*nb_remainder*/            (binaryfunc)0,
    /*nb_divmod*/               0,
    /*nb_power*/                0,
    /*nb_negative*/             (unaryfunc)0,
    /*nb_positive*/             (unaryfunc)0,
    /*nb_absolute*/             0,
    /*nb_nonzero*/              0,
    /*nb_invert*/               (unaryfunc)0,
    /*nb_lshift*/               (binaryfunc)Sbk_QStandardItemFunc___lshift__,
    /*nb_rshift*/               (binaryfunc)Sbk_QStandardItemFunc___rshift__,
    /*nb_and*/                  (binaryfunc)0,
    /*nb_xor*/                  (binaryfunc)0,
    /*nb_or*/                   (binaryfunc)0,
    /*nb_coerce*/               0,
    /*nb_int*/                  0,
    /*nb_long*/                 0,
    /*nb_float*/                0,
    /*nb_oct*/                  0,
    /*nb_hex*/                  0,
    /*nb_inplace_add*/          (binaryfunc)0,
    /*nb_inplace_subtract*/     (binaryfunc)0,
    /*nb_inplace_multiply*/     (binaryfunc)0,
    /*nb_inplace_divide*/       (binaryfunc)0,
    /*nb_inplace_remainder*/    (binaryfunc)0,
    /*nb_inplace_power*/        0,
    /*nb_inplace_lshift*/       (binaryfunc)0,
    /*nb_inplace_rshift*/       (binaryfunc)0,
    /*nb_inplace_and*/          (binaryfunc)0,
    /*nb_inplace_xor*/          (binaryfunc)0,
    /*nb_inplace_or*/           (binaryfunc)0,
    /*nb_floor_divide*/         0,
    /*nb_true_divide*/          (binaryfunc)0,
    /*nb_inplace_floor_divide*/ 0,
    /*nb_inplace_true_divide*/  0,
    /*nb_index*/                0
};

// Rich comparison
static PyObject* Sbk_QStandardItem_richcompare(PyObject* self, PyObject* arg, int op)
{
    PyObject* pyResult = 0;
    QStandardItem& cppSelf = *Shiboken::Converter< QStandardItem* >::toCpp(self);

    switch (op) {
        default:
            goto Sbk_QStandardItem_RichComparison_TypeError;
    }

    if (pyResult && !PyErr_Occurred())
        return pyResult;
    Sbk_QStandardItem_RichComparison_TypeError:
    PyErr_SetString(PyExc_NotImplementedError, "operator not implemented.");
    return 0;

}

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QStandardItem_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QStandardItem",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        &Sbk_QStandardItem_as_number,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      Sbk_QStandardItem_richcompare,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QStandardItem_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&SbkObject_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QStandardItem_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern


void init_QStandardItem(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QSTANDARDITEM_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QStandardItem_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QStandardItem_Type);
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QStandardItem_Type, &Shiboken::callCppDestructor<QStandardItem >);
    Py_INCREF((PyObject*)&Sbk_QStandardItem_Type); //Incref due the 'PyModule_AddObject' steals the reference.
    if (PyType_Ready((PyTypeObject*)&Sbk_QStandardItem_Type) < 0)
        return;

    // Fill type discovery information

    Shiboken::ObjectType::setOriginalName(&Sbk_QStandardItem_Type, "QStandardItem*");
    PyModule_AddObject(module, "QStandardItem",
        ((PyObject*)&Sbk_QStandardItem_Type));

    // Initialize enums
    PyObject* enumItem;

    // init enum: ItemType
    PyTypeObject* SbkPySide_QtGui_QStandardItem_ItemType = Shiboken::Enum::newType("PySide.QtGui.QStandardItem.ItemType");
    SbkPySide_QtGuiTypes[SBK_QSTANDARDITEM_ITEMTYPE_IDX] = SbkPySide_QtGui_QStandardItem_ItemType;
    if (PyType_Ready(SbkPySide_QtGui_QStandardItem_ItemType) < 0)
        return;
    PyDict_SetItemString(Sbk_QStandardItem_Type.super.ht_type.tp_dict,
            "ItemType",((PyObject*)SbkPySide_QtGui_QStandardItem_ItemType));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStandardItem_ItemType,(long) QStandardItem::Type, "Type");
    PyDict_SetItemString(Sbk_QStandardItem_Type.super.ht_type.tp_dict,"Type", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStandardItem_ItemType->tp_dict,"Type", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStandardItem_ItemType,(long) QStandardItem::UserType, "UserType");
    PyDict_SetItemString(Sbk_QStandardItem_Type.super.ht_type.tp_dict,"UserType", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStandardItem_ItemType->tp_dict,"UserType", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QStandardItem::ItemType");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::ItemType");
    // end of enum ItemType


    Shiboken::TypeResolver::createObjectTypeResolver<QStandardItem >("QStandardItem*");
    Shiboken::TypeResolver::createObjectTypeResolver<QStandardItem >(typeid(QStandardItem).name());
    Shiboken::TypeResolver::createObjectTypeResolver<QStandardItem >(typeid(QStandardItemWrapper).name());
    qRegisterMetaType< ::QStandardItem* >("QStandardItem*");
    qRegisterMetaType< ::QStandardItem::ItemType >("QStandardItem::ItemType");
}

