/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtgui_python.h"

#include "qstylehintreturn_wrapper.h"

// Extra includes



// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QStyleHintReturn_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QStyleHintReturn >()))
        return -1;

    QStyleHintReturn* cptr = 0;
    int overloadId = -1;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);

    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);

    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QStyleHintReturn(): too many arguments");
        return -1;
    }

    if (!PyArg_ParseTuple(args, "|OO:QStyleHintReturn", &(pyargs[0]), &(pyargs[1])))
        return -1;

    // Overloaded function decisor
    // 0: QStyleHintReturn(int,int)
    if (numArgs == 0) {
        overloadId = 0; // QStyleHintReturn(int,int)
    } else if (SbkNumber_Check(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // QStyleHintReturn(int,int)
        } else if (SbkNumber_Check(pyargs[1])) {
            overloadId = 0; // QStyleHintReturn(int,int)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QStyleHintReturn_Init_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "version");
                if (value) {
                    if (pyargs[0])
                        errorArgName = "version";
                    else if (SbkNumber_Check(value))
                        pyargs[0] = value;
                    else
                        goto Sbk_QStyleHintReturn_Init_TypeError;
                }
                value = PyDict_GetItemString(kwds, "type");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "type";
                    else if (SbkNumber_Check(value))
                        pyargs[1] = value;
                    else
                        goto Sbk_QStyleHintReturn_Init_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QStyleHintReturn(): got multiple values for keyword argument '%s'", errorArgName);
                    return -1;
                }
            }
            int cppArg0 = pyargs[0] ? Shiboken::Converter<int >::toCpp(pyargs[0]) : QStyleOption::Version;
            int cppArg1 = pyargs[1] ? Shiboken::Converter<int >::toCpp(pyargs[1]) : QStyleHintReturn::SH_Default;

            if(!PyErr_Occurred()) {
                // QStyleHintReturn(int,int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new QStyleHintReturn(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QStyleHintReturn >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QStyleHintReturn_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QStyleHintReturn_Init_TypeError:
        const char* overloads[] = {"int = QStyleOption.Version, int = SH_Default", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QStyleHintReturn", overloads);
        return -1;
}

static PyMethodDef Sbk_QStyleHintReturn_methods[] = {

    {0} // Sentinel
};

static PyObject* Sbk_QStyleHintReturn_get_version(PyObject* self, void*)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    PyObject* val = Shiboken::Converter< int >::toPython( Shiboken::Converter< QStyleHintReturn* >::toCpp(self)->version);
    return val;
}

static int Sbk_QStyleHintReturn_set_version(PyObject* self, PyObject* value, void*)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'version' may not be deleted");
        return -1;
    }
    if (!SbkNumber_Check(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'version', 'int' or convertible type expected");
        return -1;
    }

    Shiboken::Converter< QStyleHintReturn* >::toCpp(self)->version = Shiboken::Converter< int >::toCpp(value);

    return 0;
}

static PyObject* Sbk_QStyleHintReturn_get_type(PyObject* self, void*)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    PyObject* val = Shiboken::Converter< int >::toPython( Shiboken::Converter< QStyleHintReturn* >::toCpp(self)->type);
    return val;
}

static int Sbk_QStyleHintReturn_set_type(PyObject* self, PyObject* value, void*)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'type' may not be deleted");
        return -1;
    }
    if (!SbkNumber_Check(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'type', 'int' or convertible type expected");
        return -1;
    }

    Shiboken::Converter< QStyleHintReturn* >::toCpp(self)->type = Shiboken::Converter< int >::toCpp(value);

    return 0;
}

// Getters and Setters for QStyleHintReturn
static PyGetSetDef Sbk_QStyleHintReturn_getsetlist[] = {
    {const_cast<char*>("version"), Sbk_QStyleHintReturn_get_version, Sbk_QStyleHintReturn_set_version},
    {const_cast<char*>("type"), Sbk_QStyleHintReturn_get_type, Sbk_QStyleHintReturn_set_type},
    {0}  // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QStyleHintReturn_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QStyleHintReturn",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QStyleHintReturn_methods,
    /*tp_members*/          0,
    /*tp_getset*/           Sbk_QStyleHintReturn_getsetlist,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&SbkObject_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QStyleHintReturn_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern


void init_QStyleHintReturn(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QSTYLEHINTRETURN_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QStyleHintReturn_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QStyleHintReturn_Type);
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QStyleHintReturn_Type, &Shiboken::callCppDestructor<QStyleHintReturn >);
    Py_INCREF((PyObject*)&Sbk_QStyleHintReturn_Type); //Incref due the 'PyModule_AddObject' steals the reference.
    if (PyType_Ready((PyTypeObject*)&Sbk_QStyleHintReturn_Type) < 0)
        return;

    Shiboken::ObjectType::setOriginalName(&Sbk_QStyleHintReturn_Type, "QStyleHintReturn*");
    PyModule_AddObject(module, "QStyleHintReturn",
        ((PyObject*)&Sbk_QStyleHintReturn_Type));

    // Initialize enums
    PyObject* enumItem;

    // init enum: HintReturnType
    PyTypeObject* SbkPySide_QtGui_QStyleHintReturn_HintReturnType = Shiboken::Enum::newType("PySide.QtGui.QStyleHintReturn.HintReturnType");
    SbkPySide_QtGuiTypes[SBK_QSTYLEHINTRETURN_HINTRETURNTYPE_IDX] = SbkPySide_QtGui_QStyleHintReturn_HintReturnType;
    if (PyType_Ready(SbkPySide_QtGui_QStyleHintReturn_HintReturnType) < 0)
        return;
    PyDict_SetItemString(Sbk_QStyleHintReturn_Type.super.ht_type.tp_dict,
            "HintReturnType",((PyObject*)SbkPySide_QtGui_QStyleHintReturn_HintReturnType));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyleHintReturn_HintReturnType,(long) QStyleHintReturn::SH_Default, "SH_Default");
    PyDict_SetItemString(Sbk_QStyleHintReturn_Type.super.ht_type.tp_dict,"SH_Default", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyleHintReturn_HintReturnType->tp_dict,"SH_Default", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyleHintReturn_HintReturnType,(long) QStyleHintReturn::SH_Mask, "SH_Mask");
    PyDict_SetItemString(Sbk_QStyleHintReturn_Type.super.ht_type.tp_dict,"SH_Mask", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyleHintReturn_HintReturnType->tp_dict,"SH_Mask", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyleHintReturn_HintReturnType,(long) QStyleHintReturn::SH_Variant, "SH_Variant");
    PyDict_SetItemString(Sbk_QStyleHintReturn_Type.super.ht_type.tp_dict,"SH_Variant", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyleHintReturn_HintReturnType->tp_dict,"SH_Variant", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QStyleHintReturn::HintReturnType");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::HintReturnType");
    // end of enum HintReturnType

    // init enum: StyleOptionVersion
    PyTypeObject* SbkPySide_QtGui_QStyleHintReturn_StyleOptionVersion = Shiboken::Enum::newType("PySide.QtGui.QStyleHintReturn.StyleOptionVersion");
    SbkPySide_QtGuiTypes[SBK_QSTYLEHINTRETURN_STYLEOPTIONVERSION_IDX] = SbkPySide_QtGui_QStyleHintReturn_StyleOptionVersion;
    if (PyType_Ready(SbkPySide_QtGui_QStyleHintReturn_StyleOptionVersion) < 0)
        return;
    PyDict_SetItemString(Sbk_QStyleHintReturn_Type.super.ht_type.tp_dict,
            "StyleOptionVersion",((PyObject*)SbkPySide_QtGui_QStyleHintReturn_StyleOptionVersion));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyleHintReturn_StyleOptionVersion,(long) QStyleHintReturn::Version, "Version");
    PyDict_SetItemString(Sbk_QStyleHintReturn_Type.super.ht_type.tp_dict,"Version", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyleHintReturn_StyleOptionVersion->tp_dict,"Version", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QStyleHintReturn::StyleOptionVersion");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::StyleOptionVersion");
    // end of enum StyleOptionVersion

    // init enum: StyleOptionType
    PyTypeObject* SbkPySide_QtGui_QStyleHintReturn_StyleOptionType = Shiboken::Enum::newType("PySide.QtGui.QStyleHintReturn.StyleOptionType");
    SbkPySide_QtGuiTypes[SBK_QSTYLEHINTRETURN_STYLEOPTIONTYPE_IDX] = SbkPySide_QtGui_QStyleHintReturn_StyleOptionType;
    if (PyType_Ready(SbkPySide_QtGui_QStyleHintReturn_StyleOptionType) < 0)
        return;
    PyDict_SetItemString(Sbk_QStyleHintReturn_Type.super.ht_type.tp_dict,
            "StyleOptionType",((PyObject*)SbkPySide_QtGui_QStyleHintReturn_StyleOptionType));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyleHintReturn_StyleOptionType,(long) QStyleHintReturn::Type, "Type");
    PyDict_SetItemString(Sbk_QStyleHintReturn_Type.super.ht_type.tp_dict,"Type", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyleHintReturn_StyleOptionType->tp_dict,"Type", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QStyleHintReturn::StyleOptionType");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::StyleOptionType");
    // end of enum StyleOptionType


    Shiboken::TypeResolver::createObjectTypeResolver<QStyleHintReturn >("QStyleHintReturn*");
    Shiboken::TypeResolver::createObjectTypeResolver<QStyleHintReturn >(typeid(QStyleHintReturn).name());
    qRegisterMetaType< ::QStyleHintReturn* >("QStyleHintReturn*");
    qRegisterMetaType< ::QStyleHintReturn::HintReturnType >("QStyleHintReturn::HintReturnType");
    qRegisterMetaType< ::QStyleHintReturn::StyleOptionVersion >("QStyleHintReturn::StyleOptionVersion");
    qRegisterMetaType< ::QStyleHintReturn::StyleOptionType >("QStyleHintReturn::StyleOptionType");
}

