/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtgui_python.h"

#include "qstyleoption_wrapper.h"

// Extra includes
#include <qstyleoption.h>
#include <qwidget.h>



// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QStyleOption_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QStyleOption >()))
        return -1;

    QStyleOption* cptr = 0;
    int overloadId = -1;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);

    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);

    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QStyleOption(): too many arguments");
        return -1;
    }

    if (!PyArg_ParseTuple(args, "|OO:QStyleOption", &(pyargs[0]), &(pyargs[1])))
        return -1;

    // Overloaded function decisor
    // 0: QStyleOption(QStyleOption)
    // 1: QStyleOption(int,int)
    if (numArgs == 0) {
        overloadId = 1; // QStyleOption(int,int)
    } else if (SbkNumber_Check(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 1; // QStyleOption(int,int)
        } else if (SbkNumber_Check(pyargs[1])) {
            overloadId = 1; // QStyleOption(int,int)
        }
    } else if (numArgs == 1 && Shiboken::Converter< ::QStyleOption >::isConvertible(pyargs[0])) {
        overloadId = 0; // QStyleOption(QStyleOption)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QStyleOption_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QStyleOption(QStyleOption)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QStyleOption cppArg0 = Shiboken::Converter<QStyleOption >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QStyleOption(QStyleOption)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QStyleOption(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // QStyleOption(int,int)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "version");
                    if (value) {
                        if (pyargs[0])
                            errorArgName = "version";
                        else if (SbkNumber_Check(value))
                            pyargs[0] = value;
                        else
                            goto Sbk_QStyleOption_Init_TypeError;
                    }
                    value = PyDict_GetItemString(kwds, "type");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "type";
                        else if (SbkNumber_Check(value))
                            pyargs[1] = value;
                        else
                            goto Sbk_QStyleOption_Init_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QStyleOption(): got multiple values for keyword argument '%s'", errorArgName);
                        return -1;
                    }
                }
                int cppArg0 = pyargs[0] ? Shiboken::Converter<int >::toCpp(pyargs[0]) : QStyleOption::Version;
                int cppArg1 = pyargs[1] ? Shiboken::Converter<int >::toCpp(pyargs[1]) : QStyleOption::SO_Default;

                if(!PyErr_Occurred()) {
                    // QStyleOption(int,int)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QStyleOption(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QStyleOption >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QStyleOption_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QStyleOption_Init_TypeError:
        const char* overloads[] = {"PySide.QtGui.QStyleOption", "int = QStyleOption.Version, int = SO_Default", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QStyleOption", overloads);
        return -1;
}

static PyObject* Sbk_QStyleOptionFunc_initFrom(PyObject* self, PyObject* arg)
{
    QStyleOption* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QStyleOption* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: initFrom(const QWidget*)
    if (Shiboken::Converter< ::QWidget * >::isConvertible(arg)) {
        overloadId = 0; // initFrom(const QWidget*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QStyleOptionFunc_initFrom_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QWidget * cppArg0 = Shiboken::Converter<QWidget * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // initFrom(const QWidget*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->initFrom(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QStyleOptionFunc_initFrom_TypeError:
        const char* overloads[] = {"PySide.QtGui.QWidget", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QStyleOption.initFrom", overloads);
        return 0;
}

static PyObject *Sbk_QStyleOption___copy__(PyObject *self)
{
        QStyleOption* cppSelf = 0;
        if (!Shiboken::Object::isValid(self))
            return 0;
        cppSelf = Shiboken::Converter<QStyleOption*>::toCpp(self);
        PyObject* pyResult = 0;
        QStyleOption* copy = new QStyleOption(*cppSelf);
        pyResult = Shiboken::Converter<QStyleOption*>::toPython(copy);
        Shiboken::Object::getOwnership(pyResult);

        if (PyErr_Occurred() || !pyResult) {
            Py_XDECREF(pyResult);
            return 0;
        }
        return pyResult;
}

static PyMethodDef Sbk_QStyleOption_methods[] = {
    {"initFrom", (PyCFunction)Sbk_QStyleOptionFunc_initFrom, METH_O},

    {"__copy__", (PyCFunction)Sbk_QStyleOption___copy__, METH_NOARGS},
    {0} // Sentinel
};

static PyObject* Sbk_QStyleOption_get_palette(PyObject* self, void*)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    PyObject* val = Shiboken::createWrapper(&Shiboken::Converter< QStyleOption* >::toCpp(self)->palette);
    Shiboken::Object::releaseOwnership(val);
    Shiboken::Object::setParent(self, val);
    return val;
}

static int Sbk_QStyleOption_set_palette(PyObject* self, PyObject* value, void*)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'palette' may not be deleted");
        return -1;
    }
    if (!Shiboken::Converter< ::QPalette >::isConvertible(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'palette', 'QPalette' or convertible type expected");
        return -1;
    }

    Shiboken::Converter< QStyleOption* >::toCpp(self)->palette = Shiboken::Converter< ::QPalette >::toCpp(value);

    return 0;
}

static PyObject* Sbk_QStyleOption_get_version(PyObject* self, void*)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    PyObject* val = Shiboken::Converter< int >::toPython( Shiboken::Converter< QStyleOption* >::toCpp(self)->version);
    return val;
}

static int Sbk_QStyleOption_set_version(PyObject* self, PyObject* value, void*)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'version' may not be deleted");
        return -1;
    }
    if (!SbkNumber_Check(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'version', 'int' or convertible type expected");
        return -1;
    }

    Shiboken::Converter< QStyleOption* >::toCpp(self)->version = Shiboken::Converter< int >::toCpp(value);

    return 0;
}

static PyObject* Sbk_QStyleOption_get_direction(PyObject* self, void*)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    PyObject* val = Shiboken::Converter< ::Qt::LayoutDirection >::toPython( Shiboken::Converter< QStyleOption* >::toCpp(self)->direction);
    return val;
}

static int Sbk_QStyleOption_set_direction(PyObject* self, PyObject* value, void*)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'direction' may not be deleted");
        return -1;
    }
    if (!Shiboken::Converter< ::Qt::LayoutDirection >::isConvertible(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'direction', 'LayoutDirection' or convertible type expected");
        return -1;
    }

    Shiboken::Converter< QStyleOption* >::toCpp(self)->direction = Shiboken::Converter< ::Qt::LayoutDirection >::toCpp(value);

    return 0;
}

static PyObject* Sbk_QStyleOption_get_rect(PyObject* self, void*)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    PyObject* val = Shiboken::createWrapper(&Shiboken::Converter< QStyleOption* >::toCpp(self)->rect);
    Shiboken::Object::releaseOwnership(val);
    Shiboken::Object::setParent(self, val);
    return val;
}

static int Sbk_QStyleOption_set_rect(PyObject* self, PyObject* value, void*)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'rect' may not be deleted");
        return -1;
    }
    if (!Shiboken::Converter< ::QRect >::isConvertible(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'rect', 'QRect' or convertible type expected");
        return -1;
    }

    Shiboken::Converter< QStyleOption* >::toCpp(self)->rect = Shiboken::Converter< ::QRect >::toCpp(value);

    return 0;
}

static PyObject* Sbk_QStyleOption_get_type(PyObject* self, void*)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    PyObject* val = Shiboken::Converter< int >::toPython( Shiboken::Converter< QStyleOption* >::toCpp(self)->type);
    return val;
}

static int Sbk_QStyleOption_set_type(PyObject* self, PyObject* value, void*)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'type' may not be deleted");
        return -1;
    }
    if (!SbkNumber_Check(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'type', 'int' or convertible type expected");
        return -1;
    }

    Shiboken::Converter< QStyleOption* >::toCpp(self)->type = Shiboken::Converter< int >::toCpp(value);

    return 0;
}

static PyObject* Sbk_QStyleOption_get_state(PyObject* self, void*)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    PyObject* val = Shiboken::Converter< ::QFlags<QStyle::StateFlag> >::toPython( Shiboken::Converter< QStyleOption* >::toCpp(self)->state);
    return val;
}

static int Sbk_QStyleOption_set_state(PyObject* self, PyObject* value, void*)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'state' may not be deleted");
        return -1;
    }
    if (!Shiboken::Converter< ::QFlags<QStyle::StateFlag> >::isConvertible(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'state', 'State' or convertible type expected");
        return -1;
    }

    Shiboken::Converter< QStyleOption* >::toCpp(self)->state = Shiboken::Converter< ::QFlags<QStyle::StateFlag> >::toCpp(value);

    return 0;
}

static PyObject* Sbk_QStyleOption_get_fontMetrics(PyObject* self, void*)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    PyObject* val = Shiboken::createWrapper(&Shiboken::Converter< QStyleOption* >::toCpp(self)->fontMetrics);
    Shiboken::Object::releaseOwnership(val);
    Shiboken::Object::setParent(self, val);
    return val;
}

static int Sbk_QStyleOption_set_fontMetrics(PyObject* self, PyObject* value, void*)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'fontMetrics' may not be deleted");
        return -1;
    }
    if (!Shiboken::Converter< ::QFontMetrics >::isConvertible(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'fontMetrics', 'QFontMetrics' or convertible type expected");
        return -1;
    }

    Shiboken::Converter< QStyleOption* >::toCpp(self)->fontMetrics = Shiboken::Converter< ::QFontMetrics >::toCpp(value);

    return 0;
}

// Getters and Setters for QStyleOption
static PyGetSetDef Sbk_QStyleOption_getsetlist[] = {
    {const_cast<char*>("palette"), Sbk_QStyleOption_get_palette, Sbk_QStyleOption_set_palette},
    {const_cast<char*>("version"), Sbk_QStyleOption_get_version, Sbk_QStyleOption_set_version},
    {const_cast<char*>("direction"), Sbk_QStyleOption_get_direction, Sbk_QStyleOption_set_direction},
    {const_cast<char*>("rect"), Sbk_QStyleOption_get_rect, Sbk_QStyleOption_set_rect},
    {const_cast<char*>("type"), Sbk_QStyleOption_get_type, Sbk_QStyleOption_set_type},
    {const_cast<char*>("state"), Sbk_QStyleOption_get_state, Sbk_QStyleOption_set_state},
    {const_cast<char*>("fontMetrics"), Sbk_QStyleOption_get_fontMetrics, Sbk_QStyleOption_set_fontMetrics},
    {0}  // Sentinel
};

} // extern "C"

extern "C"
{
static PyObject* Sbk_QStyleOption__repr__(PyObject* pyObj)
{
    QBuffer buffer;
    buffer.open(QBuffer::ReadWrite);
    QDebug dbg(&buffer);
    dbg << Shiboken::Converter< ::QStyleOption >::toCpp(pyObj);
    buffer.close();
    return PyString_FromFormat("<PySide.QtGui.%s at %p>", buffer.data().constData(), pyObj);
}
} // extern C

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QStyleOption_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QStyleOption",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Sbk_QStyleOption__repr__,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QStyleOption_methods,
    /*tp_members*/          0,
    /*tp_getset*/           Sbk_QStyleOption_getsetlist,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&SbkObject_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QStyleOption_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern


void init_QStyleOption(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QSTYLEOPTION_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QStyleOption_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QStyleOption_Type);
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QStyleOption_Type, &Shiboken::callCppDestructor<QStyleOption >);
    Py_INCREF((PyObject*)&Sbk_QStyleOption_Type); //Incref due the 'PyModule_AddObject' steals the reference.
    if (PyType_Ready((PyTypeObject*)&Sbk_QStyleOption_Type) < 0)
        return;

    Shiboken::ObjectType::setOriginalName(&Sbk_QStyleOption_Type, "QStyleOption");
    PyModule_AddObject(module, "QStyleOption",
        ((PyObject*)&Sbk_QStyleOption_Type));

    // Initialize enums
    PyObject* enumItem;

    // init enum: StyleOptionVersion
    PyTypeObject* SbkPySide_QtGui_QStyleOption_StyleOptionVersion = Shiboken::Enum::newType("PySide.QtGui.QStyleOption.StyleOptionVersion");
    SbkPySide_QtGuiTypes[SBK_QSTYLEOPTION_STYLEOPTIONVERSION_IDX] = SbkPySide_QtGui_QStyleOption_StyleOptionVersion;
    if (PyType_Ready(SbkPySide_QtGui_QStyleOption_StyleOptionVersion) < 0)
        return;
    PyDict_SetItemString(Sbk_QStyleOption_Type.super.ht_type.tp_dict,
            "StyleOptionVersion",((PyObject*)SbkPySide_QtGui_QStyleOption_StyleOptionVersion));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyleOption_StyleOptionVersion,(long) QStyleOption::Version, "Version");
    PyDict_SetItemString(Sbk_QStyleOption_Type.super.ht_type.tp_dict,"Version", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyleOption_StyleOptionVersion->tp_dict,"Version", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QStyleOption::StyleOptionVersion");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::StyleOptionVersion");
    // end of enum StyleOptionVersion

    // init enum: StyleOptionType
    PyTypeObject* SbkPySide_QtGui_QStyleOption_StyleOptionType = Shiboken::Enum::newType("PySide.QtGui.QStyleOption.StyleOptionType");
    SbkPySide_QtGuiTypes[SBK_QSTYLEOPTION_STYLEOPTIONTYPE_IDX] = SbkPySide_QtGui_QStyleOption_StyleOptionType;
    if (PyType_Ready(SbkPySide_QtGui_QStyleOption_StyleOptionType) < 0)
        return;
    PyDict_SetItemString(Sbk_QStyleOption_Type.super.ht_type.tp_dict,
            "StyleOptionType",((PyObject*)SbkPySide_QtGui_QStyleOption_StyleOptionType));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyleOption_StyleOptionType,(long) QStyleOption::Type, "Type");
    PyDict_SetItemString(Sbk_QStyleOption_Type.super.ht_type.tp_dict,"Type", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyleOption_StyleOptionType->tp_dict,"Type", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QStyleOption::StyleOptionType");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::StyleOptionType");
    // end of enum StyleOptionType

    // init enum: OptionType
    PyTypeObject* SbkPySide_QtGui_QStyleOption_OptionType = Shiboken::Enum::newType("PySide.QtGui.QStyleOption.OptionType");
    SbkPySide_QtGuiTypes[SBK_QSTYLEOPTION_OPTIONTYPE_IDX] = SbkPySide_QtGui_QStyleOption_OptionType;
    if (PyType_Ready(SbkPySide_QtGui_QStyleOption_OptionType) < 0)
        return;
    PyDict_SetItemString(Sbk_QStyleOption_Type.super.ht_type.tp_dict,
            "OptionType",((PyObject*)SbkPySide_QtGui_QStyleOption_OptionType));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyleOption_OptionType,(long) QStyleOption::SO_Default, "SO_Default");
    PyDict_SetItemString(Sbk_QStyleOption_Type.super.ht_type.tp_dict,"SO_Default", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyleOption_OptionType->tp_dict,"SO_Default", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyleOption_OptionType,(long) QStyleOption::SO_FocusRect, "SO_FocusRect");
    PyDict_SetItemString(Sbk_QStyleOption_Type.super.ht_type.tp_dict,"SO_FocusRect", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyleOption_OptionType->tp_dict,"SO_FocusRect", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyleOption_OptionType,(long) QStyleOption::SO_Button, "SO_Button");
    PyDict_SetItemString(Sbk_QStyleOption_Type.super.ht_type.tp_dict,"SO_Button", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyleOption_OptionType->tp_dict,"SO_Button", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyleOption_OptionType,(long) QStyleOption::SO_Tab, "SO_Tab");
    PyDict_SetItemString(Sbk_QStyleOption_Type.super.ht_type.tp_dict,"SO_Tab", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyleOption_OptionType->tp_dict,"SO_Tab", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyleOption_OptionType,(long) QStyleOption::SO_MenuItem, "SO_MenuItem");
    PyDict_SetItemString(Sbk_QStyleOption_Type.super.ht_type.tp_dict,"SO_MenuItem", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyleOption_OptionType->tp_dict,"SO_MenuItem", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyleOption_OptionType,(long) QStyleOption::SO_Frame, "SO_Frame");
    PyDict_SetItemString(Sbk_QStyleOption_Type.super.ht_type.tp_dict,"SO_Frame", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyleOption_OptionType->tp_dict,"SO_Frame", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyleOption_OptionType,(long) QStyleOption::SO_ProgressBar, "SO_ProgressBar");
    PyDict_SetItemString(Sbk_QStyleOption_Type.super.ht_type.tp_dict,"SO_ProgressBar", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyleOption_OptionType->tp_dict,"SO_ProgressBar", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyleOption_OptionType,(long) QStyleOption::SO_ToolBox, "SO_ToolBox");
    PyDict_SetItemString(Sbk_QStyleOption_Type.super.ht_type.tp_dict,"SO_ToolBox", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyleOption_OptionType->tp_dict,"SO_ToolBox", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyleOption_OptionType,(long) QStyleOption::SO_Header, "SO_Header");
    PyDict_SetItemString(Sbk_QStyleOption_Type.super.ht_type.tp_dict,"SO_Header", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyleOption_OptionType->tp_dict,"SO_Header", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyleOption_OptionType,(long) QStyleOption::SO_Q3DockWindow, "SO_Q3DockWindow");
    PyDict_SetItemString(Sbk_QStyleOption_Type.super.ht_type.tp_dict,"SO_Q3DockWindow", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyleOption_OptionType->tp_dict,"SO_Q3DockWindow", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyleOption_OptionType,(long) QStyleOption::SO_DockWidget, "SO_DockWidget");
    PyDict_SetItemString(Sbk_QStyleOption_Type.super.ht_type.tp_dict,"SO_DockWidget", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyleOption_OptionType->tp_dict,"SO_DockWidget", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyleOption_OptionType,(long) QStyleOption::SO_Q3ListViewItem, "SO_Q3ListViewItem");
    PyDict_SetItemString(Sbk_QStyleOption_Type.super.ht_type.tp_dict,"SO_Q3ListViewItem", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyleOption_OptionType->tp_dict,"SO_Q3ListViewItem", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyleOption_OptionType,(long) QStyleOption::SO_ViewItem, "SO_ViewItem");
    PyDict_SetItemString(Sbk_QStyleOption_Type.super.ht_type.tp_dict,"SO_ViewItem", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyleOption_OptionType->tp_dict,"SO_ViewItem", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyleOption_OptionType,(long) QStyleOption::SO_TabWidgetFrame, "SO_TabWidgetFrame");
    PyDict_SetItemString(Sbk_QStyleOption_Type.super.ht_type.tp_dict,"SO_TabWidgetFrame", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyleOption_OptionType->tp_dict,"SO_TabWidgetFrame", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyleOption_OptionType,(long) QStyleOption::SO_TabBarBase, "SO_TabBarBase");
    PyDict_SetItemString(Sbk_QStyleOption_Type.super.ht_type.tp_dict,"SO_TabBarBase", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyleOption_OptionType->tp_dict,"SO_TabBarBase", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyleOption_OptionType,(long) QStyleOption::SO_RubberBand, "SO_RubberBand");
    PyDict_SetItemString(Sbk_QStyleOption_Type.super.ht_type.tp_dict,"SO_RubberBand", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyleOption_OptionType->tp_dict,"SO_RubberBand", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyleOption_OptionType,(long) QStyleOption::SO_ToolBar, "SO_ToolBar");
    PyDict_SetItemString(Sbk_QStyleOption_Type.super.ht_type.tp_dict,"SO_ToolBar", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyleOption_OptionType->tp_dict,"SO_ToolBar", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyleOption_OptionType,(long) QStyleOption::SO_GraphicsItem, "SO_GraphicsItem");
    PyDict_SetItemString(Sbk_QStyleOption_Type.super.ht_type.tp_dict,"SO_GraphicsItem", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyleOption_OptionType->tp_dict,"SO_GraphicsItem", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyleOption_OptionType,(long) QStyleOption::SO_Complex, "SO_Complex");
    PyDict_SetItemString(Sbk_QStyleOption_Type.super.ht_type.tp_dict,"SO_Complex", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyleOption_OptionType->tp_dict,"SO_Complex", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyleOption_OptionType,(long) QStyleOption::SO_Slider, "SO_Slider");
    PyDict_SetItemString(Sbk_QStyleOption_Type.super.ht_type.tp_dict,"SO_Slider", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyleOption_OptionType->tp_dict,"SO_Slider", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyleOption_OptionType,(long) QStyleOption::SO_SpinBox, "SO_SpinBox");
    PyDict_SetItemString(Sbk_QStyleOption_Type.super.ht_type.tp_dict,"SO_SpinBox", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyleOption_OptionType->tp_dict,"SO_SpinBox", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyleOption_OptionType,(long) QStyleOption::SO_ToolButton, "SO_ToolButton");
    PyDict_SetItemString(Sbk_QStyleOption_Type.super.ht_type.tp_dict,"SO_ToolButton", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyleOption_OptionType->tp_dict,"SO_ToolButton", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyleOption_OptionType,(long) QStyleOption::SO_ComboBox, "SO_ComboBox");
    PyDict_SetItemString(Sbk_QStyleOption_Type.super.ht_type.tp_dict,"SO_ComboBox", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyleOption_OptionType->tp_dict,"SO_ComboBox", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyleOption_OptionType,(long) QStyleOption::SO_Q3ListView, "SO_Q3ListView");
    PyDict_SetItemString(Sbk_QStyleOption_Type.super.ht_type.tp_dict,"SO_Q3ListView", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyleOption_OptionType->tp_dict,"SO_Q3ListView", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyleOption_OptionType,(long) QStyleOption::SO_TitleBar, "SO_TitleBar");
    PyDict_SetItemString(Sbk_QStyleOption_Type.super.ht_type.tp_dict,"SO_TitleBar", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyleOption_OptionType->tp_dict,"SO_TitleBar", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyleOption_OptionType,(long) QStyleOption::SO_GroupBox, "SO_GroupBox");
    PyDict_SetItemString(Sbk_QStyleOption_Type.super.ht_type.tp_dict,"SO_GroupBox", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyleOption_OptionType->tp_dict,"SO_GroupBox", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyleOption_OptionType,(long) QStyleOption::SO_SizeGrip, "SO_SizeGrip");
    PyDict_SetItemString(Sbk_QStyleOption_Type.super.ht_type.tp_dict,"SO_SizeGrip", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyleOption_OptionType->tp_dict,"SO_SizeGrip", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyleOption_OptionType,(long) QStyleOption::SO_CustomBase, "SO_CustomBase");
    PyDict_SetItemString(Sbk_QStyleOption_Type.super.ht_type.tp_dict,"SO_CustomBase", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyleOption_OptionType->tp_dict,"SO_CustomBase", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyleOption_OptionType,(long) QStyleOption::SO_ComplexCustomBase, "SO_ComplexCustomBase");
    PyDict_SetItemString(Sbk_QStyleOption_Type.super.ht_type.tp_dict,"SO_ComplexCustomBase", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyleOption_OptionType->tp_dict,"SO_ComplexCustomBase", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QStyleOption::OptionType");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::OptionType");
    // end of enum OptionType


    Shiboken::TypeResolver::createValueTypeResolver<QStyleOption >("QStyleOption");
    Shiboken::TypeResolver::createObjectTypeResolver<QStyleOption >("QStyleOption*");
    Shiboken::TypeResolver::createValueTypeResolver<QStyleOption >(typeid(QStyleOption).name());
    qRegisterMetaType< ::QStyleOption* >("QStyleOption*");
    qRegisterMetaType< ::QStyleOption::StyleOptionVersion >("QStyleOption::StyleOptionVersion");
    qRegisterMetaType< ::QStyleOption::StyleOptionType >("QStyleOption::StyleOptionType");
    qRegisterMetaType< ::QStyleOption::OptionType >("QStyleOption::OptionType");
}

