/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtgui_python.h"

#include "qstyleoptionspinbox_wrapper.h"

// Extra includes
#include <qstyleoption.h>
#include <qwidget.h>



// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QStyleOptionSpinBox_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QStyleOptionSpinBox >()))
        return -1;

    QStyleOptionSpinBox* cptr = 0;
    int overloadId = -1;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QStyleOptionSpinBox", 0, 1, &(pyargs[0])))
        return -1;

    // Overloaded function decisor
    // 0: QStyleOptionSpinBox()
    // 1: QStyleOptionSpinBox(QStyleOptionSpinBox)
    // 2: QStyleOptionSpinBox(int)
    if (numArgs == 0) {
        overloadId = 0; // QStyleOptionSpinBox()
    } else if (numArgs == 1 && SbkNumber_Check(pyargs[0])) {
        overloadId = 2; // QStyleOptionSpinBox(int)
    } else if (numArgs == 1 && Shiboken::Converter< ::QStyleOptionSpinBox >::isConvertible(pyargs[0])) {
        overloadId = 1; // QStyleOptionSpinBox(QStyleOptionSpinBox)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QStyleOptionSpinBox_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QStyleOptionSpinBox()
            {

                if(!PyErr_Occurred()) {
                    // QStyleOptionSpinBox()
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QStyleOptionSpinBox();
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // QStyleOptionSpinBox(QStyleOptionSpinBox)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QStyleOptionSpinBox cppArg0 = Shiboken::Converter<QStyleOptionSpinBox >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QStyleOptionSpinBox(QStyleOptionSpinBox)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QStyleOptionSpinBox(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 2: // QStyleOptionSpinBox(int)
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QStyleOptionSpinBox(int)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QStyleOptionSpinBox(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QStyleOptionSpinBox >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QStyleOptionSpinBox_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QStyleOptionSpinBox_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtGui.QStyleOptionSpinBox", "int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QStyleOptionSpinBox", overloads);
        return -1;
}

static PyObject *Sbk_QStyleOptionSpinBox___copy__(PyObject *self)
{
        QStyleOptionSpinBox* cppSelf = 0;
        if (!Shiboken::Object::isValid(self))
            return 0;
        cppSelf = Shiboken::Converter<QStyleOptionSpinBox*>::toCpp(self);
        PyObject* pyResult = 0;
        QStyleOptionSpinBox* copy = new QStyleOptionSpinBox(*cppSelf);
        pyResult = Shiboken::Converter<QStyleOptionSpinBox*>::toPython(copy);
        Shiboken::Object::getOwnership(pyResult);

        if (PyErr_Occurred() || !pyResult) {
            Py_XDECREF(pyResult);
            return 0;
        }
        return pyResult;
}

static PyMethodDef Sbk_QStyleOptionSpinBox_methods[] = {

    {"__copy__", (PyCFunction)Sbk_QStyleOptionSpinBox___copy__, METH_NOARGS},
    {0} // Sentinel
};

static PyObject* Sbk_QStyleOptionSpinBox_get_stepEnabled(PyObject* self, void*)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    PyObject* val = Shiboken::Converter< ::QFlags<QAbstractSpinBox::StepEnabledFlag> >::toPython( Shiboken::Converter< QStyleOptionSpinBox* >::toCpp(self)->stepEnabled);
    return val;
}

static int Sbk_QStyleOptionSpinBox_set_stepEnabled(PyObject* self, PyObject* value, void*)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'stepEnabled' may not be deleted");
        return -1;
    }
    if (!Shiboken::Converter< ::QFlags<QAbstractSpinBox::StepEnabledFlag> >::isConvertible(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'stepEnabled', 'StepEnabled' or convertible type expected");
        return -1;
    }

    Shiboken::Converter< QStyleOptionSpinBox* >::toCpp(self)->stepEnabled = Shiboken::Converter< ::QFlags<QAbstractSpinBox::StepEnabledFlag> >::toCpp(value);

    return 0;
}

static PyObject* Sbk_QStyleOptionSpinBox_get_buttonSymbols(PyObject* self, void*)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    PyObject* val = Shiboken::Converter< ::QAbstractSpinBox::ButtonSymbols >::toPython( Shiboken::Converter< QStyleOptionSpinBox* >::toCpp(self)->buttonSymbols);
    return val;
}

static int Sbk_QStyleOptionSpinBox_set_buttonSymbols(PyObject* self, PyObject* value, void*)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'buttonSymbols' may not be deleted");
        return -1;
    }
    if (!Shiboken::Converter< ::QAbstractSpinBox::ButtonSymbols >::isConvertible(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'buttonSymbols', 'ButtonSymbols' or convertible type expected");
        return -1;
    }

    Shiboken::Converter< QStyleOptionSpinBox* >::toCpp(self)->buttonSymbols = Shiboken::Converter< ::QAbstractSpinBox::ButtonSymbols >::toCpp(value);

    return 0;
}

static PyObject* Sbk_QStyleOptionSpinBox_get_frame(PyObject* self, void*)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    PyObject* val = Shiboken::Converter< bool >::toPython( Shiboken::Converter< QStyleOptionSpinBox* >::toCpp(self)->frame);
    return val;
}

static int Sbk_QStyleOptionSpinBox_set_frame(PyObject* self, PyObject* value, void*)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'frame' may not be deleted");
        return -1;
    }
    if (!SbkNumber_Check(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'frame', 'bool' or convertible type expected");
        return -1;
    }

    Shiboken::Converter< QStyleOptionSpinBox* >::toCpp(self)->frame = Shiboken::Converter< bool >::toCpp(value);

    return 0;
}

// Getters and Setters for QStyleOptionSpinBox
static PyGetSetDef Sbk_QStyleOptionSpinBox_getsetlist[] = {
    {const_cast<char*>("stepEnabled"), Sbk_QStyleOptionSpinBox_get_stepEnabled, Sbk_QStyleOptionSpinBox_set_stepEnabled},
    {const_cast<char*>("buttonSymbols"), Sbk_QStyleOptionSpinBox_get_buttonSymbols, Sbk_QStyleOptionSpinBox_set_buttonSymbols},
    {const_cast<char*>("frame"), Sbk_QStyleOptionSpinBox_get_frame, Sbk_QStyleOptionSpinBox_set_frame},
    {0}  // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QStyleOptionSpinBox_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QStyleOptionSpinBox",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QStyleOptionSpinBox_methods,
    /*tp_members*/          0,
    /*tp_getset*/           Sbk_QStyleOptionSpinBox_getsetlist,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QStyleOptionSpinBox_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern


void init_QStyleOptionSpinBox(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONSPINBOX_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QStyleOptionSpinBox_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QStyleOptionSpinBox_Type);
    Sbk_QStyleOptionSpinBox_Type.super.ht_type.tp_base = SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONCOMPLEX_IDX];
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QStyleOptionSpinBox_Type, &Shiboken::callCppDestructor<QStyleOptionSpinBox >);
    Py_INCREF((PyObject*)&Sbk_QStyleOptionSpinBox_Type); //Incref due the 'PyModule_AddObject' steals the reference.
    if (PyType_Ready((PyTypeObject*)&Sbk_QStyleOptionSpinBox_Type) < 0)
        return;

    Shiboken::ObjectType::setOriginalName(&Sbk_QStyleOptionSpinBox_Type, "QStyleOptionSpinBox");
    PyModule_AddObject(module, "QStyleOptionSpinBox",
        ((PyObject*)&Sbk_QStyleOptionSpinBox_Type));

    // Initialize enums
    PyObject* enumItem;

    // init enum: StyleOptionVersion
    PyTypeObject* SbkPySide_QtGui_QStyleOptionSpinBox_StyleOptionVersion = Shiboken::Enum::newType("PySide.QtGui.QStyleOptionSpinBox.StyleOptionVersion");
    SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONSPINBOX_STYLEOPTIONVERSION_IDX] = SbkPySide_QtGui_QStyleOptionSpinBox_StyleOptionVersion;
    if (PyType_Ready(SbkPySide_QtGui_QStyleOptionSpinBox_StyleOptionVersion) < 0)
        return;
    PyDict_SetItemString(Sbk_QStyleOptionSpinBox_Type.super.ht_type.tp_dict,
            "StyleOptionVersion",((PyObject*)SbkPySide_QtGui_QStyleOptionSpinBox_StyleOptionVersion));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyleOptionSpinBox_StyleOptionVersion,(long) QStyleOptionSpinBox::Version, "Version");
    PyDict_SetItemString(Sbk_QStyleOptionSpinBox_Type.super.ht_type.tp_dict,"Version", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyleOptionSpinBox_StyleOptionVersion->tp_dict,"Version", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QStyleOptionSpinBox::StyleOptionVersion");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::StyleOptionVersion");
    // end of enum StyleOptionVersion

    // init enum: StyleOptionType
    PyTypeObject* SbkPySide_QtGui_QStyleOptionSpinBox_StyleOptionType = Shiboken::Enum::newType("PySide.QtGui.QStyleOptionSpinBox.StyleOptionType");
    SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONSPINBOX_STYLEOPTIONTYPE_IDX] = SbkPySide_QtGui_QStyleOptionSpinBox_StyleOptionType;
    if (PyType_Ready(SbkPySide_QtGui_QStyleOptionSpinBox_StyleOptionType) < 0)
        return;
    PyDict_SetItemString(Sbk_QStyleOptionSpinBox_Type.super.ht_type.tp_dict,
            "StyleOptionType",((PyObject*)SbkPySide_QtGui_QStyleOptionSpinBox_StyleOptionType));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyleOptionSpinBox_StyleOptionType,(long) QStyleOptionSpinBox::Type, "Type");
    PyDict_SetItemString(Sbk_QStyleOptionSpinBox_Type.super.ht_type.tp_dict,"Type", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyleOptionSpinBox_StyleOptionType->tp_dict,"Type", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QStyleOptionSpinBox::StyleOptionType");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::StyleOptionType");
    // end of enum StyleOptionType


    Shiboken::TypeResolver::createValueTypeResolver<QStyleOptionSpinBox >("QStyleOptionSpinBox");
    Shiboken::TypeResolver::createObjectTypeResolver<QStyleOptionSpinBox >("QStyleOptionSpinBox*");
    Shiboken::TypeResolver::createValueTypeResolver<QStyleOptionSpinBox >(typeid(QStyleOptionSpinBox).name());
    qRegisterMetaType< ::QStyleOptionSpinBox >("QStyleOptionSpinBox");
    qRegisterMetaType< ::QStyleOptionSpinBox::StyleOptionVersion >("QStyleOptionSpinBox::StyleOptionVersion");
    qRegisterMetaType< ::QStyleOptionSpinBox::StyleOptionType >("QStyleOptionSpinBox::StyleOptionType");
}

