/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtgui_python.h"

#include "qstyleoptiontabv3_wrapper.h"

// Extra includes
#include <qstyleoption.h>
#include <qwidget.h>



// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QStyleOptionTabV3_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QStyleOptionTabV3 >()))
        return -1;

    QStyleOptionTabV3* cptr = 0;
    int overloadId = -1;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QStyleOptionTabV3", 0, 1, &(pyargs[0])))
        return -1;

    // Overloaded function decisor
    // 0: QStyleOptionTabV3()
    // 1: QStyleOptionTabV3(QStyleOptionTab)
    // 2: QStyleOptionTabV3(QStyleOptionTabV2)
    // 3: QStyleOptionTabV3(QStyleOptionTabV3)
    // 4: QStyleOptionTabV3(int)
    if (numArgs == 0) {
        overloadId = 0; // QStyleOptionTabV3()
    } else if (numArgs == 1 && SbkNumber_Check(pyargs[0])) {
        overloadId = 4; // QStyleOptionTabV3(int)
    } else if (numArgs == 1 && Shiboken::Converter< ::QStyleOptionTabV3 >::isConvertible(pyargs[0])) {
        overloadId = 3; // QStyleOptionTabV3(QStyleOptionTabV3)
    } else if (numArgs == 1 && Shiboken::Converter< ::QStyleOptionTabV2 >::isConvertible(pyargs[0])) {
        overloadId = 2; // QStyleOptionTabV3(QStyleOptionTabV2)
    } else if (numArgs == 1 && Shiboken::Converter< ::QStyleOptionTab >::isConvertible(pyargs[0])) {
        overloadId = 1; // QStyleOptionTabV3(QStyleOptionTab)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QStyleOptionTabV3_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QStyleOptionTabV3()
            {

                if(!PyErr_Occurred()) {
                    // QStyleOptionTabV3()
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QStyleOptionTabV3();
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // QStyleOptionTabV3(QStyleOptionTab)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QStyleOptionTab cppArg0 = Shiboken::Converter<QStyleOptionTab >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QStyleOptionTabV3(QStyleOptionTab)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QStyleOptionTabV3(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 2: // QStyleOptionTabV3(QStyleOptionTabV2)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QStyleOptionTabV2 cppArg0 = Shiboken::Converter<QStyleOptionTabV2 >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QStyleOptionTabV3(QStyleOptionTabV2)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QStyleOptionTabV3(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 3: // QStyleOptionTabV3(QStyleOptionTabV3)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QStyleOptionTabV3 cppArg0 = Shiboken::Converter<QStyleOptionTabV3 >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QStyleOptionTabV3(QStyleOptionTabV3)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QStyleOptionTabV3(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 4: // QStyleOptionTabV3(int)
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QStyleOptionTabV3(int)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QStyleOptionTabV3(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QStyleOptionTabV3 >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QStyleOptionTabV3_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QStyleOptionTabV3_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtGui.QStyleOptionTab", "PySide.QtGui.QStyleOptionTabV2", "PySide.QtGui.QStyleOptionTabV3", "int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QStyleOptionTabV3", overloads);
        return -1;
}

static PyObject *Sbk_QStyleOptionTabV3___copy__(PyObject *self)
{
        QStyleOptionTabV3* cppSelf = 0;
        if (!Shiboken::Object::isValid(self))
            return 0;
        cppSelf = Shiboken::Converter<QStyleOptionTabV3*>::toCpp(self);
        PyObject* pyResult = 0;
        QStyleOptionTabV3* copy = new QStyleOptionTabV3(*cppSelf);
        pyResult = Shiboken::Converter<QStyleOptionTabV3*>::toPython(copy);
        Shiboken::Object::getOwnership(pyResult);

        if (PyErr_Occurred() || !pyResult) {
            Py_XDECREF(pyResult);
            return 0;
        }
        return pyResult;
}

static PyMethodDef Sbk_QStyleOptionTabV3_methods[] = {

    {"__copy__", (PyCFunction)Sbk_QStyleOptionTabV3___copy__, METH_NOARGS},
    {0} // Sentinel
};

static PyObject* Sbk_QStyleOptionTabV3_get_documentMode(PyObject* self, void*)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    PyObject* val = Shiboken::Converter< bool >::toPython( Shiboken::Converter< QStyleOptionTabV3* >::toCpp(self)->documentMode);
    return val;
}

static int Sbk_QStyleOptionTabV3_set_documentMode(PyObject* self, PyObject* value, void*)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'documentMode' may not be deleted");
        return -1;
    }
    if (!SbkNumber_Check(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'documentMode', 'bool' or convertible type expected");
        return -1;
    }

    Shiboken::Converter< QStyleOptionTabV3* >::toCpp(self)->documentMode = Shiboken::Converter< bool >::toCpp(value);

    return 0;
}

static PyObject* Sbk_QStyleOptionTabV3_get_rightButtonSize(PyObject* self, void*)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    PyObject* val = Shiboken::createWrapper(&Shiboken::Converter< QStyleOptionTabV3* >::toCpp(self)->rightButtonSize);
    Shiboken::Object::releaseOwnership(val);
    Shiboken::Object::setParent(self, val);
    return val;
}

static int Sbk_QStyleOptionTabV3_set_rightButtonSize(PyObject* self, PyObject* value, void*)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'rightButtonSize' may not be deleted");
        return -1;
    }
    if (!Shiboken::Converter< ::QSize >::isConvertible(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'rightButtonSize', 'QSize' or convertible type expected");
        return -1;
    }

    Shiboken::Converter< QStyleOptionTabV3* >::toCpp(self)->rightButtonSize = Shiboken::Converter< ::QSize >::toCpp(value);

    return 0;
}

static PyObject* Sbk_QStyleOptionTabV3_get_leftButtonSize(PyObject* self, void*)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    PyObject* val = Shiboken::createWrapper(&Shiboken::Converter< QStyleOptionTabV3* >::toCpp(self)->leftButtonSize);
    Shiboken::Object::releaseOwnership(val);
    Shiboken::Object::setParent(self, val);
    return val;
}

static int Sbk_QStyleOptionTabV3_set_leftButtonSize(PyObject* self, PyObject* value, void*)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'leftButtonSize' may not be deleted");
        return -1;
    }
    if (!Shiboken::Converter< ::QSize >::isConvertible(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'leftButtonSize', 'QSize' or convertible type expected");
        return -1;
    }

    Shiboken::Converter< QStyleOptionTabV3* >::toCpp(self)->leftButtonSize = Shiboken::Converter< ::QSize >::toCpp(value);

    return 0;
}

// Getters and Setters for QStyleOptionTabV3
static PyGetSetDef Sbk_QStyleOptionTabV3_getsetlist[] = {
    {const_cast<char*>("documentMode"), Sbk_QStyleOptionTabV3_get_documentMode, Sbk_QStyleOptionTabV3_set_documentMode},
    {const_cast<char*>("rightButtonSize"), Sbk_QStyleOptionTabV3_get_rightButtonSize, Sbk_QStyleOptionTabV3_set_rightButtonSize},
    {const_cast<char*>("leftButtonSize"), Sbk_QStyleOptionTabV3_get_leftButtonSize, Sbk_QStyleOptionTabV3_set_leftButtonSize},
    {0}  // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QStyleOptionTabV3_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QStyleOptionTabV3",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QStyleOptionTabV3_methods,
    /*tp_members*/          0,
    /*tp_getset*/           Sbk_QStyleOptionTabV3_getsetlist,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QStyleOptionTabV3_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern


void init_QStyleOptionTabV3(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONTABV3_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QStyleOptionTabV3_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QStyleOptionTabV3_Type);
    Sbk_QStyleOptionTabV3_Type.super.ht_type.tp_base = SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONTABV2_IDX];
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QStyleOptionTabV3_Type, &Shiboken::callCppDestructor<QStyleOptionTabV3 >);
    Py_INCREF((PyObject*)&Sbk_QStyleOptionTabV3_Type); //Incref due the 'PyModule_AddObject' steals the reference.
    if (PyType_Ready((PyTypeObject*)&Sbk_QStyleOptionTabV3_Type) < 0)
        return;

    Shiboken::ObjectType::setOriginalName(&Sbk_QStyleOptionTabV3_Type, "QStyleOptionTabV3");
    PyModule_AddObject(module, "QStyleOptionTabV3",
        ((PyObject*)&Sbk_QStyleOptionTabV3_Type));

    // Initialize enums
    PyObject* enumItem;

    // init enum: StyleOptionVersion
    PyTypeObject* SbkPySide_QtGui_QStyleOptionTabV3_StyleOptionVersion = Shiboken::Enum::newType("PySide.QtGui.QStyleOptionTabV3.StyleOptionVersion");
    SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONTABV3_STYLEOPTIONVERSION_IDX] = SbkPySide_QtGui_QStyleOptionTabV3_StyleOptionVersion;
    if (PyType_Ready(SbkPySide_QtGui_QStyleOptionTabV3_StyleOptionVersion) < 0)
        return;
    PyDict_SetItemString(Sbk_QStyleOptionTabV3_Type.super.ht_type.tp_dict,
            "StyleOptionVersion",((PyObject*)SbkPySide_QtGui_QStyleOptionTabV3_StyleOptionVersion));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyleOptionTabV3_StyleOptionVersion,(long) QStyleOptionTabV3::Version, "Version");
    PyDict_SetItemString(Sbk_QStyleOptionTabV3_Type.super.ht_type.tp_dict,"Version", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyleOptionTabV3_StyleOptionVersion->tp_dict,"Version", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QStyleOptionTabV3::StyleOptionVersion");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::StyleOptionVersion");
    // end of enum StyleOptionVersion


    Shiboken::TypeResolver::createValueTypeResolver<QStyleOptionTabV3 >("QStyleOptionTabV3");
    Shiboken::TypeResolver::createObjectTypeResolver<QStyleOptionTabV3 >("QStyleOptionTabV3*");
    Shiboken::TypeResolver::createValueTypeResolver<QStyleOptionTabV3 >(typeid(QStyleOptionTabV3).name());
    qRegisterMetaType< ::QStyleOptionTabV3 >("QStyleOptionTabV3");
    qRegisterMetaType< ::QStyleOptionTabV3::StyleOptionVersion >("QStyleOptionTabV3::StyleOptionVersion");
}

