/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtgui_python.h"

#include "qtextcharformat_wrapper.h"

// Extra includes
#include <QMap>
#include <QStringList>
#include <QVector>
#include <qbrush.h>
#include <qcolor.h>
#include <qfont.h>
#include <qpen.h>
#include <qtextformat.h>



// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QTextCharFormat_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QTextCharFormat >()))
        return -1;

    QTextCharFormat* cptr = 0;
    int overloadId = -1;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QTextCharFormat", 0, 1, &(pyargs[0])))
        return -1;

    // Overloaded function decisor
    // 0: QTextCharFormat()
    // 1: QTextCharFormat(QTextCharFormat)
    // 2: QTextCharFormat(QTextFormat)
    if (numArgs == 0) {
        overloadId = 0; // QTextCharFormat()
    } else if (numArgs == 1 && Shiboken::Converter< ::QTextCharFormat >::isConvertible(pyargs[0])) {
        overloadId = 1; // QTextCharFormat(QTextCharFormat)
    } else if (numArgs == 1 && Shiboken::Converter< ::QTextFormat >::isConvertible(pyargs[0])) {
        overloadId = 2; // QTextCharFormat(QTextFormat)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextCharFormat_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QTextCharFormat()
            {

                if(!PyErr_Occurred()) {
                    // QTextCharFormat()
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QTextCharFormat();
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // QTextCharFormat(QTextCharFormat)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QTextCharFormat cppArg0 = Shiboken::Converter<QTextCharFormat >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QTextCharFormat(QTextCharFormat)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QTextCharFormat(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 2: // QTextCharFormat(QTextFormat)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QTextFormat cppArg0 = Shiboken::Converter<QTextFormat >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QTextCharFormat(QTextFormat)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QTextCharFormat(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QTextCharFormat >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QTextCharFormat_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QTextCharFormat_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtGui.QTextCharFormat", "PySide.QtGui.QTextFormat", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QTextCharFormat", overloads);
        return -1;
}

static PyObject* Sbk_QTextCharFormatFunc_anchorHref(PyObject* self)
{
    QTextCharFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextCharFormat* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // anchorHref()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = const_cast<const QTextCharFormat*>(cppSelf)->anchorHref();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextCharFormatFunc_anchorNames(PyObject* self)
{
    QTextCharFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextCharFormat* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // anchorNames()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QStringList cppResult = const_cast<const QTextCharFormat*>(cppSelf)->anchorNames();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QStringList >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextCharFormatFunc_font(PyObject* self)
{
    QTextCharFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextCharFormat* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // font()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QFont cppResult = const_cast<const QTextCharFormat*>(cppSelf)->font();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QFont >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextCharFormatFunc_fontCapitalization(PyObject* self)
{
    QTextCharFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextCharFormat* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // fontCapitalization()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QFont::Capitalization cppResult = const_cast<const QTextCharFormat*>(cppSelf)->fontCapitalization();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QFont::Capitalization >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextCharFormatFunc_fontFamily(PyObject* self)
{
    QTextCharFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextCharFormat* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // fontFamily()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = const_cast<const QTextCharFormat*>(cppSelf)->fontFamily();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextCharFormatFunc_fontFixedPitch(PyObject* self)
{
    QTextCharFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextCharFormat* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // fontFixedPitch()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QTextCharFormat*>(cppSelf)->fontFixedPitch();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextCharFormatFunc_fontItalic(PyObject* self)
{
    QTextCharFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextCharFormat* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // fontItalic()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QTextCharFormat*>(cppSelf)->fontItalic();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextCharFormatFunc_fontKerning(PyObject* self)
{
    QTextCharFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextCharFormat* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // fontKerning()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QTextCharFormat*>(cppSelf)->fontKerning();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextCharFormatFunc_fontLetterSpacing(PyObject* self)
{
    QTextCharFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextCharFormat* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // fontLetterSpacing()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                qreal cppResult = const_cast<const QTextCharFormat*>(cppSelf)->fontLetterSpacing();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< double >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextCharFormatFunc_fontOverline(PyObject* self)
{
    QTextCharFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextCharFormat* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // fontOverline()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QTextCharFormat*>(cppSelf)->fontOverline();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextCharFormatFunc_fontPointSize(PyObject* self)
{
    QTextCharFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextCharFormat* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // fontPointSize()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                qreal cppResult = const_cast<const QTextCharFormat*>(cppSelf)->fontPointSize();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< double >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextCharFormatFunc_fontStrikeOut(PyObject* self)
{
    QTextCharFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextCharFormat* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // fontStrikeOut()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QTextCharFormat*>(cppSelf)->fontStrikeOut();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextCharFormatFunc_fontStyleHint(PyObject* self)
{
    QTextCharFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextCharFormat* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // fontStyleHint()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QFont::StyleHint cppResult = const_cast<const QTextCharFormat*>(cppSelf)->fontStyleHint();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QFont::StyleHint >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextCharFormatFunc_fontStyleStrategy(PyObject* self)
{
    QTextCharFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextCharFormat* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // fontStyleStrategy()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QFont::StyleStrategy cppResult = const_cast<const QTextCharFormat*>(cppSelf)->fontStyleStrategy();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QFont::StyleStrategy >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextCharFormatFunc_fontUnderline(PyObject* self)
{
    QTextCharFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextCharFormat* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // fontUnderline()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QTextCharFormat*>(cppSelf)->fontUnderline();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextCharFormatFunc_fontWeight(PyObject* self)
{
    QTextCharFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextCharFormat* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // fontWeight()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QTextCharFormat*>(cppSelf)->fontWeight();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextCharFormatFunc_fontWordSpacing(PyObject* self)
{
    QTextCharFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextCharFormat* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // fontWordSpacing()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                qreal cppResult = const_cast<const QTextCharFormat*>(cppSelf)->fontWordSpacing();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< double >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextCharFormatFunc_isAnchor(PyObject* self)
{
    QTextCharFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextCharFormat* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isAnchor()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QTextCharFormat*>(cppSelf)->isAnchor();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextCharFormatFunc_isValid(PyObject* self)
{
    QTextCharFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextCharFormat* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isValid()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QTextCharFormat*>(cppSelf)->isValid();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextCharFormatFunc_setAnchor(PyObject* self, PyObject* arg)
{
    QTextCharFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextCharFormat* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setAnchor(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setAnchor(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextCharFormatFunc_setAnchor_TypeError;

    // Call function/method
    {
        {
            bool cppArg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setAnchor(bool)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setAnchor(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextCharFormatFunc_setAnchor_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextCharFormat.setAnchor", overloads);
        return 0;
}

static PyObject* Sbk_QTextCharFormatFunc_setAnchorHref(PyObject* self, PyObject* arg)
{
    QTextCharFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextCharFormat* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setAnchorHref(QString)
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // setAnchorHref(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextCharFormatFunc_setAnchorHref_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setAnchorHref(QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setAnchorHref(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextCharFormatFunc_setAnchorHref_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextCharFormat.setAnchorHref", overloads);
        return 0;
}

static PyObject* Sbk_QTextCharFormatFunc_setAnchorNames(PyObject* self, PyObject* arg)
{
    QTextCharFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextCharFormat* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setAnchorNames(QStringList)
    if (Shiboken::Converter< ::QStringList >::isConvertible(arg)) {
        overloadId = 0; // setAnchorNames(QStringList)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextCharFormatFunc_setAnchorNames_TypeError;

    // Call function/method
    {
        {
            QStringList cppArg0 = Shiboken::Converter<QStringList >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setAnchorNames(QStringList)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setAnchorNames(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextCharFormatFunc_setAnchorNames_TypeError:
        const char* overloads[] = {"list", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextCharFormat.setAnchorNames", overloads);
        return 0;
}

static PyObject* Sbk_QTextCharFormatFunc_setFont(PyObject* self, PyObject* arg)
{
    QTextCharFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextCharFormat* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setFont(QFont)
    if (Shiboken::Converter< ::QFont >::isConvertible(arg)) {
        overloadId = 0; // setFont(QFont)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextCharFormatFunc_setFont_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QFont cppArg0 = Shiboken::Converter<QFont >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setFont(QFont)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setFont(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextCharFormatFunc_setFont_TypeError:
        const char* overloads[] = {"PySide.QtGui.QFont", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextCharFormat.setFont", overloads);
        return 0;
}

static PyObject* Sbk_QTextCharFormatFunc_setFontCapitalization(PyObject* self, PyObject* arg)
{
    QTextCharFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextCharFormat* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setFontCapitalization(QFont::Capitalization)
    if (Shiboken::Converter< ::QFont::Capitalization >::isConvertible(arg)) {
        overloadId = 0; // setFontCapitalization(QFont::Capitalization)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextCharFormatFunc_setFontCapitalization_TypeError;

    // Call function/method
    {
        {
            QFont::Capitalization cppArg0 = Shiboken::Converter<QFont::Capitalization >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setFontCapitalization(QFont::Capitalization)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setFontCapitalization(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextCharFormatFunc_setFontCapitalization_TypeError:
        const char* overloads[] = {"PySide.QtGui.QFont.Capitalization", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextCharFormat.setFontCapitalization", overloads);
        return 0;
}

static PyObject* Sbk_QTextCharFormatFunc_setFontFamily(PyObject* self, PyObject* arg)
{
    QTextCharFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextCharFormat* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setFontFamily(QString)
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // setFontFamily(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextCharFormatFunc_setFontFamily_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setFontFamily(QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setFontFamily(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextCharFormatFunc_setFontFamily_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextCharFormat.setFontFamily", overloads);
        return 0;
}

static PyObject* Sbk_QTextCharFormatFunc_setFontFixedPitch(PyObject* self, PyObject* arg)
{
    QTextCharFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextCharFormat* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setFontFixedPitch(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setFontFixedPitch(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextCharFormatFunc_setFontFixedPitch_TypeError;

    // Call function/method
    {
        {
            bool cppArg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setFontFixedPitch(bool)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setFontFixedPitch(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextCharFormatFunc_setFontFixedPitch_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextCharFormat.setFontFixedPitch", overloads);
        return 0;
}

static PyObject* Sbk_QTextCharFormatFunc_setFontItalic(PyObject* self, PyObject* arg)
{
    QTextCharFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextCharFormat* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setFontItalic(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setFontItalic(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextCharFormatFunc_setFontItalic_TypeError;

    // Call function/method
    {
        {
            bool cppArg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setFontItalic(bool)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setFontItalic(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextCharFormatFunc_setFontItalic_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextCharFormat.setFontItalic", overloads);
        return 0;
}

static PyObject* Sbk_QTextCharFormatFunc_setFontKerning(PyObject* self, PyObject* arg)
{
    QTextCharFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextCharFormat* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setFontKerning(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setFontKerning(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextCharFormatFunc_setFontKerning_TypeError;

    // Call function/method
    {
        {
            bool cppArg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setFontKerning(bool)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setFontKerning(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextCharFormatFunc_setFontKerning_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextCharFormat.setFontKerning", overloads);
        return 0;
}

static PyObject* Sbk_QTextCharFormatFunc_setFontLetterSpacing(PyObject* self, PyObject* arg)
{
    QTextCharFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextCharFormat* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setFontLetterSpacing(qreal)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setFontLetterSpacing(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextCharFormatFunc_setFontLetterSpacing_TypeError;

    // Call function/method
    {
        {
            qreal cppArg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setFontLetterSpacing(qreal)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setFontLetterSpacing(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextCharFormatFunc_setFontLetterSpacing_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextCharFormat.setFontLetterSpacing", overloads);
        return 0;
}

static PyObject* Sbk_QTextCharFormatFunc_setFontOverline(PyObject* self, PyObject* arg)
{
    QTextCharFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextCharFormat* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setFontOverline(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setFontOverline(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextCharFormatFunc_setFontOverline_TypeError;

    // Call function/method
    {
        {
            bool cppArg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setFontOverline(bool)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setFontOverline(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextCharFormatFunc_setFontOverline_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextCharFormat.setFontOverline", overloads);
        return 0;
}

static PyObject* Sbk_QTextCharFormatFunc_setFontPointSize(PyObject* self, PyObject* arg)
{
    QTextCharFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextCharFormat* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setFontPointSize(qreal)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setFontPointSize(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextCharFormatFunc_setFontPointSize_TypeError;

    // Call function/method
    {
        {
            qreal cppArg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setFontPointSize(qreal)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setFontPointSize(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextCharFormatFunc_setFontPointSize_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextCharFormat.setFontPointSize", overloads);
        return 0;
}

static PyObject* Sbk_QTextCharFormatFunc_setFontStrikeOut(PyObject* self, PyObject* arg)
{
    QTextCharFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextCharFormat* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setFontStrikeOut(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setFontStrikeOut(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextCharFormatFunc_setFontStrikeOut_TypeError;

    // Call function/method
    {
        {
            bool cppArg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setFontStrikeOut(bool)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setFontStrikeOut(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextCharFormatFunc_setFontStrikeOut_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextCharFormat.setFontStrikeOut", overloads);
        return 0;
}

static PyObject* Sbk_QTextCharFormatFunc_setFontStyleHint(PyObject* self, PyObject* args, PyObject* kwds)
{
    QTextCharFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextCharFormat* >::toCpp(self);

    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QTextCharFormat.setFontStyleHint(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QTextCharFormat.setFontStyleHint(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:setFontStyleHint", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setFontStyleHint(QFont::StyleHint,QFont::StyleStrategy)
    if (Shiboken::Converter< ::QFont::StyleHint >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // setFontStyleHint(QFont::StyleHint,QFont::StyleStrategy)
        } else if (Shiboken::Converter< ::QFont::StyleStrategy >::isConvertible(pyargs[1])) {
            overloadId = 0; // setFontStyleHint(QFont::StyleHint,QFont::StyleStrategy)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextCharFormatFunc_setFontStyleHint_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "strategy");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "strategy";
                    else if (Shiboken::Converter< ::QFont::StyleStrategy >::isConvertible(value))
                        pyargs[1] = value;
                    else
                        goto Sbk_QTextCharFormatFunc_setFontStyleHint_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QTextCharFormat.setFontStyleHint(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QFont::StyleHint cppArg0 = Shiboken::Converter<QFont::StyleHint >::toCpp(pyargs[0]);
            QFont::StyleStrategy cppArg1 = pyargs[1] ? Shiboken::Converter<QFont::StyleStrategy >::toCpp(pyargs[1]) : QFont::PreferDefault;

            if(!PyErr_Occurred()) {
                // setFontStyleHint(QFont::StyleHint,QFont::StyleStrategy)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setFontStyleHint(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextCharFormatFunc_setFontStyleHint_TypeError:
        const char* overloads[] = {"PySide.QtGui.QFont.StyleHint, PySide.QtGui.QFont.StyleStrategy = QFont.PreferDefault", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QTextCharFormat.setFontStyleHint", overloads);
        return 0;
}

static PyObject* Sbk_QTextCharFormatFunc_setFontStyleStrategy(PyObject* self, PyObject* arg)
{
    QTextCharFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextCharFormat* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setFontStyleStrategy(QFont::StyleStrategy)
    if (Shiboken::Converter< ::QFont::StyleStrategy >::isConvertible(arg)) {
        overloadId = 0; // setFontStyleStrategy(QFont::StyleStrategy)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextCharFormatFunc_setFontStyleStrategy_TypeError;

    // Call function/method
    {
        {
            QFont::StyleStrategy cppArg0 = Shiboken::Converter<QFont::StyleStrategy >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setFontStyleStrategy(QFont::StyleStrategy)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setFontStyleStrategy(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextCharFormatFunc_setFontStyleStrategy_TypeError:
        const char* overloads[] = {"PySide.QtGui.QFont.StyleStrategy", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextCharFormat.setFontStyleStrategy", overloads);
        return 0;
}

static PyObject* Sbk_QTextCharFormatFunc_setFontUnderline(PyObject* self, PyObject* arg)
{
    QTextCharFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextCharFormat* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setFontUnderline(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setFontUnderline(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextCharFormatFunc_setFontUnderline_TypeError;

    // Call function/method
    {
        {
            bool cppArg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setFontUnderline(bool)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setFontUnderline(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextCharFormatFunc_setFontUnderline_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextCharFormat.setFontUnderline", overloads);
        return 0;
}

static PyObject* Sbk_QTextCharFormatFunc_setFontWeight(PyObject* self, PyObject* arg)
{
    QTextCharFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextCharFormat* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setFontWeight(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setFontWeight(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextCharFormatFunc_setFontWeight_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setFontWeight(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setFontWeight(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextCharFormatFunc_setFontWeight_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextCharFormat.setFontWeight", overloads);
        return 0;
}

static PyObject* Sbk_QTextCharFormatFunc_setFontWordSpacing(PyObject* self, PyObject* arg)
{
    QTextCharFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextCharFormat* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setFontWordSpacing(qreal)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setFontWordSpacing(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextCharFormatFunc_setFontWordSpacing_TypeError;

    // Call function/method
    {
        {
            qreal cppArg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setFontWordSpacing(qreal)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setFontWordSpacing(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextCharFormatFunc_setFontWordSpacing_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextCharFormat.setFontWordSpacing", overloads);
        return 0;
}

static PyObject* Sbk_QTextCharFormatFunc_setTableCellColumnSpan(PyObject* self, PyObject* arg)
{
    QTextCharFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextCharFormat* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setTableCellColumnSpan(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setTableCellColumnSpan(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextCharFormatFunc_setTableCellColumnSpan_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setTableCellColumnSpan(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setTableCellColumnSpan(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextCharFormatFunc_setTableCellColumnSpan_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextCharFormat.setTableCellColumnSpan", overloads);
        return 0;
}

static PyObject* Sbk_QTextCharFormatFunc_setTableCellRowSpan(PyObject* self, PyObject* arg)
{
    QTextCharFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextCharFormat* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setTableCellRowSpan(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setTableCellRowSpan(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextCharFormatFunc_setTableCellRowSpan_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setTableCellRowSpan(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setTableCellRowSpan(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextCharFormatFunc_setTableCellRowSpan_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextCharFormat.setTableCellRowSpan", overloads);
        return 0;
}

static PyObject* Sbk_QTextCharFormatFunc_setTextOutline(PyObject* self, PyObject* arg)
{
    QTextCharFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextCharFormat* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setTextOutline(QPen)
    if (Shiboken::Converter< ::QPen >::isConvertible(arg)) {
        overloadId = 0; // setTextOutline(QPen)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextCharFormatFunc_setTextOutline_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QPen cppArg0 = Shiboken::Converter<QPen >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setTextOutline(QPen)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setTextOutline(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextCharFormatFunc_setTextOutline_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPen", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextCharFormat.setTextOutline", overloads);
        return 0;
}

static PyObject* Sbk_QTextCharFormatFunc_setToolTip(PyObject* self, PyObject* arg)
{
    QTextCharFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextCharFormat* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setToolTip(QString)
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // setToolTip(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextCharFormatFunc_setToolTip_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setToolTip(QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setToolTip(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextCharFormatFunc_setToolTip_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextCharFormat.setToolTip", overloads);
        return 0;
}

static PyObject* Sbk_QTextCharFormatFunc_setUnderlineColor(PyObject* self, PyObject* arg)
{
    QTextCharFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextCharFormat* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setUnderlineColor(QColor)
    if (Shiboken::Converter< ::QColor >::isConvertible(arg)) {
        overloadId = 0; // setUnderlineColor(QColor)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextCharFormatFunc_setUnderlineColor_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QColor cppArg0 = Shiboken::Converter<QColor >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setUnderlineColor(QColor)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setUnderlineColor(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextCharFormatFunc_setUnderlineColor_TypeError:
        const char* overloads[] = {"PySide.QtGui.QColor", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextCharFormat.setUnderlineColor", overloads);
        return 0;
}

static PyObject* Sbk_QTextCharFormatFunc_setUnderlineStyle(PyObject* self, PyObject* arg)
{
    QTextCharFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextCharFormat* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setUnderlineStyle(QTextCharFormat::UnderlineStyle)
    if (Shiboken::Converter< ::QTextCharFormat::UnderlineStyle >::isConvertible(arg)) {
        overloadId = 0; // setUnderlineStyle(QTextCharFormat::UnderlineStyle)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextCharFormatFunc_setUnderlineStyle_TypeError;

    // Call function/method
    {
        {
            QTextCharFormat::UnderlineStyle cppArg0 = Shiboken::Converter<QTextCharFormat::UnderlineStyle >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setUnderlineStyle(QTextCharFormat::UnderlineStyle)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setUnderlineStyle(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextCharFormatFunc_setUnderlineStyle_TypeError:
        const char* overloads[] = {"PySide.QtGui.QTextCharFormat.UnderlineStyle", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextCharFormat.setUnderlineStyle", overloads);
        return 0;
}

static PyObject* Sbk_QTextCharFormatFunc_setVerticalAlignment(PyObject* self, PyObject* arg)
{
    QTextCharFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextCharFormat* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setVerticalAlignment(QTextCharFormat::VerticalAlignment)
    if (Shiboken::Converter< ::QTextCharFormat::VerticalAlignment >::isConvertible(arg)) {
        overloadId = 0; // setVerticalAlignment(QTextCharFormat::VerticalAlignment)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextCharFormatFunc_setVerticalAlignment_TypeError;

    // Call function/method
    {
        {
            QTextCharFormat::VerticalAlignment cppArg0 = Shiboken::Converter<QTextCharFormat::VerticalAlignment >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setVerticalAlignment(QTextCharFormat::VerticalAlignment)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setVerticalAlignment(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextCharFormatFunc_setVerticalAlignment_TypeError:
        const char* overloads[] = {"PySide.QtGui.QTextCharFormat.VerticalAlignment", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextCharFormat.setVerticalAlignment", overloads);
        return 0;
}

static PyObject* Sbk_QTextCharFormatFunc_tableCellColumnSpan(PyObject* self)
{
    QTextCharFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextCharFormat* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // tableCellColumnSpan()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QTextCharFormat*>(cppSelf)->tableCellColumnSpan();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextCharFormatFunc_tableCellRowSpan(PyObject* self)
{
    QTextCharFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextCharFormat* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // tableCellRowSpan()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QTextCharFormat*>(cppSelf)->tableCellRowSpan();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextCharFormatFunc_textOutline(PyObject* self)
{
    QTextCharFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextCharFormat* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // textOutline()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QPen cppResult = const_cast<const QTextCharFormat*>(cppSelf)->textOutline();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QPen >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextCharFormatFunc_toolTip(PyObject* self)
{
    QTextCharFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextCharFormat* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // toolTip()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = const_cast<const QTextCharFormat*>(cppSelf)->toolTip();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextCharFormatFunc_underlineColor(PyObject* self)
{
    QTextCharFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextCharFormat* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // underlineColor()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QColor cppResult = const_cast<const QTextCharFormat*>(cppSelf)->underlineColor();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QColor >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextCharFormatFunc_underlineStyle(PyObject* self)
{
    QTextCharFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextCharFormat* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // underlineStyle()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QTextCharFormat::UnderlineStyle cppResult = const_cast<const QTextCharFormat*>(cppSelf)->underlineStyle();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QTextCharFormat::UnderlineStyle >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextCharFormatFunc_verticalAlignment(PyObject* self)
{
    QTextCharFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextCharFormat* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // verticalAlignment()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QTextCharFormat::VerticalAlignment cppResult = const_cast<const QTextCharFormat*>(cppSelf)->verticalAlignment();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QTextCharFormat::VerticalAlignment >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject *Sbk_QTextCharFormat___copy__(PyObject *self)
{
        QTextCharFormat* cppSelf = 0;
        if (!Shiboken::Object::isValid(self))
            return 0;
        cppSelf = Shiboken::Converter<QTextCharFormat*>::toCpp(self);
        PyObject* pyResult = 0;
        QTextCharFormat* copy = new QTextCharFormat(*cppSelf);
        pyResult = Shiboken::Converter<QTextCharFormat*>::toPython(copy);
        Shiboken::Object::getOwnership(pyResult);

        if (PyErr_Occurred() || !pyResult) {
            Py_XDECREF(pyResult);
            return 0;
        }
        return pyResult;
}

static PyMethodDef Sbk_QTextCharFormat_methods[] = {
    {"anchorHref", (PyCFunction)Sbk_QTextCharFormatFunc_anchorHref, METH_NOARGS},
    {"anchorNames", (PyCFunction)Sbk_QTextCharFormatFunc_anchorNames, METH_NOARGS},
    {"font", (PyCFunction)Sbk_QTextCharFormatFunc_font, METH_NOARGS},
    {"fontCapitalization", (PyCFunction)Sbk_QTextCharFormatFunc_fontCapitalization, METH_NOARGS},
    {"fontFamily", (PyCFunction)Sbk_QTextCharFormatFunc_fontFamily, METH_NOARGS},
    {"fontFixedPitch", (PyCFunction)Sbk_QTextCharFormatFunc_fontFixedPitch, METH_NOARGS},
    {"fontItalic", (PyCFunction)Sbk_QTextCharFormatFunc_fontItalic, METH_NOARGS},
    {"fontKerning", (PyCFunction)Sbk_QTextCharFormatFunc_fontKerning, METH_NOARGS},
    {"fontLetterSpacing", (PyCFunction)Sbk_QTextCharFormatFunc_fontLetterSpacing, METH_NOARGS},
    {"fontOverline", (PyCFunction)Sbk_QTextCharFormatFunc_fontOverline, METH_NOARGS},
    {"fontPointSize", (PyCFunction)Sbk_QTextCharFormatFunc_fontPointSize, METH_NOARGS},
    {"fontStrikeOut", (PyCFunction)Sbk_QTextCharFormatFunc_fontStrikeOut, METH_NOARGS},
    {"fontStyleHint", (PyCFunction)Sbk_QTextCharFormatFunc_fontStyleHint, METH_NOARGS},
    {"fontStyleStrategy", (PyCFunction)Sbk_QTextCharFormatFunc_fontStyleStrategy, METH_NOARGS},
    {"fontUnderline", (PyCFunction)Sbk_QTextCharFormatFunc_fontUnderline, METH_NOARGS},
    {"fontWeight", (PyCFunction)Sbk_QTextCharFormatFunc_fontWeight, METH_NOARGS},
    {"fontWordSpacing", (PyCFunction)Sbk_QTextCharFormatFunc_fontWordSpacing, METH_NOARGS},
    {"isAnchor", (PyCFunction)Sbk_QTextCharFormatFunc_isAnchor, METH_NOARGS},
    {"isValid", (PyCFunction)Sbk_QTextCharFormatFunc_isValid, METH_NOARGS},
    {"setAnchor", (PyCFunction)Sbk_QTextCharFormatFunc_setAnchor, METH_O},
    {"setAnchorHref", (PyCFunction)Sbk_QTextCharFormatFunc_setAnchorHref, METH_O},
    {"setAnchorNames", (PyCFunction)Sbk_QTextCharFormatFunc_setAnchorNames, METH_O},
    {"setFont", (PyCFunction)Sbk_QTextCharFormatFunc_setFont, METH_O},
    {"setFontCapitalization", (PyCFunction)Sbk_QTextCharFormatFunc_setFontCapitalization, METH_O},
    {"setFontFamily", (PyCFunction)Sbk_QTextCharFormatFunc_setFontFamily, METH_O},
    {"setFontFixedPitch", (PyCFunction)Sbk_QTextCharFormatFunc_setFontFixedPitch, METH_O},
    {"setFontItalic", (PyCFunction)Sbk_QTextCharFormatFunc_setFontItalic, METH_O},
    {"setFontKerning", (PyCFunction)Sbk_QTextCharFormatFunc_setFontKerning, METH_O},
    {"setFontLetterSpacing", (PyCFunction)Sbk_QTextCharFormatFunc_setFontLetterSpacing, METH_O},
    {"setFontOverline", (PyCFunction)Sbk_QTextCharFormatFunc_setFontOverline, METH_O},
    {"setFontPointSize", (PyCFunction)Sbk_QTextCharFormatFunc_setFontPointSize, METH_O},
    {"setFontStrikeOut", (PyCFunction)Sbk_QTextCharFormatFunc_setFontStrikeOut, METH_O},
    {"setFontStyleHint", (PyCFunction)Sbk_QTextCharFormatFunc_setFontStyleHint, METH_VARARGS|METH_KEYWORDS},
    {"setFontStyleStrategy", (PyCFunction)Sbk_QTextCharFormatFunc_setFontStyleStrategy, METH_O},
    {"setFontUnderline", (PyCFunction)Sbk_QTextCharFormatFunc_setFontUnderline, METH_O},
    {"setFontWeight", (PyCFunction)Sbk_QTextCharFormatFunc_setFontWeight, METH_O},
    {"setFontWordSpacing", (PyCFunction)Sbk_QTextCharFormatFunc_setFontWordSpacing, METH_O},
    {"setTableCellColumnSpan", (PyCFunction)Sbk_QTextCharFormatFunc_setTableCellColumnSpan, METH_O},
    {"setTableCellRowSpan", (PyCFunction)Sbk_QTextCharFormatFunc_setTableCellRowSpan, METH_O},
    {"setTextOutline", (PyCFunction)Sbk_QTextCharFormatFunc_setTextOutline, METH_O},
    {"setToolTip", (PyCFunction)Sbk_QTextCharFormatFunc_setToolTip, METH_O},
    {"setUnderlineColor", (PyCFunction)Sbk_QTextCharFormatFunc_setUnderlineColor, METH_O},
    {"setUnderlineStyle", (PyCFunction)Sbk_QTextCharFormatFunc_setUnderlineStyle, METH_O},
    {"setVerticalAlignment", (PyCFunction)Sbk_QTextCharFormatFunc_setVerticalAlignment, METH_O},
    {"tableCellColumnSpan", (PyCFunction)Sbk_QTextCharFormatFunc_tableCellColumnSpan, METH_NOARGS},
    {"tableCellRowSpan", (PyCFunction)Sbk_QTextCharFormatFunc_tableCellRowSpan, METH_NOARGS},
    {"textOutline", (PyCFunction)Sbk_QTextCharFormatFunc_textOutline, METH_NOARGS},
    {"toolTip", (PyCFunction)Sbk_QTextCharFormatFunc_toolTip, METH_NOARGS},
    {"underlineColor", (PyCFunction)Sbk_QTextCharFormatFunc_underlineColor, METH_NOARGS},
    {"underlineStyle", (PyCFunction)Sbk_QTextCharFormatFunc_underlineStyle, METH_NOARGS},
    {"verticalAlignment", (PyCFunction)Sbk_QTextCharFormatFunc_verticalAlignment, METH_NOARGS},

    {"__copy__", (PyCFunction)Sbk_QTextCharFormat___copy__, METH_NOARGS},
    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QTextCharFormat_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QTextCharFormat",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QTextCharFormat_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QTextCharFormat_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern


void init_QTextCharFormat(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QTEXTCHARFORMAT_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QTextCharFormat_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QTextCharFormat_Type);
    Sbk_QTextCharFormat_Type.super.ht_type.tp_base = SbkPySide_QtGuiTypes[SBK_QTEXTFORMAT_IDX];
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QTextCharFormat_Type, &Shiboken::callCppDestructor<QTextCharFormat >);
    Py_INCREF((PyObject*)&Sbk_QTextCharFormat_Type); //Incref due the 'PyModule_AddObject' steals the reference.
    if (PyType_Ready((PyTypeObject*)&Sbk_QTextCharFormat_Type) < 0)
        return;

    Shiboken::ObjectType::setOriginalName(&Sbk_QTextCharFormat_Type, "QTextCharFormat");
    PyModule_AddObject(module, "QTextCharFormat",
        ((PyObject*)&Sbk_QTextCharFormat_Type));

    // Initialize enums
    PyObject* enumItem;

    // init enum: VerticalAlignment
    PyTypeObject* SbkPySide_QtGui_QTextCharFormat_VerticalAlignment = Shiboken::Enum::newType("PySide.QtGui.QTextCharFormat.VerticalAlignment");
    SbkPySide_QtGuiTypes[SBK_QTEXTCHARFORMAT_VERTICALALIGNMENT_IDX] = SbkPySide_QtGui_QTextCharFormat_VerticalAlignment;
    if (PyType_Ready(SbkPySide_QtGui_QTextCharFormat_VerticalAlignment) < 0)
        return;
    PyDict_SetItemString(Sbk_QTextCharFormat_Type.super.ht_type.tp_dict,
            "VerticalAlignment",((PyObject*)SbkPySide_QtGui_QTextCharFormat_VerticalAlignment));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTextCharFormat_VerticalAlignment,(long) QTextCharFormat::AlignNormal, "AlignNormal");
    PyDict_SetItemString(Sbk_QTextCharFormat_Type.super.ht_type.tp_dict,"AlignNormal", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTextCharFormat_VerticalAlignment->tp_dict,"AlignNormal", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTextCharFormat_VerticalAlignment,(long) QTextCharFormat::AlignSuperScript, "AlignSuperScript");
    PyDict_SetItemString(Sbk_QTextCharFormat_Type.super.ht_type.tp_dict,"AlignSuperScript", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTextCharFormat_VerticalAlignment->tp_dict,"AlignSuperScript", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTextCharFormat_VerticalAlignment,(long) QTextCharFormat::AlignSubScript, "AlignSubScript");
    PyDict_SetItemString(Sbk_QTextCharFormat_Type.super.ht_type.tp_dict,"AlignSubScript", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTextCharFormat_VerticalAlignment->tp_dict,"AlignSubScript", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTextCharFormat_VerticalAlignment,(long) QTextCharFormat::AlignMiddle, "AlignMiddle");
    PyDict_SetItemString(Sbk_QTextCharFormat_Type.super.ht_type.tp_dict,"AlignMiddle", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTextCharFormat_VerticalAlignment->tp_dict,"AlignMiddle", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTextCharFormat_VerticalAlignment,(long) QTextCharFormat::AlignTop, "AlignTop");
    PyDict_SetItemString(Sbk_QTextCharFormat_Type.super.ht_type.tp_dict,"AlignTop", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTextCharFormat_VerticalAlignment->tp_dict,"AlignTop", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTextCharFormat_VerticalAlignment,(long) QTextCharFormat::AlignBottom, "AlignBottom");
    PyDict_SetItemString(Sbk_QTextCharFormat_Type.super.ht_type.tp_dict,"AlignBottom", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTextCharFormat_VerticalAlignment->tp_dict,"AlignBottom", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QTextCharFormat::VerticalAlignment");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::VerticalAlignment");
    // end of enum VerticalAlignment

    // init enum: UnderlineStyle
    PyTypeObject* SbkPySide_QtGui_QTextCharFormat_UnderlineStyle = Shiboken::Enum::newType("PySide.QtGui.QTextCharFormat.UnderlineStyle");
    SbkPySide_QtGuiTypes[SBK_QTEXTCHARFORMAT_UNDERLINESTYLE_IDX] = SbkPySide_QtGui_QTextCharFormat_UnderlineStyle;
    if (PyType_Ready(SbkPySide_QtGui_QTextCharFormat_UnderlineStyle) < 0)
        return;
    PyDict_SetItemString(Sbk_QTextCharFormat_Type.super.ht_type.tp_dict,
            "UnderlineStyle",((PyObject*)SbkPySide_QtGui_QTextCharFormat_UnderlineStyle));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTextCharFormat_UnderlineStyle,(long) QTextCharFormat::NoUnderline, "NoUnderline");
    PyDict_SetItemString(Sbk_QTextCharFormat_Type.super.ht_type.tp_dict,"NoUnderline", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTextCharFormat_UnderlineStyle->tp_dict,"NoUnderline", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTextCharFormat_UnderlineStyle,(long) QTextCharFormat::SingleUnderline, "SingleUnderline");
    PyDict_SetItemString(Sbk_QTextCharFormat_Type.super.ht_type.tp_dict,"SingleUnderline", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTextCharFormat_UnderlineStyle->tp_dict,"SingleUnderline", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTextCharFormat_UnderlineStyle,(long) QTextCharFormat::DashUnderline, "DashUnderline");
    PyDict_SetItemString(Sbk_QTextCharFormat_Type.super.ht_type.tp_dict,"DashUnderline", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTextCharFormat_UnderlineStyle->tp_dict,"DashUnderline", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTextCharFormat_UnderlineStyle,(long) QTextCharFormat::DotLine, "DotLine");
    PyDict_SetItemString(Sbk_QTextCharFormat_Type.super.ht_type.tp_dict,"DotLine", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTextCharFormat_UnderlineStyle->tp_dict,"DotLine", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTextCharFormat_UnderlineStyle,(long) QTextCharFormat::DashDotLine, "DashDotLine");
    PyDict_SetItemString(Sbk_QTextCharFormat_Type.super.ht_type.tp_dict,"DashDotLine", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTextCharFormat_UnderlineStyle->tp_dict,"DashDotLine", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTextCharFormat_UnderlineStyle,(long) QTextCharFormat::DashDotDotLine, "DashDotDotLine");
    PyDict_SetItemString(Sbk_QTextCharFormat_Type.super.ht_type.tp_dict,"DashDotDotLine", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTextCharFormat_UnderlineStyle->tp_dict,"DashDotDotLine", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTextCharFormat_UnderlineStyle,(long) QTextCharFormat::WaveUnderline, "WaveUnderline");
    PyDict_SetItemString(Sbk_QTextCharFormat_Type.super.ht_type.tp_dict,"WaveUnderline", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTextCharFormat_UnderlineStyle->tp_dict,"WaveUnderline", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTextCharFormat_UnderlineStyle,(long) QTextCharFormat::SpellCheckUnderline, "SpellCheckUnderline");
    PyDict_SetItemString(Sbk_QTextCharFormat_Type.super.ht_type.tp_dict,"SpellCheckUnderline", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTextCharFormat_UnderlineStyle->tp_dict,"SpellCheckUnderline", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QTextCharFormat::UnderlineStyle");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::UnderlineStyle");
    // end of enum UnderlineStyle


    Shiboken::TypeResolver::createValueTypeResolver<QTextCharFormat >("QTextCharFormat");
    Shiboken::TypeResolver::createObjectTypeResolver<QTextCharFormat >("QTextCharFormat*");
    Shiboken::TypeResolver::createValueTypeResolver<QTextCharFormat >(typeid(QTextCharFormat).name());
    qRegisterMetaType< ::QTextCharFormat >("QTextCharFormat");
    qRegisterMetaType< ::QTextCharFormat::VerticalAlignment >("QTextCharFormat::VerticalAlignment");
    qRegisterMetaType< ::QTextCharFormat::UnderlineStyle >("QTextCharFormat::UnderlineStyle");
}

