/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtgui_python.h"

#include "qtextcursor_wrapper.h"

// Extra includes
#include <QTextBlock>
#include <QTextDocumentFragment>
#include <qimage.h>
#include <qtextcursor.h>
#include <qtextdocument.h>
#include <qtextdocumentfragment.h>
#include <qtextformat.h>
#include <qtextlist.h>
#include <qtextobject.h>
#include <qtexttable.h>



// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QTextCursor_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QTextCursor >()))
        return -1;

    QTextCursor* cptr = 0;
    int overloadId = -1;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QTextCursor", 0, 1, &(pyargs[0])))
        return -1;

    // Overloaded function decisor
    // 0: QTextCursor()
    // 1: QTextCursor(QTextDocument*)
    // 2: QTextCursor(QTextFrame*)
    // 3: QTextCursor(QTextBlock)
    // 4: QTextCursor(QTextCursor)
    if (numArgs == 0) {
        overloadId = 0; // QTextCursor()
    } else if (numArgs == 1 && Shiboken::Converter< ::QTextCursor >::isConvertible(pyargs[0])) {
        overloadId = 4; // QTextCursor(QTextCursor)
    } else if (numArgs == 1 && Shiboken::Converter< ::QTextBlock >::isConvertible(pyargs[0])) {
        overloadId = 3; // QTextCursor(QTextBlock)
    } else if (numArgs == 1 && Shiboken::Converter< ::QTextFrame * >::isConvertible(pyargs[0])) {
        overloadId = 2; // QTextCursor(QTextFrame*)
    } else if (numArgs == 1 && Shiboken::Converter< ::QTextDocument * >::isConvertible(pyargs[0])) {
        overloadId = 1; // QTextCursor(QTextDocument*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextCursor_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QTextCursor()
            {

                if(!PyErr_Occurred()) {
                    // QTextCursor()
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QTextCursor();
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // QTextCursor(QTextDocument*)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QTextDocument * cppArg0 = Shiboken::Converter<QTextDocument * >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QTextCursor(QTextDocument*)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QTextCursor(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 2: // QTextCursor(QTextFrame*)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QTextFrame * cppArg0 = Shiboken::Converter<QTextFrame * >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QTextCursor(QTextFrame*)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QTextCursor(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 3: // QTextCursor(QTextBlock)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QTextBlock cppArg0 = Shiboken::Converter<QTextBlock >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QTextCursor(QTextBlock)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QTextCursor(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 4: // QTextCursor(QTextCursor)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QTextCursor cppArg0 = Shiboken::Converter<QTextCursor >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QTextCursor(QTextCursor)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QTextCursor(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QTextCursor >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QTextCursor_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QTextCursor_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtGui.QTextDocument", "PySide.QtGui.QTextFrame", "PySide.QtGui.QTextBlock", "PySide.QtGui.QTextCursor", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QTextCursor", overloads);
        return -1;
}

static PyObject* Sbk_QTextCursorFunc_anchor(PyObject* self)
{
    QTextCursor* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextCursor* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // anchor()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QTextCursor*>(cppSelf)->anchor();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextCursorFunc_atBlockEnd(PyObject* self)
{
    QTextCursor* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextCursor* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // atBlockEnd()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QTextCursor*>(cppSelf)->atBlockEnd();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextCursorFunc_atBlockStart(PyObject* self)
{
    QTextCursor* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextCursor* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // atBlockStart()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QTextCursor*>(cppSelf)->atBlockStart();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextCursorFunc_atEnd(PyObject* self)
{
    QTextCursor* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextCursor* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // atEnd()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QTextCursor*>(cppSelf)->atEnd();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextCursorFunc_atStart(PyObject* self)
{
    QTextCursor* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextCursor* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // atStart()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QTextCursor*>(cppSelf)->atStart();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextCursorFunc_beginEditBlock(PyObject* self)
{
    QTextCursor* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextCursor* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // beginEditBlock()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->beginEditBlock();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QTextCursorFunc_block(PyObject* self)
{
    QTextCursor* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextCursor* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // block()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QTextBlock cppResult = const_cast<const QTextCursor*>(cppSelf)->block();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QTextBlock >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextCursorFunc_blockCharFormat(PyObject* self)
{
    QTextCursor* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextCursor* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // blockCharFormat()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QTextCharFormat cppResult = const_cast<const QTextCursor*>(cppSelf)->blockCharFormat();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QTextCharFormat >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextCursorFunc_blockFormat(PyObject* self)
{
    QTextCursor* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextCursor* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // blockFormat()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QTextBlockFormat cppResult = const_cast<const QTextCursor*>(cppSelf)->blockFormat();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QTextBlockFormat >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextCursorFunc_blockNumber(PyObject* self)
{
    QTextCursor* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextCursor* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // blockNumber()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QTextCursor*>(cppSelf)->blockNumber();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextCursorFunc_charFormat(PyObject* self)
{
    QTextCursor* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextCursor* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // charFormat()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QTextCharFormat cppResult = const_cast<const QTextCursor*>(cppSelf)->charFormat();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QTextCharFormat >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextCursorFunc_clearSelection(PyObject* self)
{
    QTextCursor* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextCursor* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // clearSelection()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->clearSelection();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QTextCursorFunc_columnNumber(PyObject* self)
{
    QTextCursor* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextCursor* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // columnNumber()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QTextCursor*>(cppSelf)->columnNumber();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextCursorFunc_createList(PyObject* self, PyObject* arg)
{
    QTextCursor* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextCursor* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: createList(QTextListFormat::Style)
    // 1: createList(QTextListFormat)
    if (Shiboken::Converter< ::QTextListFormat >::isConvertible(arg)) {
        overloadId = 1; // createList(QTextListFormat)
    } else if (Shiboken::Converter< ::QTextListFormat::Style >::isConvertible(arg)) {
        overloadId = 0; // createList(QTextListFormat::Style)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextCursorFunc_createList_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // createList(QTextListFormat::Style)
            {
                QTextListFormat::Style cppArg0 = Shiboken::Converter<QTextListFormat::Style >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // createList(QTextListFormat::Style)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QTextList * cppResult = cppSelf->createList(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QTextList * >::toPython(cppResult);
                    Shiboken::Object::setParent(self, pyResult);
                }
                break;
            }
            case 1: // createList(QTextListFormat)
            {
                if (!Shiboken::Object::isValid(arg))
                    return 0;
                QTextListFormat cppArg0 = Shiboken::Converter<QTextListFormat >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // createList(QTextListFormat)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QTextList * cppResult = cppSelf->createList(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QTextList * >::toPython(cppResult);
                    Shiboken::Object::setParent(self, pyResult);
                }
                break;
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QTextCursorFunc_createList_TypeError:
        const char* overloads[] = {"PySide.QtGui.QTextListFormat.Style", "PySide.QtGui.QTextListFormat", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextCursor.createList", overloads);
        return 0;
}

static PyObject* Sbk_QTextCursorFunc_currentFrame(PyObject* self)
{
    QTextCursor* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextCursor* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // currentFrame()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QTextFrame * cppResult = const_cast<const QTextCursor*>(cppSelf)->currentFrame();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QTextFrame * >::toPython(cppResult);

                // Ownership transferences.
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextCursorFunc_currentList(PyObject* self)
{
    QTextCursor* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextCursor* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // currentList()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QTextList * cppResult = const_cast<const QTextCursor*>(cppSelf)->currentList();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QTextList * >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextCursorFunc_currentTable(PyObject* self)
{
    QTextCursor* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextCursor* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // currentTable()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QTextTable * cppResult = const_cast<const QTextCursor*>(cppSelf)->currentTable();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QTextTable * >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextCursorFunc_deleteChar(PyObject* self)
{
    QTextCursor* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextCursor* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // deleteChar()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->deleteChar();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QTextCursorFunc_deletePreviousChar(PyObject* self)
{
    QTextCursor* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextCursor* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // deletePreviousChar()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->deletePreviousChar();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QTextCursorFunc_document(PyObject* self)
{
    QTextCursor* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextCursor* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // document()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QTextDocument * cppResult = const_cast<const QTextCursor*>(cppSelf)->document();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QTextDocument * >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextCursorFunc_endEditBlock(PyObject* self)
{
    QTextCursor* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextCursor* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // endEditBlock()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->endEditBlock();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QTextCursorFunc_hasComplexSelection(PyObject* self)
{
    QTextCursor* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextCursor* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // hasComplexSelection()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QTextCursor*>(cppSelf)->hasComplexSelection();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextCursorFunc_hasSelection(PyObject* self)
{
    QTextCursor* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextCursor* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // hasSelection()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QTextCursor*>(cppSelf)->hasSelection();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextCursorFunc_insertBlock(PyObject* self, PyObject* args)
{
    QTextCursor* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextCursor* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "insertBlock", 0, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: insertBlock()
    // 1: insertBlock(QTextBlockFormat)
    // 2: insertBlock(QTextBlockFormat,QTextCharFormat)
    if (numArgs == 0) {
        overloadId = 0; // insertBlock()
    } else if (Shiboken::Converter< ::QTextBlockFormat >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 1; // insertBlock(QTextBlockFormat)
        } else if (numArgs == 2 && Shiboken::Converter< ::QTextCharFormat >::isConvertible(pyargs[1])) {
            overloadId = 2; // insertBlock(QTextBlockFormat,QTextCharFormat)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextCursorFunc_insertBlock_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // insertBlock()
            {

                if(!PyErr_Occurred()) {
                    // insertBlock()
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->insertBlock();
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // insertBlock(QTextBlockFormat)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QTextBlockFormat cppArg0 = Shiboken::Converter<QTextBlockFormat >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // insertBlock(QTextBlockFormat)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->insertBlock(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 2: // insertBlock(QTextBlockFormat,QTextCharFormat)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QTextBlockFormat cppArg0 = Shiboken::Converter<QTextBlockFormat >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return 0;
                QTextCharFormat cppArg1 = Shiboken::Converter<QTextCharFormat >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // insertBlock(QTextBlockFormat,QTextCharFormat)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->insertBlock(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextCursorFunc_insertBlock_TypeError:
        const char* overloads[] = {"", "PySide.QtGui.QTextBlockFormat", "PySide.QtGui.QTextBlockFormat, PySide.QtGui.QTextCharFormat", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QTextCursor.insertBlock", overloads);
        return 0;
}

static PyObject* Sbk_QTextCursorFunc_insertFragment(PyObject* self, PyObject* arg)
{
    QTextCursor* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextCursor* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: insertFragment(QTextDocumentFragment)
    if (Shiboken::Converter< ::QTextDocumentFragment >::isConvertible(arg)) {
        overloadId = 0; // insertFragment(QTextDocumentFragment)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextCursorFunc_insertFragment_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QTextDocumentFragment cppArg0 = Shiboken::Converter<QTextDocumentFragment >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // insertFragment(QTextDocumentFragment)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->insertFragment(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextCursorFunc_insertFragment_TypeError:
        const char* overloads[] = {"PySide.QtGui.QTextDocumentFragment", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextCursor.insertFragment", overloads);
        return 0;
}

static PyObject* Sbk_QTextCursorFunc_insertFrame(PyObject* self, PyObject* arg)
{
    QTextCursor* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextCursor* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: insertFrame(QTextFrameFormat)
    if (Shiboken::Converter< ::QTextFrameFormat >::isConvertible(arg)) {
        overloadId = 0; // insertFrame(QTextFrameFormat)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextCursorFunc_insertFrame_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QTextFrameFormat cppArg0 = Shiboken::Converter<QTextFrameFormat >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // insertFrame(QTextFrameFormat)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QTextFrame * cppResult = cppSelf->insertFrame(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QTextFrame * >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QTextCursorFunc_insertFrame_TypeError:
        const char* overloads[] = {"PySide.QtGui.QTextFrameFormat", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextCursor.insertFrame", overloads);
        return 0;
}

static PyObject* Sbk_QTextCursorFunc_insertHtml(PyObject* self, PyObject* arg)
{
    QTextCursor* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextCursor* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: insertHtml(QString)
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // insertHtml(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextCursorFunc_insertHtml_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // insertHtml(QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->insertHtml(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextCursorFunc_insertHtml_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextCursor.insertHtml", overloads);
        return 0;
}

static PyObject* Sbk_QTextCursorFunc_insertImage(PyObject* self, PyObject* args, PyObject* kwds)
{
    QTextCursor* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextCursor* >::toCpp(self);

    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QTextCursor.insertImage(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QTextCursor.insertImage(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:insertImage", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: insertImage(QImage,QString)
    // 1: insertImage(QString)
    // 2: insertImage(QTextImageFormat)
    // 3: insertImage(QTextImageFormat,QTextFrameFormat::Position)
    if (Shiboken::Converter< ::QTextImageFormat >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 2; // insertImage(QTextImageFormat)
        } else if (numArgs == 2 && Shiboken::Converter< ::QTextFrameFormat::Position >::isConvertible(pyargs[1])) {
            overloadId = 3; // insertImage(QTextImageFormat,QTextFrameFormat::Position)
        }
    } else if (numArgs == 1 && Shiboken::Converter< QString >::isConvertible(pyargs[0])) {
        overloadId = 1; // insertImage(QString)
    } else if (Shiboken::Converter< ::QImage >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // insertImage(QImage,QString)
        } else if (Shiboken::Converter< QString >::isConvertible(pyargs[1])) {
            overloadId = 0; // insertImage(QImage,QString)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextCursorFunc_insertImage_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // insertImage(QImage,QString)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "name");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "name";
                        else if (Shiboken::Converter< QString >::isConvertible(value))
                            pyargs[1] = value;
                        else
                            goto Sbk_QTextCursorFunc_insertImage_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QTextCursor.insertImage(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QImage cppArg0 = Shiboken::Converter<QImage >::toCpp(pyargs[0]);
                QString cppArg1 = pyargs[1] ? Shiboken::Converter<QString >::toCpp(pyargs[1]) : QString();

                if(!PyErr_Occurred()) {
                    // insertImage(QImage,QString)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->insertImage(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // insertImage(QString)
            {
                QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // insertImage(QString)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->insertImage(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 2: // insertImage(QTextImageFormat)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QTextImageFormat cppArg0 = Shiboken::Converter<QTextImageFormat >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // insertImage(QTextImageFormat)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->insertImage(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 3: // insertImage(QTextImageFormat,QTextFrameFormat::Position)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QTextImageFormat cppArg0 = Shiboken::Converter<QTextImageFormat >::toCpp(pyargs[0]);
                QTextFrameFormat::Position cppArg1 = Shiboken::Converter<QTextFrameFormat::Position >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // insertImage(QTextImageFormat,QTextFrameFormat::Position)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->insertImage(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextCursorFunc_insertImage_TypeError:
        const char* overloads[] = {"PySide.QtGui.QImage, QString = QString()", "QString", "PySide.QtGui.QTextImageFormat", "PySide.QtGui.QTextImageFormat, PySide.QtGui.QTextFrameFormat.Position", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QTextCursor.insertImage", overloads);
        return 0;
}

static PyObject* Sbk_QTextCursorFunc_insertList(PyObject* self, PyObject* arg)
{
    QTextCursor* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextCursor* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: insertList(QTextListFormat::Style)
    // 1: insertList(QTextListFormat)
    if (Shiboken::Converter< ::QTextListFormat >::isConvertible(arg)) {
        overloadId = 1; // insertList(QTextListFormat)
    } else if (Shiboken::Converter< ::QTextListFormat::Style >::isConvertible(arg)) {
        overloadId = 0; // insertList(QTextListFormat::Style)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextCursorFunc_insertList_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // insertList(QTextListFormat::Style)
            {
                QTextListFormat::Style cppArg0 = Shiboken::Converter<QTextListFormat::Style >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // insertList(QTextListFormat::Style)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QTextList * cppResult = cppSelf->insertList(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QTextList * >::toPython(cppResult);
                    Shiboken::Object::setParent(self, pyResult);
                }
                break;
            }
            case 1: // insertList(QTextListFormat)
            {
                if (!Shiboken::Object::isValid(arg))
                    return 0;
                QTextListFormat cppArg0 = Shiboken::Converter<QTextListFormat >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // insertList(QTextListFormat)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QTextList * cppResult = cppSelf->insertList(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QTextList * >::toPython(cppResult);
                    Shiboken::Object::setParent(self, pyResult);
                }
                break;
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QTextCursorFunc_insertList_TypeError:
        const char* overloads[] = {"PySide.QtGui.QTextListFormat.Style", "PySide.QtGui.QTextListFormat", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextCursor.insertList", overloads);
        return 0;
}

static PyObject* Sbk_QTextCursorFunc_insertTable(PyObject* self, PyObject* args)
{
    QTextCursor* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextCursor* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "insertTable", 2, 3, &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: insertTable(int,int)
    // 1: insertTable(int,int,QTextTableFormat)
    if (numArgs >= 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        if (numArgs == 2) {
            overloadId = 0; // insertTable(int,int)
        } else if (numArgs == 3 && Shiboken::Converter< ::QTextTableFormat >::isConvertible(pyargs[2])) {
            overloadId = 1; // insertTable(int,int,QTextTableFormat)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextCursorFunc_insertTable_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // insertTable(int,int)
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // insertTable(int,int)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QTextTable * cppResult = cppSelf->insertTable(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QTextTable * >::toPython(cppResult);

                    // Ownership transferences.
                }
                break;
            }
            case 1: // insertTable(int,int,QTextTableFormat)
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                if (!Shiboken::Object::isValid(pyargs[2]))
                    return 0;
                QTextTableFormat cppArg2 = Shiboken::Converter<QTextTableFormat >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                    // insertTable(int,int,QTextTableFormat)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QTextTable * cppResult = cppSelf->insertTable(cppArg0, cppArg1, cppArg2);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QTextTable * >::toPython(cppResult);

                    // Ownership transferences.
                }
                break;
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QTextCursorFunc_insertTable_TypeError:
        const char* overloads[] = {"int, int", "int, int, PySide.QtGui.QTextTableFormat", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QTextCursor.insertTable", overloads);
        return 0;
}

static PyObject* Sbk_QTextCursorFunc_insertText(PyObject* self, PyObject* args)
{
    QTextCursor* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextCursor* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "insertText", 1, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: insertText(QString)
    // 1: insertText(QString,QTextCharFormat)
    if (Shiboken::Converter< QString >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // insertText(QString)
        } else if (numArgs == 2 && Shiboken::Converter< ::QTextCharFormat >::isConvertible(pyargs[1])) {
            overloadId = 1; // insertText(QString,QTextCharFormat)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextCursorFunc_insertText_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // insertText(QString)
            {
                QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // insertText(QString)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->insertText(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // insertText(QString,QTextCharFormat)
            {
                QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return 0;
                QTextCharFormat cppArg1 = Shiboken::Converter<QTextCharFormat >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // insertText(QString,QTextCharFormat)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->insertText(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextCursorFunc_insertText_TypeError:
        const char* overloads[] = {"QString", "QString, PySide.QtGui.QTextCharFormat", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QTextCursor.insertText", overloads);
        return 0;
}

static PyObject* Sbk_QTextCursorFunc_isCopyOf(PyObject* self, PyObject* arg)
{
    QTextCursor* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextCursor* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: isCopyOf(QTextCursor)const
    if (Shiboken::Converter< ::QTextCursor >::isConvertible(arg)) {
        overloadId = 0; // isCopyOf(QTextCursor)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextCursorFunc_isCopyOf_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QTextCursor cppArg0 = Shiboken::Converter<QTextCursor >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // isCopyOf(QTextCursor)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QTextCursor*>(cppSelf)->isCopyOf(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QTextCursorFunc_isCopyOf_TypeError:
        const char* overloads[] = {"PySide.QtGui.QTextCursor", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextCursor.isCopyOf", overloads);
        return 0;
}

static PyObject* Sbk_QTextCursorFunc_isNull(PyObject* self)
{
    QTextCursor* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextCursor* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isNull()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QTextCursor*>(cppSelf)->isNull();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextCursorFunc_joinPreviousEditBlock(PyObject* self)
{
    QTextCursor* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextCursor* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // joinPreviousEditBlock()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->joinPreviousEditBlock();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QTextCursorFunc_keepPositionOnInsert(PyObject* self)
{
    QTextCursor* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextCursor* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // keepPositionOnInsert()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QTextCursor*>(cppSelf)->keepPositionOnInsert();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextCursorFunc_mergeBlockCharFormat(PyObject* self, PyObject* arg)
{
    QTextCursor* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextCursor* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: mergeBlockCharFormat(QTextCharFormat)
    if (Shiboken::Converter< ::QTextCharFormat >::isConvertible(arg)) {
        overloadId = 0; // mergeBlockCharFormat(QTextCharFormat)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextCursorFunc_mergeBlockCharFormat_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QTextCharFormat cppArg0 = Shiboken::Converter<QTextCharFormat >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // mergeBlockCharFormat(QTextCharFormat)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->mergeBlockCharFormat(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextCursorFunc_mergeBlockCharFormat_TypeError:
        const char* overloads[] = {"PySide.QtGui.QTextCharFormat", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextCursor.mergeBlockCharFormat", overloads);
        return 0;
}

static PyObject* Sbk_QTextCursorFunc_mergeBlockFormat(PyObject* self, PyObject* arg)
{
    QTextCursor* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextCursor* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: mergeBlockFormat(QTextBlockFormat)
    if (Shiboken::Converter< ::QTextBlockFormat >::isConvertible(arg)) {
        overloadId = 0; // mergeBlockFormat(QTextBlockFormat)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextCursorFunc_mergeBlockFormat_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QTextBlockFormat cppArg0 = Shiboken::Converter<QTextBlockFormat >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // mergeBlockFormat(QTextBlockFormat)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->mergeBlockFormat(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextCursorFunc_mergeBlockFormat_TypeError:
        const char* overloads[] = {"PySide.QtGui.QTextBlockFormat", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextCursor.mergeBlockFormat", overloads);
        return 0;
}

static PyObject* Sbk_QTextCursorFunc_mergeCharFormat(PyObject* self, PyObject* arg)
{
    QTextCursor* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextCursor* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: mergeCharFormat(QTextCharFormat)
    if (Shiboken::Converter< ::QTextCharFormat >::isConvertible(arg)) {
        overloadId = 0; // mergeCharFormat(QTextCharFormat)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextCursorFunc_mergeCharFormat_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QTextCharFormat cppArg0 = Shiboken::Converter<QTextCharFormat >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // mergeCharFormat(QTextCharFormat)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->mergeCharFormat(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextCursorFunc_mergeCharFormat_TypeError:
        const char* overloads[] = {"PySide.QtGui.QTextCharFormat", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextCursor.mergeCharFormat", overloads);
        return 0;
}

static PyObject* Sbk_QTextCursorFunc_movePosition(PyObject* self, PyObject* args, PyObject* kwds)
{
    QTextCursor* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextCursor* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QTextCursor.movePosition(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QTextCursor.movePosition(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOO:movePosition", &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: movePosition(QTextCursor::MoveOperation,QTextCursor::MoveMode,int)
    if (Shiboken::Converter< ::QTextCursor::MoveOperation >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // movePosition(QTextCursor::MoveOperation,QTextCursor::MoveMode,int)
        } else if (Shiboken::Converter< ::QTextCursor::MoveMode >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 0; // movePosition(QTextCursor::MoveOperation,QTextCursor::MoveMode,int)
            } else if (SbkNumber_Check(pyargs[2])) {
                overloadId = 0; // movePosition(QTextCursor::MoveOperation,QTextCursor::MoveMode,int)
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextCursorFunc_movePosition_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "arg__2");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "arg__2";
                    else if (Shiboken::Converter< ::QTextCursor::MoveMode >::isConvertible(value))
                        pyargs[1] = value;
                    else
                        goto Sbk_QTextCursorFunc_movePosition_TypeError;
                }
                value = PyDict_GetItemString(kwds, "n");
                if (value) {
                    if (pyargs[2])
                        errorArgName = "n";
                    else if (SbkNumber_Check(value))
                        pyargs[2] = value;
                    else
                        goto Sbk_QTextCursorFunc_movePosition_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QTextCursor.movePosition(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QTextCursor::MoveOperation cppArg0 = Shiboken::Converter<QTextCursor::MoveOperation >::toCpp(pyargs[0]);
            QTextCursor::MoveMode cppArg1 = pyargs[1] ? Shiboken::Converter<QTextCursor::MoveMode >::toCpp(pyargs[1]) : QTextCursor::MoveAnchor;
            int cppArg2 = pyargs[2] ? Shiboken::Converter<int >::toCpp(pyargs[2]) : 1;

            if(!PyErr_Occurred()) {
                // movePosition(QTextCursor::MoveOperation,QTextCursor::MoveMode,int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->movePosition(cppArg0, cppArg1, cppArg2);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QTextCursorFunc_movePosition_TypeError:
        const char* overloads[] = {"PySide.QtGui.QTextCursor.MoveOperation, PySide.QtGui.QTextCursor.MoveMode = MoveAnchor, int = 1", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QTextCursor.movePosition", overloads);
        return 0;
}

static PyObject* Sbk_QTextCursorFunc_position(PyObject* self)
{
    QTextCursor* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextCursor* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // position()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QTextCursor*>(cppSelf)->position();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextCursorFunc_positionInBlock(PyObject* self)
{
    QTextCursor* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextCursor* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // positionInBlock()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QTextCursor*>(cppSelf)->positionInBlock();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextCursorFunc_removeSelectedText(PyObject* self)
{
    QTextCursor* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextCursor* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // removeSelectedText()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->removeSelectedText();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QTextCursorFunc_select(PyObject* self, PyObject* arg)
{
    QTextCursor* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextCursor* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: select(QTextCursor::SelectionType)
    if (Shiboken::Converter< ::QTextCursor::SelectionType >::isConvertible(arg)) {
        overloadId = 0; // select(QTextCursor::SelectionType)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextCursorFunc_select_TypeError;

    // Call function/method
    {
        {
            QTextCursor::SelectionType cppArg0 = Shiboken::Converter<QTextCursor::SelectionType >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // select(QTextCursor::SelectionType)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->select(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextCursorFunc_select_TypeError:
        const char* overloads[] = {"PySide.QtGui.QTextCursor.SelectionType", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextCursor.select", overloads);
        return 0;
}

static PyObject* Sbk_QTextCursorFunc_selectedTableCells(PyObject* self)
{
    QTextCursor* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextCursor* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // selectedTableCells(int*,int*,int*,int*)const
                // Begin code injection

                // TEMPLATE - fix_number*,number*,number*,number* - START
                int a, b, c, d;
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->::QTextCursor::selectedTableCells(&a, &b, &c, &d);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::makeTuple(a, b, c, d);
                // TEMPLATE - fix_number*,number*,number*,number* - END

                // End of code injection


            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextCursorFunc_selectedText(PyObject* self)
{
    QTextCursor* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextCursor* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // selectedText()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = const_cast<const QTextCursor*>(cppSelf)->selectedText();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextCursorFunc_selection(PyObject* self)
{
    QTextCursor* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextCursor* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // selection()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QTextDocumentFragment cppResult = const_cast<const QTextCursor*>(cppSelf)->selection();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QTextDocumentFragment >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextCursorFunc_selectionEnd(PyObject* self)
{
    QTextCursor* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextCursor* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // selectionEnd()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QTextCursor*>(cppSelf)->selectionEnd();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextCursorFunc_selectionStart(PyObject* self)
{
    QTextCursor* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextCursor* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // selectionStart()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QTextCursor*>(cppSelf)->selectionStart();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextCursorFunc_setBlockCharFormat(PyObject* self, PyObject* arg)
{
    QTextCursor* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextCursor* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setBlockCharFormat(QTextCharFormat)
    if (Shiboken::Converter< ::QTextCharFormat >::isConvertible(arg)) {
        overloadId = 0; // setBlockCharFormat(QTextCharFormat)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextCursorFunc_setBlockCharFormat_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QTextCharFormat cppArg0 = Shiboken::Converter<QTextCharFormat >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setBlockCharFormat(QTextCharFormat)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setBlockCharFormat(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextCursorFunc_setBlockCharFormat_TypeError:
        const char* overloads[] = {"PySide.QtGui.QTextCharFormat", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextCursor.setBlockCharFormat", overloads);
        return 0;
}

static PyObject* Sbk_QTextCursorFunc_setBlockFormat(PyObject* self, PyObject* arg)
{
    QTextCursor* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextCursor* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setBlockFormat(QTextBlockFormat)
    if (Shiboken::Converter< ::QTextBlockFormat >::isConvertible(arg)) {
        overloadId = 0; // setBlockFormat(QTextBlockFormat)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextCursorFunc_setBlockFormat_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QTextBlockFormat cppArg0 = Shiboken::Converter<QTextBlockFormat >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setBlockFormat(QTextBlockFormat)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setBlockFormat(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextCursorFunc_setBlockFormat_TypeError:
        const char* overloads[] = {"PySide.QtGui.QTextBlockFormat", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextCursor.setBlockFormat", overloads);
        return 0;
}

static PyObject* Sbk_QTextCursorFunc_setCharFormat(PyObject* self, PyObject* arg)
{
    QTextCursor* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextCursor* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setCharFormat(QTextCharFormat)
    if (Shiboken::Converter< ::QTextCharFormat >::isConvertible(arg)) {
        overloadId = 0; // setCharFormat(QTextCharFormat)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextCursorFunc_setCharFormat_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QTextCharFormat cppArg0 = Shiboken::Converter<QTextCharFormat >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setCharFormat(QTextCharFormat)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setCharFormat(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextCursorFunc_setCharFormat_TypeError:
        const char* overloads[] = {"PySide.QtGui.QTextCharFormat", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextCursor.setCharFormat", overloads);
        return 0;
}

static PyObject* Sbk_QTextCursorFunc_setKeepPositionOnInsert(PyObject* self, PyObject* arg)
{
    QTextCursor* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextCursor* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setKeepPositionOnInsert(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setKeepPositionOnInsert(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextCursorFunc_setKeepPositionOnInsert_TypeError;

    // Call function/method
    {
        {
            bool cppArg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setKeepPositionOnInsert(bool)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setKeepPositionOnInsert(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextCursorFunc_setKeepPositionOnInsert_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextCursor.setKeepPositionOnInsert", overloads);
        return 0;
}

static PyObject* Sbk_QTextCursorFunc_setPosition(PyObject* self, PyObject* args, PyObject* kwds)
{
    QTextCursor* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextCursor* >::toCpp(self);

    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QTextCursor.setPosition(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QTextCursor.setPosition(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:setPosition", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setPosition(int,QTextCursor::MoveMode)
    if (SbkNumber_Check(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // setPosition(int,QTextCursor::MoveMode)
        } else if (Shiboken::Converter< ::QTextCursor::MoveMode >::isConvertible(pyargs[1])) {
            overloadId = 0; // setPosition(int,QTextCursor::MoveMode)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextCursorFunc_setPosition_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "mode");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "mode";
                    else if (Shiboken::Converter< ::QTextCursor::MoveMode >::isConvertible(value))
                        pyargs[1] = value;
                    else
                        goto Sbk_QTextCursorFunc_setPosition_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QTextCursor.setPosition(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            QTextCursor::MoveMode cppArg1 = pyargs[1] ? Shiboken::Converter<QTextCursor::MoveMode >::toCpp(pyargs[1]) : QTextCursor::MoveAnchor;

            if(!PyErr_Occurred()) {
                // setPosition(int,QTextCursor::MoveMode)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setPosition(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextCursorFunc_setPosition_TypeError:
        const char* overloads[] = {"int, PySide.QtGui.QTextCursor.MoveMode = MoveAnchor", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QTextCursor.setPosition", overloads);
        return 0;
}

static PyObject* Sbk_QTextCursorFunc_setVerticalMovementX(PyObject* self, PyObject* arg)
{
    QTextCursor* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextCursor* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setVerticalMovementX(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setVerticalMovementX(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextCursorFunc_setVerticalMovementX_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setVerticalMovementX(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setVerticalMovementX(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextCursorFunc_setVerticalMovementX_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextCursor.setVerticalMovementX", overloads);
        return 0;
}

static PyObject* Sbk_QTextCursorFunc_setVisualNavigation(PyObject* self, PyObject* arg)
{
    QTextCursor* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextCursor* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setVisualNavigation(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setVisualNavigation(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextCursorFunc_setVisualNavigation_TypeError;

    // Call function/method
    {
        {
            bool cppArg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setVisualNavigation(bool)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setVisualNavigation(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextCursorFunc_setVisualNavigation_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextCursor.setVisualNavigation", overloads);
        return 0;
}

static PyObject* Sbk_QTextCursorFunc_verticalMovementX(PyObject* self)
{
    QTextCursor* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextCursor* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // verticalMovementX()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QTextCursor*>(cppSelf)->verticalMovementX();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextCursorFunc_visualNavigation(PyObject* self)
{
    QTextCursor* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextCursor* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // visualNavigation()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QTextCursor*>(cppSelf)->visualNavigation();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject *Sbk_QTextCursor___copy__(PyObject *self)
{
        QTextCursor* cppSelf = 0;
        if (!Shiboken::Object::isValid(self))
            return 0;
        cppSelf = Shiboken::Converter<QTextCursor*>::toCpp(self);
        PyObject* pyResult = 0;
        QTextCursor* copy = new QTextCursor(*cppSelf);
        pyResult = Shiboken::Converter<QTextCursor*>::toPython(copy);
        Shiboken::Object::getOwnership(pyResult);

        if (PyErr_Occurred() || !pyResult) {
            Py_XDECREF(pyResult);
            return 0;
        }
        return pyResult;
}

static PyMethodDef Sbk_QTextCursor_methods[] = {
    {"anchor", (PyCFunction)Sbk_QTextCursorFunc_anchor, METH_NOARGS},
    {"atBlockEnd", (PyCFunction)Sbk_QTextCursorFunc_atBlockEnd, METH_NOARGS},
    {"atBlockStart", (PyCFunction)Sbk_QTextCursorFunc_atBlockStart, METH_NOARGS},
    {"atEnd", (PyCFunction)Sbk_QTextCursorFunc_atEnd, METH_NOARGS},
    {"atStart", (PyCFunction)Sbk_QTextCursorFunc_atStart, METH_NOARGS},
    {"beginEditBlock", (PyCFunction)Sbk_QTextCursorFunc_beginEditBlock, METH_NOARGS},
    {"block", (PyCFunction)Sbk_QTextCursorFunc_block, METH_NOARGS},
    {"blockCharFormat", (PyCFunction)Sbk_QTextCursorFunc_blockCharFormat, METH_NOARGS},
    {"blockFormat", (PyCFunction)Sbk_QTextCursorFunc_blockFormat, METH_NOARGS},
    {"blockNumber", (PyCFunction)Sbk_QTextCursorFunc_blockNumber, METH_NOARGS},
    {"charFormat", (PyCFunction)Sbk_QTextCursorFunc_charFormat, METH_NOARGS},
    {"clearSelection", (PyCFunction)Sbk_QTextCursorFunc_clearSelection, METH_NOARGS},
    {"columnNumber", (PyCFunction)Sbk_QTextCursorFunc_columnNumber, METH_NOARGS},
    {"createList", (PyCFunction)Sbk_QTextCursorFunc_createList, METH_O},
    {"currentFrame", (PyCFunction)Sbk_QTextCursorFunc_currentFrame, METH_NOARGS},
    {"currentList", (PyCFunction)Sbk_QTextCursorFunc_currentList, METH_NOARGS},
    {"currentTable", (PyCFunction)Sbk_QTextCursorFunc_currentTable, METH_NOARGS},
    {"deleteChar", (PyCFunction)Sbk_QTextCursorFunc_deleteChar, METH_NOARGS},
    {"deletePreviousChar", (PyCFunction)Sbk_QTextCursorFunc_deletePreviousChar, METH_NOARGS},
    {"document", (PyCFunction)Sbk_QTextCursorFunc_document, METH_NOARGS},
    {"endEditBlock", (PyCFunction)Sbk_QTextCursorFunc_endEditBlock, METH_NOARGS},
    {"hasComplexSelection", (PyCFunction)Sbk_QTextCursorFunc_hasComplexSelection, METH_NOARGS},
    {"hasSelection", (PyCFunction)Sbk_QTextCursorFunc_hasSelection, METH_NOARGS},
    {"insertBlock", (PyCFunction)Sbk_QTextCursorFunc_insertBlock, METH_VARARGS},
    {"insertFragment", (PyCFunction)Sbk_QTextCursorFunc_insertFragment, METH_O},
    {"insertFrame", (PyCFunction)Sbk_QTextCursorFunc_insertFrame, METH_O},
    {"insertHtml", (PyCFunction)Sbk_QTextCursorFunc_insertHtml, METH_O},
    {"insertImage", (PyCFunction)Sbk_QTextCursorFunc_insertImage, METH_VARARGS|METH_KEYWORDS},
    {"insertList", (PyCFunction)Sbk_QTextCursorFunc_insertList, METH_O},
    {"insertTable", (PyCFunction)Sbk_QTextCursorFunc_insertTable, METH_VARARGS},
    {"insertText", (PyCFunction)Sbk_QTextCursorFunc_insertText, METH_VARARGS},
    {"isCopyOf", (PyCFunction)Sbk_QTextCursorFunc_isCopyOf, METH_O},
    {"isNull", (PyCFunction)Sbk_QTextCursorFunc_isNull, METH_NOARGS},
    {"joinPreviousEditBlock", (PyCFunction)Sbk_QTextCursorFunc_joinPreviousEditBlock, METH_NOARGS},
    {"keepPositionOnInsert", (PyCFunction)Sbk_QTextCursorFunc_keepPositionOnInsert, METH_NOARGS},
    {"mergeBlockCharFormat", (PyCFunction)Sbk_QTextCursorFunc_mergeBlockCharFormat, METH_O},
    {"mergeBlockFormat", (PyCFunction)Sbk_QTextCursorFunc_mergeBlockFormat, METH_O},
    {"mergeCharFormat", (PyCFunction)Sbk_QTextCursorFunc_mergeCharFormat, METH_O},
    {"movePosition", (PyCFunction)Sbk_QTextCursorFunc_movePosition, METH_VARARGS|METH_KEYWORDS},
    {"position", (PyCFunction)Sbk_QTextCursorFunc_position, METH_NOARGS},
    {"positionInBlock", (PyCFunction)Sbk_QTextCursorFunc_positionInBlock, METH_NOARGS},
    {"removeSelectedText", (PyCFunction)Sbk_QTextCursorFunc_removeSelectedText, METH_NOARGS},
    {"select", (PyCFunction)Sbk_QTextCursorFunc_select, METH_O},
    {"selectedTableCells", (PyCFunction)Sbk_QTextCursorFunc_selectedTableCells, METH_NOARGS},
    {"selectedText", (PyCFunction)Sbk_QTextCursorFunc_selectedText, METH_NOARGS},
    {"selection", (PyCFunction)Sbk_QTextCursorFunc_selection, METH_NOARGS},
    {"selectionEnd", (PyCFunction)Sbk_QTextCursorFunc_selectionEnd, METH_NOARGS},
    {"selectionStart", (PyCFunction)Sbk_QTextCursorFunc_selectionStart, METH_NOARGS},
    {"setBlockCharFormat", (PyCFunction)Sbk_QTextCursorFunc_setBlockCharFormat, METH_O},
    {"setBlockFormat", (PyCFunction)Sbk_QTextCursorFunc_setBlockFormat, METH_O},
    {"setCharFormat", (PyCFunction)Sbk_QTextCursorFunc_setCharFormat, METH_O},
    {"setKeepPositionOnInsert", (PyCFunction)Sbk_QTextCursorFunc_setKeepPositionOnInsert, METH_O},
    {"setPosition", (PyCFunction)Sbk_QTextCursorFunc_setPosition, METH_VARARGS|METH_KEYWORDS},
    {"setVerticalMovementX", (PyCFunction)Sbk_QTextCursorFunc_setVerticalMovementX, METH_O},
    {"setVisualNavigation", (PyCFunction)Sbk_QTextCursorFunc_setVisualNavigation, METH_O},
    {"verticalMovementX", (PyCFunction)Sbk_QTextCursorFunc_verticalMovementX, METH_NOARGS},
    {"visualNavigation", (PyCFunction)Sbk_QTextCursorFunc_visualNavigation, METH_NOARGS},

    {"__copy__", (PyCFunction)Sbk_QTextCursor___copy__, METH_NOARGS},
    {0} // Sentinel
};

static int Sbk_QTextCursor___nb_bool(PyObject* pyObj)
{
    if (!Shiboken::Object::isValid(pyObj))
        return -1;
    const ::QTextCursor* cppSelf = Shiboken::Converter< ::QTextCursor*>::toCpp(pyObj);
    int result;
    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
    result = !cppSelf->isNull();
    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
    return result;
}

// type has number operators
static PyNumberMethods Sbk_QTextCursor_as_number = {
    /*nb_add*/                  (binaryfunc)0,
    /*nb_subtract*/             (binaryfunc)0,
    /*nb_multiply*/             (binaryfunc)0,
    /*nb_divide*/               (binaryfunc)0,
    /*nb_remainder*/            (binaryfunc)0,
    /*nb_divmod*/               0,
    /*nb_power*/                0,
    /*nb_negative*/             (unaryfunc)0,
    /*nb_positive*/             (unaryfunc)0,
    /*nb_absolute*/             0,
    /*nb_nonzero*/              Sbk_QTextCursor___nb_bool,
    /*nb_invert*/               (unaryfunc)0,
    /*nb_lshift*/               (binaryfunc)0,
    /*nb_rshift*/               (binaryfunc)0,
    /*nb_and*/                  (binaryfunc)0,
    /*nb_xor*/                  (binaryfunc)0,
    /*nb_or*/                   (binaryfunc)0,
    /*nb_coerce*/               0,
    /*nb_int*/                  0,
    /*nb_long*/                 0,
    /*nb_float*/                0,
    /*nb_oct*/                  0,
    /*nb_hex*/                  0,
    /*nb_inplace_add*/          (binaryfunc)0,
    /*nb_inplace_subtract*/     (binaryfunc)0,
    /*nb_inplace_multiply*/     (binaryfunc)0,
    /*nb_inplace_divide*/       (binaryfunc)0,
    /*nb_inplace_remainder*/    (binaryfunc)0,
    /*nb_inplace_power*/        0,
    /*nb_inplace_lshift*/       (binaryfunc)0,
    /*nb_inplace_rshift*/       (binaryfunc)0,
    /*nb_inplace_and*/          (binaryfunc)0,
    /*nb_inplace_xor*/          (binaryfunc)0,
    /*nb_inplace_or*/           (binaryfunc)0,
    /*nb_floor_divide*/         0,
    /*nb_true_divide*/          (binaryfunc)0,
    /*nb_inplace_floor_divide*/ 0,
    /*nb_inplace_true_divide*/  0,
    /*nb_index*/                0
};

// Rich comparison
static PyObject* Sbk_QTextCursor_richcompare(PyObject* self, PyObject* arg, int op)
{
    PyObject* pyResult = 0;
    QTextCursor& cppSelf = *Shiboken::Converter< QTextCursor* >::toCpp(self);

    switch (op) {
        case Py_NE:
            if (Shiboken::Converter< ::QTextCursor >::isConvertible(arg)) {
                // operator!=(const QTextCursor & rhs) const
                QTextCursor cppArg0 = Shiboken::Converter< ::QTextCursor >::toCpp(arg);
                pyResult = Shiboken::Converter< bool >::toPython(cppSelf != cppArg0);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_LT:
            if (Shiboken::Converter< ::QTextCursor >::isConvertible(arg)) {
                // operator<(const QTextCursor & rhs) const
                QTextCursor cppArg0 = Shiboken::Converter< ::QTextCursor >::toCpp(arg);
                pyResult = Shiboken::Converter< bool >::toPython(cppSelf < cppArg0);
            } else {
                goto Sbk_QTextCursor_RichComparison_TypeError;
            }

            break;
        case Py_LE:
            if (Shiboken::Converter< ::QTextCursor >::isConvertible(arg)) {
                // operator<=(const QTextCursor & rhs) const
                QTextCursor cppArg0 = Shiboken::Converter< ::QTextCursor >::toCpp(arg);
                pyResult = Shiboken::Converter< bool >::toPython(cppSelf <= cppArg0);
            } else {
                goto Sbk_QTextCursor_RichComparison_TypeError;
            }

            break;
        case Py_EQ:
            if (Shiboken::Converter< ::QTextCursor >::isConvertible(arg)) {
                // operator==(const QTextCursor & rhs) const
                QTextCursor cppArg0 = Shiboken::Converter< ::QTextCursor >::toCpp(arg);
                pyResult = Shiboken::Converter< bool >::toPython(cppSelf == cppArg0);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        case Py_GT:
            if (Shiboken::Converter< ::QTextCursor >::isConvertible(arg)) {
                // operator>(const QTextCursor & rhs) const
                QTextCursor cppArg0 = Shiboken::Converter< ::QTextCursor >::toCpp(arg);
                pyResult = Shiboken::Converter< bool >::toPython(cppSelf > cppArg0);
            } else {
                goto Sbk_QTextCursor_RichComparison_TypeError;
            }

            break;
        case Py_GE:
            if (Shiboken::Converter< ::QTextCursor >::isConvertible(arg)) {
                // operator>=(const QTextCursor & rhs) const
                QTextCursor cppArg0 = Shiboken::Converter< ::QTextCursor >::toCpp(arg);
                pyResult = Shiboken::Converter< bool >::toPython(cppSelf >= cppArg0);
            } else {
                goto Sbk_QTextCursor_RichComparison_TypeError;
            }

            break;
        default:
            goto Sbk_QTextCursor_RichComparison_TypeError;
    }

    if (pyResult && !PyErr_Occurred())
        return pyResult;
    Sbk_QTextCursor_RichComparison_TypeError:
    PyErr_SetString(PyExc_NotImplementedError, "operator not implemented.");
    return 0;

}

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QTextCursor_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QTextCursor",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        &Sbk_QTextCursor_as_number,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      Sbk_QTextCursor_richcompare,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QTextCursor_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&SbkObject_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QTextCursor_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern


void init_QTextCursor(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QTEXTCURSOR_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QTextCursor_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QTextCursor_Type);
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QTextCursor_Type, &Shiboken::callCppDestructor<QTextCursor >);
    Py_INCREF((PyObject*)&Sbk_QTextCursor_Type); //Incref due the 'PyModule_AddObject' steals the reference.
    if (PyType_Ready((PyTypeObject*)&Sbk_QTextCursor_Type) < 0)
        return;

    Shiboken::ObjectType::setOriginalName(&Sbk_QTextCursor_Type, "QTextCursor");
    PyModule_AddObject(module, "QTextCursor",
        ((PyObject*)&Sbk_QTextCursor_Type));

    // Initialize enums
    PyObject* enumItem;

    // init enum: MoveMode
    PyTypeObject* SbkPySide_QtGui_QTextCursor_MoveMode = Shiboken::Enum::newType("PySide.QtGui.QTextCursor.MoveMode");
    SbkPySide_QtGuiTypes[SBK_QTEXTCURSOR_MOVEMODE_IDX] = SbkPySide_QtGui_QTextCursor_MoveMode;
    if (PyType_Ready(SbkPySide_QtGui_QTextCursor_MoveMode) < 0)
        return;
    PyDict_SetItemString(Sbk_QTextCursor_Type.super.ht_type.tp_dict,
            "MoveMode",((PyObject*)SbkPySide_QtGui_QTextCursor_MoveMode));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTextCursor_MoveMode,(long) QTextCursor::MoveAnchor, "MoveAnchor");
    PyDict_SetItemString(Sbk_QTextCursor_Type.super.ht_type.tp_dict,"MoveAnchor", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTextCursor_MoveMode->tp_dict,"MoveAnchor", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTextCursor_MoveMode,(long) QTextCursor::KeepAnchor, "KeepAnchor");
    PyDict_SetItemString(Sbk_QTextCursor_Type.super.ht_type.tp_dict,"KeepAnchor", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTextCursor_MoveMode->tp_dict,"KeepAnchor", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QTextCursor::MoveMode");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::MoveMode");
    // end of enum MoveMode

    // init enum: MoveOperation
    PyTypeObject* SbkPySide_QtGui_QTextCursor_MoveOperation = Shiboken::Enum::newType("PySide.QtGui.QTextCursor.MoveOperation");
    SbkPySide_QtGuiTypes[SBK_QTEXTCURSOR_MOVEOPERATION_IDX] = SbkPySide_QtGui_QTextCursor_MoveOperation;
    if (PyType_Ready(SbkPySide_QtGui_QTextCursor_MoveOperation) < 0)
        return;
    PyDict_SetItemString(Sbk_QTextCursor_Type.super.ht_type.tp_dict,
            "MoveOperation",((PyObject*)SbkPySide_QtGui_QTextCursor_MoveOperation));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTextCursor_MoveOperation,(long) QTextCursor::NoMove, "NoMove");
    PyDict_SetItemString(Sbk_QTextCursor_Type.super.ht_type.tp_dict,"NoMove", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTextCursor_MoveOperation->tp_dict,"NoMove", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTextCursor_MoveOperation,(long) QTextCursor::Start, "Start");
    PyDict_SetItemString(Sbk_QTextCursor_Type.super.ht_type.tp_dict,"Start", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTextCursor_MoveOperation->tp_dict,"Start", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTextCursor_MoveOperation,(long) QTextCursor::Up, "Up");
    PyDict_SetItemString(Sbk_QTextCursor_Type.super.ht_type.tp_dict,"Up", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTextCursor_MoveOperation->tp_dict,"Up", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTextCursor_MoveOperation,(long) QTextCursor::StartOfLine, "StartOfLine");
    PyDict_SetItemString(Sbk_QTextCursor_Type.super.ht_type.tp_dict,"StartOfLine", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTextCursor_MoveOperation->tp_dict,"StartOfLine", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTextCursor_MoveOperation,(long) QTextCursor::StartOfBlock, "StartOfBlock");
    PyDict_SetItemString(Sbk_QTextCursor_Type.super.ht_type.tp_dict,"StartOfBlock", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTextCursor_MoveOperation->tp_dict,"StartOfBlock", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTextCursor_MoveOperation,(long) QTextCursor::StartOfWord, "StartOfWord");
    PyDict_SetItemString(Sbk_QTextCursor_Type.super.ht_type.tp_dict,"StartOfWord", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTextCursor_MoveOperation->tp_dict,"StartOfWord", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTextCursor_MoveOperation,(long) QTextCursor::PreviousBlock, "PreviousBlock");
    PyDict_SetItemString(Sbk_QTextCursor_Type.super.ht_type.tp_dict,"PreviousBlock", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTextCursor_MoveOperation->tp_dict,"PreviousBlock", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTextCursor_MoveOperation,(long) QTextCursor::PreviousCharacter, "PreviousCharacter");
    PyDict_SetItemString(Sbk_QTextCursor_Type.super.ht_type.tp_dict,"PreviousCharacter", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTextCursor_MoveOperation->tp_dict,"PreviousCharacter", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTextCursor_MoveOperation,(long) QTextCursor::PreviousWord, "PreviousWord");
    PyDict_SetItemString(Sbk_QTextCursor_Type.super.ht_type.tp_dict,"PreviousWord", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTextCursor_MoveOperation->tp_dict,"PreviousWord", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTextCursor_MoveOperation,(long) QTextCursor::Left, "Left");
    PyDict_SetItemString(Sbk_QTextCursor_Type.super.ht_type.tp_dict,"Left", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTextCursor_MoveOperation->tp_dict,"Left", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTextCursor_MoveOperation,(long) QTextCursor::WordLeft, "WordLeft");
    PyDict_SetItemString(Sbk_QTextCursor_Type.super.ht_type.tp_dict,"WordLeft", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTextCursor_MoveOperation->tp_dict,"WordLeft", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTextCursor_MoveOperation,(long) QTextCursor::End, "End");
    PyDict_SetItemString(Sbk_QTextCursor_Type.super.ht_type.tp_dict,"End", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTextCursor_MoveOperation->tp_dict,"End", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTextCursor_MoveOperation,(long) QTextCursor::Down, "Down");
    PyDict_SetItemString(Sbk_QTextCursor_Type.super.ht_type.tp_dict,"Down", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTextCursor_MoveOperation->tp_dict,"Down", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTextCursor_MoveOperation,(long) QTextCursor::EndOfLine, "EndOfLine");
    PyDict_SetItemString(Sbk_QTextCursor_Type.super.ht_type.tp_dict,"EndOfLine", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTextCursor_MoveOperation->tp_dict,"EndOfLine", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTextCursor_MoveOperation,(long) QTextCursor::EndOfWord, "EndOfWord");
    PyDict_SetItemString(Sbk_QTextCursor_Type.super.ht_type.tp_dict,"EndOfWord", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTextCursor_MoveOperation->tp_dict,"EndOfWord", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTextCursor_MoveOperation,(long) QTextCursor::EndOfBlock, "EndOfBlock");
    PyDict_SetItemString(Sbk_QTextCursor_Type.super.ht_type.tp_dict,"EndOfBlock", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTextCursor_MoveOperation->tp_dict,"EndOfBlock", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTextCursor_MoveOperation,(long) QTextCursor::NextBlock, "NextBlock");
    PyDict_SetItemString(Sbk_QTextCursor_Type.super.ht_type.tp_dict,"NextBlock", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTextCursor_MoveOperation->tp_dict,"NextBlock", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTextCursor_MoveOperation,(long) QTextCursor::NextCharacter, "NextCharacter");
    PyDict_SetItemString(Sbk_QTextCursor_Type.super.ht_type.tp_dict,"NextCharacter", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTextCursor_MoveOperation->tp_dict,"NextCharacter", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTextCursor_MoveOperation,(long) QTextCursor::NextWord, "NextWord");
    PyDict_SetItemString(Sbk_QTextCursor_Type.super.ht_type.tp_dict,"NextWord", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTextCursor_MoveOperation->tp_dict,"NextWord", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTextCursor_MoveOperation,(long) QTextCursor::Right, "Right");
    PyDict_SetItemString(Sbk_QTextCursor_Type.super.ht_type.tp_dict,"Right", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTextCursor_MoveOperation->tp_dict,"Right", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTextCursor_MoveOperation,(long) QTextCursor::WordRight, "WordRight");
    PyDict_SetItemString(Sbk_QTextCursor_Type.super.ht_type.tp_dict,"WordRight", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTextCursor_MoveOperation->tp_dict,"WordRight", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTextCursor_MoveOperation,(long) QTextCursor::NextCell, "NextCell");
    PyDict_SetItemString(Sbk_QTextCursor_Type.super.ht_type.tp_dict,"NextCell", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTextCursor_MoveOperation->tp_dict,"NextCell", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTextCursor_MoveOperation,(long) QTextCursor::PreviousCell, "PreviousCell");
    PyDict_SetItemString(Sbk_QTextCursor_Type.super.ht_type.tp_dict,"PreviousCell", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTextCursor_MoveOperation->tp_dict,"PreviousCell", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTextCursor_MoveOperation,(long) QTextCursor::NextRow, "NextRow");
    PyDict_SetItemString(Sbk_QTextCursor_Type.super.ht_type.tp_dict,"NextRow", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTextCursor_MoveOperation->tp_dict,"NextRow", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTextCursor_MoveOperation,(long) QTextCursor::PreviousRow, "PreviousRow");
    PyDict_SetItemString(Sbk_QTextCursor_Type.super.ht_type.tp_dict,"PreviousRow", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTextCursor_MoveOperation->tp_dict,"PreviousRow", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QTextCursor::MoveOperation");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::MoveOperation");
    // end of enum MoveOperation

    // init enum: SelectionType
    PyTypeObject* SbkPySide_QtGui_QTextCursor_SelectionType = Shiboken::Enum::newType("PySide.QtGui.QTextCursor.SelectionType");
    SbkPySide_QtGuiTypes[SBK_QTEXTCURSOR_SELECTIONTYPE_IDX] = SbkPySide_QtGui_QTextCursor_SelectionType;
    if (PyType_Ready(SbkPySide_QtGui_QTextCursor_SelectionType) < 0)
        return;
    PyDict_SetItemString(Sbk_QTextCursor_Type.super.ht_type.tp_dict,
            "SelectionType",((PyObject*)SbkPySide_QtGui_QTextCursor_SelectionType));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTextCursor_SelectionType,(long) QTextCursor::WordUnderCursor, "WordUnderCursor");
    PyDict_SetItemString(Sbk_QTextCursor_Type.super.ht_type.tp_dict,"WordUnderCursor", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTextCursor_SelectionType->tp_dict,"WordUnderCursor", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTextCursor_SelectionType,(long) QTextCursor::LineUnderCursor, "LineUnderCursor");
    PyDict_SetItemString(Sbk_QTextCursor_Type.super.ht_type.tp_dict,"LineUnderCursor", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTextCursor_SelectionType->tp_dict,"LineUnderCursor", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTextCursor_SelectionType,(long) QTextCursor::BlockUnderCursor, "BlockUnderCursor");
    PyDict_SetItemString(Sbk_QTextCursor_Type.super.ht_type.tp_dict,"BlockUnderCursor", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTextCursor_SelectionType->tp_dict,"BlockUnderCursor", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTextCursor_SelectionType,(long) QTextCursor::Document, "Document");
    PyDict_SetItemString(Sbk_QTextCursor_Type.super.ht_type.tp_dict,"Document", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTextCursor_SelectionType->tp_dict,"Document", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QTextCursor::SelectionType");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::SelectionType");
    // end of enum SelectionType


    Shiboken::TypeResolver::createValueTypeResolver<QTextCursor >("QTextCursor");
    Shiboken::TypeResolver::createObjectTypeResolver<QTextCursor >("QTextCursor*");
    Shiboken::TypeResolver::createValueTypeResolver<QTextCursor >(typeid(QTextCursor).name());
    qRegisterMetaType< ::QTextCursor >("QTextCursor");
    qRegisterMetaType< ::QTextCursor::MoveMode >("QTextCursor::MoveMode");
    qRegisterMetaType< ::QTextCursor::MoveOperation >("QTextCursor::MoveOperation");
    qRegisterMetaType< ::QTextCursor::SelectionType >("QTextCursor::SelectionType");
}

