/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtgui_python.h"

#include "qtextlayout_wrapper.h"
#include "qtextlayout_formatrange_wrapper.h"

// Extra includes
#include <QList>
#include <QTextLayout>
#include <QTextOption>
#include <QVector>
#include <qfont.h>
#include <qpaintdevice.h>
#include <qpainter.h>
#include <qpoint.h>
#include <qrect.h>
#include <qtextlayout.h>
#include <qtextobject.h>
#include <qtextoption.h>



// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QTextLayout_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QTextLayout >()))
        return -1;

    QTextLayout* cptr = 0;
    int overloadId = -1;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);

    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);

    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QTextLayout(): too many arguments");
        return -1;
    }

    if (!PyArg_ParseTuple(args, "|OOO:QTextLayout", &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return -1;

    // Overloaded function decisor
    // 0: QTextLayout()
    // 1: QTextLayout(QString)
    // 2: QTextLayout(QString,QFont,QPaintDevice*)
    // 3: QTextLayout(QTextBlock)
    if (numArgs == 0) {
        overloadId = 0; // QTextLayout()
    } else if (numArgs == 1 && Shiboken::Converter< ::QTextBlock >::isConvertible(pyargs[0])) {
        overloadId = 3; // QTextLayout(QTextBlock)
    } else if (Shiboken::Converter< QString >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 1; // QTextLayout(QString)
        } else if (Shiboken::Converter< ::QFont >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 2; // QTextLayout(QString,QFont,QPaintDevice*)
            } else if (Shiboken::Converter< ::QPaintDevice * >::isConvertible(pyargs[2])) {
                overloadId = 2; // QTextLayout(QString,QFont,QPaintDevice*)
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextLayout_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QTextLayout()
            {

                if(!PyErr_Occurred()) {
                    // QTextLayout()
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QTextLayout();
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // QTextLayout(QString)
            {
                QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QTextLayout(QString)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QTextLayout(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 2: // QTextLayout(QString,QFont,QPaintDevice*)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "paintdevice");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "paintdevice";
                        else if (Shiboken::Converter< ::QPaintDevice * >::isConvertible(value))
                            pyargs[2] = value;
                        else
                            goto Sbk_QTextLayout_Init_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QTextLayout(): got multiple values for keyword argument '%s'", errorArgName);
                        return -1;
                    }
                }
                QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return -1;
                QFont cppArg1 = Shiboken::Converter<QFont >::toCpp(pyargs[1]);
                if (!Shiboken::Object::isValid(pyargs[2]))
                    return -1;
                QPaintDevice * cppArg2 = pyargs[2] ? Shiboken::Converter<QPaintDevice * >::toCpp(pyargs[2]) : 0;

                if(!PyErr_Occurred()) {
                    // QTextLayout(QString,QFont,QPaintDevice*)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QTextLayout(cppArg0, cppArg1, cppArg2);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 3: // QTextLayout(QTextBlock)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QTextBlock cppArg0 = Shiboken::Converter<QTextBlock >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QTextLayout(QTextBlock)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QTextLayout(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QTextLayout >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QTextLayout_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QTextLayout_Init_TypeError:
        const char* overloads[] = {"", "QString", "QString, PySide.QtGui.QFont, PySide.QtGui.QPaintDevice = None", "PySide.QtGui.QTextBlock", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QTextLayout", overloads);
        return -1;
}

static PyObject* Sbk_QTextLayoutFunc_additionalFormats(PyObject* self)
{
    QTextLayout* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextLayout* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // additionalFormats()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QList<QTextLayout::FormatRange > cppResult = const_cast<const QTextLayout*>(cppSelf)->additionalFormats();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QList<QTextLayout::FormatRange > >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextLayoutFunc_beginLayout(PyObject* self)
{
    QTextLayout* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextLayout* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // beginLayout()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->beginLayout();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QTextLayoutFunc_boundingRect(PyObject* self)
{
    QTextLayout* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextLayout* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // boundingRect()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QRectF cppResult = const_cast<const QTextLayout*>(cppSelf)->boundingRect();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QRectF >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextLayoutFunc_cacheEnabled(PyObject* self)
{
    QTextLayout* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextLayout* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // cacheEnabled()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QTextLayout*>(cppSelf)->cacheEnabled();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextLayoutFunc_clearAdditionalFormats(PyObject* self)
{
    QTextLayout* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextLayout* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // clearAdditionalFormats()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->clearAdditionalFormats();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QTextLayoutFunc_clearLayout(PyObject* self)
{
    QTextLayout* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextLayout* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // clearLayout()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->clearLayout();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QTextLayoutFunc_createLine(PyObject* self)
{
    QTextLayout* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextLayout* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // createLine()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QTextLine cppResult = cppSelf->createLine();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QTextLine >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextLayoutFunc_draw(PyObject* self, PyObject* args, PyObject* kwds)
{
    QTextLayout* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextLayout* >::toCpp(self);

    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 4) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QTextLayout.draw(): too many arguments");
        return 0;
    } else if (numArgs < 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QTextLayout.draw(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOOO:draw", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return 0;


    // Overloaded function decisor
    // 0: draw(QPainter*,QPointF,QVector<QTextLayout::FormatRange>,QRectF)const
    if (numArgs >= 2 && Shiboken::Converter< ::QPainter * >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QPointF >::isConvertible(pyargs[1])) {
        if (numArgs == 2) {
            overloadId = 0; // draw(QPainter*,QPointF,QVector<QTextLayout::FormatRange>,QRectF)const
        } else if (Shiboken::Converter< ::QVector<QTextLayout::FormatRange > >::isConvertible(pyargs[2])) {
            if (numArgs == 3) {
                overloadId = 0; // draw(QPainter*,QPointF,QVector<QTextLayout::FormatRange>,QRectF)const
            } else if (Shiboken::Converter< ::QRectF >::isConvertible(pyargs[3])) {
                overloadId = 0; // draw(QPainter*,QPointF,QVector<QTextLayout::FormatRange>,QRectF)const
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextLayoutFunc_draw_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "selections");
                if (value) {
                    if (pyargs[2])
                        errorArgName = "selections";
                    else if (Shiboken::Converter< ::QVector<QTextLayout::FormatRange > >::isConvertible(value))
                        pyargs[2] = value;
                    else
                        goto Sbk_QTextLayoutFunc_draw_TypeError;
                }
                value = PyDict_GetItemString(kwds, "clip");
                if (value) {
                    if (pyargs[3])
                        errorArgName = "clip";
                    else if (Shiboken::Converter< ::QRectF >::isConvertible(value))
                        pyargs[3] = value;
                    else
                        goto Sbk_QTextLayoutFunc_draw_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QTextLayout.draw(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QPainter * cppArg0 = Shiboken::Converter<QPainter * >::toCpp(pyargs[0]);
            if (!Shiboken::Object::isValid(pyargs[1]))
                return 0;
            QPointF cppArg1 = Shiboken::Converter<QPointF >::toCpp(pyargs[1]);
            QVector<QTextLayout::FormatRange > cppArg2 = pyargs[2] ? Shiboken::Converter<QVector<QTextLayout::FormatRange > >::toCpp(pyargs[2]) : QVector< QTextLayout::FormatRange >();
            if (!Shiboken::Object::isValid(pyargs[3]))
                return 0;
            QRectF cppArg3_tmp = QRectF();
            QRectF cppArg3 = pyargs[3] ? Shiboken::Converter<QRectF >::toCpp(pyargs[3]) : cppArg3_tmp;

            if(!PyErr_Occurred()) {
                // draw(QPainter*,QPointF,QVector<QTextLayout::FormatRange>,QRectF)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                const_cast<const QTextLayout*>(cppSelf)->draw(cppArg0, cppArg1, cppArg2, cppArg3);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextLayoutFunc_draw_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPainter, PySide.QtCore.QPointF, list = QVector< QTextLayout.FormatRange >(), PySide.QtCore.QRectF = QRectF()", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QTextLayout.draw", overloads);
        return 0;
}

static PyObject* Sbk_QTextLayoutFunc_drawCursor(PyObject* self, PyObject* args)
{
    QTextLayout* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextLayout* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "drawCursor", 3, 4, &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return 0;


    // Overloaded function decisor
    // 0: drawCursor(QPainter*,QPointF,int)const
    // 1: drawCursor(QPainter*,QPointF,int,int)const
    if (numArgs >= 3 && Shiboken::Converter< ::QPainter * >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QPointF >::isConvertible(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
        if (numArgs == 3) {
            overloadId = 0; // drawCursor(QPainter*,QPointF,int)const
        } else if (numArgs == 4 && SbkNumber_Check(pyargs[3])) {
            overloadId = 1; // drawCursor(QPainter*,QPointF,int,int)const
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextLayoutFunc_drawCursor_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // drawCursor(QPainter*,QPointF,int)const
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QPainter * cppArg0 = Shiboken::Converter<QPainter * >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return 0;
                QPointF cppArg1 = Shiboken::Converter<QPointF >::toCpp(pyargs[1]);
                int cppArg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                    // drawCursor(QPainter*,QPointF,int)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    const_cast<const QTextLayout*>(cppSelf)->drawCursor(cppArg0, cppArg1, cppArg2);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // drawCursor(QPainter*,QPointF,int,int)const
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QPainter * cppArg0 = Shiboken::Converter<QPainter * >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return 0;
                QPointF cppArg1 = Shiboken::Converter<QPointF >::toCpp(pyargs[1]);
                int cppArg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);
                int cppArg3 = Shiboken::Converter<int >::toCpp(pyargs[3]);

                if(!PyErr_Occurred()) {
                    // drawCursor(QPainter*,QPointF,int,int)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    const_cast<const QTextLayout*>(cppSelf)->drawCursor(cppArg0, cppArg1, cppArg2, cppArg3);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextLayoutFunc_drawCursor_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPainter, PySide.QtCore.QPointF, int", "PySide.QtGui.QPainter, PySide.QtCore.QPointF, int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QTextLayout.drawCursor", overloads);
        return 0;
}

static PyObject* Sbk_QTextLayoutFunc_endLayout(PyObject* self)
{
    QTextLayout* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextLayout* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // endLayout()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->endLayout();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QTextLayoutFunc_font(PyObject* self)
{
    QTextLayout* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextLayout* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // font()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QFont cppResult = const_cast<const QTextLayout*>(cppSelf)->font();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QFont >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextLayoutFunc_isValidCursorPosition(PyObject* self, PyObject* arg)
{
    QTextLayout* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextLayout* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: isValidCursorPosition(int)const
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // isValidCursorPosition(int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextLayoutFunc_isValidCursorPosition_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // isValidCursorPosition(int)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QTextLayout*>(cppSelf)->isValidCursorPosition(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QTextLayoutFunc_isValidCursorPosition_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextLayout.isValidCursorPosition", overloads);
        return 0;
}

static PyObject* Sbk_QTextLayoutFunc_lineAt(PyObject* self, PyObject* arg)
{
    QTextLayout* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextLayout* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: lineAt(int)const
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // lineAt(int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextLayoutFunc_lineAt_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // lineAt(int)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QTextLine cppResult = const_cast<const QTextLayout*>(cppSelf)->lineAt(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QTextLine >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QTextLayoutFunc_lineAt_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextLayout.lineAt", overloads);
        return 0;
}

static PyObject* Sbk_QTextLayoutFunc_lineCount(PyObject* self)
{
    QTextLayout* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextLayout* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // lineCount()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QTextLayout*>(cppSelf)->lineCount();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextLayoutFunc_lineForTextPosition(PyObject* self, PyObject* arg)
{
    QTextLayout* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextLayout* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: lineForTextPosition(int)const
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // lineForTextPosition(int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextLayoutFunc_lineForTextPosition_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // lineForTextPosition(int)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QTextLine cppResult = const_cast<const QTextLayout*>(cppSelf)->lineForTextPosition(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QTextLine >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QTextLayoutFunc_lineForTextPosition_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextLayout.lineForTextPosition", overloads);
        return 0;
}

static PyObject* Sbk_QTextLayoutFunc_maximumWidth(PyObject* self)
{
    QTextLayout* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextLayout* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // maximumWidth()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                qreal cppResult = const_cast<const QTextLayout*>(cppSelf)->maximumWidth();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< double >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextLayoutFunc_minimumWidth(PyObject* self)
{
    QTextLayout* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextLayout* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // minimumWidth()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                qreal cppResult = const_cast<const QTextLayout*>(cppSelf)->minimumWidth();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< double >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextLayoutFunc_nextCursorPosition(PyObject* self, PyObject* args, PyObject* kwds)
{
    QTextLayout* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextLayout* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QTextLayout.nextCursorPosition(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QTextLayout.nextCursorPosition(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:nextCursorPosition", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: nextCursorPosition(int,QTextLayout::CursorMode)const
    if (SbkNumber_Check(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // nextCursorPosition(int,QTextLayout::CursorMode)const
        } else if (Shiboken::Converter< ::QTextLayout::CursorMode >::isConvertible(pyargs[1])) {
            overloadId = 0; // nextCursorPosition(int,QTextLayout::CursorMode)const
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextLayoutFunc_nextCursorPosition_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "mode");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "mode";
                    else if (Shiboken::Converter< ::QTextLayout::CursorMode >::isConvertible(value))
                        pyargs[1] = value;
                    else
                        goto Sbk_QTextLayoutFunc_nextCursorPosition_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QTextLayout.nextCursorPosition(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            QTextLayout::CursorMode cppArg1 = pyargs[1] ? Shiboken::Converter<QTextLayout::CursorMode >::toCpp(pyargs[1]) : QTextLayout::SkipCharacters;

            if(!PyErr_Occurred()) {
                // nextCursorPosition(int,QTextLayout::CursorMode)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QTextLayout*>(cppSelf)->nextCursorPosition(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QTextLayoutFunc_nextCursorPosition_TypeError:
        const char* overloads[] = {"int, PySide.QtGui.QTextLayout.CursorMode = SkipCharacters", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QTextLayout.nextCursorPosition", overloads);
        return 0;
}

static PyObject* Sbk_QTextLayoutFunc_position(PyObject* self)
{
    QTextLayout* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextLayout* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // position()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QPointF cppResult = const_cast<const QTextLayout*>(cppSelf)->position();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QPointF >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextLayoutFunc_preeditAreaPosition(PyObject* self)
{
    QTextLayout* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextLayout* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // preeditAreaPosition()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QTextLayout*>(cppSelf)->preeditAreaPosition();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextLayoutFunc_preeditAreaText(PyObject* self)
{
    QTextLayout* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextLayout* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // preeditAreaText()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = const_cast<const QTextLayout*>(cppSelf)->preeditAreaText();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextLayoutFunc_previousCursorPosition(PyObject* self, PyObject* args, PyObject* kwds)
{
    QTextLayout* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextLayout* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QTextLayout.previousCursorPosition(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QTextLayout.previousCursorPosition(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:previousCursorPosition", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: previousCursorPosition(int,QTextLayout::CursorMode)const
    if (SbkNumber_Check(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // previousCursorPosition(int,QTextLayout::CursorMode)const
        } else if (Shiboken::Converter< ::QTextLayout::CursorMode >::isConvertible(pyargs[1])) {
            overloadId = 0; // previousCursorPosition(int,QTextLayout::CursorMode)const
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextLayoutFunc_previousCursorPosition_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "mode");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "mode";
                    else if (Shiboken::Converter< ::QTextLayout::CursorMode >::isConvertible(value))
                        pyargs[1] = value;
                    else
                        goto Sbk_QTextLayoutFunc_previousCursorPosition_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QTextLayout.previousCursorPosition(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            QTextLayout::CursorMode cppArg1 = pyargs[1] ? Shiboken::Converter<QTextLayout::CursorMode >::toCpp(pyargs[1]) : QTextLayout::SkipCharacters;

            if(!PyErr_Occurred()) {
                // previousCursorPosition(int,QTextLayout::CursorMode)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QTextLayout*>(cppSelf)->previousCursorPosition(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QTextLayoutFunc_previousCursorPosition_TypeError:
        const char* overloads[] = {"int, PySide.QtGui.QTextLayout.CursorMode = SkipCharacters", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QTextLayout.previousCursorPosition", overloads);
        return 0;
}

static PyObject* Sbk_QTextLayoutFunc_setAdditionalFormats(PyObject* self, PyObject* arg)
{
    QTextLayout* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextLayout* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setAdditionalFormats(QList<QTextLayout::FormatRange>)
    if (Shiboken::Converter< ::QList<QTextLayout::FormatRange > >::isConvertible(arg)) {
        overloadId = 0; // setAdditionalFormats(QList<QTextLayout::FormatRange>)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextLayoutFunc_setAdditionalFormats_TypeError;

    // Call function/method
    {
        {
            QList<QTextLayout::FormatRange > cppArg0 = Shiboken::Converter<QList<QTextLayout::FormatRange > >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setAdditionalFormats(QList<QTextLayout::FormatRange>)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setAdditionalFormats(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextLayoutFunc_setAdditionalFormats_TypeError:
        const char* overloads[] = {"list", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextLayout.setAdditionalFormats", overloads);
        return 0;
}

static PyObject* Sbk_QTextLayoutFunc_setCacheEnabled(PyObject* self, PyObject* arg)
{
    QTextLayout* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextLayout* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setCacheEnabled(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setCacheEnabled(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextLayoutFunc_setCacheEnabled_TypeError;

    // Call function/method
    {
        {
            bool cppArg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setCacheEnabled(bool)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setCacheEnabled(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextLayoutFunc_setCacheEnabled_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextLayout.setCacheEnabled", overloads);
        return 0;
}

static PyObject* Sbk_QTextLayoutFunc_setFlags(PyObject* self, PyObject* arg)
{
    QTextLayout* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextLayout* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setFlags(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setFlags(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextLayoutFunc_setFlags_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setFlags(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setFlags(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextLayoutFunc_setFlags_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextLayout.setFlags", overloads);
        return 0;
}

static PyObject* Sbk_QTextLayoutFunc_setFont(PyObject* self, PyObject* arg)
{
    QTextLayout* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextLayout* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setFont(QFont)
    if (Shiboken::Converter< ::QFont >::isConvertible(arg)) {
        overloadId = 0; // setFont(QFont)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextLayoutFunc_setFont_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QFont cppArg0 = Shiboken::Converter<QFont >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setFont(QFont)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setFont(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextLayoutFunc_setFont_TypeError:
        const char* overloads[] = {"PySide.QtGui.QFont", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextLayout.setFont", overloads);
        return 0;
}

static PyObject* Sbk_QTextLayoutFunc_setPosition(PyObject* self, PyObject* arg)
{
    QTextLayout* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextLayout* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setPosition(QPointF)
    if (Shiboken::Converter< ::QPointF >::isConvertible(arg)) {
        overloadId = 0; // setPosition(QPointF)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextLayoutFunc_setPosition_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QPointF cppArg0 = Shiboken::Converter<QPointF >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setPosition(QPointF)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setPosition(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextLayoutFunc_setPosition_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPointF", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextLayout.setPosition", overloads);
        return 0;
}

static PyObject* Sbk_QTextLayoutFunc_setPreeditArea(PyObject* self, PyObject* args)
{
    QTextLayout* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextLayout* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setPreeditArea", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setPreeditArea(int,QString)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && Shiboken::Converter< QString >::isConvertible(pyargs[1])) {
        overloadId = 0; // setPreeditArea(int,QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextLayoutFunc_setPreeditArea_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            QString cppArg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // setPreeditArea(int,QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setPreeditArea(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextLayoutFunc_setPreeditArea_TypeError:
        const char* overloads[] = {"int, QString", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QTextLayout.setPreeditArea", overloads);
        return 0;
}

static PyObject* Sbk_QTextLayoutFunc_setText(PyObject* self, PyObject* arg)
{
    QTextLayout* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextLayout* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setText(QString)
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // setText(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextLayoutFunc_setText_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setText(QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setText(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextLayoutFunc_setText_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextLayout.setText", overloads);
        return 0;
}

static PyObject* Sbk_QTextLayoutFunc_setTextOption(PyObject* self, PyObject* arg)
{
    QTextLayout* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextLayout* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setTextOption(QTextOption)
    if (Shiboken::Converter< ::QTextOption >::isConvertible(arg)) {
        overloadId = 0; // setTextOption(QTextOption)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextLayoutFunc_setTextOption_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QTextOption cppArg0 = Shiboken::Converter<QTextOption >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setTextOption(QTextOption)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setTextOption(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextLayoutFunc_setTextOption_TypeError:
        const char* overloads[] = {"PySide.QtGui.QTextOption", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextLayout.setTextOption", overloads);
        return 0;
}

static PyObject* Sbk_QTextLayoutFunc_text(PyObject* self)
{
    QTextLayout* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextLayout* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // text()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = const_cast<const QTextLayout*>(cppSelf)->text();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextLayoutFunc_textOption(PyObject* self)
{
    QTextLayout* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextLayout* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // textOption()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QTextOption cppResult = const_cast<const QTextLayout*>(cppSelf)->textOption();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QTextOption >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef Sbk_QTextLayout_methods[] = {
    {"additionalFormats", (PyCFunction)Sbk_QTextLayoutFunc_additionalFormats, METH_NOARGS},
    {"beginLayout", (PyCFunction)Sbk_QTextLayoutFunc_beginLayout, METH_NOARGS},
    {"boundingRect", (PyCFunction)Sbk_QTextLayoutFunc_boundingRect, METH_NOARGS},
    {"cacheEnabled", (PyCFunction)Sbk_QTextLayoutFunc_cacheEnabled, METH_NOARGS},
    {"clearAdditionalFormats", (PyCFunction)Sbk_QTextLayoutFunc_clearAdditionalFormats, METH_NOARGS},
    {"clearLayout", (PyCFunction)Sbk_QTextLayoutFunc_clearLayout, METH_NOARGS},
    {"createLine", (PyCFunction)Sbk_QTextLayoutFunc_createLine, METH_NOARGS},
    {"draw", (PyCFunction)Sbk_QTextLayoutFunc_draw, METH_VARARGS|METH_KEYWORDS},
    {"drawCursor", (PyCFunction)Sbk_QTextLayoutFunc_drawCursor, METH_VARARGS},
    {"endLayout", (PyCFunction)Sbk_QTextLayoutFunc_endLayout, METH_NOARGS},
    {"font", (PyCFunction)Sbk_QTextLayoutFunc_font, METH_NOARGS},
    {"isValidCursorPosition", (PyCFunction)Sbk_QTextLayoutFunc_isValidCursorPosition, METH_O},
    {"lineAt", (PyCFunction)Sbk_QTextLayoutFunc_lineAt, METH_O},
    {"lineCount", (PyCFunction)Sbk_QTextLayoutFunc_lineCount, METH_NOARGS},
    {"lineForTextPosition", (PyCFunction)Sbk_QTextLayoutFunc_lineForTextPosition, METH_O},
    {"maximumWidth", (PyCFunction)Sbk_QTextLayoutFunc_maximumWidth, METH_NOARGS},
    {"minimumWidth", (PyCFunction)Sbk_QTextLayoutFunc_minimumWidth, METH_NOARGS},
    {"nextCursorPosition", (PyCFunction)Sbk_QTextLayoutFunc_nextCursorPosition, METH_VARARGS|METH_KEYWORDS},
    {"position", (PyCFunction)Sbk_QTextLayoutFunc_position, METH_NOARGS},
    {"preeditAreaPosition", (PyCFunction)Sbk_QTextLayoutFunc_preeditAreaPosition, METH_NOARGS},
    {"preeditAreaText", (PyCFunction)Sbk_QTextLayoutFunc_preeditAreaText, METH_NOARGS},
    {"previousCursorPosition", (PyCFunction)Sbk_QTextLayoutFunc_previousCursorPosition, METH_VARARGS|METH_KEYWORDS},
    {"setAdditionalFormats", (PyCFunction)Sbk_QTextLayoutFunc_setAdditionalFormats, METH_O},
    {"setCacheEnabled", (PyCFunction)Sbk_QTextLayoutFunc_setCacheEnabled, METH_O},
    {"setFlags", (PyCFunction)Sbk_QTextLayoutFunc_setFlags, METH_O},
    {"setFont", (PyCFunction)Sbk_QTextLayoutFunc_setFont, METH_O},
    {"setPosition", (PyCFunction)Sbk_QTextLayoutFunc_setPosition, METH_O},
    {"setPreeditArea", (PyCFunction)Sbk_QTextLayoutFunc_setPreeditArea, METH_VARARGS},
    {"setText", (PyCFunction)Sbk_QTextLayoutFunc_setText, METH_O},
    {"setTextOption", (PyCFunction)Sbk_QTextLayoutFunc_setTextOption, METH_O},
    {"text", (PyCFunction)Sbk_QTextLayoutFunc_text, METH_NOARGS},
    {"textOption", (PyCFunction)Sbk_QTextLayoutFunc_textOption, METH_NOARGS},

    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QTextLayout_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QTextLayout",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QTextLayout_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&SbkObject_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QTextLayout_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern


void init_QTextLayout(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QTEXTLAYOUT_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QTextLayout_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QTextLayout_Type);
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QTextLayout_Type, &Shiboken::callCppDestructor<QTextLayout >);
    Py_INCREF((PyObject*)&Sbk_QTextLayout_Type); //Incref due the 'PyModule_AddObject' steals the reference.
    if (PyType_Ready((PyTypeObject*)&Sbk_QTextLayout_Type) < 0)
        return;

    Shiboken::ObjectType::setOriginalName(&Sbk_QTextLayout_Type, "QTextLayout*");
    PyModule_AddObject(module, "QTextLayout",
        ((PyObject*)&Sbk_QTextLayout_Type));

    // Initialize enums
    PyObject* enumItem;

    // init enum: CursorMode
    PyTypeObject* SbkPySide_QtGui_QTextLayout_CursorMode = Shiboken::Enum::newType("PySide.QtGui.QTextLayout.CursorMode");
    SbkPySide_QtGuiTypes[SBK_QTEXTLAYOUT_CURSORMODE_IDX] = SbkPySide_QtGui_QTextLayout_CursorMode;
    if (PyType_Ready(SbkPySide_QtGui_QTextLayout_CursorMode) < 0)
        return;
    PyDict_SetItemString(Sbk_QTextLayout_Type.super.ht_type.tp_dict,
            "CursorMode",((PyObject*)SbkPySide_QtGui_QTextLayout_CursorMode));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTextLayout_CursorMode,(long) QTextLayout::SkipCharacters, "SkipCharacters");
    PyDict_SetItemString(Sbk_QTextLayout_Type.super.ht_type.tp_dict,"SkipCharacters", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTextLayout_CursorMode->tp_dict,"SkipCharacters", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTextLayout_CursorMode,(long) QTextLayout::SkipWords, "SkipWords");
    PyDict_SetItemString(Sbk_QTextLayout_Type.super.ht_type.tp_dict,"SkipWords", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTextLayout_CursorMode->tp_dict,"SkipWords", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QTextLayout::CursorMode");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::CursorMode");
    // end of enum CursorMode


    Shiboken::TypeResolver::createObjectTypeResolver<QTextLayout >("QTextLayout*");
    Shiboken::TypeResolver::createObjectTypeResolver<QTextLayout >(typeid(QTextLayout).name());
    qRegisterMetaType< ::QTextLayout* >("QTextLayout*");
    qRegisterMetaType< ::QTextLayout::CursorMode >("QTextLayout::CursorMode");
}

