/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtgui_python.h"

#include "qtextline_wrapper.h"

// Extra includes
#include <QTextLayout>
#include <qpainter.h>
#include <qpoint.h>
#include <qrect.h>



// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QTextLine_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QTextLine >()))
        return -1;

    QTextLine* cptr = 0;
    int overloadId = -1;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QTextLine", 0, 1, &(pyargs[0])))
        return -1;

    // Overloaded function decisor
    // 0: QTextLine()
    // 1: QTextLine(QTextLine)
    if (numArgs == 0) {
        overloadId = 0; // QTextLine()
    } else if (numArgs == 1 && Shiboken::Converter< ::QTextLine >::isConvertible(pyargs[0])) {
        overloadId = 1; // QTextLine(QTextLine)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextLine_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QTextLine()
            {

                if(!PyErr_Occurred()) {
                    // QTextLine()
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QTextLine();
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // QTextLine(QTextLine)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QTextLine cppArg0 = Shiboken::Converter<QTextLine >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QTextLine(QTextLine)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QTextLine(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QTextLine >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QTextLine_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QTextLine_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtGui.QTextLine", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QTextLine", overloads);
        return -1;
}

static PyObject* Sbk_QTextLineFunc_ascent(PyObject* self)
{
    QTextLine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextLine* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // ascent()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                qreal cppResult = const_cast<const QTextLine*>(cppSelf)->ascent();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< double >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextLineFunc_cursorToX(PyObject* self, PyObject* args, PyObject* kwds)
{
    QTextLine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextLine* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QTextLine.cursorToX(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QTextLine.cursorToX(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:cursorToX", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: cursorToX(int,QTextLine::Edge)const
    if (SbkNumber_Check(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // cursorToX(int,QTextLine::Edge)const
        } else if (Shiboken::Converter< ::QTextLine::Edge >::isConvertible(pyargs[1])) {
            overloadId = 0; // cursorToX(int,QTextLine::Edge)const
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextLineFunc_cursorToX_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "edge");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "edge";
                    else if (Shiboken::Converter< ::QTextLine::Edge >::isConvertible(value))
                        pyargs[1] = value;
                    else
                        goto Sbk_QTextLineFunc_cursorToX_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QTextLine.cursorToX(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            QTextLine::Edge cppArg1 = pyargs[1] ? Shiboken::Converter<QTextLine::Edge >::toCpp(pyargs[1]) : QTextLine::Leading;

            if(!PyErr_Occurred()) {
                // cursorToX(int,QTextLine::Edge)const
                // Begin code injection

                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                qreal cppResult = cppSelf->::QTextLine::cursorToX(&cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::makeTuple(cppResult, cppArg0);

                // End of code injection


            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QTextLineFunc_cursorToX_TypeError:
        const char* overloads[] = {"int, PySide.QtGui.QTextLine.Edge = Leading", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QTextLine.cursorToX", overloads);
        return 0;
}

static PyObject* Sbk_QTextLineFunc_descent(PyObject* self)
{
    QTextLine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextLine* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // descent()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                qreal cppResult = const_cast<const QTextLine*>(cppSelf)->descent();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< double >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextLineFunc_draw(PyObject* self, PyObject* args, PyObject* kwds)
{
    QTextLine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextLine* >::toCpp(self);

    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QTextLine.draw(): too many arguments");
        return 0;
    } else if (numArgs < 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QTextLine.draw(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOO:draw", &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: draw(QPainter*,QPointF,const QTextLayout::FormatRange*)const
    if (numArgs >= 2 && Shiboken::Converter< ::QPainter * >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QPointF >::isConvertible(pyargs[1])) {
        if (numArgs == 2) {
            overloadId = 0; // draw(QPainter*,QPointF,const QTextLayout::FormatRange*)const
        } else if (Shiboken::Converter< ::QTextLayout::FormatRange * >::isConvertible(pyargs[2])) {
            overloadId = 0; // draw(QPainter*,QPointF,const QTextLayout::FormatRange*)const
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextLineFunc_draw_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "selection");
                if (value) {
                    if (pyargs[2])
                        errorArgName = "selection";
                    else if (Shiboken::Converter< ::QTextLayout::FormatRange * >::isConvertible(value))
                        pyargs[2] = value;
                    else
                        goto Sbk_QTextLineFunc_draw_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QTextLine.draw(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QPainter * cppArg0 = Shiboken::Converter<QPainter * >::toCpp(pyargs[0]);
            if (!Shiboken::Object::isValid(pyargs[1]))
                return 0;
            QPointF cppArg1 = Shiboken::Converter<QPointF >::toCpp(pyargs[1]);
            if (!Shiboken::Object::isValid(pyargs[2]))
                return 0;
            QTextLayout::FormatRange * cppArg2 = pyargs[2] ? Shiboken::Converter<QTextLayout::FormatRange * >::toCpp(pyargs[2]) : 0;

            if(!PyErr_Occurred()) {
                // draw(QPainter*,QPointF,const QTextLayout::FormatRange*)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                const_cast<const QTextLine*>(cppSelf)->draw(cppArg0, cppArg1, cppArg2);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextLineFunc_draw_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPainter, PySide.QtCore.QPointF, PySide.QtGui.QTextLayout::FormatRange = None", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QTextLine.draw", overloads);
        return 0;
}

static PyObject* Sbk_QTextLineFunc_height(PyObject* self)
{
    QTextLine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextLine* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // height()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                qreal cppResult = const_cast<const QTextLine*>(cppSelf)->height();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< double >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextLineFunc_horizontalAdvance(PyObject* self)
{
    QTextLine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextLine* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // horizontalAdvance()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                qreal cppResult = const_cast<const QTextLine*>(cppSelf)->horizontalAdvance();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< double >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextLineFunc_isValid(PyObject* self)
{
    QTextLine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextLine* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isValid()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QTextLine*>(cppSelf)->isValid();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextLineFunc_leading(PyObject* self)
{
    QTextLine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextLine* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // leading()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                qreal cppResult = const_cast<const QTextLine*>(cppSelf)->leading();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< double >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextLineFunc_leadingIncluded(PyObject* self)
{
    QTextLine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextLine* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // leadingIncluded()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QTextLine*>(cppSelf)->leadingIncluded();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextLineFunc_lineNumber(PyObject* self)
{
    QTextLine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextLine* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // lineNumber()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QTextLine*>(cppSelf)->lineNumber();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextLineFunc_naturalTextRect(PyObject* self)
{
    QTextLine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextLine* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // naturalTextRect()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QRectF cppResult = const_cast<const QTextLine*>(cppSelf)->naturalTextRect();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QRectF >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextLineFunc_naturalTextWidth(PyObject* self)
{
    QTextLine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextLine* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // naturalTextWidth()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                qreal cppResult = const_cast<const QTextLine*>(cppSelf)->naturalTextWidth();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< double >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextLineFunc_position(PyObject* self)
{
    QTextLine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextLine* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // position()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QPointF cppResult = const_cast<const QTextLine*>(cppSelf)->position();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QPointF >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextLineFunc_rect(PyObject* self)
{
    QTextLine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextLine* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // rect()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QRectF cppResult = const_cast<const QTextLine*>(cppSelf)->rect();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QRectF >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextLineFunc_setLeadingIncluded(PyObject* self, PyObject* arg)
{
    QTextLine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextLine* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setLeadingIncluded(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setLeadingIncluded(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextLineFunc_setLeadingIncluded_TypeError;

    // Call function/method
    {
        {
            bool cppArg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setLeadingIncluded(bool)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setLeadingIncluded(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextLineFunc_setLeadingIncluded_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextLine.setLeadingIncluded", overloads);
        return 0;
}

static PyObject* Sbk_QTextLineFunc_setLineWidth(PyObject* self, PyObject* arg)
{
    QTextLine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextLine* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setLineWidth(qreal)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setLineWidth(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextLineFunc_setLineWidth_TypeError;

    // Call function/method
    {
        {
            qreal cppArg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setLineWidth(qreal)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setLineWidth(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextLineFunc_setLineWidth_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextLine.setLineWidth", overloads);
        return 0;
}

static PyObject* Sbk_QTextLineFunc_setNumColumns(PyObject* self, PyObject* args)
{
    QTextLine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextLine* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setNumColumns", 1, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setNumColumns(int)
    // 1: setNumColumns(int,qreal)
    if (SbkNumber_Check(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // setNumColumns(int)
        } else if (numArgs == 2 && SbkNumber_Check(pyargs[1])) {
            overloadId = 1; // setNumColumns(int,qreal)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextLineFunc_setNumColumns_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // setNumColumns(int)
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // setNumColumns(int)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setNumColumns(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // setNumColumns(int,qreal)
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                qreal cppArg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // setNumColumns(int,qreal)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setNumColumns(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextLineFunc_setNumColumns_TypeError:
        const char* overloads[] = {"int", "int, float", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QTextLine.setNumColumns", overloads);
        return 0;
}

static PyObject* Sbk_QTextLineFunc_setPosition(PyObject* self, PyObject* arg)
{
    QTextLine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextLine* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setPosition(QPointF)
    if (Shiboken::Converter< ::QPointF >::isConvertible(arg)) {
        overloadId = 0; // setPosition(QPointF)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextLineFunc_setPosition_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QPointF cppArg0 = Shiboken::Converter<QPointF >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setPosition(QPointF)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setPosition(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextLineFunc_setPosition_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPointF", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextLine.setPosition", overloads);
        return 0;
}

static PyObject* Sbk_QTextLineFunc_textLength(PyObject* self)
{
    QTextLine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextLine* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // textLength()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QTextLine*>(cppSelf)->textLength();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextLineFunc_textStart(PyObject* self)
{
    QTextLine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextLine* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // textStart()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QTextLine*>(cppSelf)->textStart();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextLineFunc_width(PyObject* self)
{
    QTextLine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextLine* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // width()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                qreal cppResult = const_cast<const QTextLine*>(cppSelf)->width();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< double >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextLineFunc_x(PyObject* self)
{
    QTextLine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextLine* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // x()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                qreal cppResult = const_cast<const QTextLine*>(cppSelf)->x();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< double >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextLineFunc_xToCursor(PyObject* self, PyObject* args, PyObject* kwds)
{
    QTextLine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextLine* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QTextLine.xToCursor(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QTextLine.xToCursor(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:xToCursor", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: xToCursor(qreal,QTextLine::CursorPosition)const
    if (SbkNumber_Check(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // xToCursor(qreal,QTextLine::CursorPosition)const
        } else if (Shiboken::Converter< ::QTextLine::CursorPosition >::isConvertible(pyargs[1])) {
            overloadId = 0; // xToCursor(qreal,QTextLine::CursorPosition)const
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextLineFunc_xToCursor_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "edge");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "edge";
                    else if (Shiboken::Converter< ::QTextLine::CursorPosition >::isConvertible(value))
                        pyargs[1] = value;
                    else
                        goto Sbk_QTextLineFunc_xToCursor_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QTextLine.xToCursor(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            qreal cppArg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
            QTextLine::CursorPosition cppArg1 = pyargs[1] ? Shiboken::Converter<QTextLine::CursorPosition >::toCpp(pyargs[1]) : QTextLine::CursorBetweenCharacters;

            if(!PyErr_Occurred()) {
                // xToCursor(qreal,QTextLine::CursorPosition)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QTextLine*>(cppSelf)->xToCursor(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QTextLineFunc_xToCursor_TypeError:
        const char* overloads[] = {"float, PySide.QtGui.QTextLine.CursorPosition = CursorBetweenCharacters", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QTextLine.xToCursor", overloads);
        return 0;
}

static PyObject* Sbk_QTextLineFunc_y(PyObject* self)
{
    QTextLine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextLine* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // y()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                qreal cppResult = const_cast<const QTextLine*>(cppSelf)->y();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< double >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject *Sbk_QTextLine___copy__(PyObject *self)
{
        QTextLine* cppSelf = 0;
        if (!Shiboken::Object::isValid(self))
            return 0;
        cppSelf = Shiboken::Converter<QTextLine*>::toCpp(self);
        PyObject* pyResult = 0;
        QTextLine* copy = new QTextLine(*cppSelf);
        pyResult = Shiboken::Converter<QTextLine*>::toPython(copy);
        Shiboken::Object::getOwnership(pyResult);

        if (PyErr_Occurred() || !pyResult) {
            Py_XDECREF(pyResult);
            return 0;
        }
        return pyResult;
}

static PyMethodDef Sbk_QTextLine_methods[] = {
    {"ascent", (PyCFunction)Sbk_QTextLineFunc_ascent, METH_NOARGS},
    {"cursorToX", (PyCFunction)Sbk_QTextLineFunc_cursorToX, METH_VARARGS|METH_KEYWORDS},
    {"descent", (PyCFunction)Sbk_QTextLineFunc_descent, METH_NOARGS},
    {"draw", (PyCFunction)Sbk_QTextLineFunc_draw, METH_VARARGS|METH_KEYWORDS},
    {"height", (PyCFunction)Sbk_QTextLineFunc_height, METH_NOARGS},
    {"horizontalAdvance", (PyCFunction)Sbk_QTextLineFunc_horizontalAdvance, METH_NOARGS},
    {"isValid", (PyCFunction)Sbk_QTextLineFunc_isValid, METH_NOARGS},
    {"leading", (PyCFunction)Sbk_QTextLineFunc_leading, METH_NOARGS},
    {"leadingIncluded", (PyCFunction)Sbk_QTextLineFunc_leadingIncluded, METH_NOARGS},
    {"lineNumber", (PyCFunction)Sbk_QTextLineFunc_lineNumber, METH_NOARGS},
    {"naturalTextRect", (PyCFunction)Sbk_QTextLineFunc_naturalTextRect, METH_NOARGS},
    {"naturalTextWidth", (PyCFunction)Sbk_QTextLineFunc_naturalTextWidth, METH_NOARGS},
    {"position", (PyCFunction)Sbk_QTextLineFunc_position, METH_NOARGS},
    {"rect", (PyCFunction)Sbk_QTextLineFunc_rect, METH_NOARGS},
    {"setLeadingIncluded", (PyCFunction)Sbk_QTextLineFunc_setLeadingIncluded, METH_O},
    {"setLineWidth", (PyCFunction)Sbk_QTextLineFunc_setLineWidth, METH_O},
    {"setNumColumns", (PyCFunction)Sbk_QTextLineFunc_setNumColumns, METH_VARARGS},
    {"setPosition", (PyCFunction)Sbk_QTextLineFunc_setPosition, METH_O},
    {"textLength", (PyCFunction)Sbk_QTextLineFunc_textLength, METH_NOARGS},
    {"textStart", (PyCFunction)Sbk_QTextLineFunc_textStart, METH_NOARGS},
    {"width", (PyCFunction)Sbk_QTextLineFunc_width, METH_NOARGS},
    {"x", (PyCFunction)Sbk_QTextLineFunc_x, METH_NOARGS},
    {"xToCursor", (PyCFunction)Sbk_QTextLineFunc_xToCursor, METH_VARARGS|METH_KEYWORDS},
    {"y", (PyCFunction)Sbk_QTextLineFunc_y, METH_NOARGS},

    {"__copy__", (PyCFunction)Sbk_QTextLine___copy__, METH_NOARGS},
    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QTextLine_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QTextLine",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QTextLine_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&SbkObject_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QTextLine_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern


void init_QTextLine(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QTEXTLINE_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QTextLine_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QTextLine_Type);
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QTextLine_Type, &Shiboken::callCppDestructor<QTextLine >);
    Py_INCREF((PyObject*)&Sbk_QTextLine_Type); //Incref due the 'PyModule_AddObject' steals the reference.
    if (PyType_Ready((PyTypeObject*)&Sbk_QTextLine_Type) < 0)
        return;

    Shiboken::ObjectType::setOriginalName(&Sbk_QTextLine_Type, "QTextLine");
    PyModule_AddObject(module, "QTextLine",
        ((PyObject*)&Sbk_QTextLine_Type));

    // Initialize enums
    PyObject* enumItem;

    // init enum: Edge
    PyTypeObject* SbkPySide_QtGui_QTextLine_Edge = Shiboken::Enum::newType("PySide.QtGui.QTextLine.Edge");
    SbkPySide_QtGuiTypes[SBK_QTEXTLINE_EDGE_IDX] = SbkPySide_QtGui_QTextLine_Edge;
    if (PyType_Ready(SbkPySide_QtGui_QTextLine_Edge) < 0)
        return;
    PyDict_SetItemString(Sbk_QTextLine_Type.super.ht_type.tp_dict,
            "Edge",((PyObject*)SbkPySide_QtGui_QTextLine_Edge));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTextLine_Edge,(long) QTextLine::Leading, "Leading");
    PyDict_SetItemString(Sbk_QTextLine_Type.super.ht_type.tp_dict,"Leading", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTextLine_Edge->tp_dict,"Leading", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTextLine_Edge,(long) QTextLine::Trailing, "Trailing");
    PyDict_SetItemString(Sbk_QTextLine_Type.super.ht_type.tp_dict,"Trailing", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTextLine_Edge->tp_dict,"Trailing", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QTextLine::Edge");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::Edge");
    // end of enum Edge

    // init enum: CursorPosition
    PyTypeObject* SbkPySide_QtGui_QTextLine_CursorPosition = Shiboken::Enum::newType("PySide.QtGui.QTextLine.CursorPosition");
    SbkPySide_QtGuiTypes[SBK_QTEXTLINE_CURSORPOSITION_IDX] = SbkPySide_QtGui_QTextLine_CursorPosition;
    if (PyType_Ready(SbkPySide_QtGui_QTextLine_CursorPosition) < 0)
        return;
    PyDict_SetItemString(Sbk_QTextLine_Type.super.ht_type.tp_dict,
            "CursorPosition",((PyObject*)SbkPySide_QtGui_QTextLine_CursorPosition));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTextLine_CursorPosition,(long) QTextLine::CursorBetweenCharacters, "CursorBetweenCharacters");
    PyDict_SetItemString(Sbk_QTextLine_Type.super.ht_type.tp_dict,"CursorBetweenCharacters", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTextLine_CursorPosition->tp_dict,"CursorBetweenCharacters", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTextLine_CursorPosition,(long) QTextLine::CursorOnCharacter, "CursorOnCharacter");
    PyDict_SetItemString(Sbk_QTextLine_Type.super.ht_type.tp_dict,"CursorOnCharacter", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTextLine_CursorPosition->tp_dict,"CursorOnCharacter", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QTextLine::CursorPosition");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::CursorPosition");
    // end of enum CursorPosition


    Shiboken::TypeResolver::createValueTypeResolver<QTextLine >("QTextLine");
    Shiboken::TypeResolver::createObjectTypeResolver<QTextLine >("QTextLine*");
    Shiboken::TypeResolver::createValueTypeResolver<QTextLine >(typeid(QTextLine).name());
    qRegisterMetaType< ::QTextLine >("QTextLine");
    qRegisterMetaType< ::QTextLine::Edge >("QTextLine::Edge");
    qRegisterMetaType< ::QTextLine::CursorPosition >("QTextLine::CursorPosition");
}

