/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtgui_python.h"

#include "qtextoption_tab_wrapper.h"

// Extra includes
#include <qtextoption.h>



// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QTextOption_Tab_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QTextOption::Tab >()))
        return -1;

    QTextOption::Tab* cptr = 0;
    int overloadId = -1;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);

    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);

    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.Tab(): too many arguments");
        return -1;
    }

    if (!PyArg_ParseTuple(args, "|OOO:Tab", &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return -1;

    // Overloaded function decisor
    // 0: Tab()
    // 1: Tab(QTextOption::Tab)
    // 2: Tab(qreal,QTextOption::TabType,QChar)
    if (numArgs == 0) {
        overloadId = 0; // Tab()
    } else if (numArgs >= 2 && SbkNumber_Check(pyargs[0]) && Shiboken::Converter< ::QTextOption::TabType >::isConvertible(pyargs[1])) {
        if (numArgs == 2) {
            overloadId = 2; // Tab(qreal,QTextOption::TabType,QChar)
        } else if (Shiboken::Converter< QChar >::isConvertible(pyargs[2])) {
            overloadId = 2; // Tab(qreal,QTextOption::TabType,QChar)
        }
    } else if (numArgs == 1 && Shiboken::Converter< ::QTextOption::Tab >::isConvertible(pyargs[0])) {
        overloadId = 1; // Tab(QTextOption::Tab)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextOption_Tab_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // Tab()
            {

                if(!PyErr_Occurred()) {
                    // Tab()
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QTextOption::Tab();
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // Tab(QTextOption::Tab)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QTextOption::Tab cppArg0 = Shiboken::Converter<QTextOption::Tab >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // Tab(QTextOption::Tab)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QTextOption::Tab(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 2: // Tab(qreal,QTextOption::TabType,QChar)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "delim");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "delim";
                        else if (Shiboken::Converter< QChar >::isConvertible(value))
                            pyargs[2] = value;
                        else
                            goto Sbk_QTextOption_Tab_Init_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.Tab(): got multiple values for keyword argument '%s'", errorArgName);
                        return -1;
                    }
                }
                qreal cppArg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
                QTextOption::TabType cppArg1 = Shiboken::Converter<QTextOption::TabType >::toCpp(pyargs[1]);
                QChar cppArg2 = pyargs[2] ? Shiboken::Converter<QChar >::toCpp(pyargs[2]) : QChar();

                if(!PyErr_Occurred()) {
                    // Tab(qreal,QTextOption::TabType,QChar)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QTextOption::Tab(cppArg0, cppArg1, cppArg2);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QTextOption::Tab >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QTextOption_Tab_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QTextOption_Tab_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtGui.QTextOption::Tab", "float, PySide.QtGui.QTextOption.TabType, QChar = QChar()", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.Tab", overloads);
        return -1;
}

static PyObject *Sbk_QTextOption_Tab___copy__(PyObject *self)
{
        QTextOption::Tab* cppSelf = 0;
        if (!Shiboken::Object::isValid(self))
            return 0;
        cppSelf = Shiboken::Converter<QTextOption::Tab*>::toCpp(self);
        PyObject* pyResult = 0;
        QTextOption::Tab* copy = new QTextOption::Tab(*cppSelf);
        pyResult = Shiboken::Converter<QTextOption::Tab*>::toPython(copy);
        Shiboken::Object::getOwnership(pyResult);

        if (PyErr_Occurred() || !pyResult) {
            Py_XDECREF(pyResult);
            return 0;
        }
        return pyResult;
}

static PyMethodDef Sbk_QTextOption_Tab_methods[] = {

    {"__copy__", (PyCFunction)Sbk_QTextOption_Tab___copy__, METH_NOARGS},
    {0} // Sentinel
};

// Rich comparison
static PyObject* Sbk_QTextOption_Tab_richcompare(PyObject* self, PyObject* arg, int op)
{
    PyObject* pyResult = 0;
    QTextOption::Tab& cppSelf = *Shiboken::Converter< QTextOption::Tab* >::toCpp(self);

    switch (op) {
        case Py_NE:
            if (Shiboken::Converter< ::QTextOption::Tab >::isConvertible(arg)) {
                // operator!=(const QTextOption::Tab & other) const
                QTextOption::Tab cppArg0 = Shiboken::Converter< ::QTextOption::Tab >::toCpp(arg);
                pyResult = Shiboken::Converter< bool >::toPython(cppSelf != cppArg0);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_EQ:
            if (Shiboken::Converter< ::QTextOption::Tab >::isConvertible(arg)) {
                // operator==(const QTextOption::Tab & other) const
                QTextOption::Tab cppArg0 = Shiboken::Converter< ::QTextOption::Tab >::toCpp(arg);
                pyResult = Shiboken::Converter< bool >::toPython(cppSelf == cppArg0);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            goto Sbk_QTextOption_Tab_RichComparison_TypeError;
    }

    if (pyResult && !PyErr_Occurred())
        return pyResult;
    Sbk_QTextOption_Tab_RichComparison_TypeError:
    PyErr_SetString(PyExc_NotImplementedError, "operator not implemented.");
    return 0;

}

static PyObject* Sbk_QTextOption_Tab_get_delimiter(PyObject* self, void*)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    PyObject* val = Shiboken::Converter< QChar >::toPython( Shiboken::Converter< QTextOption::Tab* >::toCpp(self)->delimiter);
    return val;
}

static int Sbk_QTextOption_Tab_set_delimiter(PyObject* self, PyObject* value, void*)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'delimiter' may not be deleted");
        return -1;
    }
    if (!Shiboken::Converter< QChar >::isConvertible(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'delimiter', 'QChar' or convertible type expected");
        return -1;
    }

    Shiboken::Converter< QTextOption::Tab* >::toCpp(self)->delimiter = Shiboken::Converter< QChar >::toCpp(value);

    return 0;
}

static PyObject* Sbk_QTextOption_Tab_get_position(PyObject* self, void*)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    PyObject* val = Shiboken::Converter< double >::toPython( Shiboken::Converter< QTextOption::Tab* >::toCpp(self)->position);
    return val;
}

static int Sbk_QTextOption_Tab_set_position(PyObject* self, PyObject* value, void*)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'position' may not be deleted");
        return -1;
    }
    if (!SbkNumber_Check(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'position', 'qreal' or convertible type expected");
        return -1;
    }

    Shiboken::Converter< QTextOption::Tab* >::toCpp(self)->position = Shiboken::Converter< double >::toCpp(value);

    return 0;
}

static PyObject* Sbk_QTextOption_Tab_get_type(PyObject* self, void*)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    PyObject* val = Shiboken::Converter< ::QTextOption::TabType >::toPython( Shiboken::Converter< QTextOption::Tab* >::toCpp(self)->type);
    return val;
}

static int Sbk_QTextOption_Tab_set_type(PyObject* self, PyObject* value, void*)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'type' may not be deleted");
        return -1;
    }
    if (!Shiboken::Converter< ::QTextOption::TabType >::isConvertible(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'type', 'TabType' or convertible type expected");
        return -1;
    }

    Shiboken::Converter< QTextOption::Tab* >::toCpp(self)->type = Shiboken::Converter< ::QTextOption::TabType >::toCpp(value);

    return 0;
}

// Getters and Setters for Tab
static PyGetSetDef Sbk_QTextOption_Tab_getsetlist[] = {
    {const_cast<char*>("delimiter"), Sbk_QTextOption_Tab_get_delimiter, Sbk_QTextOption_Tab_set_delimiter},
    {const_cast<char*>("position"), Sbk_QTextOption_Tab_get_position, Sbk_QTextOption_Tab_set_position},
    {const_cast<char*>("type"), Sbk_QTextOption_Tab_get_type, Sbk_QTextOption_Tab_set_type},
    {0}  // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QTextOption_Tab_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QTextOption.Tab",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      Sbk_QTextOption_Tab_richcompare,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QTextOption_Tab_methods,
    /*tp_members*/          0,
    /*tp_getset*/           Sbk_QTextOption_Tab_getsetlist,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&SbkObject_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QTextOption_Tab_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern


void init_QTextOption_Tab(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QTEXTOPTION_TAB_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QTextOption_Tab_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QTextOption_Tab_Type);
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QTextOption_Tab_Type, &Shiboken::callCppDestructor<QTextOption::Tab >);
    Py_INCREF((PyObject*)&Sbk_QTextOption_Tab_Type); //Incref due the 'PyModule_AddObject' steals the reference.
    if (PyType_Ready((PyTypeObject*)&Sbk_QTextOption_Tab_Type) < 0)
        return;

    Shiboken::ObjectType::setOriginalName(&Sbk_QTextOption_Tab_Type, "QTextOption::Tab");
    PyDict_SetItemString(module,"Tab", (PyObject*)&Sbk_QTextOption_Tab_Type);

    Shiboken::TypeResolver::createValueTypeResolver<QTextOption::Tab >("QTextOption::Tab");
    Shiboken::TypeResolver::createObjectTypeResolver<QTextOption::Tab >("QTextOption::Tab*");
    Shiboken::TypeResolver::createValueTypeResolver<QTextOption::Tab >(typeid(QTextOption::Tab).name());
    qRegisterMetaType< ::QTextOption::Tab >("Tab");
    qRegisterMetaType< ::QTextOption::Tab >("QTextOption::Tab");
}

