/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtgui_python.h"

#include "qtilerules_wrapper.h"

// Extra includes



// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QTileRules_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QTileRules >()))
        return -1;

    QTileRules* cptr = 0;
    int overloadId = -1;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);

    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);

    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QTileRules(): too many arguments");
        return -1;
    }

    if (!PyArg_ParseTuple(args, "|OO:QTileRules", &(pyargs[0]), &(pyargs[1])))
        return -1;

    // Overloaded function decisor
    // 0: QTileRules(Qt::TileRule,Qt::TileRule)
    // 1: QTileRules(Qt::TileRule)
    // 2: QTileRules(QTileRules)
    if (numArgs == 0) {
        overloadId = 1; // QTileRules(Qt::TileRule)
    } else if (Shiboken::Converter< ::Qt::TileRule >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 1; // QTileRules(Qt::TileRule)
        } else if (numArgs == 2 && Shiboken::Converter< ::Qt::TileRule >::isConvertible(pyargs[1])) {
            overloadId = 0; // QTileRules(Qt::TileRule,Qt::TileRule)
        }
    } else if (numArgs == 1 && Shiboken::Converter< ::QTileRules >::isConvertible(pyargs[0])) {
        overloadId = 2; // QTileRules(QTileRules)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTileRules_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QTileRules(Qt::TileRule,Qt::TileRule)
            {
                Qt::TileRule cppArg0 = Shiboken::Converter<Qt::TileRule >::toCpp(pyargs[0]);
                Qt::TileRule cppArg1 = Shiboken::Converter<Qt::TileRule >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // QTileRules(Qt::TileRule,Qt::TileRule)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QTileRules(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // QTileRules(Qt::TileRule)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "rule");
                    if (value) {
                        if (pyargs[0])
                            errorArgName = "rule";
                        else if (Shiboken::Converter< ::Qt::TileRule >::isConvertible(value))
                            pyargs[0] = value;
                        else
                            goto Sbk_QTileRules_Init_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QTileRules(): got multiple values for keyword argument '%s'", errorArgName);
                        return -1;
                    }
                }
                Qt::TileRule cppArg0 = pyargs[0] ? Shiboken::Converter<Qt::TileRule >::toCpp(pyargs[0]) : Qt::StretchTile;

                if(!PyErr_Occurred()) {
                    // QTileRules(Qt::TileRule)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QTileRules(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 2: // QTileRules(QTileRules)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QTileRules cppArg0 = Shiboken::Converter<QTileRules >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QTileRules(QTileRules)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QTileRules(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QTileRules >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QTileRules_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QTileRules_Init_TypeError:
        const char* overloads[] = {"PySide.QtCore.Qt.TileRule, PySide.QtCore.Qt.TileRule", "PySide.QtCore.Qt.TileRule = Qt.StretchTile", "PySide.QtGui.QTileRules", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QTileRules", overloads);
        return -1;
}

static PyObject *Sbk_QTileRules___copy__(PyObject *self)
{
        QTileRules* cppSelf = 0;
        if (!Shiboken::Object::isValid(self))
            return 0;
        cppSelf = Shiboken::Converter<QTileRules*>::toCpp(self);
        PyObject* pyResult = 0;
        QTileRules* copy = new QTileRules(*cppSelf);
        pyResult = Shiboken::Converter<QTileRules*>::toPython(copy);
        Shiboken::Object::getOwnership(pyResult);

        if (PyErr_Occurred() || !pyResult) {
            Py_XDECREF(pyResult);
            return 0;
        }
        return pyResult;
}

static PyMethodDef Sbk_QTileRules_methods[] = {

    {"__copy__", (PyCFunction)Sbk_QTileRules___copy__, METH_NOARGS},
    {0} // Sentinel
};

static PyObject* Sbk_QTileRules_get_vertical(PyObject* self, void*)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    PyObject* val = Shiboken::Converter< ::Qt::TileRule >::toPython( Shiboken::Converter< QTileRules* >::toCpp(self)->vertical);
    return val;
}

static int Sbk_QTileRules_set_vertical(PyObject* self, PyObject* value, void*)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'vertical' may not be deleted");
        return -1;
    }
    if (!Shiboken::Converter< ::Qt::TileRule >::isConvertible(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'vertical', 'TileRule' or convertible type expected");
        return -1;
    }

    Shiboken::Converter< QTileRules* >::toCpp(self)->vertical = Shiboken::Converter< ::Qt::TileRule >::toCpp(value);

    return 0;
}

static PyObject* Sbk_QTileRules_get_horizontal(PyObject* self, void*)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    PyObject* val = Shiboken::Converter< ::Qt::TileRule >::toPython( Shiboken::Converter< QTileRules* >::toCpp(self)->horizontal);
    return val;
}

static int Sbk_QTileRules_set_horizontal(PyObject* self, PyObject* value, void*)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'horizontal' may not be deleted");
        return -1;
    }
    if (!Shiboken::Converter< ::Qt::TileRule >::isConvertible(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'horizontal', 'TileRule' or convertible type expected");
        return -1;
    }

    Shiboken::Converter< QTileRules* >::toCpp(self)->horizontal = Shiboken::Converter< ::Qt::TileRule >::toCpp(value);

    return 0;
}

// Getters and Setters for QTileRules
static PyGetSetDef Sbk_QTileRules_getsetlist[] = {
    {const_cast<char*>("vertical"), Sbk_QTileRules_get_vertical, Sbk_QTileRules_set_vertical},
    {const_cast<char*>("horizontal"), Sbk_QTileRules_get_horizontal, Sbk_QTileRules_set_horizontal},
    {0}  // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QTileRules_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QTileRules",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QTileRules_methods,
    /*tp_members*/          0,
    /*tp_getset*/           Sbk_QTileRules_getsetlist,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&SbkObject_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QTileRules_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern


void init_QTileRules(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QTILERULES_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QTileRules_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QTileRules_Type);
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QTileRules_Type, &Shiboken::callCppDestructor<QTileRules >);
    Py_INCREF((PyObject*)&Sbk_QTileRules_Type); //Incref due the 'PyModule_AddObject' steals the reference.
    if (PyType_Ready((PyTypeObject*)&Sbk_QTileRules_Type) < 0)
        return;

    Shiboken::ObjectType::setOriginalName(&Sbk_QTileRules_Type, "QTileRules");
    PyModule_AddObject(module, "QTileRules",
        ((PyObject*)&Sbk_QTileRules_Type));


    Shiboken::TypeResolver::createValueTypeResolver<QTileRules >("QTileRules");
    Shiboken::TypeResolver::createObjectTypeResolver<QTileRules >("QTileRules*");
    Shiboken::TypeResolver::createValueTypeResolver<QTileRules >(typeid(QTileRules).name());
    qRegisterMetaType< ::QTileRules* >("QTileRules*");
}

