/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qthelp_python.h"

#include "qhelpsearchquery_wrapper.h"

// Extra includes
#include <QStringList>



// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QHelpSearchQuery_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QHelpSearchQuery >()))
        return -1;

    QHelpSearchQuery* cptr = 0;
    int overloadId = -1;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QHelpSearchQuery", 0, 2, &(pyargs[0]), &(pyargs[1])))
        return -1;

    // Overloaded function decisor
    // 0: QHelpSearchQuery()
    // 1: QHelpSearchQuery(QHelpSearchQuery::FieldName,QStringList)
    // 2: QHelpSearchQuery(QHelpSearchQuery)
    if (numArgs == 0) {
        overloadId = 0; // QHelpSearchQuery()
    } else if (numArgs == 1 && Shiboken::Converter< ::QHelpSearchQuery >::isConvertible(pyargs[0])) {
        overloadId = 2; // QHelpSearchQuery(QHelpSearchQuery)
    } else if (numArgs == 2 && Shiboken::Converter< ::QHelpSearchQuery::FieldName >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QStringList >::isConvertible(pyargs[1])) {
        overloadId = 1; // QHelpSearchQuery(QHelpSearchQuery::FieldName,QStringList)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QHelpSearchQuery_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QHelpSearchQuery()
            {

                if(!PyErr_Occurred()) {
                    // QHelpSearchQuery()
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QHelpSearchQuery();
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // QHelpSearchQuery(QHelpSearchQuery::FieldName,QStringList)
            {
                QHelpSearchQuery::FieldName cppArg0 = Shiboken::Converter<QHelpSearchQuery::FieldName >::toCpp(pyargs[0]);
                QStringList cppArg1 = Shiboken::Converter<QStringList >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // QHelpSearchQuery(QHelpSearchQuery::FieldName,QStringList)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QHelpSearchQuery(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 2: // QHelpSearchQuery(QHelpSearchQuery)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QHelpSearchQuery cppArg0 = Shiboken::Converter<QHelpSearchQuery >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QHelpSearchQuery(QHelpSearchQuery)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QHelpSearchQuery(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QHelpSearchQuery >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QHelpSearchQuery_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QHelpSearchQuery_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtHelp.QHelpSearchQuery.FieldName, list", "PySide.QtHelp.QHelpSearchQuery", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtHelp.QHelpSearchQuery", overloads);
        return -1;
}

static PyObject *Sbk_QHelpSearchQuery___copy__(PyObject *self)
{
        QHelpSearchQuery* cppSelf = 0;
        if (!Shiboken::Object::isValid(self))
            return 0;
        cppSelf = Shiboken::Converter<QHelpSearchQuery*>::toCpp(self);
        PyObject* pyResult = 0;
        QHelpSearchQuery* copy = new QHelpSearchQuery(*cppSelf);
        pyResult = Shiboken::Converter<QHelpSearchQuery*>::toPython(copy);
        Shiboken::Object::getOwnership(pyResult);

        if (PyErr_Occurred() || !pyResult) {
            Py_XDECREF(pyResult);
            return 0;
        }
        return pyResult;
}

static PyMethodDef Sbk_QHelpSearchQuery_methods[] = {

    {"__copy__", (PyCFunction)Sbk_QHelpSearchQuery___copy__, METH_NOARGS},
    {0} // Sentinel
};

static PyObject* Sbk_QHelpSearchQuery_get_wordList(PyObject* self, void*)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    PyObject* val = Shiboken::createWrapper(&Shiboken::Converter< QHelpSearchQuery* >::toCpp(self)->wordList);
    Shiboken::Object::releaseOwnership(val);
    Shiboken::Object::setParent(self, val);
    return val;
}

static int Sbk_QHelpSearchQuery_set_wordList(PyObject* self, PyObject* value, void*)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'wordList' may not be deleted");
        return -1;
    }
    if (!Shiboken::Converter< ::QStringList >::isConvertible(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'wordList', 'QList' or convertible type expected");
        return -1;
    }

    Shiboken::Converter< QHelpSearchQuery* >::toCpp(self)->wordList = Shiboken::Converter< ::QStringList >::toCpp(value);

    return 0;
}

static PyObject* Sbk_QHelpSearchQuery_get_fieldName(PyObject* self, void*)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    PyObject* val = Shiboken::Converter< ::QHelpSearchQuery::FieldName >::toPython( Shiboken::Converter< QHelpSearchQuery* >::toCpp(self)->fieldName);
    return val;
}

static int Sbk_QHelpSearchQuery_set_fieldName(PyObject* self, PyObject* value, void*)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'fieldName' may not be deleted");
        return -1;
    }
    if (!Shiboken::Converter< ::QHelpSearchQuery::FieldName >::isConvertible(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'fieldName', 'FieldName' or convertible type expected");
        return -1;
    }

    Shiboken::Converter< QHelpSearchQuery* >::toCpp(self)->fieldName = Shiboken::Converter< ::QHelpSearchQuery::FieldName >::toCpp(value);

    return 0;
}

// Getters and Setters for QHelpSearchQuery
static PyGetSetDef Sbk_QHelpSearchQuery_getsetlist[] = {
    {const_cast<char*>("wordList"), Sbk_QHelpSearchQuery_get_wordList, Sbk_QHelpSearchQuery_set_wordList},
    {const_cast<char*>("fieldName"), Sbk_QHelpSearchQuery_get_fieldName, Sbk_QHelpSearchQuery_set_fieldName},
    {0}  // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QHelpSearchQuery_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtHelp.QHelpSearchQuery",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QHelpSearchQuery_methods,
    /*tp_members*/          0,
    /*tp_getset*/           Sbk_QHelpSearchQuery_getsetlist,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&SbkObject_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QHelpSearchQuery_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern


void init_QHelpSearchQuery(PyObject* module)
{
    SbkPySide_QtHelpTypes[SBK_QHELPSEARCHQUERY_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QHelpSearchQuery_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QHelpSearchQuery_Type);
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QHelpSearchQuery_Type, &Shiboken::callCppDestructor<QHelpSearchQuery >);
    Py_INCREF((PyObject*)&Sbk_QHelpSearchQuery_Type); //Incref due the 'PyModule_AddObject' steals the reference.
    if (PyType_Ready((PyTypeObject*)&Sbk_QHelpSearchQuery_Type) < 0)
        return;

    Shiboken::ObjectType::setOriginalName(&Sbk_QHelpSearchQuery_Type, "QHelpSearchQuery");
    PyModule_AddObject(module, "QHelpSearchQuery",
        ((PyObject*)&Sbk_QHelpSearchQuery_Type));

    // Initialize enums
    PyObject* enumItem;

    // init enum: FieldName
    PyTypeObject* SbkPySide_QtHelp_QHelpSearchQuery_FieldName = Shiboken::Enum::newType("PySide.QtHelp.QHelpSearchQuery.FieldName");
    SbkPySide_QtHelpTypes[SBK_QHELPSEARCHQUERY_FIELDNAME_IDX] = SbkPySide_QtHelp_QHelpSearchQuery_FieldName;
    if (PyType_Ready(SbkPySide_QtHelp_QHelpSearchQuery_FieldName) < 0)
        return;
    PyDict_SetItemString(Sbk_QHelpSearchQuery_Type.super.ht_type.tp_dict,
            "FieldName",((PyObject*)SbkPySide_QtHelp_QHelpSearchQuery_FieldName));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtHelp_QHelpSearchQuery_FieldName,(long) QHelpSearchQuery::DEFAULT, "DEFAULT");
    PyDict_SetItemString(Sbk_QHelpSearchQuery_Type.super.ht_type.tp_dict,"DEFAULT", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtHelp_QHelpSearchQuery_FieldName->tp_dict,"DEFAULT", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtHelp_QHelpSearchQuery_FieldName,(long) QHelpSearchQuery::FUZZY, "FUZZY");
    PyDict_SetItemString(Sbk_QHelpSearchQuery_Type.super.ht_type.tp_dict,"FUZZY", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtHelp_QHelpSearchQuery_FieldName->tp_dict,"FUZZY", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtHelp_QHelpSearchQuery_FieldName,(long) QHelpSearchQuery::WITHOUT, "WITHOUT");
    PyDict_SetItemString(Sbk_QHelpSearchQuery_Type.super.ht_type.tp_dict,"WITHOUT", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtHelp_QHelpSearchQuery_FieldName->tp_dict,"WITHOUT", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtHelp_QHelpSearchQuery_FieldName,(long) QHelpSearchQuery::PHRASE, "PHRASE");
    PyDict_SetItemString(Sbk_QHelpSearchQuery_Type.super.ht_type.tp_dict,"PHRASE", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtHelp_QHelpSearchQuery_FieldName->tp_dict,"PHRASE", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtHelp_QHelpSearchQuery_FieldName,(long) QHelpSearchQuery::ALL, "ALL");
    PyDict_SetItemString(Sbk_QHelpSearchQuery_Type.super.ht_type.tp_dict,"ALL", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtHelp_QHelpSearchQuery_FieldName->tp_dict,"ALL", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtHelp_QHelpSearchQuery_FieldName,(long) QHelpSearchQuery::ATLEAST, "ATLEAST");
    PyDict_SetItemString(Sbk_QHelpSearchQuery_Type.super.ht_type.tp_dict,"ATLEAST", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtHelp_QHelpSearchQuery_FieldName->tp_dict,"ATLEAST", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QHelpSearchQuery::FieldName");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::FieldName");
    // end of enum FieldName


    Shiboken::TypeResolver::createValueTypeResolver<QHelpSearchQuery >("QHelpSearchQuery");
    Shiboken::TypeResolver::createObjectTypeResolver<QHelpSearchQuery >("QHelpSearchQuery*");
    Shiboken::TypeResolver::createValueTypeResolver<QHelpSearchQuery >(typeid(QHelpSearchQuery).name());
    qRegisterMetaType< ::QHelpSearchQuery >("QHelpSearchQuery");
    qRegisterMetaType< ::QHelpSearchQuery::FieldName >("QHelpSearchQuery::FieldName");
}

