/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtmultimedia_python.h"

#include "qaudioenginefactoryinterface_wrapper.h"

// Extra includes
#include <QList>
#include <QStringList>
#include <qaudioengine.h>
#include <qaudioformat.h>
#include <qbytearray.h>


// Native ---------------------------------------------------------

QAudioEngineFactoryInterfaceWrapper::QAudioEngineFactoryInterfaceWrapper() : QAudioEngineFactoryInterface() {
    // ... middle
}

QList<QByteArray > QAudioEngineFactoryInterfaceWrapper::availableDevices(QAudio::Mode arg__1) const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return QList<QByteArray >();
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "availableDevices"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QAudioEngineFactoryInterface.availableDevices()' not implemented.");
        return QList<QByteArray >();
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QAudio::Mode >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QList<QByteArray >();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QList<QByteArray > >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QAudioEngineFactoryInterface.availableDevices", "list", pyResult->ob_type->tp_name);
        return QList<QByteArray >();
    }
    QList<QByteArray > cppResult(Shiboken::Converter< ::QList<QByteArray > >::toCpp(pyResult));
    return cppResult;
}

QAbstractAudioDeviceInfo * QAudioEngineFactoryInterfaceWrapper::createDeviceInfo(const QByteArray & device, QAudio::Mode mode)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return 0;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "createDeviceInfo"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QAudioEngineFactoryInterface.createDeviceInfo()' not implemented.");
        return 0;
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter< ::QByteArray >::toPython(device),
        Shiboken::Converter< ::QAudio::Mode >::toPython(mode)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return 0;
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QAbstractAudioDeviceInfo * >::isConvertible(pyResult);
    typeIsValid = typeIsValid || (pyResult == Py_None);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QAudioEngineFactoryInterface.createDeviceInfo", Shiboken::SbkType<QAbstractAudioDeviceInfo >()->tp_name, pyResult->ob_type->tp_name);
        return 0;
    }
    QAbstractAudioDeviceInfo * cppResult(Shiboken::Converter< ::QAbstractAudioDeviceInfo * >::toCpp(pyResult));
    return cppResult;
}

QAbstractAudioInput * QAudioEngineFactoryInterfaceWrapper::createInput(const QByteArray & device, const QAudioFormat & format)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return 0;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "createInput"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QAudioEngineFactoryInterface.createInput()' not implemented.");
        return 0;
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter< ::QByteArray >::toPython(device),
        Shiboken::Converter< ::QAudioFormat >::toPython(format)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return 0;
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QAbstractAudioInput * >::isConvertible(pyResult);
    typeIsValid = typeIsValid || (pyResult == Py_None);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QAudioEngineFactoryInterface.createInput", Shiboken::SbkType<QAbstractAudioInput >()->tp_name, pyResult->ob_type->tp_name);
        return 0;
    }
    QAbstractAudioInput * cppResult(Shiboken::Converter< ::QAbstractAudioInput * >::toCpp(pyResult));
    return cppResult;
}

QAbstractAudioOutput * QAudioEngineFactoryInterfaceWrapper::createOutput(const QByteArray & device, const QAudioFormat & format)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return 0;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "createOutput"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QAudioEngineFactoryInterface.createOutput()' not implemented.");
        return 0;
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter< ::QByteArray >::toPython(device),
        Shiboken::Converter< ::QAudioFormat >::toPython(format)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return 0;
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QAbstractAudioOutput * >::isConvertible(pyResult);
    typeIsValid = typeIsValid || (pyResult == Py_None);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QAudioEngineFactoryInterface.createOutput", Shiboken::SbkType<QAbstractAudioOutput >()->tp_name, pyResult->ob_type->tp_name);
        return 0;
    }
    QAbstractAudioOutput * cppResult(Shiboken::Converter< ::QAbstractAudioOutput * >::toCpp(pyResult));
    return cppResult;
}

QStringList QAudioEngineFactoryInterfaceWrapper::keys() const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return QStringList();
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "keys"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QAudioEngineFactoryInterface.keys()' not implemented.");
        return QStringList();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QStringList();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QStringList >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QAudioEngineFactoryInterface.keys", "list", pyResult->ob_type->tp_name);
        return QStringList();
    }
    QStringList cppResult(Shiboken::Converter< ::QStringList >::toCpp(pyResult));
    return cppResult;
}

QAudioEngineFactoryInterfaceWrapper::~QAudioEngineFactoryInterfaceWrapper()
{
    SbkObject* wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QAudioEngineFactoryInterface_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QAudioEngineFactoryInterface >()))
        return -1;

    QAudioEngineFactoryInterfaceWrapper* cptr = 0;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);
    SbkObjectType* type = reinterpret_cast<SbkObjectType*>(self->ob_type);
    SbkObjectType* myType = reinterpret_cast<SbkObjectType*>(SbkPySide_QtMultimediaTypes[SBK_QAUDIOENGINEFACTORYINTERFACE_IDX]);
    if (type == myType) {
        PyErr_SetString(PyExc_NotImplementedError,
            "'QAudioEngineFactoryInterface' represents a C++ abstract class and cannot be instantiated");
        return -1;
    }


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // QAudioEngineFactoryInterface()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new QAudioEngineFactoryInterfaceWrapper();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QAudioEngineFactoryInterface >(), cptr)) {
        delete cptr;
        return -1;
    }
    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject* Sbk_QAudioEngineFactoryInterfaceFunc_availableDevices(PyObject* self, PyObject* arg)
{
    QAudioEngineFactoryInterface* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QAudioEngineFactoryInterface* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: availableDevices(QAudio::Mode)const
    if (Shiboken::Converter< ::QAudio::Mode >::isConvertible(arg)) {
        overloadId = 0; // availableDevices(QAudio::Mode)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QAudioEngineFactoryInterfaceFunc_availableDevices_TypeError;

    // Call function/method
    {
        {
            QAudio::Mode cppArg0 = Shiboken::Converter<QAudio::Mode >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // availableDevices(QAudio::Mode)const
                if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject*>(self))) {
                    PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QAudioEngineFactoryInterface.availableDevices()' not implemented.");
                    return 0;
                }
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QList<QByteArray > cppResult = const_cast<const QAudioEngineFactoryInterface*>(cppSelf)->availableDevices(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QList<QByteArray > >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QAudioEngineFactoryInterfaceFunc_availableDevices_TypeError:
        const char* overloads[] = {"PySide.QtMultimedia.QAudio.Mode", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtMultimedia.QAudioEngineFactoryInterface.availableDevices", overloads);
        return 0;
}

static PyObject* Sbk_QAudioEngineFactoryInterfaceFunc_createDeviceInfo(PyObject* self, PyObject* args)
{
    QAudioEngineFactoryInterface* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QAudioEngineFactoryInterface* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "createDeviceInfo", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: createDeviceInfo(QByteArray,QAudio::Mode)
    if (numArgs == 2 && Shiboken::Converter< ::QByteArray >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QAudio::Mode >::isConvertible(pyargs[1])) {
        overloadId = 0; // createDeviceInfo(QByteArray,QAudio::Mode)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QAudioEngineFactoryInterfaceFunc_createDeviceInfo_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QByteArray cppArg0 = Shiboken::Converter<QByteArray >::toCpp(pyargs[0]);
            QAudio::Mode cppArg1 = Shiboken::Converter<QAudio::Mode >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // createDeviceInfo(QByteArray,QAudio::Mode)
                if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject*>(self))) {
                    PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QAudioEngineFactoryInterface.createDeviceInfo()' not implemented.");
                    return 0;
                }
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QAbstractAudioDeviceInfo * cppResult = cppSelf->createDeviceInfo(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QAbstractAudioDeviceInfo * >::toPython(cppResult);

                // Ownership transferences.
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QAudioEngineFactoryInterfaceFunc_createDeviceInfo_TypeError:
        const char* overloads[] = {"PySide.QtCore.QByteArray, PySide.QtMultimedia.QAudio.Mode", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtMultimedia.QAudioEngineFactoryInterface.createDeviceInfo", overloads);
        return 0;
}

static PyObject* Sbk_QAudioEngineFactoryInterfaceFunc_createInput(PyObject* self, PyObject* args, PyObject* kwds)
{
    QAudioEngineFactoryInterface* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QAudioEngineFactoryInterface* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtMultimedia.QAudioEngineFactoryInterface.createInput(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtMultimedia.QAudioEngineFactoryInterface.createInput(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:createInput", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: createInput(QByteArray,QAudioFormat)
    if (Shiboken::Converter< ::QByteArray >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // createInput(QByteArray,QAudioFormat)
        } else if (Shiboken::Converter< ::QAudioFormat >::isConvertible(pyargs[1])) {
            overloadId = 0; // createInput(QByteArray,QAudioFormat)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QAudioEngineFactoryInterfaceFunc_createInput_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "format");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "format";
                    else if (Shiboken::Converter< ::QAudioFormat >::isConvertible(value))
                        pyargs[1] = value;
                    else
                        goto Sbk_QAudioEngineFactoryInterfaceFunc_createInput_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtMultimedia.QAudioEngineFactoryInterface.createInput(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QByteArray cppArg0 = Shiboken::Converter<QByteArray >::toCpp(pyargs[0]);
            if (!Shiboken::Object::isValid(pyargs[1]))
                return 0;
            QAudioFormat cppArg1_tmp = QAudioFormat();
            QAudioFormat cppArg1 = pyargs[1] ? Shiboken::Converter<QAudioFormat >::toCpp(pyargs[1]) : cppArg1_tmp;

            if(!PyErr_Occurred()) {
                // createInput(QByteArray,QAudioFormat)
                if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject*>(self))) {
                    PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QAudioEngineFactoryInterface.createInput()' not implemented.");
                    return 0;
                }
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QAbstractAudioInput * cppResult = cppSelf->createInput(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QAbstractAudioInput * >::toPython(cppResult);

                // Ownership transferences.
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QAudioEngineFactoryInterfaceFunc_createInput_TypeError:
        const char* overloads[] = {"PySide.QtCore.QByteArray, PySide.QtMultimedia.QAudioFormat = QAudioFormat()", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtMultimedia.QAudioEngineFactoryInterface.createInput", overloads);
        return 0;
}

static PyObject* Sbk_QAudioEngineFactoryInterfaceFunc_createOutput(PyObject* self, PyObject* args, PyObject* kwds)
{
    QAudioEngineFactoryInterface* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QAudioEngineFactoryInterface* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtMultimedia.QAudioEngineFactoryInterface.createOutput(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtMultimedia.QAudioEngineFactoryInterface.createOutput(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:createOutput", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: createOutput(QByteArray,QAudioFormat)
    if (Shiboken::Converter< ::QByteArray >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // createOutput(QByteArray,QAudioFormat)
        } else if (Shiboken::Converter< ::QAudioFormat >::isConvertible(pyargs[1])) {
            overloadId = 0; // createOutput(QByteArray,QAudioFormat)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QAudioEngineFactoryInterfaceFunc_createOutput_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "format");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "format";
                    else if (Shiboken::Converter< ::QAudioFormat >::isConvertible(value))
                        pyargs[1] = value;
                    else
                        goto Sbk_QAudioEngineFactoryInterfaceFunc_createOutput_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtMultimedia.QAudioEngineFactoryInterface.createOutput(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QByteArray cppArg0 = Shiboken::Converter<QByteArray >::toCpp(pyargs[0]);
            if (!Shiboken::Object::isValid(pyargs[1]))
                return 0;
            QAudioFormat cppArg1_tmp = QAudioFormat();
            QAudioFormat cppArg1 = pyargs[1] ? Shiboken::Converter<QAudioFormat >::toCpp(pyargs[1]) : cppArg1_tmp;

            if(!PyErr_Occurred()) {
                // createOutput(QByteArray,QAudioFormat)
                if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject*>(self))) {
                    PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QAudioEngineFactoryInterface.createOutput()' not implemented.");
                    return 0;
                }
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QAbstractAudioOutput * cppResult = cppSelf->createOutput(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QAbstractAudioOutput * >::toPython(cppResult);

                // Ownership transferences.
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QAudioEngineFactoryInterfaceFunc_createOutput_TypeError:
        const char* overloads[] = {"PySide.QtCore.QByteArray, PySide.QtMultimedia.QAudioFormat = QAudioFormat()", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtMultimedia.QAudioEngineFactoryInterface.createOutput", overloads);
        return 0;
}

static PyMethodDef Sbk_QAudioEngineFactoryInterface_methods[] = {
    {"availableDevices", (PyCFunction)Sbk_QAudioEngineFactoryInterfaceFunc_availableDevices, METH_O},
    {"createDeviceInfo", (PyCFunction)Sbk_QAudioEngineFactoryInterfaceFunc_createDeviceInfo, METH_VARARGS},
    {"createInput", (PyCFunction)Sbk_QAudioEngineFactoryInterfaceFunc_createInput, METH_VARARGS|METH_KEYWORDS},
    {"createOutput", (PyCFunction)Sbk_QAudioEngineFactoryInterfaceFunc_createOutput, METH_VARARGS|METH_KEYWORDS},

    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QAudioEngineFactoryInterface_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtMultimedia.QAudioEngineFactoryInterface",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QAudioEngineFactoryInterface_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QAudioEngineFactoryInterface_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern

static SbkObjectType* Sbk_QAudioEngineFactoryInterface_typeDiscovery(void* cptr, SbkObjectType* instanceType)
{
    if (instanceType == reinterpret_cast<SbkObjectType*>(Shiboken::SbkType<QFactoryInterface >()) && dynamic_cast<QAudioEngineFactoryInterface*>(reinterpret_cast<QFactoryInterface*>(cptr)))
        return &Sbk_QAudioEngineFactoryInterface_Type;
    return 0;
}


void init_QAudioEngineFactoryInterface(PyObject* module)
{
    SbkPySide_QtMultimediaTypes[SBK_QAUDIOENGINEFACTORYINTERFACE_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QAudioEngineFactoryInterface_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QAudioEngineFactoryInterface_Type);
    Sbk_QAudioEngineFactoryInterface_Type.super.ht_type.tp_base = SbkPySide_QtCoreTypes[SBK_QFACTORYINTERFACE_IDX];
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QAudioEngineFactoryInterface_Type, &Shiboken::callCppDestructor<QAudioEngineFactoryInterface >);
    Py_INCREF((PyObject*)&Sbk_QAudioEngineFactoryInterface_Type); //Incref due the 'PyModule_AddObject' steals the reference.
    if (PyType_Ready((PyTypeObject*)&Sbk_QAudioEngineFactoryInterface_Type) < 0)
        return;

    // Fill type discovery information
    Shiboken::ObjectType::setTypeDiscoveryFunction(&Sbk_QAudioEngineFactoryInterface_Type, &Sbk_QAudioEngineFactoryInterface_typeDiscovery);
    Shiboken::BindingManager& bm = Shiboken::BindingManager::instance();
    bm.addClassInheritance(reinterpret_cast<SbkObjectType*>(SbkPySide_QtCoreTypes[SBK_QFACTORYINTERFACE_IDX]), &Sbk_QAudioEngineFactoryInterface_Type);

    Shiboken::ObjectType::setOriginalName(&Sbk_QAudioEngineFactoryInterface_Type, "QAudioEngineFactoryInterface*");
    PyModule_AddObject(module, "QAudioEngineFactoryInterface",
        ((PyObject*)&Sbk_QAudioEngineFactoryInterface_Type));


    Shiboken::TypeResolver::createObjectTypeResolver<QAudioEngineFactoryInterface >("QAudioEngineFactoryInterface*");
    Shiboken::TypeResolver::createObjectTypeResolver<QAudioEngineFactoryInterface >("QAudioEngineFactoryInterface$ConcreteWrapper*");
    Shiboken::TypeResolver::createObjectTypeResolver<QAudioEngineFactoryInterface >(typeid(QAudioEngineFactoryInterface).name());
    Shiboken::TypeResolver::createObjectTypeResolver<QAudioEngineFactoryInterface >(typeid(QAudioEngineFactoryInterfaceWrapper).name());
}

