/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtnetwork_python.h"

#include "qhostaddress_wrapper.h"

// Extra includes
#include <QPair>
#include <qdatastream.h>
#include <qhostaddress.h>



// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QHostAddress_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QHostAddress >()))
        return -1;

    QHostAddress* cptr = 0;
    int overloadId = -1;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QHostAddress", 0, 1, &(pyargs[0])))
        return -1;

    // Overloaded function decisor
    // 0: QHostAddress()
    // 1: QHostAddress(QHostAddress::SpecialAddress)
    // 2: QHostAddress(QHostAddress)
    // 3: QHostAddress(QIPv6Address)
    // 4: QHostAddress(QString)
    // 5: QHostAddress(quint32)
    if (numArgs == 0) {
        overloadId = 0; // QHostAddress()
    } else if (numArgs == 1 && Shiboken::Converter< QString >::isConvertible(pyargs[0])) {
        overloadId = 4; // QHostAddress(QString)
    } else if (numArgs == 1 && Shiboken::Converter< ::QIPv6Address >::isConvertible(pyargs[0])) {
        overloadId = 3; // QHostAddress(QIPv6Address)
    } else if (numArgs == 1 && Shiboken::Converter< ::QHostAddress::SpecialAddress >::isConvertible(pyargs[0])) {
        overloadId = 1; // QHostAddress(QHostAddress::SpecialAddress)
    } else if (numArgs == 1 && SbkNumber_Check(pyargs[0])) {
        overloadId = 5; // QHostAddress(quint32)
    } else if (numArgs == 1 && Shiboken::Converter< ::QHostAddress >::isConvertible(pyargs[0])) {
        overloadId = 2; // QHostAddress(QHostAddress)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QHostAddress_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QHostAddress()
            {

                if(!PyErr_Occurred()) {
                    // QHostAddress()
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QHostAddress();
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // QHostAddress(QHostAddress::SpecialAddress)
            {
                QHostAddress::SpecialAddress cppArg0 = Shiboken::Converter<QHostAddress::SpecialAddress >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QHostAddress(QHostAddress::SpecialAddress)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QHostAddress(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 2: // QHostAddress(QHostAddress)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QHostAddress cppArg0 = Shiboken::Converter<QHostAddress >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QHostAddress(QHostAddress)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QHostAddress(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 3: // QHostAddress(QIPv6Address)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QIPv6Address cppArg0 = Shiboken::Converter<QIPv6Address >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QHostAddress(QIPv6Address)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QHostAddress(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 4: // QHostAddress(QString)
            {
                QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QHostAddress(QString)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QHostAddress(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 5: // QHostAddress(quint32)
            {
                quint32 cppArg0 = Shiboken::Converter<quint32 >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QHostAddress(quint32)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QHostAddress(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QHostAddress >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QHostAddress_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QHostAddress_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtNetwork.QHostAddress.SpecialAddress", "PySide.QtNetwork.QHostAddress", "PySide.QtNetwork.QIPv6Address", "QString", "unsigned int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtNetwork.QHostAddress", overloads);
        return -1;
}

static PyObject* Sbk_QHostAddressFunc_clear(PyObject* self)
{
    QHostAddress* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QHostAddress* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // clear()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->clear();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QHostAddressFunc_isInSubnet(PyObject* self, PyObject* args)
{
    QHostAddress* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QHostAddress* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "isInSubnet", 1, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: isInSubnet(QHostAddress,int)const
    // 1: isInSubnet(QPair<QHostAddress,int>)const
    if (numArgs == 2 && Shiboken::Converter< ::QHostAddress >::isConvertible(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 0; // isInSubnet(QHostAddress,int)const
    } else if (numArgs == 1 && Shiboken::Converter< ::QPair<QHostAddress, int > >::isConvertible(pyargs[0])) {
        overloadId = 1; // isInSubnet(QPair<QHostAddress,int>)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QHostAddressFunc_isInSubnet_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // isInSubnet(QHostAddress,int)const
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QHostAddress cppArg0 = Shiboken::Converter<QHostAddress >::toCpp(pyargs[0]);
                int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // isInSubnet(QHostAddress,int)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    bool cppResult = const_cast<const QHostAddress*>(cppSelf)->isInSubnet(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< bool >::toPython(cppResult);
                }
                break;
            }
            case 1: // isInSubnet(QPair<QHostAddress,int>)const
            {
                QPair<QHostAddress, int > cppArg0 = Shiboken::Converter<QPair<QHostAddress, int > >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // isInSubnet(QPair<QHostAddress,int>)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    bool cppResult = const_cast<const QHostAddress*>(cppSelf)->isInSubnet(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< bool >::toPython(cppResult);
                }
                break;
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QHostAddressFunc_isInSubnet_TypeError:
        const char* overloads[] = {"PySide.QtNetwork.QHostAddress, int", "QPair", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtNetwork.QHostAddress.isInSubnet", overloads);
        return 0;
}

static PyObject* Sbk_QHostAddressFunc_isNull(PyObject* self)
{
    QHostAddress* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QHostAddress* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isNull()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QHostAddress*>(cppSelf)->isNull();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QHostAddressFunc_parseSubnet(PyObject* self, PyObject* arg)
{
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: parseSubnet(QString)
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // parseSubnet(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QHostAddressFunc_parseSubnet_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // parseSubnet(QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QPair<QHostAddress, int > cppResult = QHostAddress::parseSubnet(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QPair<QHostAddress, int > >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QHostAddressFunc_parseSubnet_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtNetwork.QHostAddress.parseSubnet", overloads);
        return 0;
}

static PyObject* Sbk_QHostAddressFunc_protocol(PyObject* self)
{
    QHostAddress* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QHostAddress* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // protocol()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QAbstractSocket::NetworkLayerProtocol cppResult = const_cast<const QHostAddress*>(cppSelf)->protocol();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QAbstractSocket::NetworkLayerProtocol >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QHostAddressFunc_scopeId(PyObject* self)
{
    QHostAddress* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QHostAddress* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // scopeId()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = const_cast<const QHostAddress*>(cppSelf)->scopeId();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QHostAddressFunc_setAddress(PyObject* self, PyObject* arg)
{
    QHostAddress* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QHostAddress* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setAddress(QIPv6Address)
    // 1: setAddress(QString)
    // 2: setAddress(quint32)
    // 3: setAddress(quint8*)
    if (Shiboken::Converter< ::quint8 * >::isConvertible(arg)) {
        overloadId = 3; // setAddress(quint8*)
    } else if (SbkNumber_Check(arg)) {
        overloadId = 2; // setAddress(quint32)
    } else if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 1; // setAddress(QString)
    } else if (Shiboken::Converter< ::QIPv6Address >::isConvertible(arg)) {
        overloadId = 0; // setAddress(QIPv6Address)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QHostAddressFunc_setAddress_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // setAddress(QIPv6Address)
            {
                if (!Shiboken::Object::isValid(arg))
                    return 0;
                QIPv6Address cppArg0 = Shiboken::Converter<QIPv6Address >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // setAddress(QIPv6Address)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setAddress(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Py_None;
                    Py_INCREF(Py_None);
                }
                break;
            }
            case 1: // setAddress(QString)
            {
                QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // setAddress(QString)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    bool cppResult = cppSelf->setAddress(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< bool >::toPython(cppResult);
                }
                break;
            }
            case 2: // setAddress(quint32)
            {
                quint32 cppArg0 = Shiboken::Converter<quint32 >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // setAddress(quint32)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setAddress(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Py_None;
                    Py_INCREF(Py_None);
                }
                break;
            }
            case 3: // setAddress(quint8*)
            {
                quint8 * cppArg0 = Shiboken::Converter<quint8 * >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // setAddress(quint8*)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setAddress(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Py_None;
                    Py_INCREF(Py_None);
                }
                break;
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QHostAddressFunc_setAddress_TypeError:
        const char* overloads[] = {"PySide.QtNetwork.QIPv6Address", "QString", "unsigned int", "quint8", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtNetwork.QHostAddress.setAddress", overloads);
        return 0;
}

static PyObject* Sbk_QHostAddressFunc_setScopeId(PyObject* self, PyObject* arg)
{
    QHostAddress* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QHostAddress* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setScopeId(QString)
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // setScopeId(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QHostAddressFunc_setScopeId_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setScopeId(QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setScopeId(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QHostAddressFunc_setScopeId_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtNetwork.QHostAddress.setScopeId", overloads);
        return 0;
}

static PyObject* Sbk_QHostAddressFunc_toIPv4Address(PyObject* self)
{
    QHostAddress* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QHostAddress* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // toIPv4Address()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                quint32 cppResult = const_cast<const QHostAddress*>(cppSelf)->toIPv4Address();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< unsigned int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QHostAddressFunc_toIPv6Address(PyObject* self)
{
    QHostAddress* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QHostAddress* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // toIPv6Address()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QIPv6Address cppResult = const_cast<const QHostAddress*>(cppSelf)->toIPv6Address();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QIPv6Address >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QHostAddressFunc_toString(PyObject* self)
{
    QHostAddress* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QHostAddress* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // toString()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = const_cast<const QHostAddress*>(cppSelf)->toString();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject *Sbk_QHostAddress___copy__(PyObject *self)
{
        QHostAddress* cppSelf = 0;
        if (!Shiboken::Object::isValid(self))
            return 0;
        cppSelf = Shiboken::Converter<QHostAddress*>::toCpp(self);
        PyObject* pyResult = 0;
        QHostAddress* copy = new QHostAddress(*cppSelf);
        pyResult = Shiboken::Converter<QHostAddress*>::toPython(copy);
        Shiboken::Object::getOwnership(pyResult);

        if (PyErr_Occurred() || !pyResult) {
            Py_XDECREF(pyResult);
            return 0;
        }
        return pyResult;
}

static PyMethodDef Sbk_QHostAddress_methods[] = {
    {"clear", (PyCFunction)Sbk_QHostAddressFunc_clear, METH_NOARGS},
    {"isInSubnet", (PyCFunction)Sbk_QHostAddressFunc_isInSubnet, METH_VARARGS},
    {"isNull", (PyCFunction)Sbk_QHostAddressFunc_isNull, METH_NOARGS},
    {"parseSubnet", (PyCFunction)Sbk_QHostAddressFunc_parseSubnet, METH_O|METH_STATIC},
    {"protocol", (PyCFunction)Sbk_QHostAddressFunc_protocol, METH_NOARGS},
    {"scopeId", (PyCFunction)Sbk_QHostAddressFunc_scopeId, METH_NOARGS},
    {"setAddress", (PyCFunction)Sbk_QHostAddressFunc_setAddress, METH_O},
    {"setScopeId", (PyCFunction)Sbk_QHostAddressFunc_setScopeId, METH_O},
    {"toIPv4Address", (PyCFunction)Sbk_QHostAddressFunc_toIPv4Address, METH_NOARGS},
    {"toIPv6Address", (PyCFunction)Sbk_QHostAddressFunc_toIPv6Address, METH_NOARGS},
    {"toString", (PyCFunction)Sbk_QHostAddressFunc_toString, METH_NOARGS},

    {"__copy__", (PyCFunction)Sbk_QHostAddress___copy__, METH_NOARGS},
    {0} // Sentinel
};

static int Sbk_QHostAddress___nb_bool(PyObject* pyObj)
{
    if (!Shiboken::Object::isValid(pyObj))
        return -1;
    const ::QHostAddress* cppSelf = Shiboken::Converter< ::QHostAddress*>::toCpp(pyObj);
    int result;
    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
    result = !cppSelf->isNull();
    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
    return result;
}

static PyObject* Sbk_QHostAddressFunc___lshift__(PyObject* self, PyObject* arg)
{
    QHostAddress* cppSelf = 0;
    bool isReverse = Shiboken::Converter< ::QHostAddress >::checkType(arg) && !Shiboken::Converter< ::QHostAddress >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QHostAddress* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && Shiboken::Object::checkType(arg)
        && !PyObject_TypeCheck(arg, self->ob_type)
        && PyObject_HasAttrString(arg, const_cast<char*>("__rlshift__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(arg, const_cast<char*>("__rlshift__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator<<(QDataStream&,QHostAddress)
    if (isReverse && Shiboken::Converter< ::QDataStream & >::isConvertible(arg)) {
        overloadId = 0; // operator<<(QDataStream&,QHostAddress)
    }

    if (isReverse && overloadId == -1) {
        PyErr_SetString(PyExc_NotImplementedError, "reverse operator not implemented.");
        return 0;
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QHostAddressFunc___lshift___TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QDataStream & cppArg0 = Shiboken::Converter<QDataStream & >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // operator<<(QDataStream&,QHostAddress) [reverse operator]
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QDataStream & cppResult = (cppArg0) << (*cppSelf);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QDataStream & >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    } // End of "if (!pyResult)"


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QHostAddressFunc___lshift___TypeError:
        const char* overloads[] = {"PySide.QtCore.QDataStream", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtNetwork.QHostAddress.__lshift__", overloads);
        return 0;
}

static PyObject* Sbk_QHostAddressFunc___rshift__(PyObject* self, PyObject* arg)
{
    QHostAddress* cppSelf = 0;
    bool isReverse = Shiboken::Converter< ::QHostAddress >::checkType(arg) && !Shiboken::Converter< ::QHostAddress >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QHostAddress* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && Shiboken::Object::checkType(arg)
        && !PyObject_TypeCheck(arg, self->ob_type)
        && PyObject_HasAttrString(arg, const_cast<char*>("__rrshift__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(arg, const_cast<char*>("__rrshift__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator>>(QDataStream&,QHostAddress&)
    if (isReverse && Shiboken::Converter< ::QDataStream & >::isConvertible(arg)) {
        overloadId = 0; // operator>>(QDataStream&,QHostAddress&)
    }

    if (isReverse && overloadId == -1) {
        PyErr_SetString(PyExc_NotImplementedError, "reverse operator not implemented.");
        return 0;
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QHostAddressFunc___rshift___TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QDataStream & cppArg0 = Shiboken::Converter<QDataStream & >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // operator>>(QDataStream&,QHostAddress&) [reverse operator]
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QDataStream & cppResult = (cppArg0) >> (*cppSelf);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QDataStream & >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    } // End of "if (!pyResult)"


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QHostAddressFunc___rshift___TypeError:
        const char* overloads[] = {"PySide.QtCore.QDataStream", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtNetwork.QHostAddress.__rshift__", overloads);
        return 0;
}

// type has number operators
static PyNumberMethods Sbk_QHostAddress_as_number = {
    /*nb_add*/                  (binaryfunc)0,
    /*nb_subtract*/             (binaryfunc)0,
    /*nb_multiply*/             (binaryfunc)0,
    /*nb_divide*/               (binaryfunc)0,
    /*nb_remainder*/            (binaryfunc)0,
    /*nb_divmod*/               0,
    /*nb_power*/                0,
    /*nb_negative*/             (unaryfunc)0,
    /*nb_positive*/             (unaryfunc)0,
    /*nb_absolute*/             0,
    /*nb_nonzero*/              Sbk_QHostAddress___nb_bool,
    /*nb_invert*/               (unaryfunc)0,
    /*nb_lshift*/               (binaryfunc)Sbk_QHostAddressFunc___lshift__,
    /*nb_rshift*/               (binaryfunc)Sbk_QHostAddressFunc___rshift__,
    /*nb_and*/                  (binaryfunc)0,
    /*nb_xor*/                  (binaryfunc)0,
    /*nb_or*/                   (binaryfunc)0,
    /*nb_coerce*/               0,
    /*nb_int*/                  0,
    /*nb_long*/                 0,
    /*nb_float*/                0,
    /*nb_oct*/                  0,
    /*nb_hex*/                  0,
    /*nb_inplace_add*/          (binaryfunc)0,
    /*nb_inplace_subtract*/     (binaryfunc)0,
    /*nb_inplace_multiply*/     (binaryfunc)0,
    /*nb_inplace_divide*/       (binaryfunc)0,
    /*nb_inplace_remainder*/    (binaryfunc)0,
    /*nb_inplace_power*/        0,
    /*nb_inplace_lshift*/       (binaryfunc)0,
    /*nb_inplace_rshift*/       (binaryfunc)0,
    /*nb_inplace_and*/          (binaryfunc)0,
    /*nb_inplace_xor*/          (binaryfunc)0,
    /*nb_inplace_or*/           (binaryfunc)0,
    /*nb_floor_divide*/         0,
    /*nb_true_divide*/          (binaryfunc)0,
    /*nb_inplace_floor_divide*/ 0,
    /*nb_inplace_true_divide*/  0,
    /*nb_index*/                0
};

// Rich comparison
static PyObject* Sbk_QHostAddress_richcompare(PyObject* self, PyObject* arg, int op)
{
    PyObject* pyResult = 0;
    QHostAddress& cppSelf = *Shiboken::Converter< QHostAddress* >::toCpp(self);

    switch (op) {
        case Py_NE:
            if (Shiboken::Converter< ::QHostAddress::SpecialAddress >::isConvertible(arg)) {
                // operator!=(QHostAddress::SpecialAddress address) const
                QHostAddress::SpecialAddress cppArg0 = Shiboken::Converter< ::QHostAddress::SpecialAddress >::toCpp(arg);
                pyResult = Shiboken::Converter< bool >::toPython(cppSelf != cppArg0);
            } else if (Shiboken::Converter< ::QHostAddress >::isConvertible(arg)) {
                // operator!=(const QHostAddress & address) const
                QHostAddress cppArg0 = Shiboken::Converter< ::QHostAddress >::toCpp(arg);
                pyResult = Shiboken::Converter< bool >::toPython(cppSelf != cppArg0);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_EQ:
            if (Shiboken::Converter< ::QHostAddress::SpecialAddress >::isConvertible(arg)) {
                // operator==(QHostAddress::SpecialAddress address) const
                QHostAddress::SpecialAddress cppArg0 = Shiboken::Converter< ::QHostAddress::SpecialAddress >::toCpp(arg);
                pyResult = Shiboken::Converter< bool >::toPython(cppSelf == cppArg0);
            } else if (Shiboken::Converter< ::QHostAddress::SpecialAddress >::isConvertible(arg)) {
                // operator==(QHostAddress::SpecialAddress address1)
                QHostAddress::SpecialAddress cppArg0 = Shiboken::Converter< ::QHostAddress::SpecialAddress >::toCpp(arg);
                pyResult = Shiboken::Converter< bool >::toPython(cppSelf == cppArg0);
            } else if (Shiboken::Converter< ::QHostAddress >::isConvertible(arg)) {
                // operator==(const QHostAddress & address) const
                QHostAddress cppArg0 = Shiboken::Converter< ::QHostAddress >::toCpp(arg);
                pyResult = Shiboken::Converter< bool >::toPython(cppSelf == cppArg0);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            goto Sbk_QHostAddress_RichComparison_TypeError;
    }

    if (pyResult && !PyErr_Occurred())
        return pyResult;
    Sbk_QHostAddress_RichComparison_TypeError:
    PyErr_SetString(PyExc_NotImplementedError, "operator not implemented.");
    return 0;

}

} // extern "C"

static long Sbk_QHostAddress_HashFunc(PyObject* obj){
    return qHash(Shiboken::Converter< ::QHostAddress >::toCpp(obj));
}

extern "C"
{
static PyObject* Sbk_QHostAddress__repr__(PyObject* pyObj)
{
    QBuffer buffer;
    buffer.open(QBuffer::ReadWrite);
    QDebug dbg(&buffer);
    dbg << Shiboken::Converter< ::QHostAddress >::toCpp(pyObj);
    buffer.close();
    return PyString_FromFormat("<PySide.QtNetwork.%s at %p>", buffer.data().constData(), pyObj);
}
} // extern C

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QHostAddress_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtNetwork.QHostAddress",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Sbk_QHostAddress__repr__,
    /*tp_as_number*/        &Sbk_QHostAddress_as_number,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             &Sbk_QHostAddress_HashFunc,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      Sbk_QHostAddress_richcompare,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QHostAddress_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&SbkObject_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QHostAddress_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern


void init_QHostAddress(PyObject* module)
{
    SbkPySide_QtNetworkTypes[SBK_QHOSTADDRESS_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QHostAddress_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QHostAddress_Type);
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QHostAddress_Type, &Shiboken::callCppDestructor<QHostAddress >);
    Py_INCREF((PyObject*)&Sbk_QHostAddress_Type); //Incref due the 'PyModule_AddObject' steals the reference.
    if (PyType_Ready((PyTypeObject*)&Sbk_QHostAddress_Type) < 0)
        return;

    Shiboken::ObjectType::setOriginalName(&Sbk_QHostAddress_Type, "QHostAddress");
    PyModule_AddObject(module, "QHostAddress",
        ((PyObject*)&Sbk_QHostAddress_Type));

    // Initialize enums
    PyObject* enumItem;

    // init enum: SpecialAddress
    PyTypeObject* SbkPySide_QtNetwork_QHostAddress_SpecialAddress = Shiboken::Enum::newType("PySide.QtNetwork.QHostAddress.SpecialAddress");
    SbkPySide_QtNetworkTypes[SBK_QHOSTADDRESS_SPECIALADDRESS_IDX] = SbkPySide_QtNetwork_QHostAddress_SpecialAddress;
    if (PyType_Ready(SbkPySide_QtNetwork_QHostAddress_SpecialAddress) < 0)
        return;
    PyDict_SetItemString(Sbk_QHostAddress_Type.super.ht_type.tp_dict,
            "SpecialAddress",((PyObject*)SbkPySide_QtNetwork_QHostAddress_SpecialAddress));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtNetwork_QHostAddress_SpecialAddress,(long) QHostAddress::Null, "Null");
    PyDict_SetItemString(Sbk_QHostAddress_Type.super.ht_type.tp_dict,"Null", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtNetwork_QHostAddress_SpecialAddress->tp_dict,"Null", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtNetwork_QHostAddress_SpecialAddress,(long) QHostAddress::Broadcast, "Broadcast");
    PyDict_SetItemString(Sbk_QHostAddress_Type.super.ht_type.tp_dict,"Broadcast", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtNetwork_QHostAddress_SpecialAddress->tp_dict,"Broadcast", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtNetwork_QHostAddress_SpecialAddress,(long) QHostAddress::LocalHost, "LocalHost");
    PyDict_SetItemString(Sbk_QHostAddress_Type.super.ht_type.tp_dict,"LocalHost", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtNetwork_QHostAddress_SpecialAddress->tp_dict,"LocalHost", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtNetwork_QHostAddress_SpecialAddress,(long) QHostAddress::LocalHostIPv6, "LocalHostIPv6");
    PyDict_SetItemString(Sbk_QHostAddress_Type.super.ht_type.tp_dict,"LocalHostIPv6", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtNetwork_QHostAddress_SpecialAddress->tp_dict,"LocalHostIPv6", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtNetwork_QHostAddress_SpecialAddress,(long) QHostAddress::Any, "Any");
    PyDict_SetItemString(Sbk_QHostAddress_Type.super.ht_type.tp_dict,"Any", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtNetwork_QHostAddress_SpecialAddress->tp_dict,"Any", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtNetwork_QHostAddress_SpecialAddress,(long) QHostAddress::AnyIPv6, "AnyIPv6");
    PyDict_SetItemString(Sbk_QHostAddress_Type.super.ht_type.tp_dict,"AnyIPv6", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtNetwork_QHostAddress_SpecialAddress->tp_dict,"AnyIPv6", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QHostAddress::SpecialAddress");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::SpecialAddress");
    // end of enum SpecialAddress


    Shiboken::TypeResolver::createValueTypeResolver<QHostAddress >("QHostAddress");
    Shiboken::TypeResolver::createObjectTypeResolver<QHostAddress >("QHostAddress*");
    Shiboken::TypeResolver::createValueTypeResolver<QHostAddress >(typeid(QHostAddress).name());
    qRegisterMetaType< ::QHostAddress >("QHostAddress");
    qRegisterMetaType< ::QHostAddress::SpecialAddress >("QHostAddress::SpecialAddress");
}

