/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtnetwork_python.h"

#include "qnetworkcachemetadata_wrapper.h"

// Extra includes
#include <QList>
#include <QPair>
#include <pysideconversions.h>
#include <qabstractnetworkcache.h>
#include <qbytearray.h>
#include <qdatastream.h>
#include <qdatetime.h>
#include <qurl.h>



// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QNetworkCacheMetaData_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QNetworkCacheMetaData >()))
        return -1;

    QNetworkCacheMetaData* cptr = 0;
    int overloadId = -1;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QNetworkCacheMetaData", 0, 1, &(pyargs[0])))
        return -1;

    // Overloaded function decisor
    // 0: QNetworkCacheMetaData()
    // 1: QNetworkCacheMetaData(QNetworkCacheMetaData)
    if (numArgs == 0) {
        overloadId = 0; // QNetworkCacheMetaData()
    } else if (numArgs == 1 && Shiboken::Converter< ::QNetworkCacheMetaData >::isConvertible(pyargs[0])) {
        overloadId = 1; // QNetworkCacheMetaData(QNetworkCacheMetaData)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QNetworkCacheMetaData_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QNetworkCacheMetaData()
            {

                if(!PyErr_Occurred()) {
                    // QNetworkCacheMetaData()
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QNetworkCacheMetaData();
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // QNetworkCacheMetaData(QNetworkCacheMetaData)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QNetworkCacheMetaData cppArg0 = Shiboken::Converter<QNetworkCacheMetaData >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QNetworkCacheMetaData(QNetworkCacheMetaData)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QNetworkCacheMetaData(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QNetworkCacheMetaData >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QNetworkCacheMetaData_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QNetworkCacheMetaData_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtNetwork.QNetworkCacheMetaData", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtNetwork.QNetworkCacheMetaData", overloads);
        return -1;
}

static PyObject* Sbk_QNetworkCacheMetaDataFunc_attributes(PyObject* self)
{
    QNetworkCacheMetaData* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QNetworkCacheMetaData* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // attributes()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QHash<QNetworkRequest::Attribute, QVariant > cppResult = const_cast<const QNetworkCacheMetaData*>(cppSelf)->attributes();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QHash<QNetworkRequest::Attribute, QVariant > >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QNetworkCacheMetaDataFunc_expirationDate(PyObject* self)
{
    QNetworkCacheMetaData* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QNetworkCacheMetaData* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // expirationDate()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QDateTime cppResult = const_cast<const QNetworkCacheMetaData*>(cppSelf)->expirationDate();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QDateTime >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QNetworkCacheMetaDataFunc_isValid(PyObject* self)
{
    QNetworkCacheMetaData* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QNetworkCacheMetaData* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isValid()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QNetworkCacheMetaData*>(cppSelf)->isValid();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QNetworkCacheMetaDataFunc_lastModified(PyObject* self)
{
    QNetworkCacheMetaData* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QNetworkCacheMetaData* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // lastModified()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QDateTime cppResult = const_cast<const QNetworkCacheMetaData*>(cppSelf)->lastModified();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QDateTime >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QNetworkCacheMetaDataFunc_rawHeaders(PyObject* self)
{
    QNetworkCacheMetaData* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QNetworkCacheMetaData* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // rawHeaders()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QList<QPair<QByteArray, QByteArray > > cppResult = const_cast<const QNetworkCacheMetaData*>(cppSelf)->rawHeaders();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QList<QPair<QByteArray, QByteArray > > >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QNetworkCacheMetaDataFunc_saveToDisk(PyObject* self)
{
    QNetworkCacheMetaData* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QNetworkCacheMetaData* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // saveToDisk()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QNetworkCacheMetaData*>(cppSelf)->saveToDisk();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QNetworkCacheMetaDataFunc_setAttributes(PyObject* self, PyObject* arg)
{
    QNetworkCacheMetaData* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QNetworkCacheMetaData* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setAttributes(QHash<QNetworkRequest::Attribute,QVariant>)
    if (Shiboken::Converter< ::QHash<QNetworkRequest::Attribute, QVariant > >::isConvertible(arg)) {
        overloadId = 0; // setAttributes(QHash<QNetworkRequest::Attribute,QVariant>)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QNetworkCacheMetaDataFunc_setAttributes_TypeError;

    // Call function/method
    {
        {
            QHash<QNetworkRequest::Attribute, QVariant > cppArg0 = Shiboken::Converter<QHash<QNetworkRequest::Attribute, QVariant > >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setAttributes(QHash<QNetworkRequest::Attribute,QVariant>)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setAttributes(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QNetworkCacheMetaDataFunc_setAttributes_TypeError:
        const char* overloads[] = {"dict", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtNetwork.QNetworkCacheMetaData.setAttributes", overloads);
        return 0;
}

static PyObject* Sbk_QNetworkCacheMetaDataFunc_setExpirationDate(PyObject* self, PyObject* arg)
{
    QNetworkCacheMetaData* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QNetworkCacheMetaData* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setExpirationDate(QDateTime)
    if (Shiboken::Converter< ::QDateTime >::isConvertible(arg)) {
        overloadId = 0; // setExpirationDate(QDateTime)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QNetworkCacheMetaDataFunc_setExpirationDate_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QDateTime cppArg0 = Shiboken::Converter<QDateTime >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setExpirationDate(QDateTime)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setExpirationDate(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QNetworkCacheMetaDataFunc_setExpirationDate_TypeError:
        const char* overloads[] = {"PySide.QtCore.QDateTime", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtNetwork.QNetworkCacheMetaData.setExpirationDate", overloads);
        return 0;
}

static PyObject* Sbk_QNetworkCacheMetaDataFunc_setLastModified(PyObject* self, PyObject* arg)
{
    QNetworkCacheMetaData* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QNetworkCacheMetaData* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setLastModified(QDateTime)
    if (Shiboken::Converter< ::QDateTime >::isConvertible(arg)) {
        overloadId = 0; // setLastModified(QDateTime)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QNetworkCacheMetaDataFunc_setLastModified_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QDateTime cppArg0 = Shiboken::Converter<QDateTime >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setLastModified(QDateTime)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setLastModified(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QNetworkCacheMetaDataFunc_setLastModified_TypeError:
        const char* overloads[] = {"PySide.QtCore.QDateTime", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtNetwork.QNetworkCacheMetaData.setLastModified", overloads);
        return 0;
}

static PyObject* Sbk_QNetworkCacheMetaDataFunc_setRawHeaders(PyObject* self, PyObject* arg)
{
    QNetworkCacheMetaData* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QNetworkCacheMetaData* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setRawHeaders(QList<QPair<QByteArray,QByteArray> >)
    if (Shiboken::Converter< ::QList<QPair<QByteArray, QByteArray > > >::isConvertible(arg)) {
        overloadId = 0; // setRawHeaders(QList<QPair<QByteArray,QByteArray> >)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QNetworkCacheMetaDataFunc_setRawHeaders_TypeError;

    // Call function/method
    {
        {
            QList<QPair<QByteArray, QByteArray > > cppArg0 = Shiboken::Converter<QList<QPair<QByteArray, QByteArray > > >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setRawHeaders(QList<QPair<QByteArray,QByteArray> >)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setRawHeaders(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QNetworkCacheMetaDataFunc_setRawHeaders_TypeError:
        const char* overloads[] = {"list", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtNetwork.QNetworkCacheMetaData.setRawHeaders", overloads);
        return 0;
}

static PyObject* Sbk_QNetworkCacheMetaDataFunc_setSaveToDisk(PyObject* self, PyObject* arg)
{
    QNetworkCacheMetaData* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QNetworkCacheMetaData* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setSaveToDisk(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setSaveToDisk(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QNetworkCacheMetaDataFunc_setSaveToDisk_TypeError;

    // Call function/method
    {
        {
            bool cppArg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setSaveToDisk(bool)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setSaveToDisk(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QNetworkCacheMetaDataFunc_setSaveToDisk_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtNetwork.QNetworkCacheMetaData.setSaveToDisk", overloads);
        return 0;
}

static PyObject* Sbk_QNetworkCacheMetaDataFunc_setUrl(PyObject* self, PyObject* arg)
{
    QNetworkCacheMetaData* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QNetworkCacheMetaData* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setUrl(QUrl)
    if (Shiboken::Converter< ::QUrl >::isConvertible(arg)) {
        overloadId = 0; // setUrl(QUrl)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QNetworkCacheMetaDataFunc_setUrl_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QUrl cppArg0 = Shiboken::Converter<QUrl >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setUrl(QUrl)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setUrl(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QNetworkCacheMetaDataFunc_setUrl_TypeError:
        const char* overloads[] = {"PySide.QtCore.QUrl", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtNetwork.QNetworkCacheMetaData.setUrl", overloads);
        return 0;
}

static PyObject* Sbk_QNetworkCacheMetaDataFunc_url(PyObject* self)
{
    QNetworkCacheMetaData* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QNetworkCacheMetaData* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // url()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QUrl cppResult = const_cast<const QNetworkCacheMetaData*>(cppSelf)->url();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QUrl >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject *Sbk_QNetworkCacheMetaData___copy__(PyObject *self)
{
        QNetworkCacheMetaData* cppSelf = 0;
        if (!Shiboken::Object::isValid(self))
            return 0;
        cppSelf = Shiboken::Converter<QNetworkCacheMetaData*>::toCpp(self);
        PyObject* pyResult = 0;
        QNetworkCacheMetaData* copy = new QNetworkCacheMetaData(*cppSelf);
        pyResult = Shiboken::Converter<QNetworkCacheMetaData*>::toPython(copy);
        Shiboken::Object::getOwnership(pyResult);

        if (PyErr_Occurred() || !pyResult) {
            Py_XDECREF(pyResult);
            return 0;
        }
        return pyResult;
}

static PyMethodDef Sbk_QNetworkCacheMetaData_methods[] = {
    {"attributes", (PyCFunction)Sbk_QNetworkCacheMetaDataFunc_attributes, METH_NOARGS},
    {"expirationDate", (PyCFunction)Sbk_QNetworkCacheMetaDataFunc_expirationDate, METH_NOARGS},
    {"isValid", (PyCFunction)Sbk_QNetworkCacheMetaDataFunc_isValid, METH_NOARGS},
    {"lastModified", (PyCFunction)Sbk_QNetworkCacheMetaDataFunc_lastModified, METH_NOARGS},
    {"rawHeaders", (PyCFunction)Sbk_QNetworkCacheMetaDataFunc_rawHeaders, METH_NOARGS},
    {"saveToDisk", (PyCFunction)Sbk_QNetworkCacheMetaDataFunc_saveToDisk, METH_NOARGS},
    {"setAttributes", (PyCFunction)Sbk_QNetworkCacheMetaDataFunc_setAttributes, METH_O},
    {"setExpirationDate", (PyCFunction)Sbk_QNetworkCacheMetaDataFunc_setExpirationDate, METH_O},
    {"setLastModified", (PyCFunction)Sbk_QNetworkCacheMetaDataFunc_setLastModified, METH_O},
    {"setRawHeaders", (PyCFunction)Sbk_QNetworkCacheMetaDataFunc_setRawHeaders, METH_O},
    {"setSaveToDisk", (PyCFunction)Sbk_QNetworkCacheMetaDataFunc_setSaveToDisk, METH_O},
    {"setUrl", (PyCFunction)Sbk_QNetworkCacheMetaDataFunc_setUrl, METH_O},
    {"url", (PyCFunction)Sbk_QNetworkCacheMetaDataFunc_url, METH_NOARGS},

    {"__copy__", (PyCFunction)Sbk_QNetworkCacheMetaData___copy__, METH_NOARGS},
    {0} // Sentinel
};

static PyObject* Sbk_QNetworkCacheMetaDataFunc___lshift__(PyObject* self, PyObject* arg)
{
    QNetworkCacheMetaData* cppSelf = 0;
    bool isReverse = Shiboken::Converter< ::QNetworkCacheMetaData >::checkType(arg) && !Shiboken::Converter< ::QNetworkCacheMetaData >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QNetworkCacheMetaData* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && Shiboken::Object::checkType(arg)
        && !PyObject_TypeCheck(arg, self->ob_type)
        && PyObject_HasAttrString(arg, const_cast<char*>("__rlshift__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(arg, const_cast<char*>("__rlshift__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator<<(QDataStream&,QNetworkCacheMetaData)
    if (isReverse && Shiboken::Converter< ::QDataStream & >::isConvertible(arg)) {
        overloadId = 0; // operator<<(QDataStream&,QNetworkCacheMetaData)
    }

    if (isReverse && overloadId == -1) {
        PyErr_SetString(PyExc_NotImplementedError, "reverse operator not implemented.");
        return 0;
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QNetworkCacheMetaDataFunc___lshift___TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QDataStream & cppArg0 = Shiboken::Converter<QDataStream & >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // operator<<(QDataStream&,QNetworkCacheMetaData) [reverse operator]
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QDataStream & cppResult = (cppArg0) << (*cppSelf);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QDataStream & >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    } // End of "if (!pyResult)"


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QNetworkCacheMetaDataFunc___lshift___TypeError:
        const char* overloads[] = {"PySide.QtCore.QDataStream", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtNetwork.QNetworkCacheMetaData.__lshift__", overloads);
        return 0;
}

static PyObject* Sbk_QNetworkCacheMetaDataFunc___rshift__(PyObject* self, PyObject* arg)
{
    QNetworkCacheMetaData* cppSelf = 0;
    bool isReverse = Shiboken::Converter< ::QNetworkCacheMetaData >::checkType(arg) && !Shiboken::Converter< ::QNetworkCacheMetaData >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QNetworkCacheMetaData* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && Shiboken::Object::checkType(arg)
        && !PyObject_TypeCheck(arg, self->ob_type)
        && PyObject_HasAttrString(arg, const_cast<char*>("__rrshift__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(arg, const_cast<char*>("__rrshift__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator>>(QDataStream&,QNetworkCacheMetaData&)
    if (isReverse && Shiboken::Converter< ::QDataStream & >::isConvertible(arg)) {
        overloadId = 0; // operator>>(QDataStream&,QNetworkCacheMetaData&)
    }

    if (isReverse && overloadId == -1) {
        PyErr_SetString(PyExc_NotImplementedError, "reverse operator not implemented.");
        return 0;
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QNetworkCacheMetaDataFunc___rshift___TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QDataStream & cppArg0 = Shiboken::Converter<QDataStream & >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // operator>>(QDataStream&,QNetworkCacheMetaData&) [reverse operator]
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QDataStream & cppResult = (cppArg0) >> (*cppSelf);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QDataStream & >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    } // End of "if (!pyResult)"


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QNetworkCacheMetaDataFunc___rshift___TypeError:
        const char* overloads[] = {"PySide.QtCore.QDataStream", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtNetwork.QNetworkCacheMetaData.__rshift__", overloads);
        return 0;
}

// type has number operators
static PyNumberMethods Sbk_QNetworkCacheMetaData_as_number = {
    /*nb_add*/                  (binaryfunc)0,
    /*nb_subtract*/             (binaryfunc)0,
    /*nb_multiply*/             (binaryfunc)0,
    /*nb_divide*/               (binaryfunc)0,
    /*nb_remainder*/            (binaryfunc)0,
    /*nb_divmod*/               0,
    /*nb_power*/                0,
    /*nb_negative*/             (unaryfunc)0,
    /*nb_positive*/             (unaryfunc)0,
    /*nb_absolute*/             0,
    /*nb_nonzero*/              0,
    /*nb_invert*/               (unaryfunc)0,
    /*nb_lshift*/               (binaryfunc)Sbk_QNetworkCacheMetaDataFunc___lshift__,
    /*nb_rshift*/               (binaryfunc)Sbk_QNetworkCacheMetaDataFunc___rshift__,
    /*nb_and*/                  (binaryfunc)0,
    /*nb_xor*/                  (binaryfunc)0,
    /*nb_or*/                   (binaryfunc)0,
    /*nb_coerce*/               0,
    /*nb_int*/                  0,
    /*nb_long*/                 0,
    /*nb_float*/                0,
    /*nb_oct*/                  0,
    /*nb_hex*/                  0,
    /*nb_inplace_add*/          (binaryfunc)0,
    /*nb_inplace_subtract*/     (binaryfunc)0,
    /*nb_inplace_multiply*/     (binaryfunc)0,
    /*nb_inplace_divide*/       (binaryfunc)0,
    /*nb_inplace_remainder*/    (binaryfunc)0,
    /*nb_inplace_power*/        0,
    /*nb_inplace_lshift*/       (binaryfunc)0,
    /*nb_inplace_rshift*/       (binaryfunc)0,
    /*nb_inplace_and*/          (binaryfunc)0,
    /*nb_inplace_xor*/          (binaryfunc)0,
    /*nb_inplace_or*/           (binaryfunc)0,
    /*nb_floor_divide*/         0,
    /*nb_true_divide*/          (binaryfunc)0,
    /*nb_inplace_floor_divide*/ 0,
    /*nb_inplace_true_divide*/  0,
    /*nb_index*/                0
};

// Rich comparison
static PyObject* Sbk_QNetworkCacheMetaData_richcompare(PyObject* self, PyObject* arg, int op)
{
    PyObject* pyResult = 0;
    QNetworkCacheMetaData& cppSelf = *Shiboken::Converter< QNetworkCacheMetaData* >::toCpp(self);

    switch (op) {
        case Py_NE:
            if (Shiboken::Converter< ::QNetworkCacheMetaData >::isConvertible(arg)) {
                // operator!=(const QNetworkCacheMetaData & other) const
                QNetworkCacheMetaData cppArg0 = Shiboken::Converter< ::QNetworkCacheMetaData >::toCpp(arg);
                pyResult = Shiboken::Converter< bool >::toPython(cppSelf != cppArg0);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_EQ:
            if (Shiboken::Converter< ::QNetworkCacheMetaData >::isConvertible(arg)) {
                // operator==(const QNetworkCacheMetaData & other) const
                QNetworkCacheMetaData cppArg0 = Shiboken::Converter< ::QNetworkCacheMetaData >::toCpp(arg);
                pyResult = Shiboken::Converter< bool >::toPython(cppSelf == cppArg0);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            goto Sbk_QNetworkCacheMetaData_RichComparison_TypeError;
    }

    if (pyResult && !PyErr_Occurred())
        return pyResult;
    Sbk_QNetworkCacheMetaData_RichComparison_TypeError:
    PyErr_SetString(PyExc_NotImplementedError, "operator not implemented.");
    return 0;

}

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QNetworkCacheMetaData_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtNetwork.QNetworkCacheMetaData",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        &Sbk_QNetworkCacheMetaData_as_number,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      Sbk_QNetworkCacheMetaData_richcompare,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QNetworkCacheMetaData_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&SbkObject_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QNetworkCacheMetaData_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern


void init_QNetworkCacheMetaData(PyObject* module)
{
    SbkPySide_QtNetworkTypes[SBK_QNETWORKCACHEMETADATA_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QNetworkCacheMetaData_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QNetworkCacheMetaData_Type);
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QNetworkCacheMetaData_Type, &Shiboken::callCppDestructor<QNetworkCacheMetaData >);
    Py_INCREF((PyObject*)&Sbk_QNetworkCacheMetaData_Type); //Incref due the 'PyModule_AddObject' steals the reference.
    if (PyType_Ready((PyTypeObject*)&Sbk_QNetworkCacheMetaData_Type) < 0)
        return;

    Shiboken::ObjectType::setOriginalName(&Sbk_QNetworkCacheMetaData_Type, "QNetworkCacheMetaData");
    PyModule_AddObject(module, "QNetworkCacheMetaData",
        ((PyObject*)&Sbk_QNetworkCacheMetaData_Type));


    Shiboken::TypeResolver::createValueTypeResolver<QNetworkCacheMetaData >("QNetworkCacheMetaData");
    Shiboken::TypeResolver::createObjectTypeResolver<QNetworkCacheMetaData >("QNetworkCacheMetaData*");
    Shiboken::TypeResolver::createValueTypeResolver<QNetworkCacheMetaData >(typeid(QNetworkCacheMetaData).name());
    qRegisterMetaType< ::QNetworkCacheMetaData >("QNetworkCacheMetaData");
}

