/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtnetwork_python.h"

#include "qnetworkconfiguration_wrapper.h"

// Extra includes
#include <QList>
#include <qnetworkconfiguration.h>



// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QNetworkConfiguration_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QNetworkConfiguration >()))
        return -1;

    QNetworkConfiguration* cptr = 0;
    int overloadId = -1;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QNetworkConfiguration", 0, 1, &(pyargs[0])))
        return -1;

    // Overloaded function decisor
    // 0: QNetworkConfiguration()
    // 1: QNetworkConfiguration(QNetworkConfiguration)
    if (numArgs == 0) {
        overloadId = 0; // QNetworkConfiguration()
    } else if (numArgs == 1 && Shiboken::Converter< ::QNetworkConfiguration >::isConvertible(pyargs[0])) {
        overloadId = 1; // QNetworkConfiguration(QNetworkConfiguration)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QNetworkConfiguration_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QNetworkConfiguration()
            {

                if(!PyErr_Occurred()) {
                    // QNetworkConfiguration()
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QNetworkConfiguration();
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // QNetworkConfiguration(QNetworkConfiguration)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QNetworkConfiguration cppArg0 = Shiboken::Converter<QNetworkConfiguration >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QNetworkConfiguration(QNetworkConfiguration)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QNetworkConfiguration(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QNetworkConfiguration >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QNetworkConfiguration_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QNetworkConfiguration_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtNetwork.QNetworkConfiguration", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtNetwork.QNetworkConfiguration", overloads);
        return -1;
}

static PyObject* Sbk_QNetworkConfigurationFunc_bearerName(PyObject* self)
{
    QNetworkConfiguration* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QNetworkConfiguration* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // bearerName()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = const_cast<const QNetworkConfiguration*>(cppSelf)->bearerName();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QNetworkConfigurationFunc_bearerType(PyObject* self)
{
    QNetworkConfiguration* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QNetworkConfiguration* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // bearerType()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QNetworkConfiguration::BearerType cppResult = const_cast<const QNetworkConfiguration*>(cppSelf)->bearerType();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QNetworkConfiguration::BearerType >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QNetworkConfigurationFunc_bearerTypeName(PyObject* self)
{
    QNetworkConfiguration* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QNetworkConfiguration* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // bearerTypeName()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = const_cast<const QNetworkConfiguration*>(cppSelf)->bearerTypeName();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QNetworkConfigurationFunc_children(PyObject* self)
{
    QNetworkConfiguration* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QNetworkConfiguration* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // children()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QList<QNetworkConfiguration > cppResult = const_cast<const QNetworkConfiguration*>(cppSelf)->children();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QList<QNetworkConfiguration > >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QNetworkConfigurationFunc_identifier(PyObject* self)
{
    QNetworkConfiguration* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QNetworkConfiguration* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // identifier()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = const_cast<const QNetworkConfiguration*>(cppSelf)->identifier();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QNetworkConfigurationFunc_isRoamingAvailable(PyObject* self)
{
    QNetworkConfiguration* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QNetworkConfiguration* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isRoamingAvailable()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QNetworkConfiguration*>(cppSelf)->isRoamingAvailable();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QNetworkConfigurationFunc_isValid(PyObject* self)
{
    QNetworkConfiguration* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QNetworkConfiguration* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isValid()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QNetworkConfiguration*>(cppSelf)->isValid();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QNetworkConfigurationFunc_name(PyObject* self)
{
    QNetworkConfiguration* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QNetworkConfiguration* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // name()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = const_cast<const QNetworkConfiguration*>(cppSelf)->name();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QNetworkConfigurationFunc_purpose(PyObject* self)
{
    QNetworkConfiguration* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QNetworkConfiguration* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // purpose()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QNetworkConfiguration::Purpose cppResult = const_cast<const QNetworkConfiguration*>(cppSelf)->purpose();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QNetworkConfiguration::Purpose >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QNetworkConfigurationFunc_state(PyObject* self)
{
    QNetworkConfiguration* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QNetworkConfiguration* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // state()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QFlags<QNetworkConfiguration::StateFlag> cppResult = const_cast<const QNetworkConfiguration*>(cppSelf)->state();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QFlags<QNetworkConfiguration::StateFlag> >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QNetworkConfigurationFunc_type(PyObject* self)
{
    QNetworkConfiguration* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QNetworkConfiguration* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // type()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QNetworkConfiguration::Type cppResult = const_cast<const QNetworkConfiguration*>(cppSelf)->type();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QNetworkConfiguration::Type >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject *Sbk_QNetworkConfiguration___copy__(PyObject *self)
{
        QNetworkConfiguration* cppSelf = 0;
        if (!Shiboken::Object::isValid(self))
            return 0;
        cppSelf = Shiboken::Converter<QNetworkConfiguration*>::toCpp(self);
        PyObject* pyResult = 0;
        QNetworkConfiguration* copy = new QNetworkConfiguration(*cppSelf);
        pyResult = Shiboken::Converter<QNetworkConfiguration*>::toPython(copy);
        Shiboken::Object::getOwnership(pyResult);

        if (PyErr_Occurred() || !pyResult) {
            Py_XDECREF(pyResult);
            return 0;
        }
        return pyResult;
}

static PyMethodDef Sbk_QNetworkConfiguration_methods[] = {
    {"bearerName", (PyCFunction)Sbk_QNetworkConfigurationFunc_bearerName, METH_NOARGS},
    {"bearerType", (PyCFunction)Sbk_QNetworkConfigurationFunc_bearerType, METH_NOARGS},
    {"bearerTypeName", (PyCFunction)Sbk_QNetworkConfigurationFunc_bearerTypeName, METH_NOARGS},
    {"children", (PyCFunction)Sbk_QNetworkConfigurationFunc_children, METH_NOARGS},
    {"identifier", (PyCFunction)Sbk_QNetworkConfigurationFunc_identifier, METH_NOARGS},
    {"isRoamingAvailable", (PyCFunction)Sbk_QNetworkConfigurationFunc_isRoamingAvailable, METH_NOARGS},
    {"isValid", (PyCFunction)Sbk_QNetworkConfigurationFunc_isValid, METH_NOARGS},
    {"name", (PyCFunction)Sbk_QNetworkConfigurationFunc_name, METH_NOARGS},
    {"purpose", (PyCFunction)Sbk_QNetworkConfigurationFunc_purpose, METH_NOARGS},
    {"state", (PyCFunction)Sbk_QNetworkConfigurationFunc_state, METH_NOARGS},
    {"type", (PyCFunction)Sbk_QNetworkConfigurationFunc_type, METH_NOARGS},

    {"__copy__", (PyCFunction)Sbk_QNetworkConfiguration___copy__, METH_NOARGS},
    {0} // Sentinel
};

// Rich comparison
static PyObject* Sbk_QNetworkConfiguration_richcompare(PyObject* self, PyObject* arg, int op)
{
    PyObject* pyResult = 0;
    QNetworkConfiguration& cppSelf = *Shiboken::Converter< QNetworkConfiguration* >::toCpp(self);

    switch (op) {
        case Py_NE:
            if (Shiboken::Converter< ::QNetworkConfiguration >::isConvertible(arg)) {
                // operator!=(const QNetworkConfiguration & cp) const
                QNetworkConfiguration cppArg0 = Shiboken::Converter< ::QNetworkConfiguration >::toCpp(arg);
                pyResult = Shiboken::Converter< bool >::toPython(cppSelf != cppArg0);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_EQ:
            if (Shiboken::Converter< ::QNetworkConfiguration >::isConvertible(arg)) {
                // operator==(const QNetworkConfiguration & cp) const
                QNetworkConfiguration cppArg0 = Shiboken::Converter< ::QNetworkConfiguration >::toCpp(arg);
                pyResult = Shiboken::Converter< bool >::toPython(cppSelf == cppArg0);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            goto Sbk_QNetworkConfiguration_RichComparison_TypeError;
    }

    if (pyResult && !PyErr_Occurred())
        return pyResult;
    Sbk_QNetworkConfiguration_RichComparison_TypeError:
    PyErr_SetString(PyExc_NotImplementedError, "operator not implemented.");
    return 0;

}

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QNetworkConfiguration_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtNetwork.QNetworkConfiguration",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      Sbk_QNetworkConfiguration_richcompare,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QNetworkConfiguration_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&SbkObject_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QNetworkConfiguration_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern

PyObject* SbkPySide_QtNetwork_QNetworkConfiguration_StateFlag___and__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QNetworkConfiguration::StateFlags >::toPython(
        Shiboken::Converter<QNetworkConfiguration::StateFlags>::toCpp(self)
        & Shiboken::Converter< QNetworkConfiguration::StateFlags >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtNetwork_QNetworkConfiguration_StateFlag___or__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QNetworkConfiguration::StateFlags >::toPython(
        Shiboken::Converter<QNetworkConfiguration::StateFlags>::toCpp(self)
        | Shiboken::Converter< QNetworkConfiguration::StateFlags >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtNetwork_QNetworkConfiguration_StateFlag___xor__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QNetworkConfiguration::StateFlags >::toPython(
        Shiboken::Converter<QNetworkConfiguration::StateFlags>::toCpp(self)
        ^ Shiboken::Converter< QNetworkConfiguration::StateFlags >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtNetwork_QNetworkConfiguration_StateFlag___invert__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QNetworkConfiguration::StateFlags >::toPython(
        ~Shiboken::Converter<QNetworkConfiguration::StateFlags >::toCpp(self)
    );
}


static PyNumberMethods SbkPySide_QtNetwork_QNetworkConfiguration_StateFlag_as_number = {
    /*nb_add*/                  0,
    /*nb_subtract*/             0,
    /*nb_multiply*/             0,
    /*nb_divide*/               0,
    /*nb_remainder*/            0,
    /*nb_divmod*/               0,
    /*nb_power*/                0,
    /*nb_negative*/             0,
    /*nb_positive*/             0,
    /*nb_absolute*/             0,
    /*nb_nonzero*/              0,
    /*nb_invert*/               (unaryfunc)SbkPySide_QtNetwork_QNetworkConfiguration_StateFlag___invert__,
    /*nb_lshift*/               0,
    /*nb_rshift*/               0,
    /*nb_and*/                  (binaryfunc)SbkPySide_QtNetwork_QNetworkConfiguration_StateFlag___and__,
    /*nb_xor*/                  (binaryfunc)SbkPySide_QtNetwork_QNetworkConfiguration_StateFlag___xor__,
    /*nb_or*/                   (binaryfunc)SbkPySide_QtNetwork_QNetworkConfiguration_StateFlag___or__,
    /*nb_coerce*/               0,
    /*nb_int*/                  0,
    /*nb_long*/                 0,
    /*nb_float*/                0,
    /*nb_oct*/                  0,
    /*nb_hex*/                  0,
    /*nb_inplace_add*/          0,
    /*nb_inplace_subtract*/     0,
    /*nb_inplace_multiply*/     0,
    /*nb_inplace_divide*/       0,
    /*nb_inplace_remainder*/    0,
    /*nb_inplace_power*/        0,
    /*nb_inplace_lshift*/       0,
    /*nb_inplace_rshift*/       0,
    /*nb_inplace_and*/          0,
    /*nb_inplace_xor*/          0,
    /*nb_inplace_or*/           0,
    /*nb_floor_divide*/         0,
    /*nb_true_divide*/          0,
    /*nb_inplace_floor_divide*/ 0,
    /*nb_inplace_true_divide*/  0,
    /*nb_index*/                0
};


// forward declaration of new function
static PyTypeObject SbkPySide_QtNetwork_QNetworkConfiguration_StateFlags_Type = {
    PyObject_HEAD_INIT(&PyType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "StateFlags",
    /*tp_basicsize*/        0,
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        &SbkPySide_QtNetwork_QNetworkConfiguration_StateFlag_as_number,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT | Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              PyInt_Type.tp_new,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};



void init_QNetworkConfiguration(PyObject* module)
{
    SbkPySide_QtNetworkTypes[SBK_QNETWORKCONFIGURATION_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QNetworkConfiguration_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QNetworkConfiguration_Type);
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QNetworkConfiguration_Type, &Shiboken::callCppDestructor<QNetworkConfiguration >);
    Py_INCREF((PyObject*)&Sbk_QNetworkConfiguration_Type); //Incref due the 'PyModule_AddObject' steals the reference.
    if (PyType_Ready((PyTypeObject*)&Sbk_QNetworkConfiguration_Type) < 0)
        return;

    Shiboken::ObjectType::setOriginalName(&Sbk_QNetworkConfiguration_Type, "QNetworkConfiguration");
    PyModule_AddObject(module, "QNetworkConfiguration",
        ((PyObject*)&Sbk_QNetworkConfiguration_Type));

    // Initialize enums
    PyObject* enumItem;

    // init enum: BearerType
    PyTypeObject* SbkPySide_QtNetwork_QNetworkConfiguration_BearerType = Shiboken::Enum::newType("PySide.QtNetwork.QNetworkConfiguration.BearerType");
    SbkPySide_QtNetworkTypes[SBK_QNETWORKCONFIGURATION_BEARERTYPE_IDX] = SbkPySide_QtNetwork_QNetworkConfiguration_BearerType;
    if (PyType_Ready(SbkPySide_QtNetwork_QNetworkConfiguration_BearerType) < 0)
        return;
    PyDict_SetItemString(Sbk_QNetworkConfiguration_Type.super.ht_type.tp_dict,
            "BearerType",((PyObject*)SbkPySide_QtNetwork_QNetworkConfiguration_BearerType));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtNetwork_QNetworkConfiguration_BearerType,(long) QNetworkConfiguration::BearerUnknown, "BearerUnknown");
    PyDict_SetItemString(Sbk_QNetworkConfiguration_Type.super.ht_type.tp_dict,"BearerUnknown", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtNetwork_QNetworkConfiguration_BearerType->tp_dict,"BearerUnknown", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtNetwork_QNetworkConfiguration_BearerType,(long) QNetworkConfiguration::BearerEthernet, "BearerEthernet");
    PyDict_SetItemString(Sbk_QNetworkConfiguration_Type.super.ht_type.tp_dict,"BearerEthernet", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtNetwork_QNetworkConfiguration_BearerType->tp_dict,"BearerEthernet", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtNetwork_QNetworkConfiguration_BearerType,(long) QNetworkConfiguration::BearerWLAN, "BearerWLAN");
    PyDict_SetItemString(Sbk_QNetworkConfiguration_Type.super.ht_type.tp_dict,"BearerWLAN", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtNetwork_QNetworkConfiguration_BearerType->tp_dict,"BearerWLAN", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtNetwork_QNetworkConfiguration_BearerType,(long) QNetworkConfiguration::Bearer2G, "Bearer2G");
    PyDict_SetItemString(Sbk_QNetworkConfiguration_Type.super.ht_type.tp_dict,"Bearer2G", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtNetwork_QNetworkConfiguration_BearerType->tp_dict,"Bearer2G", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtNetwork_QNetworkConfiguration_BearerType,(long) QNetworkConfiguration::BearerCDMA2000, "BearerCDMA2000");
    PyDict_SetItemString(Sbk_QNetworkConfiguration_Type.super.ht_type.tp_dict,"BearerCDMA2000", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtNetwork_QNetworkConfiguration_BearerType->tp_dict,"BearerCDMA2000", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtNetwork_QNetworkConfiguration_BearerType,(long) QNetworkConfiguration::BearerWCDMA, "BearerWCDMA");
    PyDict_SetItemString(Sbk_QNetworkConfiguration_Type.super.ht_type.tp_dict,"BearerWCDMA", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtNetwork_QNetworkConfiguration_BearerType->tp_dict,"BearerWCDMA", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtNetwork_QNetworkConfiguration_BearerType,(long) QNetworkConfiguration::BearerHSPA, "BearerHSPA");
    PyDict_SetItemString(Sbk_QNetworkConfiguration_Type.super.ht_type.tp_dict,"BearerHSPA", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtNetwork_QNetworkConfiguration_BearerType->tp_dict,"BearerHSPA", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtNetwork_QNetworkConfiguration_BearerType,(long) QNetworkConfiguration::BearerBluetooth, "BearerBluetooth");
    PyDict_SetItemString(Sbk_QNetworkConfiguration_Type.super.ht_type.tp_dict,"BearerBluetooth", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtNetwork_QNetworkConfiguration_BearerType->tp_dict,"BearerBluetooth", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtNetwork_QNetworkConfiguration_BearerType,(long) QNetworkConfiguration::BearerWiMAX, "BearerWiMAX");
    PyDict_SetItemString(Sbk_QNetworkConfiguration_Type.super.ht_type.tp_dict,"BearerWiMAX", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtNetwork_QNetworkConfiguration_BearerType->tp_dict,"BearerWiMAX", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QNetworkConfiguration::BearerType");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::BearerType");
    // end of enum BearerType

    // init enum: Purpose
    PyTypeObject* SbkPySide_QtNetwork_QNetworkConfiguration_Purpose = Shiboken::Enum::newType("PySide.QtNetwork.QNetworkConfiguration.Purpose");
    SbkPySide_QtNetworkTypes[SBK_QNETWORKCONFIGURATION_PURPOSE_IDX] = SbkPySide_QtNetwork_QNetworkConfiguration_Purpose;
    if (PyType_Ready(SbkPySide_QtNetwork_QNetworkConfiguration_Purpose) < 0)
        return;
    PyDict_SetItemString(Sbk_QNetworkConfiguration_Type.super.ht_type.tp_dict,
            "Purpose",((PyObject*)SbkPySide_QtNetwork_QNetworkConfiguration_Purpose));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtNetwork_QNetworkConfiguration_Purpose,(long) QNetworkConfiguration::UnknownPurpose, "UnknownPurpose");
    PyDict_SetItemString(Sbk_QNetworkConfiguration_Type.super.ht_type.tp_dict,"UnknownPurpose", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtNetwork_QNetworkConfiguration_Purpose->tp_dict,"UnknownPurpose", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtNetwork_QNetworkConfiguration_Purpose,(long) QNetworkConfiguration::PublicPurpose, "PublicPurpose");
    PyDict_SetItemString(Sbk_QNetworkConfiguration_Type.super.ht_type.tp_dict,"PublicPurpose", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtNetwork_QNetworkConfiguration_Purpose->tp_dict,"PublicPurpose", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtNetwork_QNetworkConfiguration_Purpose,(long) QNetworkConfiguration::PrivatePurpose, "PrivatePurpose");
    PyDict_SetItemString(Sbk_QNetworkConfiguration_Type.super.ht_type.tp_dict,"PrivatePurpose", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtNetwork_QNetworkConfiguration_Purpose->tp_dict,"PrivatePurpose", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtNetwork_QNetworkConfiguration_Purpose,(long) QNetworkConfiguration::ServiceSpecificPurpose, "ServiceSpecificPurpose");
    PyDict_SetItemString(Sbk_QNetworkConfiguration_Type.super.ht_type.tp_dict,"ServiceSpecificPurpose", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtNetwork_QNetworkConfiguration_Purpose->tp_dict,"ServiceSpecificPurpose", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QNetworkConfiguration::Purpose");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::Purpose");
    // end of enum Purpose

    // init enum: Type
    PyTypeObject* SbkPySide_QtNetwork_QNetworkConfiguration_Type = Shiboken::Enum::newType("PySide.QtNetwork.QNetworkConfiguration.Type");
    SbkPySide_QtNetworkTypes[SBK_QNETWORKCONFIGURATION_TYPE_IDX] = SbkPySide_QtNetwork_QNetworkConfiguration_Type;
    if (PyType_Ready(SbkPySide_QtNetwork_QNetworkConfiguration_Type) < 0)
        return;
    PyDict_SetItemString(Sbk_QNetworkConfiguration_Type.super.ht_type.tp_dict,
            "Type",((PyObject*)SbkPySide_QtNetwork_QNetworkConfiguration_Type));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtNetwork_QNetworkConfiguration_Type,(long) QNetworkConfiguration::InternetAccessPoint, "InternetAccessPoint");
    PyDict_SetItemString(Sbk_QNetworkConfiguration_Type.super.ht_type.tp_dict,"InternetAccessPoint", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtNetwork_QNetworkConfiguration_Type->tp_dict,"InternetAccessPoint", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtNetwork_QNetworkConfiguration_Type,(long) QNetworkConfiguration::ServiceNetwork, "ServiceNetwork");
    PyDict_SetItemString(Sbk_QNetworkConfiguration_Type.super.ht_type.tp_dict,"ServiceNetwork", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtNetwork_QNetworkConfiguration_Type->tp_dict,"ServiceNetwork", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtNetwork_QNetworkConfiguration_Type,(long) QNetworkConfiguration::UserChoice, "UserChoice");
    PyDict_SetItemString(Sbk_QNetworkConfiguration_Type.super.ht_type.tp_dict,"UserChoice", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtNetwork_QNetworkConfiguration_Type->tp_dict,"UserChoice", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtNetwork_QNetworkConfiguration_Type,(long) QNetworkConfiguration::Invalid, "Invalid");
    PyDict_SetItemString(Sbk_QNetworkConfiguration_Type.super.ht_type.tp_dict,"Invalid", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtNetwork_QNetworkConfiguration_Type->tp_dict,"Invalid", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QNetworkConfiguration::Type");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::Type");
    // end of enum Type

    // init enum: StateFlag
    PyTypeObject* SbkPySide_QtNetwork_QNetworkConfiguration_StateFlag = Shiboken::Enum::newType("PySide.QtNetwork.QNetworkConfiguration.StateFlag");
    SbkPySide_QtNetwork_QNetworkConfiguration_StateFlag->tp_as_number = &SbkPySide_QtNetwork_QNetworkConfiguration_StateFlag_as_number;
    SbkPySide_QtNetworkTypes[SBK_QNETWORKCONFIGURATION_STATEFLAG_IDX] = SbkPySide_QtNetwork_QNetworkConfiguration_StateFlag;
    if (PyType_Ready(SbkPySide_QtNetwork_QNetworkConfiguration_StateFlag) < 0)
        return;
    PyDict_SetItemString(Sbk_QNetworkConfiguration_Type.super.ht_type.tp_dict,
            "StateFlag",((PyObject*)SbkPySide_QtNetwork_QNetworkConfiguration_StateFlag));

    // init flags class: QFlags<QNetworkConfiguration::StateFlag>
    SbkPySide_QtNetworkTypes[SBK_QFLAGS_QNETWORKCONFIGURATION_STATEFLAG__IDX] = &SbkPySide_QtNetwork_QNetworkConfiguration_StateFlags_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtNetwork_QNetworkConfiguration_StateFlags_Type) < 0)
        return;
    PyDict_SetItemString(Sbk_QNetworkConfiguration_Type.super.ht_type.tp_dict,
            "StateFlags",((PyObject*)&SbkPySide_QtNetwork_QNetworkConfiguration_StateFlags_Type));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtNetwork_QNetworkConfiguration_StateFlag,(long) QNetworkConfiguration::Undefined, "Undefined");
    PyDict_SetItemString(Sbk_QNetworkConfiguration_Type.super.ht_type.tp_dict,"Undefined", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtNetwork_QNetworkConfiguration_StateFlag->tp_dict,"Undefined", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtNetwork_QNetworkConfiguration_StateFlag,(long) QNetworkConfiguration::Defined, "Defined");
    PyDict_SetItemString(Sbk_QNetworkConfiguration_Type.super.ht_type.tp_dict,"Defined", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtNetwork_QNetworkConfiguration_StateFlag->tp_dict,"Defined", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtNetwork_QNetworkConfiguration_StateFlag,(long) QNetworkConfiguration::Discovered, "Discovered");
    PyDict_SetItemString(Sbk_QNetworkConfiguration_Type.super.ht_type.tp_dict,"Discovered", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtNetwork_QNetworkConfiguration_StateFlag->tp_dict,"Discovered", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtNetwork_QNetworkConfiguration_StateFlag,(long) QNetworkConfiguration::Active, "Active");
    PyDict_SetItemString(Sbk_QNetworkConfiguration_Type.super.ht_type.tp_dict,"Active", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtNetwork_QNetworkConfiguration_StateFlag->tp_dict,"Active", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QNetworkConfiguration::StateFlag");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::StateFlag");
    // end of enum StateFlag


    Shiboken::TypeResolver::createValueTypeResolver<QNetworkConfiguration >("QNetworkConfiguration");
    Shiboken::TypeResolver::createObjectTypeResolver<QNetworkConfiguration >("QNetworkConfiguration*");
    Shiboken::TypeResolver::createValueTypeResolver<QNetworkConfiguration >(typeid(QNetworkConfiguration).name());
    qRegisterMetaType< ::QNetworkConfiguration >("QNetworkConfiguration");
    qRegisterMetaType< ::QNetworkConfiguration::BearerType >("QNetworkConfiguration::BearerType");
    qRegisterMetaType< ::QNetworkConfiguration::Purpose >("QNetworkConfiguration::Purpose");
    qRegisterMetaType< ::QNetworkConfiguration::Type >("QNetworkConfiguration::Type");
    qRegisterMetaType< ::QNetworkConfiguration::StateFlag >("QNetworkConfiguration::StateFlag");
    qRegisterMetaType< ::QNetworkConfiguration::StateFlags >("QNetworkConfiguration::StateFlags");
}

