/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtnetwork_python.h"

#include "qnetworkproxy_wrapper.h"

// Extra includes
#include <qnetworkproxy.h>



// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QNetworkProxy_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QNetworkProxy >()))
        return -1;

    QNetworkProxy* cptr = 0;
    int overloadId = -1;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);

    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);

    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 5) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtNetwork.QNetworkProxy(): too many arguments");
        return -1;
    }

    if (!PyArg_ParseTuple(args, "|OOOOO:QNetworkProxy", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3]), &(pyargs[4])))
        return -1;

    // Overloaded function decisor
    // 0: QNetworkProxy()
    // 1: QNetworkProxy(QNetworkProxy::ProxyType,QString,quint16,QString,QString)
    // 2: QNetworkProxy(QNetworkProxy)
    if (numArgs == 0) {
        overloadId = 0; // QNetworkProxy()
    } else if (Shiboken::Converter< ::QNetworkProxy::ProxyType >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 1; // QNetworkProxy(QNetworkProxy::ProxyType,QString,quint16,QString,QString)
        } else if (Shiboken::Converter< QString >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 1; // QNetworkProxy(QNetworkProxy::ProxyType,QString,quint16,QString,QString)
            } else if (SbkNumber_Check(pyargs[2])) {
                if (numArgs == 3) {
                    overloadId = 1; // QNetworkProxy(QNetworkProxy::ProxyType,QString,quint16,QString,QString)
                } else if (Shiboken::Converter< QString >::isConvertible(pyargs[3])) {
                    if (numArgs == 4) {
                        overloadId = 1; // QNetworkProxy(QNetworkProxy::ProxyType,QString,quint16,QString,QString)
                    } else if (Shiboken::Converter< QString >::isConvertible(pyargs[4])) {
                        overloadId = 1; // QNetworkProxy(QNetworkProxy::ProxyType,QString,quint16,QString,QString)
                    }
                }
            }
        }
    } else if (numArgs == 1 && Shiboken::Converter< ::QNetworkProxy >::isConvertible(pyargs[0])) {
        overloadId = 2; // QNetworkProxy(QNetworkProxy)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QNetworkProxy_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QNetworkProxy()
            {

                if(!PyErr_Occurred()) {
                    // QNetworkProxy()
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QNetworkProxy();
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // QNetworkProxy(QNetworkProxy::ProxyType,QString,quint16,QString,QString)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "hostName");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "hostName";
                        else if (Shiboken::Converter< QString >::isConvertible(value))
                            pyargs[1] = value;
                        else
                            goto Sbk_QNetworkProxy_Init_TypeError;
                    }
                    value = PyDict_GetItemString(kwds, "port");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "port";
                        else if (SbkNumber_Check(value))
                            pyargs[2] = value;
                        else
                            goto Sbk_QNetworkProxy_Init_TypeError;
                    }
                    value = PyDict_GetItemString(kwds, "user");
                    if (value) {
                        if (pyargs[3])
                            errorArgName = "user";
                        else if (Shiboken::Converter< QString >::isConvertible(value))
                            pyargs[3] = value;
                        else
                            goto Sbk_QNetworkProxy_Init_TypeError;
                    }
                    value = PyDict_GetItemString(kwds, "password");
                    if (value) {
                        if (pyargs[4])
                            errorArgName = "password";
                        else if (Shiboken::Converter< QString >::isConvertible(value))
                            pyargs[4] = value;
                        else
                            goto Sbk_QNetworkProxy_Init_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtNetwork.QNetworkProxy(): got multiple values for keyword argument '%s'", errorArgName);
                        return -1;
                    }
                }
                QNetworkProxy::ProxyType cppArg0 = Shiboken::Converter<QNetworkProxy::ProxyType >::toCpp(pyargs[0]);
                QString cppArg1 = pyargs[1] ? Shiboken::Converter<QString >::toCpp(pyargs[1]) : QString();
                quint16 cppArg2 = pyargs[2] ? Shiboken::Converter<quint16 >::toCpp(pyargs[2]) : 0;
                QString cppArg3 = pyargs[3] ? Shiboken::Converter<QString >::toCpp(pyargs[3]) : QString();
                QString cppArg4 = pyargs[4] ? Shiboken::Converter<QString >::toCpp(pyargs[4]) : QString();

                if(!PyErr_Occurred()) {
                    // QNetworkProxy(QNetworkProxy::ProxyType,QString,quint16,QString,QString)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QNetworkProxy(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 2: // QNetworkProxy(QNetworkProxy)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QNetworkProxy cppArg0 = Shiboken::Converter<QNetworkProxy >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QNetworkProxy(QNetworkProxy)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QNetworkProxy(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QNetworkProxy >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QNetworkProxy_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QNetworkProxy_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtNetwork.QNetworkProxy.ProxyType, QString = QString(), unsigned short = 0, QString = QString(), QString = QString()", "PySide.QtNetwork.QNetworkProxy", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtNetwork.QNetworkProxy", overloads);
        return -1;
}

static PyObject* Sbk_QNetworkProxyFunc_applicationProxy(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // applicationProxy()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QNetworkProxy cppResult = QNetworkProxy::applicationProxy();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QNetworkProxy >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QNetworkProxyFunc_capabilities(PyObject* self)
{
    QNetworkProxy* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QNetworkProxy* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // capabilities()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QFlags<QNetworkProxy::Capability> cppResult = const_cast<const QNetworkProxy*>(cppSelf)->capabilities();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QFlags<QNetworkProxy::Capability> >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QNetworkProxyFunc_hostName(PyObject* self)
{
    QNetworkProxy* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QNetworkProxy* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // hostName()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = const_cast<const QNetworkProxy*>(cppSelf)->hostName();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QNetworkProxyFunc_isCachingProxy(PyObject* self)
{
    QNetworkProxy* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QNetworkProxy* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isCachingProxy()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QNetworkProxy*>(cppSelf)->isCachingProxy();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QNetworkProxyFunc_isTransparentProxy(PyObject* self)
{
    QNetworkProxy* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QNetworkProxy* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isTransparentProxy()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QNetworkProxy*>(cppSelf)->isTransparentProxy();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QNetworkProxyFunc_password(PyObject* self)
{
    QNetworkProxy* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QNetworkProxy* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // password()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = const_cast<const QNetworkProxy*>(cppSelf)->password();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QNetworkProxyFunc_port(PyObject* self)
{
    QNetworkProxy* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QNetworkProxy* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // port()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                quint16 cppResult = const_cast<const QNetworkProxy*>(cppSelf)->port();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< unsigned short >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QNetworkProxyFunc_setApplicationProxy(PyObject* self, PyObject* arg)
{
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setApplicationProxy(QNetworkProxy)
    if (Shiboken::Converter< ::QNetworkProxy >::isConvertible(arg)) {
        overloadId = 0; // setApplicationProxy(QNetworkProxy)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QNetworkProxyFunc_setApplicationProxy_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QNetworkProxy cppArg0 = Shiboken::Converter<QNetworkProxy >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setApplicationProxy(QNetworkProxy)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QNetworkProxy::setApplicationProxy(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QNetworkProxyFunc_setApplicationProxy_TypeError:
        const char* overloads[] = {"PySide.QtNetwork.QNetworkProxy", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtNetwork.QNetworkProxy.setApplicationProxy", overloads);
        return 0;
}

static PyObject* Sbk_QNetworkProxyFunc_setCapabilities(PyObject* self, PyObject* arg)
{
    QNetworkProxy* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QNetworkProxy* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setCapabilities(QFlags<QNetworkProxy::Capability>)
    if (Shiboken::Converter< ::QFlags<QNetworkProxy::Capability> >::isConvertible(arg)) {
        overloadId = 0; // setCapabilities(QFlags<QNetworkProxy::Capability>)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QNetworkProxyFunc_setCapabilities_TypeError;

    // Call function/method
    {
        {
            QFlags<QNetworkProxy::Capability> cppArg0 = Shiboken::Converter<QFlags<QNetworkProxy::Capability> >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setCapabilities(QFlags<QNetworkProxy::Capability>)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setCapabilities(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QNetworkProxyFunc_setCapabilities_TypeError:
        const char* overloads[] = {"PySide.QtNetwork.QNetworkProxy.Capabilities", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtNetwork.QNetworkProxy.setCapabilities", overloads);
        return 0;
}

static PyObject* Sbk_QNetworkProxyFunc_setHostName(PyObject* self, PyObject* arg)
{
    QNetworkProxy* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QNetworkProxy* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setHostName(QString)
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // setHostName(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QNetworkProxyFunc_setHostName_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setHostName(QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setHostName(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QNetworkProxyFunc_setHostName_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtNetwork.QNetworkProxy.setHostName", overloads);
        return 0;
}

static PyObject* Sbk_QNetworkProxyFunc_setPassword(PyObject* self, PyObject* arg)
{
    QNetworkProxy* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QNetworkProxy* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setPassword(QString)
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // setPassword(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QNetworkProxyFunc_setPassword_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setPassword(QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setPassword(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QNetworkProxyFunc_setPassword_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtNetwork.QNetworkProxy.setPassword", overloads);
        return 0;
}

static PyObject* Sbk_QNetworkProxyFunc_setPort(PyObject* self, PyObject* arg)
{
    QNetworkProxy* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QNetworkProxy* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setPort(quint16)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setPort(quint16)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QNetworkProxyFunc_setPort_TypeError;

    // Call function/method
    {
        {
            quint16 cppArg0 = Shiboken::Converter<quint16 >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setPort(quint16)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setPort(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QNetworkProxyFunc_setPort_TypeError:
        const char* overloads[] = {"unsigned short", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtNetwork.QNetworkProxy.setPort", overloads);
        return 0;
}

static PyObject* Sbk_QNetworkProxyFunc_setType(PyObject* self, PyObject* arg)
{
    QNetworkProxy* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QNetworkProxy* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setType(QNetworkProxy::ProxyType)
    if (Shiboken::Converter< ::QNetworkProxy::ProxyType >::isConvertible(arg)) {
        overloadId = 0; // setType(QNetworkProxy::ProxyType)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QNetworkProxyFunc_setType_TypeError;

    // Call function/method
    {
        {
            QNetworkProxy::ProxyType cppArg0 = Shiboken::Converter<QNetworkProxy::ProxyType >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setType(QNetworkProxy::ProxyType)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setType(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QNetworkProxyFunc_setType_TypeError:
        const char* overloads[] = {"PySide.QtNetwork.QNetworkProxy.ProxyType", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtNetwork.QNetworkProxy.setType", overloads);
        return 0;
}

static PyObject* Sbk_QNetworkProxyFunc_setUser(PyObject* self, PyObject* arg)
{
    QNetworkProxy* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QNetworkProxy* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setUser(QString)
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // setUser(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QNetworkProxyFunc_setUser_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setUser(QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setUser(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QNetworkProxyFunc_setUser_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtNetwork.QNetworkProxy.setUser", overloads);
        return 0;
}

static PyObject* Sbk_QNetworkProxyFunc_type(PyObject* self)
{
    QNetworkProxy* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QNetworkProxy* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // type()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QNetworkProxy::ProxyType cppResult = const_cast<const QNetworkProxy*>(cppSelf)->type();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QNetworkProxy::ProxyType >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QNetworkProxyFunc_user(PyObject* self)
{
    QNetworkProxy* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QNetworkProxy* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // user()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = const_cast<const QNetworkProxy*>(cppSelf)->user();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject *Sbk_QNetworkProxy___copy__(PyObject *self)
{
        QNetworkProxy* cppSelf = 0;
        if (!Shiboken::Object::isValid(self))
            return 0;
        cppSelf = Shiboken::Converter<QNetworkProxy*>::toCpp(self);
        PyObject* pyResult = 0;
        QNetworkProxy* copy = new QNetworkProxy(*cppSelf);
        pyResult = Shiboken::Converter<QNetworkProxy*>::toPython(copy);
        Shiboken::Object::getOwnership(pyResult);

        if (PyErr_Occurred() || !pyResult) {
            Py_XDECREF(pyResult);
            return 0;
        }
        return pyResult;
}

static PyMethodDef Sbk_QNetworkProxy_methods[] = {
    {"applicationProxy", (PyCFunction)Sbk_QNetworkProxyFunc_applicationProxy, METH_NOARGS|METH_STATIC},
    {"capabilities", (PyCFunction)Sbk_QNetworkProxyFunc_capabilities, METH_NOARGS},
    {"hostName", (PyCFunction)Sbk_QNetworkProxyFunc_hostName, METH_NOARGS},
    {"isCachingProxy", (PyCFunction)Sbk_QNetworkProxyFunc_isCachingProxy, METH_NOARGS},
    {"isTransparentProxy", (PyCFunction)Sbk_QNetworkProxyFunc_isTransparentProxy, METH_NOARGS},
    {"password", (PyCFunction)Sbk_QNetworkProxyFunc_password, METH_NOARGS},
    {"port", (PyCFunction)Sbk_QNetworkProxyFunc_port, METH_NOARGS},
    {"setApplicationProxy", (PyCFunction)Sbk_QNetworkProxyFunc_setApplicationProxy, METH_O|METH_STATIC},
    {"setCapabilities", (PyCFunction)Sbk_QNetworkProxyFunc_setCapabilities, METH_O},
    {"setHostName", (PyCFunction)Sbk_QNetworkProxyFunc_setHostName, METH_O},
    {"setPassword", (PyCFunction)Sbk_QNetworkProxyFunc_setPassword, METH_O},
    {"setPort", (PyCFunction)Sbk_QNetworkProxyFunc_setPort, METH_O},
    {"setType", (PyCFunction)Sbk_QNetworkProxyFunc_setType, METH_O},
    {"setUser", (PyCFunction)Sbk_QNetworkProxyFunc_setUser, METH_O},
    {"type", (PyCFunction)Sbk_QNetworkProxyFunc_type, METH_NOARGS},
    {"user", (PyCFunction)Sbk_QNetworkProxyFunc_user, METH_NOARGS},

    {"__copy__", (PyCFunction)Sbk_QNetworkProxy___copy__, METH_NOARGS},
    {0} // Sentinel
};

// Rich comparison
static PyObject* Sbk_QNetworkProxy_richcompare(PyObject* self, PyObject* arg, int op)
{
    PyObject* pyResult = 0;
    QNetworkProxy& cppSelf = *Shiboken::Converter< QNetworkProxy* >::toCpp(self);

    switch (op) {
        case Py_NE:
            if (Shiboken::Converter< ::QNetworkProxy >::isConvertible(arg)) {
                // operator!=(const QNetworkProxy & other) const
                QNetworkProxy cppArg0 = Shiboken::Converter< ::QNetworkProxy >::toCpp(arg);
                pyResult = Shiboken::Converter< bool >::toPython(cppSelf != cppArg0);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_EQ:
            if (Shiboken::Converter< ::QNetworkProxy >::isConvertible(arg)) {
                // operator==(const QNetworkProxy & other) const
                QNetworkProxy cppArg0 = Shiboken::Converter< ::QNetworkProxy >::toCpp(arg);
                pyResult = Shiboken::Converter< bool >::toPython(cppSelf == cppArg0);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            goto Sbk_QNetworkProxy_RichComparison_TypeError;
    }

    if (pyResult && !PyErr_Occurred())
        return pyResult;
    Sbk_QNetworkProxy_RichComparison_TypeError:
    PyErr_SetString(PyExc_NotImplementedError, "operator not implemented.");
    return 0;

}

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QNetworkProxy_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtNetwork.QNetworkProxy",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      Sbk_QNetworkProxy_richcompare,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QNetworkProxy_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&SbkObject_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QNetworkProxy_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern

PyObject* SbkPySide_QtNetwork_QNetworkProxy_Capability___and__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QNetworkProxy::Capabilities >::toPython(
        Shiboken::Converter<QNetworkProxy::Capabilities>::toCpp(self)
        & Shiboken::Converter< QNetworkProxy::Capabilities >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtNetwork_QNetworkProxy_Capability___or__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QNetworkProxy::Capabilities >::toPython(
        Shiboken::Converter<QNetworkProxy::Capabilities>::toCpp(self)
        | Shiboken::Converter< QNetworkProxy::Capabilities >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtNetwork_QNetworkProxy_Capability___xor__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QNetworkProxy::Capabilities >::toPython(
        Shiboken::Converter<QNetworkProxy::Capabilities>::toCpp(self)
        ^ Shiboken::Converter< QNetworkProxy::Capabilities >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtNetwork_QNetworkProxy_Capability___invert__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QNetworkProxy::Capabilities >::toPython(
        ~Shiboken::Converter<QNetworkProxy::Capabilities >::toCpp(self)
    );
}


static PyNumberMethods SbkPySide_QtNetwork_QNetworkProxy_Capability_as_number = {
    /*nb_add*/                  0,
    /*nb_subtract*/             0,
    /*nb_multiply*/             0,
    /*nb_divide*/               0,
    /*nb_remainder*/            0,
    /*nb_divmod*/               0,
    /*nb_power*/                0,
    /*nb_negative*/             0,
    /*nb_positive*/             0,
    /*nb_absolute*/             0,
    /*nb_nonzero*/              0,
    /*nb_invert*/               (unaryfunc)SbkPySide_QtNetwork_QNetworkProxy_Capability___invert__,
    /*nb_lshift*/               0,
    /*nb_rshift*/               0,
    /*nb_and*/                  (binaryfunc)SbkPySide_QtNetwork_QNetworkProxy_Capability___and__,
    /*nb_xor*/                  (binaryfunc)SbkPySide_QtNetwork_QNetworkProxy_Capability___xor__,
    /*nb_or*/                   (binaryfunc)SbkPySide_QtNetwork_QNetworkProxy_Capability___or__,
    /*nb_coerce*/               0,
    /*nb_int*/                  0,
    /*nb_long*/                 0,
    /*nb_float*/                0,
    /*nb_oct*/                  0,
    /*nb_hex*/                  0,
    /*nb_inplace_add*/          0,
    /*nb_inplace_subtract*/     0,
    /*nb_inplace_multiply*/     0,
    /*nb_inplace_divide*/       0,
    /*nb_inplace_remainder*/    0,
    /*nb_inplace_power*/        0,
    /*nb_inplace_lshift*/       0,
    /*nb_inplace_rshift*/       0,
    /*nb_inplace_and*/          0,
    /*nb_inplace_xor*/          0,
    /*nb_inplace_or*/           0,
    /*nb_floor_divide*/         0,
    /*nb_true_divide*/          0,
    /*nb_inplace_floor_divide*/ 0,
    /*nb_inplace_true_divide*/  0,
    /*nb_index*/                0
};


// forward declaration of new function
static PyTypeObject SbkPySide_QtNetwork_QNetworkProxy_Capabilities_Type = {
    PyObject_HEAD_INIT(&PyType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "Capabilities",
    /*tp_basicsize*/        0,
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        &SbkPySide_QtNetwork_QNetworkProxy_Capability_as_number,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT | Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              PyInt_Type.tp_new,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};



void init_QNetworkProxy(PyObject* module)
{
    SbkPySide_QtNetworkTypes[SBK_QNETWORKPROXY_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QNetworkProxy_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QNetworkProxy_Type);
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QNetworkProxy_Type, &Shiboken::callCppDestructor<QNetworkProxy >);
    Py_INCREF((PyObject*)&Sbk_QNetworkProxy_Type); //Incref due the 'PyModule_AddObject' steals the reference.
    if (PyType_Ready((PyTypeObject*)&Sbk_QNetworkProxy_Type) < 0)
        return;

    Shiboken::ObjectType::setOriginalName(&Sbk_QNetworkProxy_Type, "QNetworkProxy");
    PyModule_AddObject(module, "QNetworkProxy",
        ((PyObject*)&Sbk_QNetworkProxy_Type));

    // Initialize enums
    PyObject* enumItem;

    // init enum: ProxyType
    PyTypeObject* SbkPySide_QtNetwork_QNetworkProxy_ProxyType = Shiboken::Enum::newType("PySide.QtNetwork.QNetworkProxy.ProxyType");
    SbkPySide_QtNetworkTypes[SBK_QNETWORKPROXY_PROXYTYPE_IDX] = SbkPySide_QtNetwork_QNetworkProxy_ProxyType;
    if (PyType_Ready(SbkPySide_QtNetwork_QNetworkProxy_ProxyType) < 0)
        return;
    PyDict_SetItemString(Sbk_QNetworkProxy_Type.super.ht_type.tp_dict,
            "ProxyType",((PyObject*)SbkPySide_QtNetwork_QNetworkProxy_ProxyType));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtNetwork_QNetworkProxy_ProxyType,(long) QNetworkProxy::DefaultProxy, "DefaultProxy");
    PyDict_SetItemString(Sbk_QNetworkProxy_Type.super.ht_type.tp_dict,"DefaultProxy", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtNetwork_QNetworkProxy_ProxyType->tp_dict,"DefaultProxy", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtNetwork_QNetworkProxy_ProxyType,(long) QNetworkProxy::Socks5Proxy, "Socks5Proxy");
    PyDict_SetItemString(Sbk_QNetworkProxy_Type.super.ht_type.tp_dict,"Socks5Proxy", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtNetwork_QNetworkProxy_ProxyType->tp_dict,"Socks5Proxy", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtNetwork_QNetworkProxy_ProxyType,(long) QNetworkProxy::NoProxy, "NoProxy");
    PyDict_SetItemString(Sbk_QNetworkProxy_Type.super.ht_type.tp_dict,"NoProxy", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtNetwork_QNetworkProxy_ProxyType->tp_dict,"NoProxy", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtNetwork_QNetworkProxy_ProxyType,(long) QNetworkProxy::HttpProxy, "HttpProxy");
    PyDict_SetItemString(Sbk_QNetworkProxy_Type.super.ht_type.tp_dict,"HttpProxy", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtNetwork_QNetworkProxy_ProxyType->tp_dict,"HttpProxy", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtNetwork_QNetworkProxy_ProxyType,(long) QNetworkProxy::HttpCachingProxy, "HttpCachingProxy");
    PyDict_SetItemString(Sbk_QNetworkProxy_Type.super.ht_type.tp_dict,"HttpCachingProxy", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtNetwork_QNetworkProxy_ProxyType->tp_dict,"HttpCachingProxy", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtNetwork_QNetworkProxy_ProxyType,(long) QNetworkProxy::FtpCachingProxy, "FtpCachingProxy");
    PyDict_SetItemString(Sbk_QNetworkProxy_Type.super.ht_type.tp_dict,"FtpCachingProxy", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtNetwork_QNetworkProxy_ProxyType->tp_dict,"FtpCachingProxy", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QNetworkProxy::ProxyType");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::ProxyType");
    // end of enum ProxyType

    // init enum: Capability
    PyTypeObject* SbkPySide_QtNetwork_QNetworkProxy_Capability = Shiboken::Enum::newType("PySide.QtNetwork.QNetworkProxy.Capability");
    SbkPySide_QtNetwork_QNetworkProxy_Capability->tp_as_number = &SbkPySide_QtNetwork_QNetworkProxy_Capability_as_number;
    SbkPySide_QtNetworkTypes[SBK_QNETWORKPROXY_CAPABILITY_IDX] = SbkPySide_QtNetwork_QNetworkProxy_Capability;
    if (PyType_Ready(SbkPySide_QtNetwork_QNetworkProxy_Capability) < 0)
        return;
    PyDict_SetItemString(Sbk_QNetworkProxy_Type.super.ht_type.tp_dict,
            "Capability",((PyObject*)SbkPySide_QtNetwork_QNetworkProxy_Capability));

    // init flags class: QFlags<QNetworkProxy::Capability>
    SbkPySide_QtNetworkTypes[SBK_QFLAGS_QNETWORKPROXY_CAPABILITY__IDX] = &SbkPySide_QtNetwork_QNetworkProxy_Capabilities_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtNetwork_QNetworkProxy_Capabilities_Type) < 0)
        return;
    PyDict_SetItemString(Sbk_QNetworkProxy_Type.super.ht_type.tp_dict,
            "Capabilities",((PyObject*)&SbkPySide_QtNetwork_QNetworkProxy_Capabilities_Type));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtNetwork_QNetworkProxy_Capability,(long) QNetworkProxy::TunnelingCapability, "TunnelingCapability");
    PyDict_SetItemString(Sbk_QNetworkProxy_Type.super.ht_type.tp_dict,"TunnelingCapability", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtNetwork_QNetworkProxy_Capability->tp_dict,"TunnelingCapability", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtNetwork_QNetworkProxy_Capability,(long) QNetworkProxy::ListeningCapability, "ListeningCapability");
    PyDict_SetItemString(Sbk_QNetworkProxy_Type.super.ht_type.tp_dict,"ListeningCapability", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtNetwork_QNetworkProxy_Capability->tp_dict,"ListeningCapability", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtNetwork_QNetworkProxy_Capability,(long) QNetworkProxy::UdpTunnelingCapability, "UdpTunnelingCapability");
    PyDict_SetItemString(Sbk_QNetworkProxy_Type.super.ht_type.tp_dict,"UdpTunnelingCapability", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtNetwork_QNetworkProxy_Capability->tp_dict,"UdpTunnelingCapability", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtNetwork_QNetworkProxy_Capability,(long) QNetworkProxy::CachingCapability, "CachingCapability");
    PyDict_SetItemString(Sbk_QNetworkProxy_Type.super.ht_type.tp_dict,"CachingCapability", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtNetwork_QNetworkProxy_Capability->tp_dict,"CachingCapability", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtNetwork_QNetworkProxy_Capability,(long) QNetworkProxy::HostNameLookupCapability, "HostNameLookupCapability");
    PyDict_SetItemString(Sbk_QNetworkProxy_Type.super.ht_type.tp_dict,"HostNameLookupCapability", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtNetwork_QNetworkProxy_Capability->tp_dict,"HostNameLookupCapability", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QNetworkProxy::Capability");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::Capability");
    // end of enum Capability


    Shiboken::TypeResolver::createValueTypeResolver<QNetworkProxy >("QNetworkProxy");
    Shiboken::TypeResolver::createObjectTypeResolver<QNetworkProxy >("QNetworkProxy*");
    Shiboken::TypeResolver::createValueTypeResolver<QNetworkProxy >(typeid(QNetworkProxy).name());
    qRegisterMetaType< ::QNetworkProxy >("QNetworkProxy");
    qRegisterMetaType< ::QNetworkProxy::ProxyType >("QNetworkProxy::ProxyType");
    qRegisterMetaType< ::QNetworkProxy::Capability >("QNetworkProxy::Capability");
    qRegisterMetaType< ::QNetworkProxy::Capabilities >("QNetworkProxy::Capabilities");
}

