/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtnetwork_python.h"

#include "qssl_wrapper.h"

// Extra includes
#include <qssl.h>



// Target ---------------------------------------------------------

extern "C" {
static PyMethodDef Sbk_QSsl_methods[] = {

    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QSsl_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtNetwork.QSsl",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QSsl_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&SbkObject_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              0,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern


void init_QSsl(PyObject* module)
{
    SbkPySide_QtNetworkTypes[SBK_QSSL_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QSsl_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QSsl_Type);
    Py_INCREF((PyObject*)&Sbk_QSsl_Type); //Incref due the 'PyModule_AddObject' steals the reference.
    if (PyType_Ready((PyTypeObject*)&Sbk_QSsl_Type) < 0)
        return;

    Shiboken::ObjectType::setOriginalName(&Sbk_QSsl_Type, "QSsl");
    PyModule_AddObject(module, "QSsl",
        ((PyObject*)&Sbk_QSsl_Type));

    // Initialize enums
    PyObject* enumItem;

    // init enum: KeyType
    PyTypeObject* SbkPySide_QtNetwork_QSsl_KeyType = Shiboken::Enum::newType("PySide.QtNetwork.QSsl.KeyType");
    SbkPySide_QtNetworkTypes[SBK_QSSL_KEYTYPE_IDX] = SbkPySide_QtNetwork_QSsl_KeyType;
    if (PyType_Ready(SbkPySide_QtNetwork_QSsl_KeyType) < 0)
        return;
    PyDict_SetItemString(Sbk_QSsl_Type.super.ht_type.tp_dict,
            "KeyType",((PyObject*)SbkPySide_QtNetwork_QSsl_KeyType));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtNetwork_QSsl_KeyType,(long) QSsl::PrivateKey, "PrivateKey");
    PyDict_SetItemString(Sbk_QSsl_Type.super.ht_type.tp_dict,"PrivateKey", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtNetwork_QSsl_KeyType->tp_dict,"PrivateKey", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtNetwork_QSsl_KeyType,(long) QSsl::PublicKey, "PublicKey");
    PyDict_SetItemString(Sbk_QSsl_Type.super.ht_type.tp_dict,"PublicKey", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtNetwork_QSsl_KeyType->tp_dict,"PublicKey", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QSsl::KeyType");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::KeyType");
    // end of enum KeyType

    // init enum: KeyAlgorithm
    PyTypeObject* SbkPySide_QtNetwork_QSsl_KeyAlgorithm = Shiboken::Enum::newType("PySide.QtNetwork.QSsl.KeyAlgorithm");
    SbkPySide_QtNetworkTypes[SBK_QSSL_KEYALGORITHM_IDX] = SbkPySide_QtNetwork_QSsl_KeyAlgorithm;
    if (PyType_Ready(SbkPySide_QtNetwork_QSsl_KeyAlgorithm) < 0)
        return;
    PyDict_SetItemString(Sbk_QSsl_Type.super.ht_type.tp_dict,
            "KeyAlgorithm",((PyObject*)SbkPySide_QtNetwork_QSsl_KeyAlgorithm));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtNetwork_QSsl_KeyAlgorithm,(long) QSsl::Rsa, "Rsa");
    PyDict_SetItemString(Sbk_QSsl_Type.super.ht_type.tp_dict,"Rsa", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtNetwork_QSsl_KeyAlgorithm->tp_dict,"Rsa", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtNetwork_QSsl_KeyAlgorithm,(long) QSsl::Dsa, "Dsa");
    PyDict_SetItemString(Sbk_QSsl_Type.super.ht_type.tp_dict,"Dsa", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtNetwork_QSsl_KeyAlgorithm->tp_dict,"Dsa", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QSsl::KeyAlgorithm");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::KeyAlgorithm");
    // end of enum KeyAlgorithm

    // init enum: SslProtocol
    PyTypeObject* SbkPySide_QtNetwork_QSsl_SslProtocol = Shiboken::Enum::newType("PySide.QtNetwork.QSsl.SslProtocol");
    SbkPySide_QtNetworkTypes[SBK_QSSL_SSLPROTOCOL_IDX] = SbkPySide_QtNetwork_QSsl_SslProtocol;
    if (PyType_Ready(SbkPySide_QtNetwork_QSsl_SslProtocol) < 0)
        return;
    PyDict_SetItemString(Sbk_QSsl_Type.super.ht_type.tp_dict,
            "SslProtocol",((PyObject*)SbkPySide_QtNetwork_QSsl_SslProtocol));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtNetwork_QSsl_SslProtocol,(long) QSsl::SslV3, "SslV3");
    PyDict_SetItemString(Sbk_QSsl_Type.super.ht_type.tp_dict,"SslV3", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtNetwork_QSsl_SslProtocol->tp_dict,"SslV3", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtNetwork_QSsl_SslProtocol,(long) QSsl::SslV2, "SslV2");
    PyDict_SetItemString(Sbk_QSsl_Type.super.ht_type.tp_dict,"SslV2", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtNetwork_QSsl_SslProtocol->tp_dict,"SslV2", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtNetwork_QSsl_SslProtocol,(long) QSsl::TlsV1, "TlsV1");
    PyDict_SetItemString(Sbk_QSsl_Type.super.ht_type.tp_dict,"TlsV1", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtNetwork_QSsl_SslProtocol->tp_dict,"TlsV1", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtNetwork_QSsl_SslProtocol,(long) QSsl::AnyProtocol, "AnyProtocol");
    PyDict_SetItemString(Sbk_QSsl_Type.super.ht_type.tp_dict,"AnyProtocol", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtNetwork_QSsl_SslProtocol->tp_dict,"AnyProtocol", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtNetwork_QSsl_SslProtocol,(long) QSsl::UnknownProtocol, "UnknownProtocol");
    PyDict_SetItemString(Sbk_QSsl_Type.super.ht_type.tp_dict,"UnknownProtocol", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtNetwork_QSsl_SslProtocol->tp_dict,"UnknownProtocol", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QSsl::SslProtocol");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::SslProtocol");
    // end of enum SslProtocol

    // init enum: AlternateNameEntryType
    PyTypeObject* SbkPySide_QtNetwork_QSsl_AlternateNameEntryType = Shiboken::Enum::newType("PySide.QtNetwork.QSsl.AlternateNameEntryType");
    SbkPySide_QtNetworkTypes[SBK_QSSL_ALTERNATENAMEENTRYTYPE_IDX] = SbkPySide_QtNetwork_QSsl_AlternateNameEntryType;
    if (PyType_Ready(SbkPySide_QtNetwork_QSsl_AlternateNameEntryType) < 0)
        return;
    PyDict_SetItemString(Sbk_QSsl_Type.super.ht_type.tp_dict,
            "AlternateNameEntryType",((PyObject*)SbkPySide_QtNetwork_QSsl_AlternateNameEntryType));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtNetwork_QSsl_AlternateNameEntryType,(long) QSsl::EmailEntry, "EmailEntry");
    PyDict_SetItemString(Sbk_QSsl_Type.super.ht_type.tp_dict,"EmailEntry", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtNetwork_QSsl_AlternateNameEntryType->tp_dict,"EmailEntry", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtNetwork_QSsl_AlternateNameEntryType,(long) QSsl::DnsEntry, "DnsEntry");
    PyDict_SetItemString(Sbk_QSsl_Type.super.ht_type.tp_dict,"DnsEntry", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtNetwork_QSsl_AlternateNameEntryType->tp_dict,"DnsEntry", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QSsl::AlternateNameEntryType");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::AlternateNameEntryType");
    // end of enum AlternateNameEntryType

    // init enum: EncodingFormat
    PyTypeObject* SbkPySide_QtNetwork_QSsl_EncodingFormat = Shiboken::Enum::newType("PySide.QtNetwork.QSsl.EncodingFormat");
    SbkPySide_QtNetworkTypes[SBK_QSSL_ENCODINGFORMAT_IDX] = SbkPySide_QtNetwork_QSsl_EncodingFormat;
    if (PyType_Ready(SbkPySide_QtNetwork_QSsl_EncodingFormat) < 0)
        return;
    PyDict_SetItemString(Sbk_QSsl_Type.super.ht_type.tp_dict,
            "EncodingFormat",((PyObject*)SbkPySide_QtNetwork_QSsl_EncodingFormat));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtNetwork_QSsl_EncodingFormat,(long) QSsl::Pem, "Pem");
    PyDict_SetItemString(Sbk_QSsl_Type.super.ht_type.tp_dict,"Pem", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtNetwork_QSsl_EncodingFormat->tp_dict,"Pem", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtNetwork_QSsl_EncodingFormat,(long) QSsl::Der, "Der");
    PyDict_SetItemString(Sbk_QSsl_Type.super.ht_type.tp_dict,"Der", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtNetwork_QSsl_EncodingFormat->tp_dict,"Der", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QSsl::EncodingFormat");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::EncodingFormat");
    // end of enum EncodingFormat


    qRegisterMetaType< ::QSsl::KeyType >("QSsl::KeyType");
    qRegisterMetaType< ::QSsl::KeyAlgorithm >("QSsl::KeyAlgorithm");
    qRegisterMetaType< ::QSsl::SslProtocol >("QSsl::SslProtocol");
    qRegisterMetaType< ::QSsl::AlternateNameEntryType >("QSsl::AlternateNameEntryType");
    qRegisterMetaType< ::QSsl::EncodingFormat >("QSsl::EncodingFormat");
}

