/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtnetwork_python.h"

#include "qsslconfiguration_wrapper.h"

// Extra includes
#include <QList>
#include <qsslcertificate.h>
#include <qsslcipher.h>
#include <qsslconfiguration.h>
#include <qsslkey.h>



// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QSslConfiguration_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QSslConfiguration >()))
        return -1;

    QSslConfiguration* cptr = 0;
    int overloadId = -1;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QSslConfiguration", 0, 1, &(pyargs[0])))
        return -1;

    // Overloaded function decisor
    // 0: QSslConfiguration()
    // 1: QSslConfiguration(QSslConfiguration)
    if (numArgs == 0) {
        overloadId = 0; // QSslConfiguration()
    } else if (numArgs == 1 && Shiboken::Converter< ::QSslConfiguration >::isConvertible(pyargs[0])) {
        overloadId = 1; // QSslConfiguration(QSslConfiguration)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QSslConfiguration_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QSslConfiguration()
            {

                if(!PyErr_Occurred()) {
                    // QSslConfiguration()
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QSslConfiguration();
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // QSslConfiguration(QSslConfiguration)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QSslConfiguration cppArg0 = Shiboken::Converter<QSslConfiguration >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QSslConfiguration(QSslConfiguration)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QSslConfiguration(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QSslConfiguration >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QSslConfiguration_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QSslConfiguration_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtNetwork.QSslConfiguration", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtNetwork.QSslConfiguration", overloads);
        return -1;
}

static PyObject* Sbk_QSslConfigurationFunc_caCertificates(PyObject* self)
{
    QSslConfiguration* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QSslConfiguration* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // caCertificates()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QList<QSslCertificate > cppResult = const_cast<const QSslConfiguration*>(cppSelf)->caCertificates();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QList<QSslCertificate > >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QSslConfigurationFunc_ciphers(PyObject* self)
{
    QSslConfiguration* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QSslConfiguration* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // ciphers()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QList<QSslCipher > cppResult = const_cast<const QSslConfiguration*>(cppSelf)->ciphers();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QList<QSslCipher > >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QSslConfigurationFunc_defaultConfiguration(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // defaultConfiguration()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QSslConfiguration cppResult = QSslConfiguration::defaultConfiguration();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QSslConfiguration >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QSslConfigurationFunc_isNull(PyObject* self)
{
    QSslConfiguration* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QSslConfiguration* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isNull()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QSslConfiguration*>(cppSelf)->isNull();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QSslConfigurationFunc_localCertificate(PyObject* self)
{
    QSslConfiguration* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QSslConfiguration* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // localCertificate()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QSslCertificate cppResult = const_cast<const QSslConfiguration*>(cppSelf)->localCertificate();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QSslCertificate >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QSslConfigurationFunc_peerCertificate(PyObject* self)
{
    QSslConfiguration* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QSslConfiguration* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // peerCertificate()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QSslCertificate cppResult = const_cast<const QSslConfiguration*>(cppSelf)->peerCertificate();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QSslCertificate >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QSslConfigurationFunc_peerCertificateChain(PyObject* self)
{
    QSslConfiguration* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QSslConfiguration* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // peerCertificateChain()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QList<QSslCertificate > cppResult = const_cast<const QSslConfiguration*>(cppSelf)->peerCertificateChain();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QList<QSslCertificate > >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QSslConfigurationFunc_peerVerifyDepth(PyObject* self)
{
    QSslConfiguration* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QSslConfiguration* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // peerVerifyDepth()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QSslConfiguration*>(cppSelf)->peerVerifyDepth();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QSslConfigurationFunc_peerVerifyMode(PyObject* self)
{
    QSslConfiguration* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QSslConfiguration* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // peerVerifyMode()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QSslSocket::PeerVerifyMode cppResult = const_cast<const QSslConfiguration*>(cppSelf)->peerVerifyMode();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QSslSocket::PeerVerifyMode >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QSslConfigurationFunc_privateKey(PyObject* self)
{
    QSslConfiguration* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QSslConfiguration* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // privateKey()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QSslKey cppResult = const_cast<const QSslConfiguration*>(cppSelf)->privateKey();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QSslKey >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QSslConfigurationFunc_protocol(PyObject* self)
{
    QSslConfiguration* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QSslConfiguration* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // protocol()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QSsl::SslProtocol cppResult = const_cast<const QSslConfiguration*>(cppSelf)->protocol();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QSsl::SslProtocol >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QSslConfigurationFunc_sessionCipher(PyObject* self)
{
    QSslConfiguration* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QSslConfiguration* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // sessionCipher()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QSslCipher cppResult = const_cast<const QSslConfiguration*>(cppSelf)->sessionCipher();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QSslCipher >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QSslConfigurationFunc_setCaCertificates(PyObject* self, PyObject* arg)
{
    QSslConfiguration* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QSslConfiguration* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setCaCertificates(QList<QSslCertificate>)
    if (Shiboken::Converter< ::QList<QSslCertificate > >::isConvertible(arg)) {
        overloadId = 0; // setCaCertificates(QList<QSslCertificate>)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QSslConfigurationFunc_setCaCertificates_TypeError;

    // Call function/method
    {
        {
            QList<QSslCertificate > cppArg0 = Shiboken::Converter<QList<QSslCertificate > >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setCaCertificates(QList<QSslCertificate>)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setCaCertificates(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QSslConfigurationFunc_setCaCertificates_TypeError:
        const char* overloads[] = {"list", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtNetwork.QSslConfiguration.setCaCertificates", overloads);
        return 0;
}

static PyObject* Sbk_QSslConfigurationFunc_setCiphers(PyObject* self, PyObject* arg)
{
    QSslConfiguration* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QSslConfiguration* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setCiphers(QList<QSslCipher>)
    if (Shiboken::Converter< ::QList<QSslCipher > >::isConvertible(arg)) {
        overloadId = 0; // setCiphers(QList<QSslCipher>)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QSslConfigurationFunc_setCiphers_TypeError;

    // Call function/method
    {
        {
            QList<QSslCipher > cppArg0 = Shiboken::Converter<QList<QSslCipher > >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setCiphers(QList<QSslCipher>)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setCiphers(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QSslConfigurationFunc_setCiphers_TypeError:
        const char* overloads[] = {"list", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtNetwork.QSslConfiguration.setCiphers", overloads);
        return 0;
}

static PyObject* Sbk_QSslConfigurationFunc_setDefaultConfiguration(PyObject* self, PyObject* arg)
{
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setDefaultConfiguration(QSslConfiguration)
    if (Shiboken::Converter< ::QSslConfiguration >::isConvertible(arg)) {
        overloadId = 0; // setDefaultConfiguration(QSslConfiguration)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QSslConfigurationFunc_setDefaultConfiguration_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QSslConfiguration cppArg0 = Shiboken::Converter<QSslConfiguration >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setDefaultConfiguration(QSslConfiguration)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QSslConfiguration::setDefaultConfiguration(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QSslConfigurationFunc_setDefaultConfiguration_TypeError:
        const char* overloads[] = {"PySide.QtNetwork.QSslConfiguration", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtNetwork.QSslConfiguration.setDefaultConfiguration", overloads);
        return 0;
}

static PyObject* Sbk_QSslConfigurationFunc_setLocalCertificate(PyObject* self, PyObject* arg)
{
    QSslConfiguration* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QSslConfiguration* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setLocalCertificate(QSslCertificate)
    if (Shiboken::Converter< ::QSslCertificate >::isConvertible(arg)) {
        overloadId = 0; // setLocalCertificate(QSslCertificate)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QSslConfigurationFunc_setLocalCertificate_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QSslCertificate cppArg0 = Shiboken::Converter<QSslCertificate >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setLocalCertificate(QSslCertificate)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setLocalCertificate(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QSslConfigurationFunc_setLocalCertificate_TypeError:
        const char* overloads[] = {"PySide.QtNetwork.QSslCertificate", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtNetwork.QSslConfiguration.setLocalCertificate", overloads);
        return 0;
}

static PyObject* Sbk_QSslConfigurationFunc_setPeerVerifyDepth(PyObject* self, PyObject* arg)
{
    QSslConfiguration* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QSslConfiguration* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setPeerVerifyDepth(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setPeerVerifyDepth(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QSslConfigurationFunc_setPeerVerifyDepth_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setPeerVerifyDepth(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setPeerVerifyDepth(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QSslConfigurationFunc_setPeerVerifyDepth_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtNetwork.QSslConfiguration.setPeerVerifyDepth", overloads);
        return 0;
}

static PyObject* Sbk_QSslConfigurationFunc_setPeerVerifyMode(PyObject* self, PyObject* arg)
{
    QSslConfiguration* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QSslConfiguration* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setPeerVerifyMode(QSslSocket::PeerVerifyMode)
    if (Shiboken::Converter< ::QSslSocket::PeerVerifyMode >::isConvertible(arg)) {
        overloadId = 0; // setPeerVerifyMode(QSslSocket::PeerVerifyMode)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QSslConfigurationFunc_setPeerVerifyMode_TypeError;

    // Call function/method
    {
        {
            QSslSocket::PeerVerifyMode cppArg0 = Shiboken::Converter<QSslSocket::PeerVerifyMode >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setPeerVerifyMode(QSslSocket::PeerVerifyMode)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setPeerVerifyMode(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QSslConfigurationFunc_setPeerVerifyMode_TypeError:
        const char* overloads[] = {"PySide.QtNetwork.QSslSocket.PeerVerifyMode", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtNetwork.QSslConfiguration.setPeerVerifyMode", overloads);
        return 0;
}

static PyObject* Sbk_QSslConfigurationFunc_setPrivateKey(PyObject* self, PyObject* arg)
{
    QSslConfiguration* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QSslConfiguration* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setPrivateKey(QSslKey)
    if (Shiboken::Converter< ::QSslKey >::isConvertible(arg)) {
        overloadId = 0; // setPrivateKey(QSslKey)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QSslConfigurationFunc_setPrivateKey_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QSslKey cppArg0 = Shiboken::Converter<QSslKey >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setPrivateKey(QSslKey)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setPrivateKey(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QSslConfigurationFunc_setPrivateKey_TypeError:
        const char* overloads[] = {"PySide.QtNetwork.QSslKey", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtNetwork.QSslConfiguration.setPrivateKey", overloads);
        return 0;
}

static PyObject* Sbk_QSslConfigurationFunc_setProtocol(PyObject* self, PyObject* arg)
{
    QSslConfiguration* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QSslConfiguration* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setProtocol(QSsl::SslProtocol)
    if (Shiboken::Converter< ::QSsl::SslProtocol >::isConvertible(arg)) {
        overloadId = 0; // setProtocol(QSsl::SslProtocol)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QSslConfigurationFunc_setProtocol_TypeError;

    // Call function/method
    {
        {
            QSsl::SslProtocol cppArg0 = Shiboken::Converter<QSsl::SslProtocol >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setProtocol(QSsl::SslProtocol)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setProtocol(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QSslConfigurationFunc_setProtocol_TypeError:
        const char* overloads[] = {"PySide.QtNetwork.QSsl.SslProtocol", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtNetwork.QSslConfiguration.setProtocol", overloads);
        return 0;
}

static PyObject *Sbk_QSslConfiguration___copy__(PyObject *self)
{
        QSslConfiguration* cppSelf = 0;
        if (!Shiboken::Object::isValid(self))
            return 0;
        cppSelf = Shiboken::Converter<QSslConfiguration*>::toCpp(self);
        PyObject* pyResult = 0;
        QSslConfiguration* copy = new QSslConfiguration(*cppSelf);
        pyResult = Shiboken::Converter<QSslConfiguration*>::toPython(copy);
        Shiboken::Object::getOwnership(pyResult);

        if (PyErr_Occurred() || !pyResult) {
            Py_XDECREF(pyResult);
            return 0;
        }
        return pyResult;
}

static PyMethodDef Sbk_QSslConfiguration_methods[] = {
    {"caCertificates", (PyCFunction)Sbk_QSslConfigurationFunc_caCertificates, METH_NOARGS},
    {"ciphers", (PyCFunction)Sbk_QSslConfigurationFunc_ciphers, METH_NOARGS},
    {"defaultConfiguration", (PyCFunction)Sbk_QSslConfigurationFunc_defaultConfiguration, METH_NOARGS|METH_STATIC},
    {"isNull", (PyCFunction)Sbk_QSslConfigurationFunc_isNull, METH_NOARGS},
    {"localCertificate", (PyCFunction)Sbk_QSslConfigurationFunc_localCertificate, METH_NOARGS},
    {"peerCertificate", (PyCFunction)Sbk_QSslConfigurationFunc_peerCertificate, METH_NOARGS},
    {"peerCertificateChain", (PyCFunction)Sbk_QSslConfigurationFunc_peerCertificateChain, METH_NOARGS},
    {"peerVerifyDepth", (PyCFunction)Sbk_QSslConfigurationFunc_peerVerifyDepth, METH_NOARGS},
    {"peerVerifyMode", (PyCFunction)Sbk_QSslConfigurationFunc_peerVerifyMode, METH_NOARGS},
    {"privateKey", (PyCFunction)Sbk_QSslConfigurationFunc_privateKey, METH_NOARGS},
    {"protocol", (PyCFunction)Sbk_QSslConfigurationFunc_protocol, METH_NOARGS},
    {"sessionCipher", (PyCFunction)Sbk_QSslConfigurationFunc_sessionCipher, METH_NOARGS},
    {"setCaCertificates", (PyCFunction)Sbk_QSslConfigurationFunc_setCaCertificates, METH_O},
    {"setCiphers", (PyCFunction)Sbk_QSslConfigurationFunc_setCiphers, METH_O},
    {"setDefaultConfiguration", (PyCFunction)Sbk_QSslConfigurationFunc_setDefaultConfiguration, METH_O|METH_STATIC},
    {"setLocalCertificate", (PyCFunction)Sbk_QSslConfigurationFunc_setLocalCertificate, METH_O},
    {"setPeerVerifyDepth", (PyCFunction)Sbk_QSslConfigurationFunc_setPeerVerifyDepth, METH_O},
    {"setPeerVerifyMode", (PyCFunction)Sbk_QSslConfigurationFunc_setPeerVerifyMode, METH_O},
    {"setPrivateKey", (PyCFunction)Sbk_QSslConfigurationFunc_setPrivateKey, METH_O},
    {"setProtocol", (PyCFunction)Sbk_QSslConfigurationFunc_setProtocol, METH_O},

    {"__copy__", (PyCFunction)Sbk_QSslConfiguration___copy__, METH_NOARGS},
    {0} // Sentinel
};

static int Sbk_QSslConfiguration___nb_bool(PyObject* pyObj)
{
    if (!Shiboken::Object::isValid(pyObj))
        return -1;
    const ::QSslConfiguration* cppSelf = Shiboken::Converter< ::QSslConfiguration*>::toCpp(pyObj);
    int result;
    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
    result = !cppSelf->isNull();
    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
    return result;
}

// type has number operators
static PyNumberMethods Sbk_QSslConfiguration_as_number = {
    /*nb_add*/                  (binaryfunc)0,
    /*nb_subtract*/             (binaryfunc)0,
    /*nb_multiply*/             (binaryfunc)0,
    /*nb_divide*/               (binaryfunc)0,
    /*nb_remainder*/            (binaryfunc)0,
    /*nb_divmod*/               0,
    /*nb_power*/                0,
    /*nb_negative*/             (unaryfunc)0,
    /*nb_positive*/             (unaryfunc)0,
    /*nb_absolute*/             0,
    /*nb_nonzero*/              Sbk_QSslConfiguration___nb_bool,
    /*nb_invert*/               (unaryfunc)0,
    /*nb_lshift*/               (binaryfunc)0,
    /*nb_rshift*/               (binaryfunc)0,
    /*nb_and*/                  (binaryfunc)0,
    /*nb_xor*/                  (binaryfunc)0,
    /*nb_or*/                   (binaryfunc)0,
    /*nb_coerce*/               0,
    /*nb_int*/                  0,
    /*nb_long*/                 0,
    /*nb_float*/                0,
    /*nb_oct*/                  0,
    /*nb_hex*/                  0,
    /*nb_inplace_add*/          (binaryfunc)0,
    /*nb_inplace_subtract*/     (binaryfunc)0,
    /*nb_inplace_multiply*/     (binaryfunc)0,
    /*nb_inplace_divide*/       (binaryfunc)0,
    /*nb_inplace_remainder*/    (binaryfunc)0,
    /*nb_inplace_power*/        0,
    /*nb_inplace_lshift*/       (binaryfunc)0,
    /*nb_inplace_rshift*/       (binaryfunc)0,
    /*nb_inplace_and*/          (binaryfunc)0,
    /*nb_inplace_xor*/          (binaryfunc)0,
    /*nb_inplace_or*/           (binaryfunc)0,
    /*nb_floor_divide*/         0,
    /*nb_true_divide*/          (binaryfunc)0,
    /*nb_inplace_floor_divide*/ 0,
    /*nb_inplace_true_divide*/  0,
    /*nb_index*/                0
};

// Rich comparison
static PyObject* Sbk_QSslConfiguration_richcompare(PyObject* self, PyObject* arg, int op)
{
    PyObject* pyResult = 0;
    QSslConfiguration& cppSelf = *Shiboken::Converter< QSslConfiguration* >::toCpp(self);

    switch (op) {
        case Py_NE:
            if (Shiboken::Converter< ::QSslConfiguration >::isConvertible(arg)) {
                // operator!=(const QSslConfiguration & other) const
                QSslConfiguration cppArg0 = Shiboken::Converter< ::QSslConfiguration >::toCpp(arg);
                pyResult = Shiboken::Converter< bool >::toPython(cppSelf != cppArg0);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_EQ:
            if (Shiboken::Converter< ::QSslConfiguration >::isConvertible(arg)) {
                // operator==(const QSslConfiguration & other) const
                QSslConfiguration cppArg0 = Shiboken::Converter< ::QSslConfiguration >::toCpp(arg);
                pyResult = Shiboken::Converter< bool >::toPython(cppSelf == cppArg0);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            goto Sbk_QSslConfiguration_RichComparison_TypeError;
    }

    if (pyResult && !PyErr_Occurred())
        return pyResult;
    Sbk_QSslConfiguration_RichComparison_TypeError:
    PyErr_SetString(PyExc_NotImplementedError, "operator not implemented.");
    return 0;

}

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QSslConfiguration_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtNetwork.QSslConfiguration",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        &Sbk_QSslConfiguration_as_number,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      Sbk_QSslConfiguration_richcompare,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QSslConfiguration_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&SbkObject_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QSslConfiguration_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern


void init_QSslConfiguration(PyObject* module)
{
    SbkPySide_QtNetworkTypes[SBK_QSSLCONFIGURATION_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QSslConfiguration_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QSslConfiguration_Type);
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QSslConfiguration_Type, &Shiboken::callCppDestructor<QSslConfiguration >);
    Py_INCREF((PyObject*)&Sbk_QSslConfiguration_Type); //Incref due the 'PyModule_AddObject' steals the reference.
    if (PyType_Ready((PyTypeObject*)&Sbk_QSslConfiguration_Type) < 0)
        return;

    Shiboken::ObjectType::setOriginalName(&Sbk_QSslConfiguration_Type, "QSslConfiguration");
    PyModule_AddObject(module, "QSslConfiguration",
        ((PyObject*)&Sbk_QSslConfiguration_Type));


    Shiboken::TypeResolver::createValueTypeResolver<QSslConfiguration >("QSslConfiguration");
    Shiboken::TypeResolver::createObjectTypeResolver<QSslConfiguration >("QSslConfiguration*");
    Shiboken::TypeResolver::createValueTypeResolver<QSslConfiguration >(typeid(QSslConfiguration).name());
    qRegisterMetaType< ::QSslConfiguration >("QSslConfiguration");
}

