/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtnetwork_python.h"

#include "qsslerror_wrapper.h"

// Extra includes
#include <qsslcertificate.h>
#include <qsslerror.h>



// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QSslError_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QSslError >()))
        return -1;

    QSslError* cptr = 0;
    int overloadId = -1;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QSslError", 0, 2, &(pyargs[0]), &(pyargs[1])))
        return -1;

    // Overloaded function decisor
    // 0: QSslError()
    // 1: QSslError(QSslError::SslError)
    // 2: QSslError(QSslError::SslError,QSslCertificate)
    // 3: QSslError(QSslError)
    if (numArgs == 0) {
        overloadId = 0; // QSslError()
    } else if (Shiboken::Converter< ::QSslError::SslError >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 1; // QSslError(QSslError::SslError)
        } else if (numArgs == 2 && Shiboken::Converter< ::QSslCertificate >::isConvertible(pyargs[1])) {
            overloadId = 2; // QSslError(QSslError::SslError,QSslCertificate)
        }
    } else if (numArgs == 1 && Shiboken::Converter< ::QSslError >::isConvertible(pyargs[0])) {
        overloadId = 3; // QSslError(QSslError)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QSslError_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QSslError()
            {

                if(!PyErr_Occurred()) {
                    // QSslError()
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QSslError();
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // QSslError(QSslError::SslError)
            {
                QSslError::SslError cppArg0 = Shiboken::Converter<QSslError::SslError >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QSslError(QSslError::SslError)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QSslError(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 2: // QSslError(QSslError::SslError,QSslCertificate)
            {
                QSslError::SslError cppArg0 = Shiboken::Converter<QSslError::SslError >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return -1;
                QSslCertificate cppArg1 = Shiboken::Converter<QSslCertificate >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // QSslError(QSslError::SslError,QSslCertificate)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QSslError(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 3: // QSslError(QSslError)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QSslError cppArg0 = Shiboken::Converter<QSslError >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QSslError(QSslError)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QSslError(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QSslError >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QSslError_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QSslError_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtNetwork.QSslError.SslError", "PySide.QtNetwork.QSslError.SslError, PySide.QtNetwork.QSslCertificate", "PySide.QtNetwork.QSslError", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtNetwork.QSslError", overloads);
        return -1;
}

static PyObject* Sbk_QSslErrorFunc_certificate(PyObject* self)
{
    QSslError* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QSslError* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // certificate()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QSslCertificate cppResult = const_cast<const QSslError*>(cppSelf)->certificate();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QSslCertificate >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QSslErrorFunc_error(PyObject* self)
{
    QSslError* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QSslError* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // error()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QSslError::SslError cppResult = const_cast<const QSslError*>(cppSelf)->error();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QSslError::SslError >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QSslErrorFunc_errorString(PyObject* self)
{
    QSslError* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QSslError* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // errorString()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = const_cast<const QSslError*>(cppSelf)->errorString();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject *Sbk_QSslError___copy__(PyObject *self)
{
        QSslError* cppSelf = 0;
        if (!Shiboken::Object::isValid(self))
            return 0;
        cppSelf = Shiboken::Converter<QSslError*>::toCpp(self);
        PyObject* pyResult = 0;
        QSslError* copy = new QSslError(*cppSelf);
        pyResult = Shiboken::Converter<QSslError*>::toPython(copy);
        Shiboken::Object::getOwnership(pyResult);

        if (PyErr_Occurred() || !pyResult) {
            Py_XDECREF(pyResult);
            return 0;
        }
        return pyResult;
}

static PyMethodDef Sbk_QSslError_methods[] = {
    {"certificate", (PyCFunction)Sbk_QSslErrorFunc_certificate, METH_NOARGS},
    {"error", (PyCFunction)Sbk_QSslErrorFunc_error, METH_NOARGS},
    {"errorString", (PyCFunction)Sbk_QSslErrorFunc_errorString, METH_NOARGS},

    {"__copy__", (PyCFunction)Sbk_QSslError___copy__, METH_NOARGS},
    {0} // Sentinel
};

// Rich comparison
static PyObject* Sbk_QSslError_richcompare(PyObject* self, PyObject* arg, int op)
{
    PyObject* pyResult = 0;
    QSslError& cppSelf = *Shiboken::Converter< QSslError* >::toCpp(self);

    switch (op) {
        case Py_NE:
            if (Shiboken::Converter< ::QSslError >::isConvertible(arg)) {
                // operator!=(const QSslError & other) const
                QSslError cppArg0 = Shiboken::Converter< ::QSslError >::toCpp(arg);
                pyResult = Shiboken::Converter< bool >::toPython(cppSelf != cppArg0);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_EQ:
            if (Shiboken::Converter< ::QSslError >::isConvertible(arg)) {
                // operator==(const QSslError & other) const
                QSslError cppArg0 = Shiboken::Converter< ::QSslError >::toCpp(arg);
                pyResult = Shiboken::Converter< bool >::toPython(cppSelf == cppArg0);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            goto Sbk_QSslError_RichComparison_TypeError;
    }

    if (pyResult && !PyErr_Occurred())
        return pyResult;
    Sbk_QSslError_RichComparison_TypeError:
    PyErr_SetString(PyExc_NotImplementedError, "operator not implemented.");
    return 0;

}

} // extern "C"

extern "C"
{
static PyObject* Sbk_QSslError__repr__(PyObject* pyObj)
{
    QBuffer buffer;
    buffer.open(QBuffer::ReadWrite);
    QDebug dbg(&buffer);
    dbg << Shiboken::Converter< ::QSslError >::toCpp(pyObj);
    buffer.close();
    return PyString_FromFormat("<PySide.QtNetwork.%s at %p>", buffer.data().constData(), pyObj);
}
} // extern C

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QSslError_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtNetwork.QSslError",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Sbk_QSslError__repr__,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      Sbk_QSslError_richcompare,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QSslError_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&SbkObject_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QSslError_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern


void init_QSslError(PyObject* module)
{
    SbkPySide_QtNetworkTypes[SBK_QSSLERROR_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QSslError_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QSslError_Type);
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QSslError_Type, &Shiboken::callCppDestructor<QSslError >);
    Py_INCREF((PyObject*)&Sbk_QSslError_Type); //Incref due the 'PyModule_AddObject' steals the reference.
    if (PyType_Ready((PyTypeObject*)&Sbk_QSslError_Type) < 0)
        return;

    Shiboken::ObjectType::setOriginalName(&Sbk_QSslError_Type, "QSslError");
    PyModule_AddObject(module, "QSslError",
        ((PyObject*)&Sbk_QSslError_Type));

    // Initialize enums
    PyObject* enumItem;

    // init enum: SslError
    PyTypeObject* SbkPySide_QtNetwork_QSslError_SslError = Shiboken::Enum::newType("PySide.QtNetwork.QSslError.SslError");
    SbkPySide_QtNetworkTypes[SBK_QSSLERROR_SSLERROR_IDX] = SbkPySide_QtNetwork_QSslError_SslError;
    if (PyType_Ready(SbkPySide_QtNetwork_QSslError_SslError) < 0)
        return;
    PyDict_SetItemString(Sbk_QSslError_Type.super.ht_type.tp_dict,
            "SslError",((PyObject*)SbkPySide_QtNetwork_QSslError_SslError));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtNetwork_QSslError_SslError,(long) QSslError::NoError, "NoError");
    PyDict_SetItemString(Sbk_QSslError_Type.super.ht_type.tp_dict,"NoError", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtNetwork_QSslError_SslError->tp_dict,"NoError", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtNetwork_QSslError_SslError,(long) QSslError::UnableToGetIssuerCertificate, "UnableToGetIssuerCertificate");
    PyDict_SetItemString(Sbk_QSslError_Type.super.ht_type.tp_dict,"UnableToGetIssuerCertificate", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtNetwork_QSslError_SslError->tp_dict,"UnableToGetIssuerCertificate", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtNetwork_QSslError_SslError,(long) QSslError::UnableToDecryptCertificateSignature, "UnableToDecryptCertificateSignature");
    PyDict_SetItemString(Sbk_QSslError_Type.super.ht_type.tp_dict,"UnableToDecryptCertificateSignature", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtNetwork_QSslError_SslError->tp_dict,"UnableToDecryptCertificateSignature", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtNetwork_QSslError_SslError,(long) QSslError::UnableToDecodeIssuerPublicKey, "UnableToDecodeIssuerPublicKey");
    PyDict_SetItemString(Sbk_QSslError_Type.super.ht_type.tp_dict,"UnableToDecodeIssuerPublicKey", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtNetwork_QSslError_SslError->tp_dict,"UnableToDecodeIssuerPublicKey", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtNetwork_QSslError_SslError,(long) QSslError::CertificateSignatureFailed, "CertificateSignatureFailed");
    PyDict_SetItemString(Sbk_QSslError_Type.super.ht_type.tp_dict,"CertificateSignatureFailed", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtNetwork_QSslError_SslError->tp_dict,"CertificateSignatureFailed", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtNetwork_QSslError_SslError,(long) QSslError::CertificateNotYetValid, "CertificateNotYetValid");
    PyDict_SetItemString(Sbk_QSslError_Type.super.ht_type.tp_dict,"CertificateNotYetValid", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtNetwork_QSslError_SslError->tp_dict,"CertificateNotYetValid", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtNetwork_QSslError_SslError,(long) QSslError::CertificateExpired, "CertificateExpired");
    PyDict_SetItemString(Sbk_QSslError_Type.super.ht_type.tp_dict,"CertificateExpired", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtNetwork_QSslError_SslError->tp_dict,"CertificateExpired", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtNetwork_QSslError_SslError,(long) QSslError::InvalidNotBeforeField, "InvalidNotBeforeField");
    PyDict_SetItemString(Sbk_QSslError_Type.super.ht_type.tp_dict,"InvalidNotBeforeField", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtNetwork_QSslError_SslError->tp_dict,"InvalidNotBeforeField", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtNetwork_QSslError_SslError,(long) QSslError::InvalidNotAfterField, "InvalidNotAfterField");
    PyDict_SetItemString(Sbk_QSslError_Type.super.ht_type.tp_dict,"InvalidNotAfterField", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtNetwork_QSslError_SslError->tp_dict,"InvalidNotAfterField", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtNetwork_QSslError_SslError,(long) QSslError::SelfSignedCertificate, "SelfSignedCertificate");
    PyDict_SetItemString(Sbk_QSslError_Type.super.ht_type.tp_dict,"SelfSignedCertificate", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtNetwork_QSslError_SslError->tp_dict,"SelfSignedCertificate", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtNetwork_QSslError_SslError,(long) QSslError::SelfSignedCertificateInChain, "SelfSignedCertificateInChain");
    PyDict_SetItemString(Sbk_QSslError_Type.super.ht_type.tp_dict,"SelfSignedCertificateInChain", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtNetwork_QSslError_SslError->tp_dict,"SelfSignedCertificateInChain", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtNetwork_QSslError_SslError,(long) QSslError::UnableToGetLocalIssuerCertificate, "UnableToGetLocalIssuerCertificate");
    PyDict_SetItemString(Sbk_QSslError_Type.super.ht_type.tp_dict,"UnableToGetLocalIssuerCertificate", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtNetwork_QSslError_SslError->tp_dict,"UnableToGetLocalIssuerCertificate", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtNetwork_QSslError_SslError,(long) QSslError::UnableToVerifyFirstCertificate, "UnableToVerifyFirstCertificate");
    PyDict_SetItemString(Sbk_QSslError_Type.super.ht_type.tp_dict,"UnableToVerifyFirstCertificate", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtNetwork_QSslError_SslError->tp_dict,"UnableToVerifyFirstCertificate", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtNetwork_QSslError_SslError,(long) QSslError::CertificateRevoked, "CertificateRevoked");
    PyDict_SetItemString(Sbk_QSslError_Type.super.ht_type.tp_dict,"CertificateRevoked", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtNetwork_QSslError_SslError->tp_dict,"CertificateRevoked", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtNetwork_QSslError_SslError,(long) QSslError::InvalidCaCertificate, "InvalidCaCertificate");
    PyDict_SetItemString(Sbk_QSslError_Type.super.ht_type.tp_dict,"InvalidCaCertificate", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtNetwork_QSslError_SslError->tp_dict,"InvalidCaCertificate", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtNetwork_QSslError_SslError,(long) QSslError::PathLengthExceeded, "PathLengthExceeded");
    PyDict_SetItemString(Sbk_QSslError_Type.super.ht_type.tp_dict,"PathLengthExceeded", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtNetwork_QSslError_SslError->tp_dict,"PathLengthExceeded", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtNetwork_QSslError_SslError,(long) QSslError::InvalidPurpose, "InvalidPurpose");
    PyDict_SetItemString(Sbk_QSslError_Type.super.ht_type.tp_dict,"InvalidPurpose", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtNetwork_QSslError_SslError->tp_dict,"InvalidPurpose", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtNetwork_QSslError_SslError,(long) QSslError::CertificateUntrusted, "CertificateUntrusted");
    PyDict_SetItemString(Sbk_QSslError_Type.super.ht_type.tp_dict,"CertificateUntrusted", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtNetwork_QSslError_SslError->tp_dict,"CertificateUntrusted", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtNetwork_QSslError_SslError,(long) QSslError::CertificateRejected, "CertificateRejected");
    PyDict_SetItemString(Sbk_QSslError_Type.super.ht_type.tp_dict,"CertificateRejected", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtNetwork_QSslError_SslError->tp_dict,"CertificateRejected", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtNetwork_QSslError_SslError,(long) QSslError::SubjectIssuerMismatch, "SubjectIssuerMismatch");
    PyDict_SetItemString(Sbk_QSslError_Type.super.ht_type.tp_dict,"SubjectIssuerMismatch", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtNetwork_QSslError_SslError->tp_dict,"SubjectIssuerMismatch", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtNetwork_QSslError_SslError,(long) QSslError::AuthorityIssuerSerialNumberMismatch, "AuthorityIssuerSerialNumberMismatch");
    PyDict_SetItemString(Sbk_QSslError_Type.super.ht_type.tp_dict,"AuthorityIssuerSerialNumberMismatch", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtNetwork_QSslError_SslError->tp_dict,"AuthorityIssuerSerialNumberMismatch", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtNetwork_QSslError_SslError,(long) QSslError::NoPeerCertificate, "NoPeerCertificate");
    PyDict_SetItemString(Sbk_QSslError_Type.super.ht_type.tp_dict,"NoPeerCertificate", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtNetwork_QSslError_SslError->tp_dict,"NoPeerCertificate", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtNetwork_QSslError_SslError,(long) QSslError::HostNameMismatch, "HostNameMismatch");
    PyDict_SetItemString(Sbk_QSslError_Type.super.ht_type.tp_dict,"HostNameMismatch", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtNetwork_QSslError_SslError->tp_dict,"HostNameMismatch", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtNetwork_QSslError_SslError,(long) QSslError::NoSslSupport, "NoSslSupport");
    PyDict_SetItemString(Sbk_QSslError_Type.super.ht_type.tp_dict,"NoSslSupport", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtNetwork_QSslError_SslError->tp_dict,"NoSslSupport", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtNetwork_QSslError_SslError,(long) QSslError::UnspecifiedError, "UnspecifiedError");
    PyDict_SetItemString(Sbk_QSslError_Type.super.ht_type.tp_dict,"UnspecifiedError", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtNetwork_QSslError_SslError->tp_dict,"UnspecifiedError", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QSslError::SslError");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::SslError");
    // end of enum SslError


    Shiboken::TypeResolver::createValueTypeResolver<QSslError >("QSslError");
    Shiboken::TypeResolver::createObjectTypeResolver<QSslError >("QSslError*");
    Shiboken::TypeResolver::createValueTypeResolver<QSslError >(typeid(QSslError).name());
    qRegisterMetaType< ::QSslError >("QSslError");
    qRegisterMetaType< ::QSslError::SslError >("QSslError::SslError");
}

