/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtwebkit_python.h"

#include "qwebhistoryitem_wrapper.h"

// Extra includes
#include <qdatetime.h>
#include <qicon.h>
#include <qurl.h>
#include <qwebhistory.h>



// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QWebHistoryItem_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QWebHistoryItem >()))
        return -1;

    QWebHistoryItem* cptr = 0;
    int overloadId = -1;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QWebHistoryItem", 1, 1, &(pyargs[0])))
        return -1;

    // Overloaded function decisor
    // 0: QWebHistoryItem(QWebHistoryItem)
    if (numArgs == 1 && Shiboken::Converter< ::QWebHistoryItem >::isConvertible(pyargs[0])) {
        overloadId = 0; // QWebHistoryItem(QWebHistoryItem)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWebHistoryItem_Init_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(pyargs[0]))
                return -1;
            QWebHistoryItem cppArg0 = Shiboken::Converter<QWebHistoryItem >::toCpp(pyargs[0]);

            if(!PyErr_Occurred()) {
                // QWebHistoryItem(QWebHistoryItem)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new QWebHistoryItem(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QWebHistoryItem >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QWebHistoryItem_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QWebHistoryItem_Init_TypeError:
        const char* overloads[] = {"PySide.QtWebKit.QWebHistoryItem", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtWebKit.QWebHistoryItem", overloads);
        return -1;
}

static PyObject* Sbk_QWebHistoryItemFunc_icon(PyObject* self)
{
    QWebHistoryItem* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWebHistoryItem* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // icon()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QIcon cppResult = const_cast<const QWebHistoryItem*>(cppSelf)->icon();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QIcon >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QWebHistoryItemFunc_isValid(PyObject* self)
{
    QWebHistoryItem* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWebHistoryItem* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isValid()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QWebHistoryItem*>(cppSelf)->isValid();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QWebHistoryItemFunc_lastVisited(PyObject* self)
{
    QWebHistoryItem* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWebHistoryItem* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // lastVisited()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QDateTime cppResult = const_cast<const QWebHistoryItem*>(cppSelf)->lastVisited();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QDateTime >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QWebHistoryItemFunc_originalUrl(PyObject* self)
{
    QWebHistoryItem* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWebHistoryItem* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // originalUrl()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QUrl cppResult = const_cast<const QWebHistoryItem*>(cppSelf)->originalUrl();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QUrl >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QWebHistoryItemFunc_setUserData(PyObject* self, PyObject* arg)
{
    QWebHistoryItem* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWebHistoryItem* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setUserData(QVariant)
    if (Shiboken::Converter< QVariant >::isConvertible(arg)) {
        overloadId = 0; // setUserData(QVariant)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWebHistoryItemFunc_setUserData_TypeError;

    // Call function/method
    {
        {
            QVariant cppArg0 = Shiboken::Converter<QVariant >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setUserData(QVariant)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setUserData(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWebHistoryItemFunc_setUserData_TypeError:
        const char* overloads[] = {"QVariant", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtWebKit.QWebHistoryItem.setUserData", overloads);
        return 0;
}

static PyObject* Sbk_QWebHistoryItemFunc_title(PyObject* self)
{
    QWebHistoryItem* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWebHistoryItem* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // title()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = const_cast<const QWebHistoryItem*>(cppSelf)->title();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QWebHistoryItemFunc_url(PyObject* self)
{
    QWebHistoryItem* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWebHistoryItem* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // url()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QUrl cppResult = const_cast<const QWebHistoryItem*>(cppSelf)->url();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QUrl >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QWebHistoryItemFunc_userData(PyObject* self)
{
    QWebHistoryItem* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWebHistoryItem* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // userData()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QVariant cppResult = const_cast<const QWebHistoryItem*>(cppSelf)->userData();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QVariant >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject *Sbk_QWebHistoryItem___copy__(PyObject *self)
{
        QWebHistoryItem* cppSelf = 0;
        if (!Shiboken::Object::isValid(self))
            return 0;
        cppSelf = Shiboken::Converter<QWebHistoryItem*>::toCpp(self);
        PyObject* pyResult = 0;
        QWebHistoryItem* copy = new QWebHistoryItem(*cppSelf);
        pyResult = Shiboken::Converter<QWebHistoryItem*>::toPython(copy);
        Shiboken::Object::getOwnership(pyResult);

        if (PyErr_Occurred() || !pyResult) {
            Py_XDECREF(pyResult);
            return 0;
        }
        return pyResult;
}

static PyMethodDef Sbk_QWebHistoryItem_methods[] = {
    {"icon", (PyCFunction)Sbk_QWebHistoryItemFunc_icon, METH_NOARGS},
    {"isValid", (PyCFunction)Sbk_QWebHistoryItemFunc_isValid, METH_NOARGS},
    {"lastVisited", (PyCFunction)Sbk_QWebHistoryItemFunc_lastVisited, METH_NOARGS},
    {"originalUrl", (PyCFunction)Sbk_QWebHistoryItemFunc_originalUrl, METH_NOARGS},
    {"setUserData", (PyCFunction)Sbk_QWebHistoryItemFunc_setUserData, METH_O},
    {"title", (PyCFunction)Sbk_QWebHistoryItemFunc_title, METH_NOARGS},
    {"url", (PyCFunction)Sbk_QWebHistoryItemFunc_url, METH_NOARGS},
    {"userData", (PyCFunction)Sbk_QWebHistoryItemFunc_userData, METH_NOARGS},

    {"__copy__", (PyCFunction)Sbk_QWebHistoryItem___copy__, METH_NOARGS},
    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QWebHistoryItem_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtWebKit.QWebHistoryItem",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QWebHistoryItem_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&SbkObject_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QWebHistoryItem_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern


void init_QWebHistoryItem(PyObject* module)
{
    SbkPySide_QtWebKitTypes[SBK_QWEBHISTORYITEM_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QWebHistoryItem_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QWebHistoryItem_Type);
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QWebHistoryItem_Type, &Shiboken::callCppDestructor<QWebHistoryItem >);
    Py_INCREF((PyObject*)&Sbk_QWebHistoryItem_Type); //Incref due the 'PyModule_AddObject' steals the reference.
    if (PyType_Ready((PyTypeObject*)&Sbk_QWebHistoryItem_Type) < 0)
        return;

    Shiboken::ObjectType::setOriginalName(&Sbk_QWebHistoryItem_Type, "QWebHistoryItem");
    PyModule_AddObject(module, "QWebHistoryItem",
        ((PyObject*)&Sbk_QWebHistoryItem_Type));


    Shiboken::TypeResolver::createValueTypeResolver<QWebHistoryItem >("QWebHistoryItem");
    Shiboken::TypeResolver::createObjectTypeResolver<QWebHistoryItem >("QWebHistoryItem*");
    Shiboken::TypeResolver::createValueTypeResolver<QWebHistoryItem >(typeid(QWebHistoryItem).name());
    qRegisterMetaType< ::QWebHistoryItem* >("QWebHistoryItem*");
}

