/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtxml_python.h"

#include "qdomnode_wrapper.h"

// Extra includes
#include <qdom.h>
#include <qtextstream.h>



// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QDomNode_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QDomNode >()))
        return -1;

    QDomNode* cptr = 0;
    int overloadId = -1;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QDomNode", 0, 1, &(pyargs[0])))
        return -1;

    // Overloaded function decisor
    // 0: QDomNode()
    // 1: QDomNode(QDomNode)
    if (numArgs == 0) {
        overloadId = 0; // QDomNode()
    } else if (numArgs == 1 && Shiboken::Converter< ::QDomNode >::isConvertible(pyargs[0])) {
        overloadId = 1; // QDomNode(QDomNode)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QDomNode_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QDomNode()
            {

                if(!PyErr_Occurred()) {
                    // QDomNode()
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QDomNode();
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // QDomNode(QDomNode)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QDomNode cppArg0 = Shiboken::Converter<QDomNode >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QDomNode(QDomNode)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QDomNode(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QDomNode >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QDomNode_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QDomNode_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtXml.QDomNode", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtXml.QDomNode", overloads);
        return -1;
}

static PyObject* Sbk_QDomNodeFunc_appendChild(PyObject* self, PyObject* arg)
{
    QDomNode* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDomNode* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: appendChild(QDomNode)
    if (Shiboken::Converter< ::QDomNode >::isConvertible(arg)) {
        overloadId = 0; // appendChild(QDomNode)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QDomNodeFunc_appendChild_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QDomNode cppArg0 = Shiboken::Converter<QDomNode >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // appendChild(QDomNode)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QDomNode cppResult = cppSelf->appendChild(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QDomNode >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QDomNodeFunc_appendChild_TypeError:
        const char* overloads[] = {"PySide.QtXml.QDomNode", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtXml.QDomNode.appendChild", overloads);
        return 0;
}

static PyObject* Sbk_QDomNodeFunc_attributes(PyObject* self)
{
    QDomNode* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDomNode* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // attributes()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QDomNamedNodeMap cppResult = const_cast<const QDomNode*>(cppSelf)->attributes();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QDomNamedNodeMap >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QDomNodeFunc_childNodes(PyObject* self)
{
    QDomNode* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDomNode* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // childNodes()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QDomNodeList cppResult = const_cast<const QDomNode*>(cppSelf)->childNodes();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QDomNodeList >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QDomNodeFunc_clear(PyObject* self)
{
    QDomNode* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDomNode* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // clear()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->clear();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QDomNodeFunc_cloneNode(PyObject* self, PyObject* args, PyObject* kwds)
{
    QDomNode* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDomNode* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtXml.QDomNode.cloneNode(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:cloneNode", &(pyargs[0])))
        return 0;


    // Overloaded function decisor
    // 0: cloneNode(bool)const
    if (numArgs == 0) {
        overloadId = 0; // cloneNode(bool)const
    } else if (SbkNumber_Check(pyargs[0])) {
        overloadId = 0; // cloneNode(bool)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QDomNodeFunc_cloneNode_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "deep");
                if (value) {
                    if (pyargs[0])
                        errorArgName = "deep";
                    else if (SbkNumber_Check(value))
                        pyargs[0] = value;
                    else
                        goto Sbk_QDomNodeFunc_cloneNode_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtXml.QDomNode.cloneNode(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            bool cppArg0 = pyargs[0] ? Shiboken::Converter<bool >::toCpp(pyargs[0]) : true;

            if(!PyErr_Occurred()) {
                // cloneNode(bool)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QDomNode cppResult = const_cast<const QDomNode*>(cppSelf)->cloneNode(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QDomNode >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QDomNodeFunc_cloneNode_TypeError:
        const char* overloads[] = {"bool = true", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtXml.QDomNode.cloneNode", overloads);
        return 0;
}

static PyObject* Sbk_QDomNodeFunc_columnNumber(PyObject* self)
{
    QDomNode* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDomNode* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // columnNumber()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QDomNode*>(cppSelf)->columnNumber();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QDomNodeFunc_firstChild(PyObject* self)
{
    QDomNode* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDomNode* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // firstChild()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QDomNode cppResult = const_cast<const QDomNode*>(cppSelf)->firstChild();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QDomNode >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QDomNodeFunc_firstChildElement(PyObject* self, PyObject* args, PyObject* kwds)
{
    QDomNode* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDomNode* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtXml.QDomNode.firstChildElement(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:firstChildElement", &(pyargs[0])))
        return 0;


    // Overloaded function decisor
    // 0: firstChildElement(QString)const
    if (numArgs == 0) {
        overloadId = 0; // firstChildElement(QString)const
    } else if (Shiboken::Converter< QString >::isConvertible(pyargs[0])) {
        overloadId = 0; // firstChildElement(QString)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QDomNodeFunc_firstChildElement_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "tagName");
                if (value) {
                    if (pyargs[0])
                        errorArgName = "tagName";
                    else if (Shiboken::Converter< QString >::isConvertible(value))
                        pyargs[0] = value;
                    else
                        goto Sbk_QDomNodeFunc_firstChildElement_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtXml.QDomNode.firstChildElement(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QString cppArg0 = pyargs[0] ? Shiboken::Converter<QString >::toCpp(pyargs[0]) : QString();

            if(!PyErr_Occurred()) {
                // firstChildElement(QString)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QDomElement cppResult = const_cast<const QDomNode*>(cppSelf)->firstChildElement(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QDomElement >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QDomNodeFunc_firstChildElement_TypeError:
        const char* overloads[] = {"QString = QString()", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtXml.QDomNode.firstChildElement", overloads);
        return 0;
}

static PyObject* Sbk_QDomNodeFunc_hasAttributes(PyObject* self)
{
    QDomNode* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDomNode* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // hasAttributes()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QDomNode*>(cppSelf)->hasAttributes();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QDomNodeFunc_hasChildNodes(PyObject* self)
{
    QDomNode* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDomNode* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // hasChildNodes()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QDomNode*>(cppSelf)->hasChildNodes();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QDomNodeFunc_insertAfter(PyObject* self, PyObject* args)
{
    QDomNode* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDomNode* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "insertAfter", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: insertAfter(QDomNode,QDomNode)
    if (numArgs == 2 && Shiboken::Converter< ::QDomNode >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QDomNode >::isConvertible(pyargs[1])) {
        overloadId = 0; // insertAfter(QDomNode,QDomNode)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QDomNodeFunc_insertAfter_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QDomNode cppArg0 = Shiboken::Converter<QDomNode >::toCpp(pyargs[0]);
            if (!Shiboken::Object::isValid(pyargs[1]))
                return 0;
            QDomNode cppArg1 = Shiboken::Converter<QDomNode >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // insertAfter(QDomNode,QDomNode)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QDomNode cppResult = cppSelf->insertAfter(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QDomNode >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QDomNodeFunc_insertAfter_TypeError:
        const char* overloads[] = {"PySide.QtXml.QDomNode, PySide.QtXml.QDomNode", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtXml.QDomNode.insertAfter", overloads);
        return 0;
}

static PyObject* Sbk_QDomNodeFunc_insertBefore(PyObject* self, PyObject* args)
{
    QDomNode* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDomNode* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "insertBefore", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: insertBefore(QDomNode,QDomNode)
    if (numArgs == 2 && Shiboken::Converter< ::QDomNode >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QDomNode >::isConvertible(pyargs[1])) {
        overloadId = 0; // insertBefore(QDomNode,QDomNode)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QDomNodeFunc_insertBefore_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QDomNode cppArg0 = Shiboken::Converter<QDomNode >::toCpp(pyargs[0]);
            if (!Shiboken::Object::isValid(pyargs[1]))
                return 0;
            QDomNode cppArg1 = Shiboken::Converter<QDomNode >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // insertBefore(QDomNode,QDomNode)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QDomNode cppResult = cppSelf->insertBefore(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QDomNode >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QDomNodeFunc_insertBefore_TypeError:
        const char* overloads[] = {"PySide.QtXml.QDomNode, PySide.QtXml.QDomNode", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtXml.QDomNode.insertBefore", overloads);
        return 0;
}

static PyObject* Sbk_QDomNodeFunc_isAttr(PyObject* self)
{
    QDomNode* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDomNode* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isAttr()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QDomNode*>(cppSelf)->isAttr();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QDomNodeFunc_isCDATASection(PyObject* self)
{
    QDomNode* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDomNode* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isCDATASection()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QDomNode*>(cppSelf)->isCDATASection();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QDomNodeFunc_isCharacterData(PyObject* self)
{
    QDomNode* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDomNode* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isCharacterData()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QDomNode*>(cppSelf)->isCharacterData();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QDomNodeFunc_isComment(PyObject* self)
{
    QDomNode* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDomNode* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isComment()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QDomNode*>(cppSelf)->isComment();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QDomNodeFunc_isDocument(PyObject* self)
{
    QDomNode* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDomNode* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isDocument()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QDomNode*>(cppSelf)->isDocument();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QDomNodeFunc_isDocumentFragment(PyObject* self)
{
    QDomNode* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDomNode* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isDocumentFragment()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QDomNode*>(cppSelf)->isDocumentFragment();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QDomNodeFunc_isDocumentType(PyObject* self)
{
    QDomNode* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDomNode* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isDocumentType()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QDomNode*>(cppSelf)->isDocumentType();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QDomNodeFunc_isElement(PyObject* self)
{
    QDomNode* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDomNode* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isElement()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QDomNode*>(cppSelf)->isElement();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QDomNodeFunc_isEntity(PyObject* self)
{
    QDomNode* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDomNode* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isEntity()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QDomNode*>(cppSelf)->isEntity();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QDomNodeFunc_isEntityReference(PyObject* self)
{
    QDomNode* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDomNode* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isEntityReference()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QDomNode*>(cppSelf)->isEntityReference();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QDomNodeFunc_isNotation(PyObject* self)
{
    QDomNode* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDomNode* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isNotation()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QDomNode*>(cppSelf)->isNotation();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QDomNodeFunc_isNull(PyObject* self)
{
    QDomNode* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDomNode* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isNull()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QDomNode*>(cppSelf)->isNull();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QDomNodeFunc_isProcessingInstruction(PyObject* self)
{
    QDomNode* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDomNode* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isProcessingInstruction()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QDomNode*>(cppSelf)->isProcessingInstruction();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QDomNodeFunc_isSupported(PyObject* self, PyObject* args)
{
    QDomNode* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDomNode* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "isSupported", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: isSupported(QString,QString)const
    if (numArgs == 2 && Shiboken::Converter< QString >::isConvertible(pyargs[0]) && Shiboken::Converter< QString >::isConvertible(pyargs[1])) {
        overloadId = 0; // isSupported(QString,QString)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QDomNodeFunc_isSupported_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            QString cppArg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // isSupported(QString,QString)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QDomNode*>(cppSelf)->isSupported(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QDomNodeFunc_isSupported_TypeError:
        const char* overloads[] = {"QString, QString", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtXml.QDomNode.isSupported", overloads);
        return 0;
}

static PyObject* Sbk_QDomNodeFunc_isText(PyObject* self)
{
    QDomNode* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDomNode* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isText()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QDomNode*>(cppSelf)->isText();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QDomNodeFunc_lastChild(PyObject* self)
{
    QDomNode* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDomNode* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // lastChild()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QDomNode cppResult = const_cast<const QDomNode*>(cppSelf)->lastChild();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QDomNode >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QDomNodeFunc_lastChildElement(PyObject* self, PyObject* args, PyObject* kwds)
{
    QDomNode* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDomNode* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtXml.QDomNode.lastChildElement(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:lastChildElement", &(pyargs[0])))
        return 0;


    // Overloaded function decisor
    // 0: lastChildElement(QString)const
    if (numArgs == 0) {
        overloadId = 0; // lastChildElement(QString)const
    } else if (Shiboken::Converter< QString >::isConvertible(pyargs[0])) {
        overloadId = 0; // lastChildElement(QString)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QDomNodeFunc_lastChildElement_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "tagName");
                if (value) {
                    if (pyargs[0])
                        errorArgName = "tagName";
                    else if (Shiboken::Converter< QString >::isConvertible(value))
                        pyargs[0] = value;
                    else
                        goto Sbk_QDomNodeFunc_lastChildElement_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtXml.QDomNode.lastChildElement(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QString cppArg0 = pyargs[0] ? Shiboken::Converter<QString >::toCpp(pyargs[0]) : QString();

            if(!PyErr_Occurred()) {
                // lastChildElement(QString)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QDomElement cppResult = const_cast<const QDomNode*>(cppSelf)->lastChildElement(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QDomElement >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QDomNodeFunc_lastChildElement_TypeError:
        const char* overloads[] = {"QString = QString()", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtXml.QDomNode.lastChildElement", overloads);
        return 0;
}

static PyObject* Sbk_QDomNodeFunc_lineNumber(PyObject* self)
{
    QDomNode* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDomNode* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // lineNumber()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QDomNode*>(cppSelf)->lineNumber();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QDomNodeFunc_localName(PyObject* self)
{
    QDomNode* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDomNode* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // localName()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = const_cast<const QDomNode*>(cppSelf)->localName();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QDomNodeFunc_namedItem(PyObject* self, PyObject* arg)
{
    QDomNode* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDomNode* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: namedItem(QString)const
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // namedItem(QString)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QDomNodeFunc_namedItem_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // namedItem(QString)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QDomNode cppResult = const_cast<const QDomNode*>(cppSelf)->namedItem(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QDomNode >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QDomNodeFunc_namedItem_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtXml.QDomNode.namedItem", overloads);
        return 0;
}

static PyObject* Sbk_QDomNodeFunc_namespaceURI(PyObject* self)
{
    QDomNode* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDomNode* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // namespaceURI()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = const_cast<const QDomNode*>(cppSelf)->namespaceURI();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QDomNodeFunc_nextSibling(PyObject* self)
{
    QDomNode* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDomNode* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // nextSibling()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QDomNode cppResult = const_cast<const QDomNode*>(cppSelf)->nextSibling();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QDomNode >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QDomNodeFunc_nextSiblingElement(PyObject* self, PyObject* args, PyObject* kwds)
{
    QDomNode* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDomNode* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtXml.QDomNode.nextSiblingElement(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:nextSiblingElement", &(pyargs[0])))
        return 0;


    // Overloaded function decisor
    // 0: nextSiblingElement(QString)const
    if (numArgs == 0) {
        overloadId = 0; // nextSiblingElement(QString)const
    } else if (Shiboken::Converter< QString >::isConvertible(pyargs[0])) {
        overloadId = 0; // nextSiblingElement(QString)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QDomNodeFunc_nextSiblingElement_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "taName");
                if (value) {
                    if (pyargs[0])
                        errorArgName = "taName";
                    else if (Shiboken::Converter< QString >::isConvertible(value))
                        pyargs[0] = value;
                    else
                        goto Sbk_QDomNodeFunc_nextSiblingElement_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtXml.QDomNode.nextSiblingElement(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QString cppArg0 = pyargs[0] ? Shiboken::Converter<QString >::toCpp(pyargs[0]) : QString();

            if(!PyErr_Occurred()) {
                // nextSiblingElement(QString)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QDomElement cppResult = const_cast<const QDomNode*>(cppSelf)->nextSiblingElement(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QDomElement >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QDomNodeFunc_nextSiblingElement_TypeError:
        const char* overloads[] = {"QString = QString()", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtXml.QDomNode.nextSiblingElement", overloads);
        return 0;
}

static PyObject* Sbk_QDomNodeFunc_nodeName(PyObject* self)
{
    QDomNode* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDomNode* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // nodeName()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = const_cast<const QDomNode*>(cppSelf)->nodeName();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QDomNodeFunc_nodeType(PyObject* self)
{
    QDomNode* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDomNode* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // nodeType()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QDomNode::NodeType cppResult = const_cast<const QDomNode*>(cppSelf)->nodeType();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QDomNode::NodeType >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QDomNodeFunc_nodeValue(PyObject* self)
{
    QDomNode* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDomNode* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // nodeValue()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = const_cast<const QDomNode*>(cppSelf)->nodeValue();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QDomNodeFunc_normalize(PyObject* self)
{
    QDomNode* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDomNode* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // normalize()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->normalize();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QDomNodeFunc_ownerDocument(PyObject* self)
{
    QDomNode* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDomNode* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // ownerDocument()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QDomDocument cppResult = const_cast<const QDomNode*>(cppSelf)->ownerDocument();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QDomDocument >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QDomNodeFunc_parentNode(PyObject* self)
{
    QDomNode* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDomNode* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // parentNode()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QDomNode cppResult = const_cast<const QDomNode*>(cppSelf)->parentNode();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QDomNode >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QDomNodeFunc_prefix(PyObject* self)
{
    QDomNode* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDomNode* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // prefix()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = const_cast<const QDomNode*>(cppSelf)->prefix();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QDomNodeFunc_previousSibling(PyObject* self)
{
    QDomNode* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDomNode* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // previousSibling()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QDomNode cppResult = const_cast<const QDomNode*>(cppSelf)->previousSibling();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QDomNode >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QDomNodeFunc_previousSiblingElement(PyObject* self, PyObject* args, PyObject* kwds)
{
    QDomNode* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDomNode* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtXml.QDomNode.previousSiblingElement(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:previousSiblingElement", &(pyargs[0])))
        return 0;


    // Overloaded function decisor
    // 0: previousSiblingElement(QString)const
    if (numArgs == 0) {
        overloadId = 0; // previousSiblingElement(QString)const
    } else if (Shiboken::Converter< QString >::isConvertible(pyargs[0])) {
        overloadId = 0; // previousSiblingElement(QString)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QDomNodeFunc_previousSiblingElement_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "tagName");
                if (value) {
                    if (pyargs[0])
                        errorArgName = "tagName";
                    else if (Shiboken::Converter< QString >::isConvertible(value))
                        pyargs[0] = value;
                    else
                        goto Sbk_QDomNodeFunc_previousSiblingElement_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtXml.QDomNode.previousSiblingElement(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QString cppArg0 = pyargs[0] ? Shiboken::Converter<QString >::toCpp(pyargs[0]) : QString();

            if(!PyErr_Occurred()) {
                // previousSiblingElement(QString)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QDomElement cppResult = const_cast<const QDomNode*>(cppSelf)->previousSiblingElement(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QDomElement >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QDomNodeFunc_previousSiblingElement_TypeError:
        const char* overloads[] = {"QString = QString()", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtXml.QDomNode.previousSiblingElement", overloads);
        return 0;
}

static PyObject* Sbk_QDomNodeFunc_removeChild(PyObject* self, PyObject* arg)
{
    QDomNode* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDomNode* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: removeChild(QDomNode)
    if (Shiboken::Converter< ::QDomNode >::isConvertible(arg)) {
        overloadId = 0; // removeChild(QDomNode)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QDomNodeFunc_removeChild_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QDomNode cppArg0 = Shiboken::Converter<QDomNode >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // removeChild(QDomNode)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QDomNode cppResult = cppSelf->removeChild(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QDomNode >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QDomNodeFunc_removeChild_TypeError:
        const char* overloads[] = {"PySide.QtXml.QDomNode", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtXml.QDomNode.removeChild", overloads);
        return 0;
}

static PyObject* Sbk_QDomNodeFunc_replaceChild(PyObject* self, PyObject* args)
{
    QDomNode* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDomNode* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "replaceChild", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: replaceChild(QDomNode,QDomNode)
    if (numArgs == 2 && Shiboken::Converter< ::QDomNode >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QDomNode >::isConvertible(pyargs[1])) {
        overloadId = 0; // replaceChild(QDomNode,QDomNode)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QDomNodeFunc_replaceChild_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QDomNode cppArg0 = Shiboken::Converter<QDomNode >::toCpp(pyargs[0]);
            if (!Shiboken::Object::isValid(pyargs[1]))
                return 0;
            QDomNode cppArg1 = Shiboken::Converter<QDomNode >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // replaceChild(QDomNode,QDomNode)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QDomNode cppResult = cppSelf->replaceChild(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QDomNode >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QDomNodeFunc_replaceChild_TypeError:
        const char* overloads[] = {"PySide.QtXml.QDomNode, PySide.QtXml.QDomNode", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtXml.QDomNode.replaceChild", overloads);
        return 0;
}

static PyObject* Sbk_QDomNodeFunc_save(PyObject* self, PyObject* args)
{
    QDomNode* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDomNode* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "save", 2, 3, &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: save(QTextStream&,int)const
    // 1: save(QTextStream&,int,QDomNode::EncodingPolicy)const
    if (numArgs >= 2 && Shiboken::Converter< ::QTextStream & >::isConvertible(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        if (numArgs == 2) {
            overloadId = 0; // save(QTextStream&,int)const
        } else if (numArgs == 3 && Shiboken::Converter< ::QDomNode::EncodingPolicy >::isConvertible(pyargs[2])) {
            overloadId = 1; // save(QTextStream&,int,QDomNode::EncodingPolicy)const
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QDomNodeFunc_save_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // save(QTextStream&,int)const
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QTextStream & cppArg0 = Shiboken::Converter<QTextStream & >::toCpp(pyargs[0]);
                int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // save(QTextStream&,int)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    const_cast<const QDomNode*>(cppSelf)->save(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // save(QTextStream&,int,QDomNode::EncodingPolicy)const
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QTextStream & cppArg0 = Shiboken::Converter<QTextStream & >::toCpp(pyargs[0]);
                int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                QDomNode::EncodingPolicy cppArg2 = Shiboken::Converter<QDomNode::EncodingPolicy >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                    // save(QTextStream&,int,QDomNode::EncodingPolicy)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    const_cast<const QDomNode*>(cppSelf)->save(cppArg0, cppArg1, cppArg2);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QDomNodeFunc_save_TypeError:
        const char* overloads[] = {"PySide.QtCore.QTextStream, int", "PySide.QtCore.QTextStream, int, PySide.QtXml.QDomNode.EncodingPolicy", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtXml.QDomNode.save", overloads);
        return 0;
}

static PyObject* Sbk_QDomNodeFunc_setNodeValue(PyObject* self, PyObject* arg)
{
    QDomNode* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDomNode* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setNodeValue(QString)
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // setNodeValue(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QDomNodeFunc_setNodeValue_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setNodeValue(QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setNodeValue(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QDomNodeFunc_setNodeValue_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtXml.QDomNode.setNodeValue", overloads);
        return 0;
}

static PyObject* Sbk_QDomNodeFunc_setPrefix(PyObject* self, PyObject* arg)
{
    QDomNode* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDomNode* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setPrefix(QString)
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // setPrefix(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QDomNodeFunc_setPrefix_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setPrefix(QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setPrefix(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QDomNodeFunc_setPrefix_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtXml.QDomNode.setPrefix", overloads);
        return 0;
}

static PyObject* Sbk_QDomNodeFunc_toAttr(PyObject* self)
{
    QDomNode* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDomNode* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // toAttr()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QDomAttr cppResult = const_cast<const QDomNode*>(cppSelf)->toAttr();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QDomAttr >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QDomNodeFunc_toCDATASection(PyObject* self)
{
    QDomNode* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDomNode* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // toCDATASection()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QDomCDATASection cppResult = const_cast<const QDomNode*>(cppSelf)->toCDATASection();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QDomCDATASection >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QDomNodeFunc_toCharacterData(PyObject* self)
{
    QDomNode* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDomNode* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // toCharacterData()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QDomCharacterData cppResult = const_cast<const QDomNode*>(cppSelf)->toCharacterData();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QDomCharacterData >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QDomNodeFunc_toComment(PyObject* self)
{
    QDomNode* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDomNode* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // toComment()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QDomComment cppResult = const_cast<const QDomNode*>(cppSelf)->toComment();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QDomComment >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QDomNodeFunc_toDocument(PyObject* self)
{
    QDomNode* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDomNode* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // toDocument()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QDomDocument cppResult = const_cast<const QDomNode*>(cppSelf)->toDocument();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QDomDocument >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QDomNodeFunc_toDocumentFragment(PyObject* self)
{
    QDomNode* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDomNode* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // toDocumentFragment()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QDomDocumentFragment cppResult = const_cast<const QDomNode*>(cppSelf)->toDocumentFragment();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QDomDocumentFragment >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QDomNodeFunc_toDocumentType(PyObject* self)
{
    QDomNode* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDomNode* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // toDocumentType()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QDomDocumentType cppResult = const_cast<const QDomNode*>(cppSelf)->toDocumentType();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QDomDocumentType >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QDomNodeFunc_toElement(PyObject* self)
{
    QDomNode* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDomNode* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // toElement()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QDomElement cppResult = const_cast<const QDomNode*>(cppSelf)->toElement();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QDomElement >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QDomNodeFunc_toEntity(PyObject* self)
{
    QDomNode* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDomNode* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // toEntity()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QDomEntity cppResult = const_cast<const QDomNode*>(cppSelf)->toEntity();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QDomEntity >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QDomNodeFunc_toEntityReference(PyObject* self)
{
    QDomNode* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDomNode* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // toEntityReference()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QDomEntityReference cppResult = const_cast<const QDomNode*>(cppSelf)->toEntityReference();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QDomEntityReference >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QDomNodeFunc_toNotation(PyObject* self)
{
    QDomNode* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDomNode* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // toNotation()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QDomNotation cppResult = const_cast<const QDomNode*>(cppSelf)->toNotation();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QDomNotation >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QDomNodeFunc_toProcessingInstruction(PyObject* self)
{
    QDomNode* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDomNode* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // toProcessingInstruction()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QDomProcessingInstruction cppResult = const_cast<const QDomNode*>(cppSelf)->toProcessingInstruction();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QDomProcessingInstruction >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QDomNodeFunc_toText(PyObject* self)
{
    QDomNode* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDomNode* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // toText()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QDomText cppResult = const_cast<const QDomNode*>(cppSelf)->toText();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QDomText >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject *Sbk_QDomNode___copy__(PyObject *self)
{
        QDomNode* cppSelf = 0;
        if (!Shiboken::Object::isValid(self))
            return 0;
        cppSelf = Shiboken::Converter<QDomNode*>::toCpp(self);
        PyObject* pyResult = 0;
        QDomNode* copy = new QDomNode(*cppSelf);
        pyResult = Shiboken::Converter<QDomNode*>::toPython(copy);
        Shiboken::Object::getOwnership(pyResult);

        if (PyErr_Occurred() || !pyResult) {
            Py_XDECREF(pyResult);
            return 0;
        }
        return pyResult;
}

static PyMethodDef Sbk_QDomNode_methods[] = {
    {"appendChild", (PyCFunction)Sbk_QDomNodeFunc_appendChild, METH_O},
    {"attributes", (PyCFunction)Sbk_QDomNodeFunc_attributes, METH_NOARGS},
    {"childNodes", (PyCFunction)Sbk_QDomNodeFunc_childNodes, METH_NOARGS},
    {"clear", (PyCFunction)Sbk_QDomNodeFunc_clear, METH_NOARGS},
    {"cloneNode", (PyCFunction)Sbk_QDomNodeFunc_cloneNode, METH_VARARGS|METH_KEYWORDS},
    {"columnNumber", (PyCFunction)Sbk_QDomNodeFunc_columnNumber, METH_NOARGS},
    {"firstChild", (PyCFunction)Sbk_QDomNodeFunc_firstChild, METH_NOARGS},
    {"firstChildElement", (PyCFunction)Sbk_QDomNodeFunc_firstChildElement, METH_VARARGS|METH_KEYWORDS},
    {"hasAttributes", (PyCFunction)Sbk_QDomNodeFunc_hasAttributes, METH_NOARGS},
    {"hasChildNodes", (PyCFunction)Sbk_QDomNodeFunc_hasChildNodes, METH_NOARGS},
    {"insertAfter", (PyCFunction)Sbk_QDomNodeFunc_insertAfter, METH_VARARGS},
    {"insertBefore", (PyCFunction)Sbk_QDomNodeFunc_insertBefore, METH_VARARGS},
    {"isAttr", (PyCFunction)Sbk_QDomNodeFunc_isAttr, METH_NOARGS},
    {"isCDATASection", (PyCFunction)Sbk_QDomNodeFunc_isCDATASection, METH_NOARGS},
    {"isCharacterData", (PyCFunction)Sbk_QDomNodeFunc_isCharacterData, METH_NOARGS},
    {"isComment", (PyCFunction)Sbk_QDomNodeFunc_isComment, METH_NOARGS},
    {"isDocument", (PyCFunction)Sbk_QDomNodeFunc_isDocument, METH_NOARGS},
    {"isDocumentFragment", (PyCFunction)Sbk_QDomNodeFunc_isDocumentFragment, METH_NOARGS},
    {"isDocumentType", (PyCFunction)Sbk_QDomNodeFunc_isDocumentType, METH_NOARGS},
    {"isElement", (PyCFunction)Sbk_QDomNodeFunc_isElement, METH_NOARGS},
    {"isEntity", (PyCFunction)Sbk_QDomNodeFunc_isEntity, METH_NOARGS},
    {"isEntityReference", (PyCFunction)Sbk_QDomNodeFunc_isEntityReference, METH_NOARGS},
    {"isNotation", (PyCFunction)Sbk_QDomNodeFunc_isNotation, METH_NOARGS},
    {"isNull", (PyCFunction)Sbk_QDomNodeFunc_isNull, METH_NOARGS},
    {"isProcessingInstruction", (PyCFunction)Sbk_QDomNodeFunc_isProcessingInstruction, METH_NOARGS},
    {"isSupported", (PyCFunction)Sbk_QDomNodeFunc_isSupported, METH_VARARGS},
    {"isText", (PyCFunction)Sbk_QDomNodeFunc_isText, METH_NOARGS},
    {"lastChild", (PyCFunction)Sbk_QDomNodeFunc_lastChild, METH_NOARGS},
    {"lastChildElement", (PyCFunction)Sbk_QDomNodeFunc_lastChildElement, METH_VARARGS|METH_KEYWORDS},
    {"lineNumber", (PyCFunction)Sbk_QDomNodeFunc_lineNumber, METH_NOARGS},
    {"localName", (PyCFunction)Sbk_QDomNodeFunc_localName, METH_NOARGS},
    {"namedItem", (PyCFunction)Sbk_QDomNodeFunc_namedItem, METH_O},
    {"namespaceURI", (PyCFunction)Sbk_QDomNodeFunc_namespaceURI, METH_NOARGS},
    {"nextSibling", (PyCFunction)Sbk_QDomNodeFunc_nextSibling, METH_NOARGS},
    {"nextSiblingElement", (PyCFunction)Sbk_QDomNodeFunc_nextSiblingElement, METH_VARARGS|METH_KEYWORDS},
    {"nodeName", (PyCFunction)Sbk_QDomNodeFunc_nodeName, METH_NOARGS},
    {"nodeType", (PyCFunction)Sbk_QDomNodeFunc_nodeType, METH_NOARGS},
    {"nodeValue", (PyCFunction)Sbk_QDomNodeFunc_nodeValue, METH_NOARGS},
    {"normalize", (PyCFunction)Sbk_QDomNodeFunc_normalize, METH_NOARGS},
    {"ownerDocument", (PyCFunction)Sbk_QDomNodeFunc_ownerDocument, METH_NOARGS},
    {"parentNode", (PyCFunction)Sbk_QDomNodeFunc_parentNode, METH_NOARGS},
    {"prefix", (PyCFunction)Sbk_QDomNodeFunc_prefix, METH_NOARGS},
    {"previousSibling", (PyCFunction)Sbk_QDomNodeFunc_previousSibling, METH_NOARGS},
    {"previousSiblingElement", (PyCFunction)Sbk_QDomNodeFunc_previousSiblingElement, METH_VARARGS|METH_KEYWORDS},
    {"removeChild", (PyCFunction)Sbk_QDomNodeFunc_removeChild, METH_O},
    {"replaceChild", (PyCFunction)Sbk_QDomNodeFunc_replaceChild, METH_VARARGS},
    {"save", (PyCFunction)Sbk_QDomNodeFunc_save, METH_VARARGS},
    {"setNodeValue", (PyCFunction)Sbk_QDomNodeFunc_setNodeValue, METH_O},
    {"setPrefix", (PyCFunction)Sbk_QDomNodeFunc_setPrefix, METH_O},
    {"toAttr", (PyCFunction)Sbk_QDomNodeFunc_toAttr, METH_NOARGS},
    {"toCDATASection", (PyCFunction)Sbk_QDomNodeFunc_toCDATASection, METH_NOARGS},
    {"toCharacterData", (PyCFunction)Sbk_QDomNodeFunc_toCharacterData, METH_NOARGS},
    {"toComment", (PyCFunction)Sbk_QDomNodeFunc_toComment, METH_NOARGS},
    {"toDocument", (PyCFunction)Sbk_QDomNodeFunc_toDocument, METH_NOARGS},
    {"toDocumentFragment", (PyCFunction)Sbk_QDomNodeFunc_toDocumentFragment, METH_NOARGS},
    {"toDocumentType", (PyCFunction)Sbk_QDomNodeFunc_toDocumentType, METH_NOARGS},
    {"toElement", (PyCFunction)Sbk_QDomNodeFunc_toElement, METH_NOARGS},
    {"toEntity", (PyCFunction)Sbk_QDomNodeFunc_toEntity, METH_NOARGS},
    {"toEntityReference", (PyCFunction)Sbk_QDomNodeFunc_toEntityReference, METH_NOARGS},
    {"toNotation", (PyCFunction)Sbk_QDomNodeFunc_toNotation, METH_NOARGS},
    {"toProcessingInstruction", (PyCFunction)Sbk_QDomNodeFunc_toProcessingInstruction, METH_NOARGS},
    {"toText", (PyCFunction)Sbk_QDomNodeFunc_toText, METH_NOARGS},

    {"__copy__", (PyCFunction)Sbk_QDomNode___copy__, METH_NOARGS},
    {0} // Sentinel
};

static int Sbk_QDomNode___nb_bool(PyObject* pyObj)
{
    if (!Shiboken::Object::isValid(pyObj))
        return -1;
    const ::QDomNode* cppSelf = Shiboken::Converter< ::QDomNode*>::toCpp(pyObj);
    int result;
    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
    result = !cppSelf->isNull();
    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
    return result;
}

static PyObject* Sbk_QDomNodeFunc___lshift__(PyObject* self, PyObject* arg)
{
    QDomNode* cppSelf = 0;
    bool isReverse = Shiboken::Converter< ::QDomNode >::checkType(arg) && !Shiboken::Converter< ::QDomNode >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDomNode* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && Shiboken::Object::checkType(arg)
        && !PyObject_TypeCheck(arg, self->ob_type)
        && PyObject_HasAttrString(arg, const_cast<char*>("__rlshift__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(arg, const_cast<char*>("__rlshift__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator<<(QTextStream&,QDomNode)
    if (isReverse && Shiboken::Converter< ::QTextStream & >::isConvertible(arg)) {
        overloadId = 0; // operator<<(QTextStream&,QDomNode)
    }

    if (isReverse && overloadId == -1) {
        PyErr_SetString(PyExc_NotImplementedError, "reverse operator not implemented.");
        return 0;
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QDomNodeFunc___lshift___TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QTextStream & cppArg0 = Shiboken::Converter<QTextStream & >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // operator<<(QTextStream&,QDomNode) [reverse operator]
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QTextStream & cppResult = (cppArg0) << (*cppSelf);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QTextStream & >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    } // End of "if (!pyResult)"


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QDomNodeFunc___lshift___TypeError:
        const char* overloads[] = {"PySide.QtCore.QTextStream", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtXml.QDomNode.__lshift__", overloads);
        return 0;
}

// type has number operators
static PyNumberMethods Sbk_QDomNode_as_number = {
    /*nb_add*/                  (binaryfunc)0,
    /*nb_subtract*/             (binaryfunc)0,
    /*nb_multiply*/             (binaryfunc)0,
    /*nb_divide*/               (binaryfunc)0,
    /*nb_remainder*/            (binaryfunc)0,
    /*nb_divmod*/               0,
    /*nb_power*/                0,
    /*nb_negative*/             (unaryfunc)0,
    /*nb_positive*/             (unaryfunc)0,
    /*nb_absolute*/             0,
    /*nb_nonzero*/              Sbk_QDomNode___nb_bool,
    /*nb_invert*/               (unaryfunc)0,
    /*nb_lshift*/               (binaryfunc)Sbk_QDomNodeFunc___lshift__,
    /*nb_rshift*/               (binaryfunc)0,
    /*nb_and*/                  (binaryfunc)0,
    /*nb_xor*/                  (binaryfunc)0,
    /*nb_or*/                   (binaryfunc)0,
    /*nb_coerce*/               0,
    /*nb_int*/                  0,
    /*nb_long*/                 0,
    /*nb_float*/                0,
    /*nb_oct*/                  0,
    /*nb_hex*/                  0,
    /*nb_inplace_add*/          (binaryfunc)0,
    /*nb_inplace_subtract*/     (binaryfunc)0,
    /*nb_inplace_multiply*/     (binaryfunc)0,
    /*nb_inplace_divide*/       (binaryfunc)0,
    /*nb_inplace_remainder*/    (binaryfunc)0,
    /*nb_inplace_power*/        0,
    /*nb_inplace_lshift*/       (binaryfunc)0,
    /*nb_inplace_rshift*/       (binaryfunc)0,
    /*nb_inplace_and*/          (binaryfunc)0,
    /*nb_inplace_xor*/          (binaryfunc)0,
    /*nb_inplace_or*/           (binaryfunc)0,
    /*nb_floor_divide*/         0,
    /*nb_true_divide*/          (binaryfunc)0,
    /*nb_inplace_floor_divide*/ 0,
    /*nb_inplace_true_divide*/  0,
    /*nb_index*/                0
};

// Rich comparison
static PyObject* Sbk_QDomNode_richcompare(PyObject* self, PyObject* arg, int op)
{
    PyObject* pyResult = 0;
    QDomNode& cppSelf = *Shiboken::Converter< QDomNode* >::toCpp(self);

    switch (op) {
        case Py_NE:
            if (Shiboken::Converter< ::QDomNode >::isConvertible(arg)) {
                // operator!=(const QDomNode & arg__1) const
                QDomNode cppArg0 = Shiboken::Converter< ::QDomNode >::toCpp(arg);
                pyResult = Shiboken::Converter< bool >::toPython(cppSelf != cppArg0);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_EQ:
            if (Shiboken::Converter< ::QDomNode >::isConvertible(arg)) {
                // operator==(const QDomNode & arg__1) const
                QDomNode cppArg0 = Shiboken::Converter< ::QDomNode >::toCpp(arg);
                pyResult = Shiboken::Converter< bool >::toPython(cppSelf == cppArg0);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            goto Sbk_QDomNode_RichComparison_TypeError;
    }

    if (pyResult && !PyErr_Occurred())
        return pyResult;
    Sbk_QDomNode_RichComparison_TypeError:
    PyErr_SetString(PyExc_NotImplementedError, "operator not implemented.");
    return 0;

}

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QDomNode_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtXml.QDomNode",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        &Sbk_QDomNode_as_number,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      Sbk_QDomNode_richcompare,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QDomNode_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&SbkObject_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QDomNode_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern


void init_QDomNode(PyObject* module)
{
    SbkPySide_QtXmlTypes[SBK_QDOMNODE_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QDomNode_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QDomNode_Type);
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QDomNode_Type, &Shiboken::callCppDestructor<QDomNode >);
    Py_INCREF((PyObject*)&Sbk_QDomNode_Type); //Incref due the 'PyModule_AddObject' steals the reference.
    if (PyType_Ready((PyTypeObject*)&Sbk_QDomNode_Type) < 0)
        return;

    Shiboken::ObjectType::setOriginalName(&Sbk_QDomNode_Type, "QDomNode");
    PyModule_AddObject(module, "QDomNode",
        ((PyObject*)&Sbk_QDomNode_Type));

    // Initialize enums
    PyObject* enumItem;

    // init enum: NodeType
    PyTypeObject* SbkPySide_QtXml_QDomNode_NodeType = Shiboken::Enum::newType("PySide.QtXml.QDomNode.NodeType");
    SbkPySide_QtXmlTypes[SBK_QDOMNODE_NODETYPE_IDX] = SbkPySide_QtXml_QDomNode_NodeType;
    if (PyType_Ready(SbkPySide_QtXml_QDomNode_NodeType) < 0)
        return;
    PyDict_SetItemString(Sbk_QDomNode_Type.super.ht_type.tp_dict,
            "NodeType",((PyObject*)SbkPySide_QtXml_QDomNode_NodeType));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtXml_QDomNode_NodeType,(long) QDomNode::ElementNode, "ElementNode");
    PyDict_SetItemString(Sbk_QDomNode_Type.super.ht_type.tp_dict,"ElementNode", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtXml_QDomNode_NodeType->tp_dict,"ElementNode", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtXml_QDomNode_NodeType,(long) QDomNode::AttributeNode, "AttributeNode");
    PyDict_SetItemString(Sbk_QDomNode_Type.super.ht_type.tp_dict,"AttributeNode", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtXml_QDomNode_NodeType->tp_dict,"AttributeNode", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtXml_QDomNode_NodeType,(long) QDomNode::TextNode, "TextNode");
    PyDict_SetItemString(Sbk_QDomNode_Type.super.ht_type.tp_dict,"TextNode", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtXml_QDomNode_NodeType->tp_dict,"TextNode", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtXml_QDomNode_NodeType,(long) QDomNode::CDATASectionNode, "CDATASectionNode");
    PyDict_SetItemString(Sbk_QDomNode_Type.super.ht_type.tp_dict,"CDATASectionNode", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtXml_QDomNode_NodeType->tp_dict,"CDATASectionNode", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtXml_QDomNode_NodeType,(long) QDomNode::EntityReferenceNode, "EntityReferenceNode");
    PyDict_SetItemString(Sbk_QDomNode_Type.super.ht_type.tp_dict,"EntityReferenceNode", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtXml_QDomNode_NodeType->tp_dict,"EntityReferenceNode", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtXml_QDomNode_NodeType,(long) QDomNode::EntityNode, "EntityNode");
    PyDict_SetItemString(Sbk_QDomNode_Type.super.ht_type.tp_dict,"EntityNode", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtXml_QDomNode_NodeType->tp_dict,"EntityNode", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtXml_QDomNode_NodeType,(long) QDomNode::ProcessingInstructionNode, "ProcessingInstructionNode");
    PyDict_SetItemString(Sbk_QDomNode_Type.super.ht_type.tp_dict,"ProcessingInstructionNode", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtXml_QDomNode_NodeType->tp_dict,"ProcessingInstructionNode", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtXml_QDomNode_NodeType,(long) QDomNode::CommentNode, "CommentNode");
    PyDict_SetItemString(Sbk_QDomNode_Type.super.ht_type.tp_dict,"CommentNode", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtXml_QDomNode_NodeType->tp_dict,"CommentNode", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtXml_QDomNode_NodeType,(long) QDomNode::DocumentNode, "DocumentNode");
    PyDict_SetItemString(Sbk_QDomNode_Type.super.ht_type.tp_dict,"DocumentNode", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtXml_QDomNode_NodeType->tp_dict,"DocumentNode", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtXml_QDomNode_NodeType,(long) QDomNode::DocumentTypeNode, "DocumentTypeNode");
    PyDict_SetItemString(Sbk_QDomNode_Type.super.ht_type.tp_dict,"DocumentTypeNode", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtXml_QDomNode_NodeType->tp_dict,"DocumentTypeNode", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtXml_QDomNode_NodeType,(long) QDomNode::DocumentFragmentNode, "DocumentFragmentNode");
    PyDict_SetItemString(Sbk_QDomNode_Type.super.ht_type.tp_dict,"DocumentFragmentNode", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtXml_QDomNode_NodeType->tp_dict,"DocumentFragmentNode", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtXml_QDomNode_NodeType,(long) QDomNode::NotationNode, "NotationNode");
    PyDict_SetItemString(Sbk_QDomNode_Type.super.ht_type.tp_dict,"NotationNode", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtXml_QDomNode_NodeType->tp_dict,"NotationNode", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtXml_QDomNode_NodeType,(long) QDomNode::BaseNode, "BaseNode");
    PyDict_SetItemString(Sbk_QDomNode_Type.super.ht_type.tp_dict,"BaseNode", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtXml_QDomNode_NodeType->tp_dict,"BaseNode", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtXml_QDomNode_NodeType,(long) QDomNode::CharacterDataNode, "CharacterDataNode");
    PyDict_SetItemString(Sbk_QDomNode_Type.super.ht_type.tp_dict,"CharacterDataNode", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtXml_QDomNode_NodeType->tp_dict,"CharacterDataNode", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QDomNode::NodeType");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::NodeType");
    // end of enum NodeType

    // init enum: EncodingPolicy
    PyTypeObject* SbkPySide_QtXml_QDomNode_EncodingPolicy = Shiboken::Enum::newType("PySide.QtXml.QDomNode.EncodingPolicy");
    SbkPySide_QtXmlTypes[SBK_QDOMNODE_ENCODINGPOLICY_IDX] = SbkPySide_QtXml_QDomNode_EncodingPolicy;
    if (PyType_Ready(SbkPySide_QtXml_QDomNode_EncodingPolicy) < 0)
        return;
    PyDict_SetItemString(Sbk_QDomNode_Type.super.ht_type.tp_dict,
            "EncodingPolicy",((PyObject*)SbkPySide_QtXml_QDomNode_EncodingPolicy));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtXml_QDomNode_EncodingPolicy,(long) QDomNode::EncodingFromDocument, "EncodingFromDocument");
    PyDict_SetItemString(Sbk_QDomNode_Type.super.ht_type.tp_dict,"EncodingFromDocument", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtXml_QDomNode_EncodingPolicy->tp_dict,"EncodingFromDocument", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtXml_QDomNode_EncodingPolicy,(long) QDomNode::EncodingFromTextStream, "EncodingFromTextStream");
    PyDict_SetItemString(Sbk_QDomNode_Type.super.ht_type.tp_dict,"EncodingFromTextStream", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtXml_QDomNode_EncodingPolicy->tp_dict,"EncodingFromTextStream", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QDomNode::EncodingPolicy");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::EncodingPolicy");
    // end of enum EncodingPolicy


    Shiboken::TypeResolver::createValueTypeResolver<QDomNode >("QDomNode");
    Shiboken::TypeResolver::createObjectTypeResolver<QDomNode >("QDomNode*");
    Shiboken::TypeResolver::createValueTypeResolver<QDomNode >(typeid(QDomNode).name());
    qRegisterMetaType< ::QDomNode >("QDomNode");
    qRegisterMetaType< ::QDomNode::NodeType >("QDomNode::NodeType");
    qRegisterMetaType< ::QDomNode::EncodingPolicy >("QDomNode::EncodingPolicy");
}

