/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include "pyside_qtgui_python.h"

#include "qgraphicsscene_wrapper.h"

// Extra includes
#include <QList>
#include <QVarLengthArray>
#include <qbrush.h>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qevent.h>
#include <qfont.h>
#include <qgraphicsitem.h>
#include <qgraphicsproxywidget.h>
#include <qgraphicsscene.h>
#include <qgraphicssceneevent.h>
#include <qgraphicsview.h>
#include <qgraphicswidget.h>
#include <qline.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qpainter.h>
#include <qpainterpath.h>
#include <qpalette.h>
#include <qpen.h>
#include <qpixmap.h>
#include <qpoint.h>
#include <qpolygon.h>
#include <qrect.h>
#include <qstyle.h>
#include <qthread.h>
#include <qtransform.h>
#include <qwidget.h>


// Native ---------------------------------------------------------

QGraphicsSceneWrapper::QGraphicsSceneWrapper(QObject * parent) : QGraphicsScene(parent) {
    // ... middle
}

QGraphicsSceneWrapper::QGraphicsSceneWrapper(const QRectF & sceneRect, QObject * parent) : QGraphicsScene(sceneRect, parent) {
    // ... middle
}

QGraphicsSceneWrapper::QGraphicsSceneWrapper(qreal x, qreal y, qreal width, qreal height, QObject * parent) : QGraphicsScene(x, y, width, height, parent) {
    // ... middle
}

void QGraphicsSceneWrapper::childEvent(QChildEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "childEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::childEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QChildEvent * >::toPython(arg__1)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QGraphicsSceneWrapper::connectNotify(const char * signal)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "connectNotify"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::connectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QGraphicsSceneWrapper::contextMenuEvent(QGraphicsSceneContextMenuEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "contextMenuEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QGraphicsScene::contextMenuEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QGraphicsSceneContextMenuEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QGraphicsSceneWrapper::customEvent(QEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "customEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::customEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QEvent * >::toPython(arg__1)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QGraphicsSceneWrapper::disconnectNotify(const char * signal)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "disconnectNotify"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::disconnectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QGraphicsSceneWrapper::dragEnterEvent(QGraphicsSceneDragDropEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "dragEnterEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QGraphicsScene::dragEnterEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QGraphicsSceneDragDropEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QGraphicsSceneWrapper::dragLeaveEvent(QGraphicsSceneDragDropEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "dragLeaveEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QGraphicsScene::dragLeaveEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QGraphicsSceneDragDropEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QGraphicsSceneWrapper::dragMoveEvent(QGraphicsSceneDragDropEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "dragMoveEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QGraphicsScene::dragMoveEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QGraphicsSceneDragDropEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QGraphicsSceneWrapper::drawBackground(QPainter * painter, const QRectF & rect)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "drawBackground"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QGraphicsScene::drawBackground(painter, rect);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter< ::QPainter * >::toPython(painter),
        Shiboken::Converter< ::QRectF >::toPython(rect)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QGraphicsSceneWrapper::drawForeground(QPainter * painter, const QRectF & rect)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "drawForeground"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QGraphicsScene::drawForeground(painter, rect);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter< ::QPainter * >::toPython(painter),
        Shiboken::Converter< ::QRectF >::toPython(rect)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QGraphicsSceneWrapper::dropEvent(QGraphicsSceneDragDropEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "dropEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QGraphicsScene::dropEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QGraphicsSceneDragDropEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

bool QGraphicsSceneWrapper::event(QEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return bool(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "event"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QGraphicsScene::event(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QGraphicsScene.event", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
    return cppResult;
}

bool QGraphicsSceneWrapper::eventFilter(QObject * watched, QEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return bool(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "eventFilter"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QGraphicsScene::eventFilter(watched, event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter< ::QObject * >::toPython(watched),
        Shiboken::Converter< ::QEvent * >::toPython(event)
    ));
    bool invalidadeArg2 = PyTuple_GET_ITEM(pyargs, 1)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QGraphicsScene.eventFilter", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    if (invalidadeArg2)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 1));
    return cppResult;
}

void QGraphicsSceneWrapper::focusInEvent(QFocusEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "focusInEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QGraphicsScene::focusInEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QFocusEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QGraphicsSceneWrapper::focusOutEvent(QFocusEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "focusOutEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QGraphicsScene::focusOutEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QFocusEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QGraphicsSceneWrapper::helpEvent(QGraphicsSceneHelpEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "helpEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QGraphicsScene::helpEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QGraphicsSceneHelpEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QGraphicsSceneWrapper::inputMethodEvent(QInputMethodEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "inputMethodEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QGraphicsScene::inputMethodEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QInputMethodEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

QVariant QGraphicsSceneWrapper::inputMethodQuery(Qt::InputMethodQuery query) const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return QVariant(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "inputMethodQuery"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QGraphicsScene::inputMethodQuery(query);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::Qt::InputMethodQuery >::toPython(query)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QVariant(0);
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< QVariant >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QGraphicsScene.inputMethodQuery", "QVariant", pyResult->ob_type->tp_name);
        return QVariant(0);
    }
    QVariant cppResult(Shiboken::Converter< QVariant >::toCpp(pyResult));
    return cppResult;
}

void QGraphicsSceneWrapper::keyPressEvent(QKeyEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "keyPressEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QGraphicsScene::keyPressEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QKeyEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QGraphicsSceneWrapper::keyReleaseEvent(QKeyEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "keyReleaseEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QGraphicsScene::keyReleaseEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QKeyEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QGraphicsSceneWrapper::mouseDoubleClickEvent(QGraphicsSceneMouseEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "mouseDoubleClickEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QGraphicsScene::mouseDoubleClickEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QGraphicsSceneMouseEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QGraphicsSceneWrapper::mouseMoveEvent(QGraphicsSceneMouseEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "mouseMoveEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QGraphicsScene::mouseMoveEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QGraphicsSceneMouseEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QGraphicsSceneWrapper::mousePressEvent(QGraphicsSceneMouseEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "mousePressEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QGraphicsScene::mousePressEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QGraphicsSceneMouseEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QGraphicsSceneWrapper::mouseReleaseEvent(QGraphicsSceneMouseEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "mouseReleaseEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QGraphicsScene::mouseReleaseEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QGraphicsSceneMouseEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QGraphicsSceneWrapper::timerEvent(QTimerEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "timerEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::timerEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QTimerEvent * >::toPython(arg__1)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QGraphicsSceneWrapper::wheelEvent(QGraphicsSceneWheelEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "wheelEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QGraphicsScene::wheelEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QGraphicsSceneWheelEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

const QMetaObject* QGraphicsSceneWrapper::metaObject() const
{
    SbkObject* pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    return reinterpret_cast<QMetaObject*>(Shiboken::Object::getTypeUserData(pySelf));
}

int QGraphicsSceneWrapper::qt_metacall(QMetaObject::Call call, int id, void** args)
{
    int result = QGraphicsScene::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

QGraphicsSceneWrapper::~QGraphicsSceneWrapper()
{
    SbkObject* wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QGraphicsScene_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QGraphicsScene >()))
        return -1;

    QGraphicsSceneWrapper* cptr = 0;
    int overloadId = -1;
    const char* argNames[] = {"parent"};
    const QMetaObject* metaObject;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs == 3)
        goto Sbk_QGraphicsScene_Init_TypeError;

    if (!PyArg_ParseTuple(args, "|OOOOO:QGraphicsScene", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3]), &(pyargs[4])))
        return -1;

    // Overloaded function decisor
    // 0: QGraphicsScene(QObject*)
    // 1: QGraphicsScene(QRectF,QObject*)
    // 2: QGraphicsScene(qreal,qreal,qreal,qreal,QObject*)
    if (numArgs == 0) {
        overloadId = 0; // QGraphicsScene(QObject*)
    } else if (numArgs >= 4 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2]) && SbkNumber_Check(pyargs[3])) {
        if (numArgs == 4) {
            overloadId = 2; // QGraphicsScene(qreal,qreal,qreal,qreal,QObject*)
        } else if (Shiboken::Converter< ::QObject * >::isConvertible(pyargs[4])) {
            overloadId = 2; // QGraphicsScene(qreal,qreal,qreal,qreal,QObject*)
        }
    } else if (Shiboken::Converter< ::QRectF >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 1; // QGraphicsScene(QRectF,QObject*)
        } else if (Shiboken::Converter< ::QObject * >::isConvertible(pyargs[1])) {
            overloadId = 1; // QGraphicsScene(QRectF,QObject*)
        }
    } else if (Shiboken::Converter< ::QObject * >::isConvertible(pyargs[0])) {
        overloadId = 0; // QGraphicsScene(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGraphicsScene_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QGraphicsScene(QObject*)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "parent");
                    if (value) {
                        if (pyargs[0])
                            errorArgName = "parent";
                        else if (Shiboken::Converter< ::QObject * >::isConvertible(value))
                            pyargs[0] = value;
                        else
                            goto Sbk_QGraphicsScene_Init_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QGraphicsScene(): got multiple values for keyword argument '%s'", errorArgName);
                        return -1;
                    }
                }
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QObject * cppArg0 = pyargs[0] ? Shiboken::Converter<QObject * >::toCpp(pyargs[0]) : 0;

                if(!PyErr_Occurred()) {
                    // QGraphicsScene(QObject*)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QGraphicsSceneWrapper(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    Shiboken::Object::setParent(pyargs[0], self);
                }
                break;
            }
            case 1: // QGraphicsScene(QRectF,QObject*)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "parent");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "parent";
                        else if (Shiboken::Converter< ::QObject * >::isConvertible(value))
                            pyargs[1] = value;
                        else
                            goto Sbk_QGraphicsScene_Init_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QGraphicsScene(): got multiple values for keyword argument '%s'", errorArgName);
                        return -1;
                    }
                }
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QRectF cppArg0 = Shiboken::Converter<QRectF >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return -1;
                QObject * cppArg1 = pyargs[1] ? Shiboken::Converter<QObject * >::toCpp(pyargs[1]) : 0;

                if(!PyErr_Occurred()) {
                    // QGraphicsScene(QRectF,QObject*)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QGraphicsSceneWrapper(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    Shiboken::Object::setParent(pyargs[1], self);
                }
                break;
            }
            case 2: // QGraphicsScene(qreal,qreal,qreal,qreal,QObject*)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "parent");
                    if (value) {
                        if (pyargs[4])
                            errorArgName = "parent";
                        else if (Shiboken::Converter< ::QObject * >::isConvertible(value))
                            pyargs[4] = value;
                        else
                            goto Sbk_QGraphicsScene_Init_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QGraphicsScene(): got multiple values for keyword argument '%s'", errorArgName);
                        return -1;
                    }
                }
                qreal cppArg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
                qreal cppArg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);
                qreal cppArg2 = Shiboken::Converter<qreal >::toCpp(pyargs[2]);
                qreal cppArg3 = Shiboken::Converter<qreal >::toCpp(pyargs[3]);
                if (!Shiboken::Object::isValid(pyargs[4]))
                    return -1;
                QObject * cppArg4 = pyargs[4] ? Shiboken::Converter<QObject * >::toCpp(pyargs[4]) : 0;

                if(!PyErr_Occurred()) {
                    // QGraphicsScene(qreal,qreal,qreal,qreal,QObject*)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QGraphicsSceneWrapper(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    Shiboken::Object::setParent(pyargs[4], self);
                }
                break;
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QGraphicsScene >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QGraphicsScene_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    metaObject = cptr->metaObject(); // <- init python qt properties
    if (kwds && !PySide::fillQtProperties(self, metaObject, kwds, argNames, 1))
        return -1;


    return 1;

    Sbk_QGraphicsScene_Init_TypeError:
        const char* overloads[] = {"PySide.QtCore.QObject = None", "PySide.QtCore.QRectF, PySide.QtCore.QObject = None", "float, float, float, float, PySide.QtCore.QObject = None", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QGraphicsScene", overloads);
        return -1;
}

static PyObject* Sbk_QGraphicsSceneFunc_activePanel(PyObject* self)
{
    QGraphicsScene* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsScene* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // activePanel()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QGraphicsItem * cppResult = const_cast<const QGraphicsScene*>(cppSelf)->activePanel();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QGraphicsItem * >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QGraphicsSceneFunc_activeWindow(PyObject* self)
{
    QGraphicsScene* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsScene* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // activeWindow()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QGraphicsWidget * cppResult = const_cast<const QGraphicsScene*>(cppSelf)->activeWindow();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QGraphicsWidget * >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QGraphicsSceneFunc_addEllipse(PyObject* self, PyObject* args, PyObject* kwds)
{
    QGraphicsScene* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsScene* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 6) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QGraphicsScene.addEllipse(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QGraphicsScene.addEllipse(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOOOOO:addEllipse", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3]), &(pyargs[4]), &(pyargs[5])))
        return 0;


    // Overloaded function decisor
    // 0: addEllipse(QRectF,QPen,QBrush)
    // 1: addEllipse(qreal,qreal,qreal,qreal,QPen,QBrush)
    if (numArgs >= 4 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2]) && SbkNumber_Check(pyargs[3])) {
        if (numArgs == 4) {
            overloadId = 1; // addEllipse(qreal,qreal,qreal,qreal,QPen,QBrush)
        } else if (Shiboken::Converter< ::QPen >::isConvertible(pyargs[4])) {
            if (numArgs == 5) {
                overloadId = 1; // addEllipse(qreal,qreal,qreal,qreal,QPen,QBrush)
            } else if (Shiboken::Converter< ::QBrush >::isConvertible(pyargs[5])) {
                overloadId = 1; // addEllipse(qreal,qreal,qreal,qreal,QPen,QBrush)
            }
        }
    } else if (Shiboken::Converter< ::QRectF >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // addEllipse(QRectF,QPen,QBrush)
        } else if (Shiboken::Converter< ::QPen >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 0; // addEllipse(QRectF,QPen,QBrush)
            } else if (Shiboken::Converter< ::QBrush >::isConvertible(pyargs[2])) {
                overloadId = 0; // addEllipse(QRectF,QPen,QBrush)
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGraphicsSceneFunc_addEllipse_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // addEllipse(QRectF,QPen,QBrush)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "pen");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "pen";
                        else if (Shiboken::Converter< ::QPen >::isConvertible(value))
                            pyargs[1] = value;
                        else
                            goto Sbk_QGraphicsSceneFunc_addEllipse_TypeError;
                    }
                    value = PyDict_GetItemString(kwds, "brush");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "brush";
                        else if (Shiboken::Converter< ::QBrush >::isConvertible(value))
                            pyargs[2] = value;
                        else
                            goto Sbk_QGraphicsSceneFunc_addEllipse_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QGraphicsScene.addEllipse(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QRectF cppArg0 = Shiboken::Converter<QRectF >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return 0;
                QPen cppArg1_tmp = QPen();
                QPen cppArg1 = pyargs[1] ? Shiboken::Converter<QPen >::toCpp(pyargs[1]) : cppArg1_tmp;
                if (!Shiboken::Object::isValid(pyargs[2]))
                    return 0;
                QBrush cppArg2_tmp = QBrush();
                QBrush cppArg2 = pyargs[2] ? Shiboken::Converter<QBrush >::toCpp(pyargs[2]) : cppArg2_tmp;

                if(!PyErr_Occurred()) {
                    // addEllipse(QRectF,QPen,QBrush)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QGraphicsEllipseItem * cppResult = cppSelf->addEllipse(cppArg0, cppArg1, cppArg2);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QGraphicsEllipseItem * >::toPython(cppResult);
                    Shiboken::Object::setParent(self, pyResult);
                }
                break;
            }
            case 1: // addEllipse(qreal,qreal,qreal,qreal,QPen,QBrush)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "pen");
                    if (value) {
                        if (pyargs[4])
                            errorArgName = "pen";
                        else if (Shiboken::Converter< ::QPen >::isConvertible(value))
                            pyargs[4] = value;
                        else
                            goto Sbk_QGraphicsSceneFunc_addEllipse_TypeError;
                    }
                    value = PyDict_GetItemString(kwds, "brush");
                    if (value) {
                        if (pyargs[5])
                            errorArgName = "brush";
                        else if (Shiboken::Converter< ::QBrush >::isConvertible(value))
                            pyargs[5] = value;
                        else
                            goto Sbk_QGraphicsSceneFunc_addEllipse_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QGraphicsScene.addEllipse(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                qreal cppArg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
                qreal cppArg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);
                qreal cppArg2 = Shiboken::Converter<qreal >::toCpp(pyargs[2]);
                qreal cppArg3 = Shiboken::Converter<qreal >::toCpp(pyargs[3]);
                if (!Shiboken::Object::isValid(pyargs[4]))
                    return 0;
                QPen cppArg4_tmp = QPen();
                QPen cppArg4 = pyargs[4] ? Shiboken::Converter<QPen >::toCpp(pyargs[4]) : cppArg4_tmp;
                if (!Shiboken::Object::isValid(pyargs[5]))
                    return 0;
                QBrush cppArg5_tmp = QBrush();
                QBrush cppArg5 = pyargs[5] ? Shiboken::Converter<QBrush >::toCpp(pyargs[5]) : cppArg5_tmp;

                if(!PyErr_Occurred()) {
                    // addEllipse(qreal,qreal,qreal,qreal,QPen,QBrush)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QGraphicsEllipseItem * cppResult = cppSelf->addEllipse(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QGraphicsEllipseItem * >::toPython(cppResult);
                    Shiboken::Object::setParent(self, pyResult);
                }
                break;
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QGraphicsSceneFunc_addEllipse_TypeError:
        const char* overloads[] = {"PySide.QtCore.QRectF, PySide.QtGui.QPen = QPen(), PySide.QtGui.QBrush = QBrush()", "float, float, float, float, PySide.QtGui.QPen = QPen(), PySide.QtGui.QBrush = QBrush()", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QGraphicsScene.addEllipse", overloads);
        return 0;
}

static PyObject* Sbk_QGraphicsSceneFunc_addItem(PyObject* self, PyObject* arg)
{
    QGraphicsScene* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsScene* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: addItem(QGraphicsItem*)
    if (Shiboken::Converter< ::QGraphicsItem * >::isConvertible(arg)) {
        overloadId = 0; // addItem(QGraphicsItem*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGraphicsSceneFunc_addItem_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QGraphicsItem * cppArg0 = Shiboken::Converter<QGraphicsItem * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // addItem(QGraphicsItem*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->addItem(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                Shiboken::Object::setParent(self, arg);
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGraphicsSceneFunc_addItem_TypeError:
        const char* overloads[] = {"PySide.QtGui.QGraphicsItem", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsScene.addItem", overloads);
        return 0;
}

static PyObject* Sbk_QGraphicsSceneFunc_addLine(PyObject* self, PyObject* args, PyObject* kwds)
{
    QGraphicsScene* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsScene* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 5) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QGraphicsScene.addLine(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QGraphicsScene.addLine(): not enough arguments");
        return 0;
    } else if (numArgs == 3)
        goto Sbk_QGraphicsSceneFunc_addLine_TypeError;

    if (!PyArg_ParseTuple(args, "|OOOOO:addLine", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3]), &(pyargs[4])))
        return 0;


    // Overloaded function decisor
    // 0: addLine(QLineF,QPen)
    // 1: addLine(qreal,qreal,qreal,qreal,QPen)
    if (numArgs >= 4 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2]) && SbkNumber_Check(pyargs[3])) {
        if (numArgs == 4) {
            overloadId = 1; // addLine(qreal,qreal,qreal,qreal,QPen)
        } else if (Shiboken::Converter< ::QPen >::isConvertible(pyargs[4])) {
            overloadId = 1; // addLine(qreal,qreal,qreal,qreal,QPen)
        }
    } else if (Shiboken::Converter< ::QLineF >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // addLine(QLineF,QPen)
        } else if (Shiboken::Converter< ::QPen >::isConvertible(pyargs[1])) {
            overloadId = 0; // addLine(QLineF,QPen)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGraphicsSceneFunc_addLine_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // addLine(QLineF,QPen)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "pen");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "pen";
                        else if (Shiboken::Converter< ::QPen >::isConvertible(value))
                            pyargs[1] = value;
                        else
                            goto Sbk_QGraphicsSceneFunc_addLine_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QGraphicsScene.addLine(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QLineF cppArg0 = Shiboken::Converter<QLineF >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return 0;
                QPen cppArg1_tmp = QPen();
                QPen cppArg1 = pyargs[1] ? Shiboken::Converter<QPen >::toCpp(pyargs[1]) : cppArg1_tmp;

                if(!PyErr_Occurred()) {
                    // addLine(QLineF,QPen)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QGraphicsLineItem * cppResult = cppSelf->addLine(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QGraphicsLineItem * >::toPython(cppResult);
                    Shiboken::Object::setParent(self, pyResult);
                }
                break;
            }
            case 1: // addLine(qreal,qreal,qreal,qreal,QPen)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "pen");
                    if (value) {
                        if (pyargs[4])
                            errorArgName = "pen";
                        else if (Shiboken::Converter< ::QPen >::isConvertible(value))
                            pyargs[4] = value;
                        else
                            goto Sbk_QGraphicsSceneFunc_addLine_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QGraphicsScene.addLine(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                qreal cppArg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
                qreal cppArg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);
                qreal cppArg2 = Shiboken::Converter<qreal >::toCpp(pyargs[2]);
                qreal cppArg3 = Shiboken::Converter<qreal >::toCpp(pyargs[3]);
                if (!Shiboken::Object::isValid(pyargs[4]))
                    return 0;
                QPen cppArg4_tmp = QPen();
                QPen cppArg4 = pyargs[4] ? Shiboken::Converter<QPen >::toCpp(pyargs[4]) : cppArg4_tmp;

                if(!PyErr_Occurred()) {
                    // addLine(qreal,qreal,qreal,qreal,QPen)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QGraphicsLineItem * cppResult = cppSelf->addLine(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QGraphicsLineItem * >::toPython(cppResult);
                    Shiboken::Object::setParent(self, pyResult);
                }
                break;
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QGraphicsSceneFunc_addLine_TypeError:
        const char* overloads[] = {"PySide.QtCore.QLineF, PySide.QtGui.QPen = QPen()", "float, float, float, float, PySide.QtGui.QPen = QPen()", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QGraphicsScene.addLine", overloads);
        return 0;
}

static PyObject* Sbk_QGraphicsSceneFunc_addPath(PyObject* self, PyObject* args, PyObject* kwds)
{
    QGraphicsScene* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsScene* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QGraphicsScene.addPath(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QGraphicsScene.addPath(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOO:addPath", &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: addPath(QPainterPath,QPen,QBrush)
    if (Shiboken::Converter< ::QPainterPath >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // addPath(QPainterPath,QPen,QBrush)
        } else if (Shiboken::Converter< ::QPen >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 0; // addPath(QPainterPath,QPen,QBrush)
            } else if (Shiboken::Converter< ::QBrush >::isConvertible(pyargs[2])) {
                overloadId = 0; // addPath(QPainterPath,QPen,QBrush)
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGraphicsSceneFunc_addPath_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "pen");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "pen";
                    else if (Shiboken::Converter< ::QPen >::isConvertible(value))
                        pyargs[1] = value;
                    else
                        goto Sbk_QGraphicsSceneFunc_addPath_TypeError;
                }
                value = PyDict_GetItemString(kwds, "brush");
                if (value) {
                    if (pyargs[2])
                        errorArgName = "brush";
                    else if (Shiboken::Converter< ::QBrush >::isConvertible(value))
                        pyargs[2] = value;
                    else
                        goto Sbk_QGraphicsSceneFunc_addPath_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QGraphicsScene.addPath(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QPainterPath cppArg0 = Shiboken::Converter<QPainterPath >::toCpp(pyargs[0]);
            if (!Shiboken::Object::isValid(pyargs[1]))
                return 0;
            QPen cppArg1_tmp = QPen();
            QPen cppArg1 = pyargs[1] ? Shiboken::Converter<QPen >::toCpp(pyargs[1]) : cppArg1_tmp;
            if (!Shiboken::Object::isValid(pyargs[2]))
                return 0;
            QBrush cppArg2_tmp = QBrush();
            QBrush cppArg2 = pyargs[2] ? Shiboken::Converter<QBrush >::toCpp(pyargs[2]) : cppArg2_tmp;

            if(!PyErr_Occurred()) {
                // addPath(QPainterPath,QPen,QBrush)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QGraphicsPathItem * cppResult = cppSelf->addPath(cppArg0, cppArg1, cppArg2);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QGraphicsPathItem * >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QGraphicsSceneFunc_addPath_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPainterPath, PySide.QtGui.QPen = QPen(), PySide.QtGui.QBrush = QBrush()", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QGraphicsScene.addPath", overloads);
        return 0;
}

static PyObject* Sbk_QGraphicsSceneFunc_addPixmap(PyObject* self, PyObject* arg)
{
    QGraphicsScene* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsScene* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: addPixmap(QPixmap)
    if (Shiboken::Converter< ::QPixmap >::isConvertible(arg)) {
        overloadId = 0; // addPixmap(QPixmap)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGraphicsSceneFunc_addPixmap_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QPixmap cppArg0 = Shiboken::Converter<QPixmap >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // addPixmap(QPixmap)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QGraphicsPixmapItem * cppResult = cppSelf->addPixmap(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QGraphicsPixmapItem * >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QGraphicsSceneFunc_addPixmap_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPixmap", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsScene.addPixmap", overloads);
        return 0;
}

static PyObject* Sbk_QGraphicsSceneFunc_addPolygon(PyObject* self, PyObject* args, PyObject* kwds)
{
    QGraphicsScene* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsScene* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QGraphicsScene.addPolygon(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QGraphicsScene.addPolygon(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOO:addPolygon", &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: addPolygon(QPolygonF,QPen,QBrush)
    if (Shiboken::Converter< ::QPolygonF >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // addPolygon(QPolygonF,QPen,QBrush)
        } else if (Shiboken::Converter< ::QPen >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 0; // addPolygon(QPolygonF,QPen,QBrush)
            } else if (Shiboken::Converter< ::QBrush >::isConvertible(pyargs[2])) {
                overloadId = 0; // addPolygon(QPolygonF,QPen,QBrush)
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGraphicsSceneFunc_addPolygon_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "pen");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "pen";
                    else if (Shiboken::Converter< ::QPen >::isConvertible(value))
                        pyargs[1] = value;
                    else
                        goto Sbk_QGraphicsSceneFunc_addPolygon_TypeError;
                }
                value = PyDict_GetItemString(kwds, "brush");
                if (value) {
                    if (pyargs[2])
                        errorArgName = "brush";
                    else if (Shiboken::Converter< ::QBrush >::isConvertible(value))
                        pyargs[2] = value;
                    else
                        goto Sbk_QGraphicsSceneFunc_addPolygon_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QGraphicsScene.addPolygon(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QPolygonF cppArg0 = Shiboken::Converter<QPolygonF >::toCpp(pyargs[0]);
            if (!Shiboken::Object::isValid(pyargs[1]))
                return 0;
            QPen cppArg1_tmp = QPen();
            QPen cppArg1 = pyargs[1] ? Shiboken::Converter<QPen >::toCpp(pyargs[1]) : cppArg1_tmp;
            if (!Shiboken::Object::isValid(pyargs[2]))
                return 0;
            QBrush cppArg2_tmp = QBrush();
            QBrush cppArg2 = pyargs[2] ? Shiboken::Converter<QBrush >::toCpp(pyargs[2]) : cppArg2_tmp;

            if(!PyErr_Occurred()) {
                // addPolygon(QPolygonF,QPen,QBrush)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QGraphicsPolygonItem * cppResult = cppSelf->addPolygon(cppArg0, cppArg1, cppArg2);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QGraphicsPolygonItem * >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QGraphicsSceneFunc_addPolygon_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPolygonF, PySide.QtGui.QPen = QPen(), PySide.QtGui.QBrush = QBrush()", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QGraphicsScene.addPolygon", overloads);
        return 0;
}

static PyObject* Sbk_QGraphicsSceneFunc_addRect(PyObject* self, PyObject* args, PyObject* kwds)
{
    QGraphicsScene* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsScene* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 6) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QGraphicsScene.addRect(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QGraphicsScene.addRect(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOOOOO:addRect", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3]), &(pyargs[4]), &(pyargs[5])))
        return 0;


    // Overloaded function decisor
    // 0: addRect(QRectF,QPen,QBrush)
    // 1: addRect(qreal,qreal,qreal,qreal,QPen,QBrush)
    if (numArgs >= 4 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2]) && SbkNumber_Check(pyargs[3])) {
        if (numArgs == 4) {
            overloadId = 1; // addRect(qreal,qreal,qreal,qreal,QPen,QBrush)
        } else if (Shiboken::Converter< ::QPen >::isConvertible(pyargs[4])) {
            if (numArgs == 5) {
                overloadId = 1; // addRect(qreal,qreal,qreal,qreal,QPen,QBrush)
            } else if (Shiboken::Converter< ::QBrush >::isConvertible(pyargs[5])) {
                overloadId = 1; // addRect(qreal,qreal,qreal,qreal,QPen,QBrush)
            }
        }
    } else if (Shiboken::Converter< ::QRectF >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // addRect(QRectF,QPen,QBrush)
        } else if (Shiboken::Converter< ::QPen >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 0; // addRect(QRectF,QPen,QBrush)
            } else if (Shiboken::Converter< ::QBrush >::isConvertible(pyargs[2])) {
                overloadId = 0; // addRect(QRectF,QPen,QBrush)
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGraphicsSceneFunc_addRect_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // addRect(QRectF,QPen,QBrush)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "pen");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "pen";
                        else if (Shiboken::Converter< ::QPen >::isConvertible(value))
                            pyargs[1] = value;
                        else
                            goto Sbk_QGraphicsSceneFunc_addRect_TypeError;
                    }
                    value = PyDict_GetItemString(kwds, "brush");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "brush";
                        else if (Shiboken::Converter< ::QBrush >::isConvertible(value))
                            pyargs[2] = value;
                        else
                            goto Sbk_QGraphicsSceneFunc_addRect_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QGraphicsScene.addRect(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QRectF cppArg0 = Shiboken::Converter<QRectF >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return 0;
                QPen cppArg1_tmp = QPen();
                QPen cppArg1 = pyargs[1] ? Shiboken::Converter<QPen >::toCpp(pyargs[1]) : cppArg1_tmp;
                if (!Shiboken::Object::isValid(pyargs[2]))
                    return 0;
                QBrush cppArg2_tmp = QBrush();
                QBrush cppArg2 = pyargs[2] ? Shiboken::Converter<QBrush >::toCpp(pyargs[2]) : cppArg2_tmp;

                if(!PyErr_Occurred()) {
                    // addRect(QRectF,QPen,QBrush)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QGraphicsRectItem * cppResult = cppSelf->addRect(cppArg0, cppArg1, cppArg2);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QGraphicsRectItem * >::toPython(cppResult);
                    Shiboken::Object::setParent(self, pyResult);
                }
                break;
            }
            case 1: // addRect(qreal,qreal,qreal,qreal,QPen,QBrush)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "pen");
                    if (value) {
                        if (pyargs[4])
                            errorArgName = "pen";
                        else if (Shiboken::Converter< ::QPen >::isConvertible(value))
                            pyargs[4] = value;
                        else
                            goto Sbk_QGraphicsSceneFunc_addRect_TypeError;
                    }
                    value = PyDict_GetItemString(kwds, "brush");
                    if (value) {
                        if (pyargs[5])
                            errorArgName = "brush";
                        else if (Shiboken::Converter< ::QBrush >::isConvertible(value))
                            pyargs[5] = value;
                        else
                            goto Sbk_QGraphicsSceneFunc_addRect_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QGraphicsScene.addRect(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                qreal cppArg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
                qreal cppArg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);
                qreal cppArg2 = Shiboken::Converter<qreal >::toCpp(pyargs[2]);
                qreal cppArg3 = Shiboken::Converter<qreal >::toCpp(pyargs[3]);
                if (!Shiboken::Object::isValid(pyargs[4]))
                    return 0;
                QPen cppArg4_tmp = QPen();
                QPen cppArg4 = pyargs[4] ? Shiboken::Converter<QPen >::toCpp(pyargs[4]) : cppArg4_tmp;
                if (!Shiboken::Object::isValid(pyargs[5]))
                    return 0;
                QBrush cppArg5_tmp = QBrush();
                QBrush cppArg5 = pyargs[5] ? Shiboken::Converter<QBrush >::toCpp(pyargs[5]) : cppArg5_tmp;

                if(!PyErr_Occurred()) {
                    // addRect(qreal,qreal,qreal,qreal,QPen,QBrush)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QGraphicsRectItem * cppResult = cppSelf->addRect(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QGraphicsRectItem * >::toPython(cppResult);
                    Shiboken::Object::setParent(self, pyResult);
                }
                break;
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QGraphicsSceneFunc_addRect_TypeError:
        const char* overloads[] = {"PySide.QtCore.QRectF, PySide.QtGui.QPen = QPen(), PySide.QtGui.QBrush = QBrush()", "float, float, float, float, PySide.QtGui.QPen = QPen(), PySide.QtGui.QBrush = QBrush()", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QGraphicsScene.addRect", overloads);
        return 0;
}

static PyObject* Sbk_QGraphicsSceneFunc_addSimpleText(PyObject* self, PyObject* args, PyObject* kwds)
{
    QGraphicsScene* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsScene* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QGraphicsScene.addSimpleText(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QGraphicsScene.addSimpleText(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:addSimpleText", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: addSimpleText(QString,QFont)
    if (Shiboken::Converter< QString >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // addSimpleText(QString,QFont)
        } else if (Shiboken::Converter< ::QFont >::isConvertible(pyargs[1])) {
            overloadId = 0; // addSimpleText(QString,QFont)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGraphicsSceneFunc_addSimpleText_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "font");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "font";
                    else if (Shiboken::Converter< ::QFont >::isConvertible(value))
                        pyargs[1] = value;
                    else
                        goto Sbk_QGraphicsSceneFunc_addSimpleText_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QGraphicsScene.addSimpleText(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            if (!Shiboken::Object::isValid(pyargs[1]))
                return 0;
            QFont cppArg1_tmp = QFont();
            QFont cppArg1 = pyargs[1] ? Shiboken::Converter<QFont >::toCpp(pyargs[1]) : cppArg1_tmp;

            if(!PyErr_Occurred()) {
                // addSimpleText(QString,QFont)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QGraphicsSimpleTextItem * cppResult = cppSelf->addSimpleText(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QGraphicsSimpleTextItem * >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QGraphicsSceneFunc_addSimpleText_TypeError:
        const char* overloads[] = {"QString, PySide.QtGui.QFont = QFont()", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QGraphicsScene.addSimpleText", overloads);
        return 0;
}

static PyObject* Sbk_QGraphicsSceneFunc_addText(PyObject* self, PyObject* args, PyObject* kwds)
{
    QGraphicsScene* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsScene* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QGraphicsScene.addText(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QGraphicsScene.addText(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:addText", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: addText(QString,QFont)
    if (Shiboken::Converter< QString >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // addText(QString,QFont)
        } else if (Shiboken::Converter< ::QFont >::isConvertible(pyargs[1])) {
            overloadId = 0; // addText(QString,QFont)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGraphicsSceneFunc_addText_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "font");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "font";
                    else if (Shiboken::Converter< ::QFont >::isConvertible(value))
                        pyargs[1] = value;
                    else
                        goto Sbk_QGraphicsSceneFunc_addText_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QGraphicsScene.addText(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            if (!Shiboken::Object::isValid(pyargs[1]))
                return 0;
            QFont cppArg1_tmp = QFont();
            QFont cppArg1 = pyargs[1] ? Shiboken::Converter<QFont >::toCpp(pyargs[1]) : cppArg1_tmp;

            if(!PyErr_Occurred()) {
                // addText(QString,QFont)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QGraphicsTextItem * cppResult = cppSelf->addText(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QGraphicsTextItem * >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QGraphicsSceneFunc_addText_TypeError:
        const char* overloads[] = {"QString, PySide.QtGui.QFont = QFont()", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QGraphicsScene.addText", overloads);
        return 0;
}

static PyObject* Sbk_QGraphicsSceneFunc_addWidget(PyObject* self, PyObject* args, PyObject* kwds)
{
    QGraphicsScene* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsScene* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QGraphicsScene.addWidget(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QGraphicsScene.addWidget(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:addWidget", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: addWidget(QWidget*,QFlags<Qt::WindowType>)
    if (Shiboken::Converter< ::QWidget * >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // addWidget(QWidget*,QFlags<Qt::WindowType>)
        } else if (Shiboken::Converter< ::QFlags<Qt::WindowType> >::isConvertible(pyargs[1])) {
            overloadId = 0; // addWidget(QWidget*,QFlags<Qt::WindowType>)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGraphicsSceneFunc_addWidget_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "wFlags");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "wFlags";
                    else if (Shiboken::Converter< ::QFlags<Qt::WindowType> >::isConvertible(value))
                        pyargs[1] = value;
                    else
                        goto Sbk_QGraphicsSceneFunc_addWidget_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QGraphicsScene.addWidget(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QWidget * cppArg0 = Shiboken::Converter<QWidget * >::toCpp(pyargs[0]);
            QFlags<Qt::WindowType> cppArg1 = pyargs[1] ? Shiboken::Converter<QFlags<Qt::WindowType> >::toCpp(pyargs[1]) : QFlags<Qt::WindowType>(0);

            if(!PyErr_Occurred()) {
                // addWidget(QWidget*,QFlags<Qt::WindowType>)
                // Begin code injection

                pyResult = Shiboken::Converter<QGraphicsProxyWidget * >::toPython(cppSelf->addWidget(cppArg0, cppArg1));
                Shiboken::Object::keepReference((SbkObject*)pyResult, "setWidget(QWidget*)1", pyargs[1-1]);

                // End of code injection


                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QGraphicsSceneFunc_addWidget_TypeError:
        const char* overloads[] = {"PySide.QtGui.QWidget, PySide.QtCore.Qt.WindowFlags = 0", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QGraphicsScene.addWidget", overloads);
        return 0;
}

static PyObject* Sbk_QGraphicsSceneFunc_advance(PyObject* self)
{
    QGraphicsScene* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsScene* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // advance()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->advance();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QGraphicsSceneFunc_backgroundBrush(PyObject* self)
{
    QGraphicsScene* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsScene* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // backgroundBrush()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QBrush cppResult = const_cast<const QGraphicsScene*>(cppSelf)->backgroundBrush();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QBrush >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QGraphicsSceneFunc_bspTreeDepth(PyObject* self)
{
    QGraphicsScene* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsScene* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // bspTreeDepth()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QGraphicsScene*>(cppSelf)->bspTreeDepth();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QGraphicsSceneFunc_clear(PyObject* self)
{
    QGraphicsScene* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsScene* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // clear()
                // Begin code injection

                const QList<QGraphicsItem*> items = cppSelf->items();
                Shiboken::BindingManager& bm = Shiboken::BindingManager::instance();
                foreach (QGraphicsItem* item, items) {
                    SbkObject* obj = bm.retrieveWrapper(item);
                    if (obj) {
                        if (obj->ob_refcnt > 1) // If the refcnt is 1 the object will vannish anyway.
                            Shiboken::Object::invalidate(obj);
                        Shiboken::Object::removeParent(obj);
                    }
                }
                cppSelf->clear();

                // End of code injection


            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QGraphicsSceneFunc_clearFocus(PyObject* self)
{
    QGraphicsScene* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsScene* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // clearFocus()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->clearFocus();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QGraphicsSceneFunc_clearSelection(PyObject* self)
{
    QGraphicsScene* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsScene* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // clearSelection()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->clearSelection();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QGraphicsSceneFunc_collidingItems(PyObject* self, PyObject* args, PyObject* kwds)
{
    QGraphicsScene* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsScene* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QGraphicsScene.collidingItems(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QGraphicsScene.collidingItems(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:collidingItems", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: collidingItems(const QGraphicsItem*,Qt::ItemSelectionMode)const
    if (Shiboken::Converter< ::QGraphicsItem * >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // collidingItems(const QGraphicsItem*,Qt::ItemSelectionMode)const
        } else if (Shiboken::Converter< ::Qt::ItemSelectionMode >::isConvertible(pyargs[1])) {
            overloadId = 0; // collidingItems(const QGraphicsItem*,Qt::ItemSelectionMode)const
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGraphicsSceneFunc_collidingItems_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "mode");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "mode";
                    else if (Shiboken::Converter< ::Qt::ItemSelectionMode >::isConvertible(value))
                        pyargs[1] = value;
                    else
                        goto Sbk_QGraphicsSceneFunc_collidingItems_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QGraphicsScene.collidingItems(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QGraphicsItem * cppArg0 = Shiboken::Converter<QGraphicsItem * >::toCpp(pyargs[0]);
            Qt::ItemSelectionMode cppArg1 = pyargs[1] ? Shiboken::Converter<Qt::ItemSelectionMode >::toCpp(pyargs[1]) : Qt::IntersectsItemShape;

            if(!PyErr_Occurred()) {
                // collidingItems(const QGraphicsItem*,Qt::ItemSelectionMode)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QList<QGraphicsItem * > cppResult = const_cast<const QGraphicsScene*>(cppSelf)->collidingItems(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QList<QGraphicsItem * > >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QGraphicsSceneFunc_collidingItems_TypeError:
        const char* overloads[] = {"PySide.QtGui.QGraphicsItem, PySide.QtCore.Qt.ItemSelectionMode = Qt.IntersectsItemShape", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QGraphicsScene.collidingItems", overloads);
        return 0;
}

static PyObject* Sbk_QGraphicsSceneFunc_contextMenuEvent(PyObject* self, PyObject* arg)
{
    QGraphicsScene* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsScene* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: contextMenuEvent(QGraphicsSceneContextMenuEvent*)
    if (Shiboken::Converter< ::QGraphicsSceneContextMenuEvent * >::isConvertible(arg)) {
        overloadId = 0; // contextMenuEvent(QGraphicsSceneContextMenuEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGraphicsSceneFunc_contextMenuEvent_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QGraphicsSceneContextMenuEvent * cppArg0 = Shiboken::Converter<QGraphicsSceneContextMenuEvent * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // contextMenuEvent(QGraphicsSceneContextMenuEvent*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QGraphicsScene::contextMenuEvent(cppArg0) : cppSelf->contextMenuEvent(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGraphicsSceneFunc_contextMenuEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QGraphicsSceneContextMenuEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsScene.contextMenuEvent", overloads);
        return 0;
}

static PyObject* Sbk_QGraphicsSceneFunc_createItemGroup(PyObject* self, PyObject* arg)
{
    QGraphicsScene* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsScene* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: createItemGroup(QList<QGraphicsItem*>)
    if (Shiboken::Converter< ::QList<QGraphicsItem * > >::isConvertible(arg)) {
        overloadId = 0; // createItemGroup(QList<QGraphicsItem*>)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGraphicsSceneFunc_createItemGroup_TypeError;

    // Call function/method
    {
        {
            QList<QGraphicsItem * > cppArg0 = Shiboken::Converter<QList<QGraphicsItem * > >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // createItemGroup(QList<QGraphicsItem*>)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QGraphicsItemGroup * cppResult = cppSelf->createItemGroup(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QGraphicsItemGroup * >::toPython(cppResult);

                // Ownership transferences.
                Shiboken::Object::setParent(pyResult, arg);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QGraphicsSceneFunc_createItemGroup_TypeError:
        const char* overloads[] = {"list", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsScene.createItemGroup", overloads);
        return 0;
}

static PyObject* Sbk_QGraphicsSceneFunc_destroyItemGroup(PyObject* self, PyObject* arg)
{
    QGraphicsScene* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsScene* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: destroyItemGroup(QGraphicsItemGroup*)
    if (Shiboken::Converter< ::QGraphicsItemGroup * >::isConvertible(arg)) {
        overloadId = 0; // destroyItemGroup(QGraphicsItemGroup*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGraphicsSceneFunc_destroyItemGroup_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QGraphicsItemGroup * cppArg0 = Shiboken::Converter<QGraphicsItemGroup * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // destroyItemGroup(QGraphicsItemGroup*)
                // Begin code injection

                Shiboken::AutoDecRef parent(Shiboken::Converter<QGraphicsItem* >::toPython(cppArg0->parentObject()));
                foreach (QGraphicsItem* item, cppArg0->children())
                    Shiboken::Object::setParent(parent, Shiboken::Converter<QGraphicsItem* >::toPython(item));
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->destroyItemGroup(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                // the arg was destroyed by Qt.
                Shiboken::Object::invalidate(arg);

                // End of code injection


            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGraphicsSceneFunc_destroyItemGroup_TypeError:
        const char* overloads[] = {"PySide.QtGui.QGraphicsItemGroup", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsScene.destroyItemGroup", overloads);
        return 0;
}

static PyObject* Sbk_QGraphicsSceneFunc_dragEnterEvent(PyObject* self, PyObject* arg)
{
    QGraphicsScene* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsScene* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: dragEnterEvent(QGraphicsSceneDragDropEvent*)
    if (Shiboken::Converter< ::QGraphicsSceneDragDropEvent * >::isConvertible(arg)) {
        overloadId = 0; // dragEnterEvent(QGraphicsSceneDragDropEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGraphicsSceneFunc_dragEnterEvent_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QGraphicsSceneDragDropEvent * cppArg0 = Shiboken::Converter<QGraphicsSceneDragDropEvent * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // dragEnterEvent(QGraphicsSceneDragDropEvent*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QGraphicsScene::dragEnterEvent(cppArg0) : cppSelf->dragEnterEvent(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGraphicsSceneFunc_dragEnterEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QGraphicsSceneDragDropEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsScene.dragEnterEvent", overloads);
        return 0;
}

static PyObject* Sbk_QGraphicsSceneFunc_dragLeaveEvent(PyObject* self, PyObject* arg)
{
    QGraphicsScene* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsScene* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: dragLeaveEvent(QGraphicsSceneDragDropEvent*)
    if (Shiboken::Converter< ::QGraphicsSceneDragDropEvent * >::isConvertible(arg)) {
        overloadId = 0; // dragLeaveEvent(QGraphicsSceneDragDropEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGraphicsSceneFunc_dragLeaveEvent_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QGraphicsSceneDragDropEvent * cppArg0 = Shiboken::Converter<QGraphicsSceneDragDropEvent * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // dragLeaveEvent(QGraphicsSceneDragDropEvent*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QGraphicsScene::dragLeaveEvent(cppArg0) : cppSelf->dragLeaveEvent(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGraphicsSceneFunc_dragLeaveEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QGraphicsSceneDragDropEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsScene.dragLeaveEvent", overloads);
        return 0;
}

static PyObject* Sbk_QGraphicsSceneFunc_dragMoveEvent(PyObject* self, PyObject* arg)
{
    QGraphicsScene* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsScene* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: dragMoveEvent(QGraphicsSceneDragDropEvent*)
    if (Shiboken::Converter< ::QGraphicsSceneDragDropEvent * >::isConvertible(arg)) {
        overloadId = 0; // dragMoveEvent(QGraphicsSceneDragDropEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGraphicsSceneFunc_dragMoveEvent_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QGraphicsSceneDragDropEvent * cppArg0 = Shiboken::Converter<QGraphicsSceneDragDropEvent * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // dragMoveEvent(QGraphicsSceneDragDropEvent*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QGraphicsScene::dragMoveEvent(cppArg0) : cppSelf->dragMoveEvent(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGraphicsSceneFunc_dragMoveEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QGraphicsSceneDragDropEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsScene.dragMoveEvent", overloads);
        return 0;
}

static PyObject* Sbk_QGraphicsSceneFunc_drawBackground(PyObject* self, PyObject* args)
{
    QGraphicsScene* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsScene* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "drawBackground", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: drawBackground(QPainter*,QRectF)
    if (numArgs == 2 && Shiboken::Converter< ::QPainter * >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QRectF >::isConvertible(pyargs[1])) {
        overloadId = 0; // drawBackground(QPainter*,QRectF)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGraphicsSceneFunc_drawBackground_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QPainter * cppArg0 = Shiboken::Converter<QPainter * >::toCpp(pyargs[0]);
            if (!Shiboken::Object::isValid(pyargs[1]))
                return 0;
            QRectF cppArg1 = Shiboken::Converter<QRectF >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // drawBackground(QPainter*,QRectF)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QGraphicsScene::drawBackground(cppArg0, cppArg1) : cppSelf->drawBackground(cppArg0, cppArg1));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGraphicsSceneFunc_drawBackground_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPainter, PySide.QtCore.QRectF", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QGraphicsScene.drawBackground", overloads);
        return 0;
}

static PyObject* Sbk_QGraphicsSceneFunc_drawForeground(PyObject* self, PyObject* args)
{
    QGraphicsScene* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsScene* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "drawForeground", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: drawForeground(QPainter*,QRectF)
    if (numArgs == 2 && Shiboken::Converter< ::QPainter * >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QRectF >::isConvertible(pyargs[1])) {
        overloadId = 0; // drawForeground(QPainter*,QRectF)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGraphicsSceneFunc_drawForeground_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QPainter * cppArg0 = Shiboken::Converter<QPainter * >::toCpp(pyargs[0]);
            if (!Shiboken::Object::isValid(pyargs[1]))
                return 0;
            QRectF cppArg1 = Shiboken::Converter<QRectF >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // drawForeground(QPainter*,QRectF)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QGraphicsScene::drawForeground(cppArg0, cppArg1) : cppSelf->drawForeground(cppArg0, cppArg1));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGraphicsSceneFunc_drawForeground_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPainter, PySide.QtCore.QRectF", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QGraphicsScene.drawForeground", overloads);
        return 0;
}

static PyObject* Sbk_QGraphicsSceneFunc_dropEvent(PyObject* self, PyObject* arg)
{
    QGraphicsScene* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsScene* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: dropEvent(QGraphicsSceneDragDropEvent*)
    if (Shiboken::Converter< ::QGraphicsSceneDragDropEvent * >::isConvertible(arg)) {
        overloadId = 0; // dropEvent(QGraphicsSceneDragDropEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGraphicsSceneFunc_dropEvent_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QGraphicsSceneDragDropEvent * cppArg0 = Shiboken::Converter<QGraphicsSceneDragDropEvent * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // dropEvent(QGraphicsSceneDragDropEvent*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QGraphicsScene::dropEvent(cppArg0) : cppSelf->dropEvent(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGraphicsSceneFunc_dropEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QGraphicsSceneDragDropEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsScene.dropEvent", overloads);
        return 0;
}

static PyObject* Sbk_QGraphicsSceneFunc_event(PyObject* self, PyObject* arg)
{
    QGraphicsScene* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsScene* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: event(QEvent*)
    if (Shiboken::Converter< ::QEvent * >::isConvertible(arg)) {
        overloadId = 0; // event(QEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGraphicsSceneFunc_event_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QEvent * cppArg0 = Shiboken::Converter<QEvent * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // event(QEvent*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = (Shiboken::Object::isUserType(self) ? cppSelf->::QGraphicsScene::event(cppArg0) : cppSelf->event(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QGraphicsSceneFunc_event_TypeError:
        const char* overloads[] = {"PySide.QtCore.QEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsScene.event", overloads);
        return 0;
}

static PyObject* Sbk_QGraphicsSceneFunc_eventFilter(PyObject* self, PyObject* args)
{
    QGraphicsScene* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsScene* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "eventFilter", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: eventFilter(QObject*,QEvent*)
    if (numArgs == 2 && Shiboken::Converter< ::QObject * >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QEvent * >::isConvertible(pyargs[1])) {
        overloadId = 0; // eventFilter(QObject*,QEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGraphicsSceneFunc_eventFilter_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QObject * cppArg0 = Shiboken::Converter<QObject * >::toCpp(pyargs[0]);
            if (!Shiboken::Object::isValid(pyargs[1]))
                return 0;
            QEvent * cppArg1 = Shiboken::Converter<QEvent * >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // eventFilter(QObject*,QEvent*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = (Shiboken::Object::isUserType(self) ? cppSelf->::QGraphicsScene::eventFilter(cppArg0, cppArg1) : cppSelf->eventFilter(cppArg0, cppArg1));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QGraphicsSceneFunc_eventFilter_TypeError:
        const char* overloads[] = {"PySide.QtCore.QObject, PySide.QtCore.QEvent", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QGraphicsScene.eventFilter", overloads);
        return 0;
}

static PyObject* Sbk_QGraphicsSceneFunc_focusInEvent(PyObject* self, PyObject* arg)
{
    QGraphicsScene* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsScene* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: focusInEvent(QFocusEvent*)
    if (Shiboken::Converter< ::QFocusEvent * >::isConvertible(arg)) {
        overloadId = 0; // focusInEvent(QFocusEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGraphicsSceneFunc_focusInEvent_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QFocusEvent * cppArg0 = Shiboken::Converter<QFocusEvent * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // focusInEvent(QFocusEvent*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QGraphicsScene::focusInEvent(cppArg0) : cppSelf->focusInEvent(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGraphicsSceneFunc_focusInEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QFocusEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsScene.focusInEvent", overloads);
        return 0;
}

static PyObject* Sbk_QGraphicsSceneFunc_focusItem(PyObject* self)
{
    QGraphicsScene* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsScene* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // focusItem()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QGraphicsItem * cppResult = const_cast<const QGraphicsScene*>(cppSelf)->focusItem();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QGraphicsItem * >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QGraphicsSceneFunc_focusNextPrevChild(PyObject* self, PyObject* arg)
{
    QGraphicsScene* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsScene* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: focusNextPrevChild(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // focusNextPrevChild(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGraphicsSceneFunc_focusNextPrevChild_TypeError;

    // Call function/method
    {
        {
            bool cppArg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // focusNextPrevChild(bool)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->focusNextPrevChild(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QGraphicsSceneFunc_focusNextPrevChild_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsScene.focusNextPrevChild", overloads);
        return 0;
}

static PyObject* Sbk_QGraphicsSceneFunc_focusOutEvent(PyObject* self, PyObject* arg)
{
    QGraphicsScene* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsScene* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: focusOutEvent(QFocusEvent*)
    if (Shiboken::Converter< ::QFocusEvent * >::isConvertible(arg)) {
        overloadId = 0; // focusOutEvent(QFocusEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGraphicsSceneFunc_focusOutEvent_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QFocusEvent * cppArg0 = Shiboken::Converter<QFocusEvent * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // focusOutEvent(QFocusEvent*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QGraphicsScene::focusOutEvent(cppArg0) : cppSelf->focusOutEvent(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGraphicsSceneFunc_focusOutEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QFocusEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsScene.focusOutEvent", overloads);
        return 0;
}

static PyObject* Sbk_QGraphicsSceneFunc_font(PyObject* self)
{
    QGraphicsScene* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsScene* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // font()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QFont cppResult = const_cast<const QGraphicsScene*>(cppSelf)->font();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QFont >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QGraphicsSceneFunc_foregroundBrush(PyObject* self)
{
    QGraphicsScene* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsScene* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // foregroundBrush()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QBrush cppResult = const_cast<const QGraphicsScene*>(cppSelf)->foregroundBrush();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QBrush >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QGraphicsSceneFunc_hasFocus(PyObject* self)
{
    QGraphicsScene* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsScene* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // hasFocus()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QGraphicsScene*>(cppSelf)->hasFocus();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QGraphicsSceneFunc_height(PyObject* self)
{
    QGraphicsScene* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsScene* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // height()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                qreal cppResult = const_cast<const QGraphicsScene*>(cppSelf)->height();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< double >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QGraphicsSceneFunc_helpEvent(PyObject* self, PyObject* arg)
{
    QGraphicsScene* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsScene* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: helpEvent(QGraphicsSceneHelpEvent*)
    if (Shiboken::Converter< ::QGraphicsSceneHelpEvent * >::isConvertible(arg)) {
        overloadId = 0; // helpEvent(QGraphicsSceneHelpEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGraphicsSceneFunc_helpEvent_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QGraphicsSceneHelpEvent * cppArg0 = Shiboken::Converter<QGraphicsSceneHelpEvent * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // helpEvent(QGraphicsSceneHelpEvent*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QGraphicsScene::helpEvent(cppArg0) : cppSelf->helpEvent(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGraphicsSceneFunc_helpEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QGraphicsSceneHelpEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsScene.helpEvent", overloads);
        return 0;
}

static PyObject* Sbk_QGraphicsSceneFunc_inputMethodEvent(PyObject* self, PyObject* arg)
{
    QGraphicsScene* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsScene* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: inputMethodEvent(QInputMethodEvent*)
    if (Shiboken::Converter< ::QInputMethodEvent * >::isConvertible(arg)) {
        overloadId = 0; // inputMethodEvent(QInputMethodEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGraphicsSceneFunc_inputMethodEvent_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QInputMethodEvent * cppArg0 = Shiboken::Converter<QInputMethodEvent * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // inputMethodEvent(QInputMethodEvent*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QGraphicsScene::inputMethodEvent(cppArg0) : cppSelf->inputMethodEvent(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGraphicsSceneFunc_inputMethodEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QInputMethodEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsScene.inputMethodEvent", overloads);
        return 0;
}

static PyObject* Sbk_QGraphicsSceneFunc_inputMethodQuery(PyObject* self, PyObject* arg)
{
    QGraphicsScene* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsScene* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: inputMethodQuery(Qt::InputMethodQuery)const
    if (Shiboken::Converter< ::Qt::InputMethodQuery >::isConvertible(arg)) {
        overloadId = 0; // inputMethodQuery(Qt::InputMethodQuery)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGraphicsSceneFunc_inputMethodQuery_TypeError;

    // Call function/method
    {
        {
            Qt::InputMethodQuery cppArg0 = Shiboken::Converter<Qt::InputMethodQuery >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // inputMethodQuery(Qt::InputMethodQuery)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QVariant cppResult = (Shiboken::Object::isUserType(self) ? const_cast<const QGraphicsScene*>(cppSelf)->::QGraphicsScene::inputMethodQuery(cppArg0) : const_cast<const QGraphicsScene*>(cppSelf)->inputMethodQuery(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QVariant >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QGraphicsSceneFunc_inputMethodQuery_TypeError:
        const char* overloads[] = {"PySide.QtCore.Qt.InputMethodQuery", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsScene.inputMethodQuery", overloads);
        return 0;
}

static PyObject* Sbk_QGraphicsSceneFunc_invalidate(PyObject* self, PyObject* args, PyObject* kwds)
{
    QGraphicsScene* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsScene* >::toCpp(self);

    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 5) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QGraphicsScene.invalidate(): too many arguments");
        return 0;
    } else if (numArgs == 3)
        goto Sbk_QGraphicsSceneFunc_invalidate_TypeError;

    if (!PyArg_ParseTuple(args, "|OOOOO:invalidate", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3]), &(pyargs[4])))
        return 0;


    // Overloaded function decisor
    // 0: invalidate(QRectF,QFlags<QGraphicsScene::SceneLayer>)
    // 1: invalidate(qreal,qreal,qreal,qreal,QFlags<QGraphicsScene::SceneLayer>)
    if (numArgs == 0) {
        overloadId = 0; // invalidate(QRectF,QFlags<QGraphicsScene::SceneLayer>)
    } else if (numArgs >= 4 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2]) && SbkNumber_Check(pyargs[3])) {
        if (numArgs == 4) {
            overloadId = 1; // invalidate(qreal,qreal,qreal,qreal,QFlags<QGraphicsScene::SceneLayer>)
        } else if (Shiboken::Converter< ::QFlags<QGraphicsScene::SceneLayer> >::isConvertible(pyargs[4])) {
            overloadId = 1; // invalidate(qreal,qreal,qreal,qreal,QFlags<QGraphicsScene::SceneLayer>)
        }
    } else if (Shiboken::Converter< ::QRectF >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // invalidate(QRectF,QFlags<QGraphicsScene::SceneLayer>)
        } else if (Shiboken::Converter< ::QFlags<QGraphicsScene::SceneLayer> >::isConvertible(pyargs[1])) {
            overloadId = 0; // invalidate(QRectF,QFlags<QGraphicsScene::SceneLayer>)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGraphicsSceneFunc_invalidate_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // invalidate(QRectF,QFlags<QGraphicsScene::SceneLayer>)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "rect");
                    if (value) {
                        if (pyargs[0])
                            errorArgName = "rect";
                        else if (Shiboken::Converter< ::QRectF >::isConvertible(value))
                            pyargs[0] = value;
                        else
                            goto Sbk_QGraphicsSceneFunc_invalidate_TypeError;
                    }
                    value = PyDict_GetItemString(kwds, "layers");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "layers";
                        else if (Shiboken::Converter< ::QFlags<QGraphicsScene::SceneLayer> >::isConvertible(value))
                            pyargs[1] = value;
                        else
                            goto Sbk_QGraphicsSceneFunc_invalidate_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QGraphicsScene.invalidate(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QRectF cppArg0_tmp = QRectF();
                QRectF cppArg0 = pyargs[0] ? Shiboken::Converter<QRectF >::toCpp(pyargs[0]) : cppArg0_tmp;
                QFlags<QGraphicsScene::SceneLayer> cppArg1 = pyargs[1] ? Shiboken::Converter<QFlags<QGraphicsScene::SceneLayer> >::toCpp(pyargs[1]) : QGraphicsScene::AllLayers;

                if(!PyErr_Occurred()) {
                    // invalidate(QRectF,QFlags<QGraphicsScene::SceneLayer>)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->invalidate(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // invalidate(qreal,qreal,qreal,qreal,QFlags<QGraphicsScene::SceneLayer>)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "layers");
                    if (value) {
                        if (pyargs[4])
                            errorArgName = "layers";
                        else if (Shiboken::Converter< ::QFlags<QGraphicsScene::SceneLayer> >::isConvertible(value))
                            pyargs[4] = value;
                        else
                            goto Sbk_QGraphicsSceneFunc_invalidate_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QGraphicsScene.invalidate(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                qreal cppArg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
                qreal cppArg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);
                qreal cppArg2 = Shiboken::Converter<qreal >::toCpp(pyargs[2]);
                qreal cppArg3 = Shiboken::Converter<qreal >::toCpp(pyargs[3]);
                QFlags<QGraphicsScene::SceneLayer> cppArg4 = pyargs[4] ? Shiboken::Converter<QFlags<QGraphicsScene::SceneLayer> >::toCpp(pyargs[4]) : QGraphicsScene::AllLayers;

                if(!PyErr_Occurred()) {
                    // invalidate(qreal,qreal,qreal,qreal,QFlags<QGraphicsScene::SceneLayer>)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->invalidate(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGraphicsSceneFunc_invalidate_TypeError:
        const char* overloads[] = {"PySide.QtCore.QRectF = QRectF(), PySide.QtGui.QGraphicsScene.SceneLayers = QGraphicsScene.AllLayers", "float, float, float, float, PySide.QtGui.QGraphicsScene.SceneLayers = QGraphicsScene.AllLayers", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QGraphicsScene.invalidate", overloads);
        return 0;
}

static PyObject* Sbk_QGraphicsSceneFunc_isActive(PyObject* self)
{
    QGraphicsScene* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsScene* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isActive()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QGraphicsScene*>(cppSelf)->isActive();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QGraphicsSceneFunc_isSortCacheEnabled(PyObject* self)
{
    QGraphicsScene* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsScene* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isSortCacheEnabled()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QGraphicsScene*>(cppSelf)->isSortCacheEnabled();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QGraphicsSceneFunc_itemAt(PyObject* self, PyObject* args)
{
    QGraphicsScene* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsScene* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "itemAt", 1, 3, &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: itemAt(QPointF)const
    // 1: itemAt(QPointF,QTransform)const
    // 2: itemAt(qreal,qreal)const
    // 3: itemAt(qreal,qreal,QTransform)const
    if (numArgs >= 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        if (numArgs == 2) {
            overloadId = 2; // itemAt(qreal,qreal)const
        } else if (numArgs == 3 && Shiboken::Converter< ::QTransform >::isConvertible(pyargs[2])) {
            overloadId = 3; // itemAt(qreal,qreal,QTransform)const
        }
    } else if (Shiboken::Converter< ::QPointF >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // itemAt(QPointF)const
        } else if (numArgs == 2 && Shiboken::Converter< ::QTransform >::isConvertible(pyargs[1])) {
            overloadId = 1; // itemAt(QPointF,QTransform)const
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGraphicsSceneFunc_itemAt_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // itemAt(QPointF)const
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QPointF cppArg0 = Shiboken::Converter<QPointF >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // itemAt(QPointF)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QGraphicsItem * cppResult = const_cast<const QGraphicsScene*>(cppSelf)->itemAt(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QGraphicsItem * >::toPython(cppResult);
                    Shiboken::Object::setParent(self, pyResult);
                }
                break;
            }
            case 1: // itemAt(QPointF,QTransform)const
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QPointF cppArg0 = Shiboken::Converter<QPointF >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return 0;
                QTransform cppArg1 = Shiboken::Converter<QTransform >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // itemAt(QPointF,QTransform)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QGraphicsItem * cppResult = const_cast<const QGraphicsScene*>(cppSelf)->itemAt(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QGraphicsItem * >::toPython(cppResult);
                    Shiboken::Object::setParent(self, pyResult);
                }
                break;
            }
            case 2: // itemAt(qreal,qreal)const
            {
                qreal cppArg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
                qreal cppArg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // itemAt(qreal,qreal)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QGraphicsItem * cppResult = const_cast<const QGraphicsScene*>(cppSelf)->itemAt(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QGraphicsItem * >::toPython(cppResult);
                    Shiboken::Object::setParent(self, pyResult);
                }
                break;
            }
            case 3: // itemAt(qreal,qreal,QTransform)const
            {
                qreal cppArg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
                qreal cppArg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);
                if (!Shiboken::Object::isValid(pyargs[2]))
                    return 0;
                QTransform cppArg2 = Shiboken::Converter<QTransform >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                    // itemAt(qreal,qreal,QTransform)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QGraphicsItem * cppResult = const_cast<const QGraphicsScene*>(cppSelf)->itemAt(cppArg0, cppArg1, cppArg2);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QGraphicsItem * >::toPython(cppResult);
                    Shiboken::Object::setParent(self, pyResult);
                }
                break;
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QGraphicsSceneFunc_itemAt_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPointF", "PySide.QtCore.QPointF, PySide.QtGui.QTransform", "float, float", "float, float, PySide.QtGui.QTransform", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QGraphicsScene.itemAt", overloads);
        return 0;
}

static PyObject* Sbk_QGraphicsSceneFunc_itemIndexMethod(PyObject* self)
{
    QGraphicsScene* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsScene* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // itemIndexMethod()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QGraphicsScene::ItemIndexMethod cppResult = const_cast<const QGraphicsScene*>(cppSelf)->itemIndexMethod();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QGraphicsScene::ItemIndexMethod >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QGraphicsSceneFunc_items(PyObject* self, PyObject* args, PyObject* kwds)
{
    QGraphicsScene* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsScene* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 7) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QGraphicsScene.items(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOOOOOO:items", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3]), &(pyargs[4]), &(pyargs[5]), &(pyargs[6])))
        return 0;


    // Overloaded function decisor
    // 0: items()const
    // 1: items(Qt::SortOrder)const
    // 2: items(QPainterPath,Qt::ItemSelectionMode)const
    // 3: items(QPainterPath,Qt::ItemSelectionMode,Qt::SortOrder,QTransform)const
    // 4: items(QPointF)const
    // 5: items(QPointF,Qt::ItemSelectionMode,Qt::SortOrder,QTransform)const
    // 6: items(QPolygonF,Qt::ItemSelectionMode)const
    // 7: items(QPolygonF,Qt::ItemSelectionMode,Qt::SortOrder,QTransform)const
    // 8: items(QRectF,Qt::ItemSelectionMode)const
    // 9: items(QRectF,Qt::ItemSelectionMode,Qt::SortOrder,QTransform)const
    // 10: items(qreal,qreal,qreal,qreal,Qt::ItemSelectionMode)const
    // 11: items(qreal,qreal,qreal,qreal,Qt::ItemSelectionMode,Qt::SortOrder,QTransform)const
    if (numArgs == 0) {
        overloadId = 0; // items()const
    } else if (Shiboken::Converter< ::QRectF >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 8; // items(QRectF,Qt::ItemSelectionMode)const
        } else if (Shiboken::Converter< ::Qt::ItemSelectionMode >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 8; // items(QRectF,Qt::ItemSelectionMode)const
            } else if (Shiboken::Converter< ::Qt::SortOrder >::isConvertible(pyargs[2])) {
                if (numArgs == 3) {
                    overloadId = 9; // items(QRectF,Qt::ItemSelectionMode,Qt::SortOrder,QTransform)const
                } else if (Shiboken::Converter< ::QTransform >::isConvertible(pyargs[3])) {
                    overloadId = 9; // items(QRectF,Qt::ItemSelectionMode,Qt::SortOrder,QTransform)const
                }
            }
        }
    } else if (Shiboken::Converter< ::QPointF >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 4; // items(QPointF)const
        } else if (numArgs >= 3 && Shiboken::Converter< ::Qt::ItemSelectionMode >::isConvertible(pyargs[1]) && Shiboken::Converter< ::Qt::SortOrder >::isConvertible(pyargs[2])) {
            if (numArgs == 3) {
                overloadId = 5; // items(QPointF,Qt::ItemSelectionMode,Qt::SortOrder,QTransform)const
            } else if (Shiboken::Converter< ::QTransform >::isConvertible(pyargs[3])) {
                overloadId = 5; // items(QPointF,Qt::ItemSelectionMode,Qt::SortOrder,QTransform)const
            }
        }
    } else if (Shiboken::Converter< ::QPainterPath >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 2; // items(QPainterPath,Qt::ItemSelectionMode)const
        } else if (Shiboken::Converter< ::Qt::ItemSelectionMode >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 2; // items(QPainterPath,Qt::ItemSelectionMode)const
            } else if (Shiboken::Converter< ::Qt::SortOrder >::isConvertible(pyargs[2])) {
                if (numArgs == 3) {
                    overloadId = 3; // items(QPainterPath,Qt::ItemSelectionMode,Qt::SortOrder,QTransform)const
                } else if (Shiboken::Converter< ::QTransform >::isConvertible(pyargs[3])) {
                    overloadId = 3; // items(QPainterPath,Qt::ItemSelectionMode,Qt::SortOrder,QTransform)const
                }
            }
        }
    } else if (numArgs == 1 && Shiboken::Converter< ::Qt::SortOrder >::isConvertible(pyargs[0])) {
        overloadId = 1; // items(Qt::SortOrder)const
    } else if (numArgs >= 4 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2]) && SbkNumber_Check(pyargs[3])) {
        if (numArgs == 4) {
            overloadId = 10; // items(qreal,qreal,qreal,qreal,Qt::ItemSelectionMode)const
        } else if (Shiboken::Converter< ::Qt::ItemSelectionMode >::isConvertible(pyargs[4])) {
            if (numArgs == 5) {
                overloadId = 10; // items(qreal,qreal,qreal,qreal,Qt::ItemSelectionMode)const
            } else if (Shiboken::Converter< ::Qt::SortOrder >::isConvertible(pyargs[5])) {
                if (numArgs == 6) {
                    overloadId = 11; // items(qreal,qreal,qreal,qreal,Qt::ItemSelectionMode,Qt::SortOrder,QTransform)const
                } else if (Shiboken::Converter< ::QTransform >::isConvertible(pyargs[6])) {
                    overloadId = 11; // items(qreal,qreal,qreal,qreal,Qt::ItemSelectionMode,Qt::SortOrder,QTransform)const
                }
            }
        }
    } else if (Shiboken::Converter< ::QPolygonF >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 6; // items(QPolygonF,Qt::ItemSelectionMode)const
        } else if (Shiboken::Converter< ::Qt::ItemSelectionMode >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 6; // items(QPolygonF,Qt::ItemSelectionMode)const
            } else if (Shiboken::Converter< ::Qt::SortOrder >::isConvertible(pyargs[2])) {
                if (numArgs == 3) {
                    overloadId = 7; // items(QPolygonF,Qt::ItemSelectionMode,Qt::SortOrder,QTransform)const
                } else if (Shiboken::Converter< ::QTransform >::isConvertible(pyargs[3])) {
                    overloadId = 7; // items(QPolygonF,Qt::ItemSelectionMode,Qt::SortOrder,QTransform)const
                }
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGraphicsSceneFunc_items_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // items()const
            {

                if(!PyErr_Occurred()) {
                    // items()const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QList<QGraphicsItem * > cppResult = const_cast<const QGraphicsScene*>(cppSelf)->items();
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QList<QGraphicsItem * > >::toPython(cppResult);
                }
                break;
            }
            case 1: // items(Qt::SortOrder)const
            {
                Qt::SortOrder cppArg0 = Shiboken::Converter<Qt::SortOrder >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // items(Qt::SortOrder)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QList<QGraphicsItem * > cppResult = const_cast<const QGraphicsScene*>(cppSelf)->items(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QList<QGraphicsItem * > >::toPython(cppResult);
                }
                break;
            }
            case 2: // items(QPainterPath,Qt::ItemSelectionMode)const
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "mode");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "mode";
                        else if (Shiboken::Converter< ::Qt::ItemSelectionMode >::isConvertible(value))
                            pyargs[1] = value;
                        else
                            goto Sbk_QGraphicsSceneFunc_items_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QGraphicsScene.items(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QPainterPath cppArg0 = Shiboken::Converter<QPainterPath >::toCpp(pyargs[0]);
                Qt::ItemSelectionMode cppArg1 = pyargs[1] ? Shiboken::Converter<Qt::ItemSelectionMode >::toCpp(pyargs[1]) : Qt::IntersectsItemShape;

                if(!PyErr_Occurred()) {
                    // items(QPainterPath,Qt::ItemSelectionMode)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QList<QGraphicsItem * > cppResult = const_cast<const QGraphicsScene*>(cppSelf)->items(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QList<QGraphicsItem * > >::toPython(cppResult);
                }
                break;
            }
            case 3: // items(QPainterPath,Qt::ItemSelectionMode,Qt::SortOrder,QTransform)const
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "deviceTransform");
                    if (value) {
                        if (pyargs[3])
                            errorArgName = "deviceTransform";
                        else if (Shiboken::Converter< ::QTransform >::isConvertible(value))
                            pyargs[3] = value;
                        else
                            goto Sbk_QGraphicsSceneFunc_items_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QGraphicsScene.items(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QPainterPath cppArg0 = Shiboken::Converter<QPainterPath >::toCpp(pyargs[0]);
                Qt::ItemSelectionMode cppArg1 = Shiboken::Converter<Qt::ItemSelectionMode >::toCpp(pyargs[1]);
                Qt::SortOrder cppArg2 = Shiboken::Converter<Qt::SortOrder >::toCpp(pyargs[2]);
                if (!Shiboken::Object::isValid(pyargs[3]))
                    return 0;
                QTransform cppArg3_tmp = QTransform();
                QTransform cppArg3 = pyargs[3] ? Shiboken::Converter<QTransform >::toCpp(pyargs[3]) : cppArg3_tmp;

                if(!PyErr_Occurred()) {
                    // items(QPainterPath,Qt::ItemSelectionMode,Qt::SortOrder,QTransform)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QList<QGraphicsItem * > cppResult = const_cast<const QGraphicsScene*>(cppSelf)->items(cppArg0, cppArg1, cppArg2, cppArg3);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QList<QGraphicsItem * > >::toPython(cppResult);
                }
                break;
            }
            case 4: // items(QPointF)const
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QPointF cppArg0 = Shiboken::Converter<QPointF >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // items(QPointF)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QList<QGraphicsItem * > cppResult = const_cast<const QGraphicsScene*>(cppSelf)->items(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QList<QGraphicsItem * > >::toPython(cppResult);
                }
                break;
            }
            case 5: // items(QPointF,Qt::ItemSelectionMode,Qt::SortOrder,QTransform)const
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "deviceTransform");
                    if (value) {
                        if (pyargs[3])
                            errorArgName = "deviceTransform";
                        else if (Shiboken::Converter< ::QTransform >::isConvertible(value))
                            pyargs[3] = value;
                        else
                            goto Sbk_QGraphicsSceneFunc_items_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QGraphicsScene.items(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QPointF cppArg0 = Shiboken::Converter<QPointF >::toCpp(pyargs[0]);
                Qt::ItemSelectionMode cppArg1 = Shiboken::Converter<Qt::ItemSelectionMode >::toCpp(pyargs[1]);
                Qt::SortOrder cppArg2 = Shiboken::Converter<Qt::SortOrder >::toCpp(pyargs[2]);
                if (!Shiboken::Object::isValid(pyargs[3]))
                    return 0;
                QTransform cppArg3_tmp = QTransform();
                QTransform cppArg3 = pyargs[3] ? Shiboken::Converter<QTransform >::toCpp(pyargs[3]) : cppArg3_tmp;

                if(!PyErr_Occurred()) {
                    // items(QPointF,Qt::ItemSelectionMode,Qt::SortOrder,QTransform)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QList<QGraphicsItem * > cppResult = const_cast<const QGraphicsScene*>(cppSelf)->items(cppArg0, cppArg1, cppArg2, cppArg3);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QList<QGraphicsItem * > >::toPython(cppResult);
                }
                break;
            }
            case 6: // items(QPolygonF,Qt::ItemSelectionMode)const
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "mode");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "mode";
                        else if (Shiboken::Converter< ::Qt::ItemSelectionMode >::isConvertible(value))
                            pyargs[1] = value;
                        else
                            goto Sbk_QGraphicsSceneFunc_items_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QGraphicsScene.items(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QPolygonF cppArg0 = Shiboken::Converter<QPolygonF >::toCpp(pyargs[0]);
                Qt::ItemSelectionMode cppArg1 = pyargs[1] ? Shiboken::Converter<Qt::ItemSelectionMode >::toCpp(pyargs[1]) : Qt::IntersectsItemShape;

                if(!PyErr_Occurred()) {
                    // items(QPolygonF,Qt::ItemSelectionMode)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QList<QGraphicsItem * > cppResult = const_cast<const QGraphicsScene*>(cppSelf)->items(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QList<QGraphicsItem * > >::toPython(cppResult);
                }
                break;
            }
            case 7: // items(QPolygonF,Qt::ItemSelectionMode,Qt::SortOrder,QTransform)const
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "deviceTransform");
                    if (value) {
                        if (pyargs[3])
                            errorArgName = "deviceTransform";
                        else if (Shiboken::Converter< ::QTransform >::isConvertible(value))
                            pyargs[3] = value;
                        else
                            goto Sbk_QGraphicsSceneFunc_items_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QGraphicsScene.items(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QPolygonF cppArg0 = Shiboken::Converter<QPolygonF >::toCpp(pyargs[0]);
                Qt::ItemSelectionMode cppArg1 = Shiboken::Converter<Qt::ItemSelectionMode >::toCpp(pyargs[1]);
                Qt::SortOrder cppArg2 = Shiboken::Converter<Qt::SortOrder >::toCpp(pyargs[2]);
                if (!Shiboken::Object::isValid(pyargs[3]))
                    return 0;
                QTransform cppArg3_tmp = QTransform();
                QTransform cppArg3 = pyargs[3] ? Shiboken::Converter<QTransform >::toCpp(pyargs[3]) : cppArg3_tmp;

                if(!PyErr_Occurred()) {
                    // items(QPolygonF,Qt::ItemSelectionMode,Qt::SortOrder,QTransform)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QList<QGraphicsItem * > cppResult = const_cast<const QGraphicsScene*>(cppSelf)->items(cppArg0, cppArg1, cppArg2, cppArg3);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QList<QGraphicsItem * > >::toPython(cppResult);
                }
                break;
            }
            case 8: // items(QRectF,Qt::ItemSelectionMode)const
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "mode");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "mode";
                        else if (Shiboken::Converter< ::Qt::ItemSelectionMode >::isConvertible(value))
                            pyargs[1] = value;
                        else
                            goto Sbk_QGraphicsSceneFunc_items_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QGraphicsScene.items(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QRectF cppArg0 = Shiboken::Converter<QRectF >::toCpp(pyargs[0]);
                Qt::ItemSelectionMode cppArg1 = pyargs[1] ? Shiboken::Converter<Qt::ItemSelectionMode >::toCpp(pyargs[1]) : Qt::IntersectsItemShape;

                if(!PyErr_Occurred()) {
                    // items(QRectF,Qt::ItemSelectionMode)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QList<QGraphicsItem * > cppResult = const_cast<const QGraphicsScene*>(cppSelf)->items(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QList<QGraphicsItem * > >::toPython(cppResult);
                }
                break;
            }
            case 9: // items(QRectF,Qt::ItemSelectionMode,Qt::SortOrder,QTransform)const
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "deviceTransform");
                    if (value) {
                        if (pyargs[3])
                            errorArgName = "deviceTransform";
                        else if (Shiboken::Converter< ::QTransform >::isConvertible(value))
                            pyargs[3] = value;
                        else
                            goto Sbk_QGraphicsSceneFunc_items_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QGraphicsScene.items(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QRectF cppArg0 = Shiboken::Converter<QRectF >::toCpp(pyargs[0]);
                Qt::ItemSelectionMode cppArg1 = Shiboken::Converter<Qt::ItemSelectionMode >::toCpp(pyargs[1]);
                Qt::SortOrder cppArg2 = Shiboken::Converter<Qt::SortOrder >::toCpp(pyargs[2]);
                if (!Shiboken::Object::isValid(pyargs[3]))
                    return 0;
                QTransform cppArg3_tmp = QTransform();
                QTransform cppArg3 = pyargs[3] ? Shiboken::Converter<QTransform >::toCpp(pyargs[3]) : cppArg3_tmp;

                if(!PyErr_Occurred()) {
                    // items(QRectF,Qt::ItemSelectionMode,Qt::SortOrder,QTransform)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QList<QGraphicsItem * > cppResult = const_cast<const QGraphicsScene*>(cppSelf)->items(cppArg0, cppArg1, cppArg2, cppArg3);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QList<QGraphicsItem * > >::toPython(cppResult);
                }
                break;
            }
            case 10: // items(qreal,qreal,qreal,qreal,Qt::ItemSelectionMode)const
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "mode");
                    if (value) {
                        if (pyargs[4])
                            errorArgName = "mode";
                        else if (Shiboken::Converter< ::Qt::ItemSelectionMode >::isConvertible(value))
                            pyargs[4] = value;
                        else
                            goto Sbk_QGraphicsSceneFunc_items_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QGraphicsScene.items(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                qreal cppArg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
                qreal cppArg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);
                qreal cppArg2 = Shiboken::Converter<qreal >::toCpp(pyargs[2]);
                qreal cppArg3 = Shiboken::Converter<qreal >::toCpp(pyargs[3]);
                Qt::ItemSelectionMode cppArg4 = pyargs[4] ? Shiboken::Converter<Qt::ItemSelectionMode >::toCpp(pyargs[4]) : Qt::IntersectsItemShape;

                if(!PyErr_Occurred()) {
                    // items(qreal,qreal,qreal,qreal,Qt::ItemSelectionMode)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QList<QGraphicsItem * > cppResult = const_cast<const QGraphicsScene*>(cppSelf)->items(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QList<QGraphicsItem * > >::toPython(cppResult);
                }
                break;
            }
            case 11: // items(qreal,qreal,qreal,qreal,Qt::ItemSelectionMode,Qt::SortOrder,QTransform)const
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "deviceTransform");
                    if (value) {
                        if (pyargs[6])
                            errorArgName = "deviceTransform";
                        else if (Shiboken::Converter< ::QTransform >::isConvertible(value))
                            pyargs[6] = value;
                        else
                            goto Sbk_QGraphicsSceneFunc_items_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QGraphicsScene.items(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                qreal cppArg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
                qreal cppArg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);
                qreal cppArg2 = Shiboken::Converter<qreal >::toCpp(pyargs[2]);
                qreal cppArg3 = Shiboken::Converter<qreal >::toCpp(pyargs[3]);
                Qt::ItemSelectionMode cppArg4 = Shiboken::Converter<Qt::ItemSelectionMode >::toCpp(pyargs[4]);
                Qt::SortOrder cppArg5 = Shiboken::Converter<Qt::SortOrder >::toCpp(pyargs[5]);
                if (!Shiboken::Object::isValid(pyargs[6]))
                    return 0;
                QTransform cppArg6_tmp = QTransform();
                QTransform cppArg6 = pyargs[6] ? Shiboken::Converter<QTransform >::toCpp(pyargs[6]) : cppArg6_tmp;

                if(!PyErr_Occurred()) {
                    // items(qreal,qreal,qreal,qreal,Qt::ItemSelectionMode,Qt::SortOrder,QTransform)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QList<QGraphicsItem * > cppResult = const_cast<const QGraphicsScene*>(cppSelf)->items(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5, cppArg6);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QList<QGraphicsItem * > >::toPython(cppResult);
                }
                break;
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QGraphicsSceneFunc_items_TypeError:
        const char* overloads[] = {"", "PySide.QtCore.Qt.SortOrder", "PySide.QtGui.QPainterPath, PySide.QtCore.Qt.ItemSelectionMode = Qt.IntersectsItemShape", "PySide.QtGui.QPainterPath, PySide.QtCore.Qt.ItemSelectionMode, PySide.QtCore.Qt.SortOrder, PySide.QtGui.QTransform = QTransform()", "PySide.QtCore.QPointF", "PySide.QtCore.QPointF, PySide.QtCore.Qt.ItemSelectionMode, PySide.QtCore.Qt.SortOrder, PySide.QtGui.QTransform = QTransform()", "PySide.QtGui.QPolygonF, PySide.QtCore.Qt.ItemSelectionMode = Qt.IntersectsItemShape", "PySide.QtGui.QPolygonF, PySide.QtCore.Qt.ItemSelectionMode, PySide.QtCore.Qt.SortOrder, PySide.QtGui.QTransform = QTransform()", "PySide.QtCore.QRectF, PySide.QtCore.Qt.ItemSelectionMode = Qt.IntersectsItemShape", "PySide.QtCore.QRectF, PySide.QtCore.Qt.ItemSelectionMode, PySide.QtCore.Qt.SortOrder, PySide.QtGui.QTransform = QTransform()", "float, float, float, float, PySide.QtCore.Qt.ItemSelectionMode = Qt.IntersectsItemShape", "float, float, float, float, PySide.QtCore.Qt.ItemSelectionMode, PySide.QtCore.Qt.SortOrder, PySide.QtGui.QTransform = QTransform()", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QGraphicsScene.items", overloads);
        return 0;
}

static PyObject* Sbk_QGraphicsSceneFunc_itemsBoundingRect(PyObject* self)
{
    QGraphicsScene* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsScene* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // itemsBoundingRect()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QRectF cppResult = const_cast<const QGraphicsScene*>(cppSelf)->itemsBoundingRect();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QRectF >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QGraphicsSceneFunc_keyPressEvent(PyObject* self, PyObject* arg)
{
    QGraphicsScene* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsScene* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: keyPressEvent(QKeyEvent*)
    if (Shiboken::Converter< ::QKeyEvent * >::isConvertible(arg)) {
        overloadId = 0; // keyPressEvent(QKeyEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGraphicsSceneFunc_keyPressEvent_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QKeyEvent * cppArg0 = Shiboken::Converter<QKeyEvent * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // keyPressEvent(QKeyEvent*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QGraphicsScene::keyPressEvent(cppArg0) : cppSelf->keyPressEvent(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGraphicsSceneFunc_keyPressEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QKeyEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsScene.keyPressEvent", overloads);
        return 0;
}

static PyObject* Sbk_QGraphicsSceneFunc_keyReleaseEvent(PyObject* self, PyObject* arg)
{
    QGraphicsScene* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsScene* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: keyReleaseEvent(QKeyEvent*)
    if (Shiboken::Converter< ::QKeyEvent * >::isConvertible(arg)) {
        overloadId = 0; // keyReleaseEvent(QKeyEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGraphicsSceneFunc_keyReleaseEvent_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QKeyEvent * cppArg0 = Shiboken::Converter<QKeyEvent * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // keyReleaseEvent(QKeyEvent*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QGraphicsScene::keyReleaseEvent(cppArg0) : cppSelf->keyReleaseEvent(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGraphicsSceneFunc_keyReleaseEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QKeyEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsScene.keyReleaseEvent", overloads);
        return 0;
}

static PyObject* Sbk_QGraphicsSceneFunc_mouseDoubleClickEvent(PyObject* self, PyObject* arg)
{
    QGraphicsScene* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsScene* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: mouseDoubleClickEvent(QGraphicsSceneMouseEvent*)
    if (Shiboken::Converter< ::QGraphicsSceneMouseEvent * >::isConvertible(arg)) {
        overloadId = 0; // mouseDoubleClickEvent(QGraphicsSceneMouseEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGraphicsSceneFunc_mouseDoubleClickEvent_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QGraphicsSceneMouseEvent * cppArg0 = Shiboken::Converter<QGraphicsSceneMouseEvent * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // mouseDoubleClickEvent(QGraphicsSceneMouseEvent*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QGraphicsScene::mouseDoubleClickEvent(cppArg0) : cppSelf->mouseDoubleClickEvent(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGraphicsSceneFunc_mouseDoubleClickEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QGraphicsSceneMouseEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsScene.mouseDoubleClickEvent", overloads);
        return 0;
}

static PyObject* Sbk_QGraphicsSceneFunc_mouseGrabberItem(PyObject* self)
{
    QGraphicsScene* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsScene* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // mouseGrabberItem()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QGraphicsItem * cppResult = const_cast<const QGraphicsScene*>(cppSelf)->mouseGrabberItem();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QGraphicsItem * >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QGraphicsSceneFunc_mouseMoveEvent(PyObject* self, PyObject* arg)
{
    QGraphicsScene* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsScene* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: mouseMoveEvent(QGraphicsSceneMouseEvent*)
    if (Shiboken::Converter< ::QGraphicsSceneMouseEvent * >::isConvertible(arg)) {
        overloadId = 0; // mouseMoveEvent(QGraphicsSceneMouseEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGraphicsSceneFunc_mouseMoveEvent_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QGraphicsSceneMouseEvent * cppArg0 = Shiboken::Converter<QGraphicsSceneMouseEvent * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // mouseMoveEvent(QGraphicsSceneMouseEvent*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QGraphicsScene::mouseMoveEvent(cppArg0) : cppSelf->mouseMoveEvent(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGraphicsSceneFunc_mouseMoveEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QGraphicsSceneMouseEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsScene.mouseMoveEvent", overloads);
        return 0;
}

static PyObject* Sbk_QGraphicsSceneFunc_mousePressEvent(PyObject* self, PyObject* arg)
{
    QGraphicsScene* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsScene* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: mousePressEvent(QGraphicsSceneMouseEvent*)
    if (Shiboken::Converter< ::QGraphicsSceneMouseEvent * >::isConvertible(arg)) {
        overloadId = 0; // mousePressEvent(QGraphicsSceneMouseEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGraphicsSceneFunc_mousePressEvent_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QGraphicsSceneMouseEvent * cppArg0 = Shiboken::Converter<QGraphicsSceneMouseEvent * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // mousePressEvent(QGraphicsSceneMouseEvent*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QGraphicsScene::mousePressEvent(cppArg0) : cppSelf->mousePressEvent(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGraphicsSceneFunc_mousePressEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QGraphicsSceneMouseEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsScene.mousePressEvent", overloads);
        return 0;
}

static PyObject* Sbk_QGraphicsSceneFunc_mouseReleaseEvent(PyObject* self, PyObject* arg)
{
    QGraphicsScene* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsScene* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: mouseReleaseEvent(QGraphicsSceneMouseEvent*)
    if (Shiboken::Converter< ::QGraphicsSceneMouseEvent * >::isConvertible(arg)) {
        overloadId = 0; // mouseReleaseEvent(QGraphicsSceneMouseEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGraphicsSceneFunc_mouseReleaseEvent_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QGraphicsSceneMouseEvent * cppArg0 = Shiboken::Converter<QGraphicsSceneMouseEvent * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // mouseReleaseEvent(QGraphicsSceneMouseEvent*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QGraphicsScene::mouseReleaseEvent(cppArg0) : cppSelf->mouseReleaseEvent(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGraphicsSceneFunc_mouseReleaseEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QGraphicsSceneMouseEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsScene.mouseReleaseEvent", overloads);
        return 0;
}

static PyObject* Sbk_QGraphicsSceneFunc_palette(PyObject* self)
{
    QGraphicsScene* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsScene* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // palette()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QPalette cppResult = const_cast<const QGraphicsScene*>(cppSelf)->palette();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QPalette >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QGraphicsSceneFunc_removeItem(PyObject* self, PyObject* arg)
{
    QGraphicsScene* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsScene* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: removeItem(QGraphicsItem*)
    if (Shiboken::Converter< ::QGraphicsItem * >::isConvertible(arg)) {
        overloadId = 0; // removeItem(QGraphicsItem*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGraphicsSceneFunc_removeItem_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QGraphicsItem * cppArg0 = Shiboken::Converter<QGraphicsItem * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // removeItem(QGraphicsItem*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->removeItem(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                Shiboken::Object::setParent(Py_None, arg);
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGraphicsSceneFunc_removeItem_TypeError:
        const char* overloads[] = {"PySide.QtGui.QGraphicsItem", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsScene.removeItem", overloads);
        return 0;
}

static PyObject* Sbk_QGraphicsSceneFunc_render(PyObject* self, PyObject* args, PyObject* kwds)
{
    QGraphicsScene* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsScene* >::toCpp(self);

    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 4) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QGraphicsScene.render(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QGraphicsScene.render(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOOO:render", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return 0;


    // Overloaded function decisor
    // 0: render(QPainter*,QRectF,QRectF,Qt::AspectRatioMode)
    if (Shiboken::Converter< ::QPainter * >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // render(QPainter*,QRectF,QRectF,Qt::AspectRatioMode)
        } else if (Shiboken::Converter< ::QRectF >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 0; // render(QPainter*,QRectF,QRectF,Qt::AspectRatioMode)
            } else if (Shiboken::Converter< ::QRectF >::isConvertible(pyargs[2])) {
                if (numArgs == 3) {
                    overloadId = 0; // render(QPainter*,QRectF,QRectF,Qt::AspectRatioMode)
                } else if (Shiboken::Converter< ::Qt::AspectRatioMode >::isConvertible(pyargs[3])) {
                    overloadId = 0; // render(QPainter*,QRectF,QRectF,Qt::AspectRatioMode)
                }
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGraphicsSceneFunc_render_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "target");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "target";
                    else if (Shiboken::Converter< ::QRectF >::isConvertible(value))
                        pyargs[1] = value;
                    else
                        goto Sbk_QGraphicsSceneFunc_render_TypeError;
                }
                value = PyDict_GetItemString(kwds, "source");
                if (value) {
                    if (pyargs[2])
                        errorArgName = "source";
                    else if (Shiboken::Converter< ::QRectF >::isConvertible(value))
                        pyargs[2] = value;
                    else
                        goto Sbk_QGraphicsSceneFunc_render_TypeError;
                }
                value = PyDict_GetItemString(kwds, "aspectRatioMode");
                if (value) {
                    if (pyargs[3])
                        errorArgName = "aspectRatioMode";
                    else if (Shiboken::Converter< ::Qt::AspectRatioMode >::isConvertible(value))
                        pyargs[3] = value;
                    else
                        goto Sbk_QGraphicsSceneFunc_render_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QGraphicsScene.render(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QPainter * cppArg0 = Shiboken::Converter<QPainter * >::toCpp(pyargs[0]);
            if (!Shiboken::Object::isValid(pyargs[1]))
                return 0;
            QRectF cppArg1_tmp = QRectF();
            QRectF cppArg1 = pyargs[1] ? Shiboken::Converter<QRectF >::toCpp(pyargs[1]) : cppArg1_tmp;
            if (!Shiboken::Object::isValid(pyargs[2]))
                return 0;
            QRectF cppArg2_tmp = QRectF();
            QRectF cppArg2 = pyargs[2] ? Shiboken::Converter<QRectF >::toCpp(pyargs[2]) : cppArg2_tmp;
            Qt::AspectRatioMode cppArg3 = pyargs[3] ? Shiboken::Converter<Qt::AspectRatioMode >::toCpp(pyargs[3]) : Qt::KeepAspectRatio;

            if(!PyErr_Occurred()) {
                // render(QPainter*,QRectF,QRectF,Qt::AspectRatioMode)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->render(cppArg0, cppArg1, cppArg2, cppArg3);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGraphicsSceneFunc_render_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPainter, PySide.QtCore.QRectF = QRectF(), PySide.QtCore.QRectF = QRectF(), PySide.QtCore.Qt.AspectRatioMode = Qt.KeepAspectRatio", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QGraphicsScene.render", overloads);
        return 0;
}

static PyObject* Sbk_QGraphicsSceneFunc_sceneRect(PyObject* self)
{
    QGraphicsScene* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsScene* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // sceneRect()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QRectF cppResult = const_cast<const QGraphicsScene*>(cppSelf)->sceneRect();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QRectF >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QGraphicsSceneFunc_selectedItems(PyObject* self)
{
    QGraphicsScene* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsScene* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // selectedItems()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QList<QGraphicsItem * > cppResult = const_cast<const QGraphicsScene*>(cppSelf)->selectedItems();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QList<QGraphicsItem * > >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QGraphicsSceneFunc_selectionArea(PyObject* self)
{
    QGraphicsScene* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsScene* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // selectionArea()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QPainterPath cppResult = const_cast<const QGraphicsScene*>(cppSelf)->selectionArea();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QPainterPath >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QGraphicsSceneFunc_sendEvent(PyObject* self, PyObject* args)
{
    QGraphicsScene* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsScene* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "sendEvent", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: sendEvent(QGraphicsItem*,QEvent*)
    if (numArgs == 2 && Shiboken::Converter< ::QGraphicsItem * >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QEvent * >::isConvertible(pyargs[1])) {
        overloadId = 0; // sendEvent(QGraphicsItem*,QEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGraphicsSceneFunc_sendEvent_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QGraphicsItem * cppArg0 = Shiboken::Converter<QGraphicsItem * >::toCpp(pyargs[0]);
            if (!Shiboken::Object::isValid(pyargs[1]))
                return 0;
            QEvent * cppArg1 = Shiboken::Converter<QEvent * >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // sendEvent(QGraphicsItem*,QEvent*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->sendEvent(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QGraphicsSceneFunc_sendEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QGraphicsItem, PySide.QtCore.QEvent", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QGraphicsScene.sendEvent", overloads);
        return 0;
}

static PyObject* Sbk_QGraphicsSceneFunc_setActivePanel(PyObject* self, PyObject* arg)
{
    QGraphicsScene* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsScene* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setActivePanel(QGraphicsItem*)
    if (Shiboken::Converter< ::QGraphicsItem * >::isConvertible(arg)) {
        overloadId = 0; // setActivePanel(QGraphicsItem*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGraphicsSceneFunc_setActivePanel_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QGraphicsItem * cppArg0 = Shiboken::Converter<QGraphicsItem * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setActivePanel(QGraphicsItem*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setActivePanel(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGraphicsSceneFunc_setActivePanel_TypeError:
        const char* overloads[] = {"PySide.QtGui.QGraphicsItem", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsScene.setActivePanel", overloads);
        return 0;
}

static PyObject* Sbk_QGraphicsSceneFunc_setActiveWindow(PyObject* self, PyObject* arg)
{
    QGraphicsScene* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsScene* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setActiveWindow(QGraphicsWidget*)
    if (Shiboken::Converter< ::QGraphicsWidget * >::isConvertible(arg)) {
        overloadId = 0; // setActiveWindow(QGraphicsWidget*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGraphicsSceneFunc_setActiveWindow_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QGraphicsWidget * cppArg0 = Shiboken::Converter<QGraphicsWidget * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setActiveWindow(QGraphicsWidget*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setActiveWindow(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGraphicsSceneFunc_setActiveWindow_TypeError:
        const char* overloads[] = {"PySide.QtGui.QGraphicsWidget", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsScene.setActiveWindow", overloads);
        return 0;
}

static PyObject* Sbk_QGraphicsSceneFunc_setBackgroundBrush(PyObject* self, PyObject* arg)
{
    QGraphicsScene* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsScene* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setBackgroundBrush(QBrush)
    if (Shiboken::Converter< ::QBrush >::isConvertible(arg)) {
        overloadId = 0; // setBackgroundBrush(QBrush)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGraphicsSceneFunc_setBackgroundBrush_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QBrush cppArg0 = Shiboken::Converter<QBrush >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setBackgroundBrush(QBrush)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setBackgroundBrush(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGraphicsSceneFunc_setBackgroundBrush_TypeError:
        const char* overloads[] = {"PySide.QtGui.QBrush", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsScene.setBackgroundBrush", overloads);
        return 0;
}

static PyObject* Sbk_QGraphicsSceneFunc_setBspTreeDepth(PyObject* self, PyObject* arg)
{
    QGraphicsScene* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsScene* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setBspTreeDepth(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setBspTreeDepth(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGraphicsSceneFunc_setBspTreeDepth_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setBspTreeDepth(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setBspTreeDepth(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGraphicsSceneFunc_setBspTreeDepth_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsScene.setBspTreeDepth", overloads);
        return 0;
}

static PyObject* Sbk_QGraphicsSceneFunc_setFocus(PyObject* self, PyObject* args, PyObject* kwds)
{
    QGraphicsScene* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsScene* >::toCpp(self);

    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QGraphicsScene.setFocus(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:setFocus", &(pyargs[0])))
        return 0;


    // Overloaded function decisor
    // 0: setFocus(Qt::FocusReason)
    if (numArgs == 0) {
        overloadId = 0; // setFocus(Qt::FocusReason)
    } else if (Shiboken::Converter< ::Qt::FocusReason >::isConvertible(pyargs[0])) {
        overloadId = 0; // setFocus(Qt::FocusReason)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGraphicsSceneFunc_setFocus_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "focusReason");
                if (value) {
                    if (pyargs[0])
                        errorArgName = "focusReason";
                    else if (Shiboken::Converter< ::Qt::FocusReason >::isConvertible(value))
                        pyargs[0] = value;
                    else
                        goto Sbk_QGraphicsSceneFunc_setFocus_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QGraphicsScene.setFocus(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            Qt::FocusReason cppArg0 = pyargs[0] ? Shiboken::Converter<Qt::FocusReason >::toCpp(pyargs[0]) : Qt::OtherFocusReason;

            if(!PyErr_Occurred()) {
                // setFocus(Qt::FocusReason)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setFocus(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGraphicsSceneFunc_setFocus_TypeError:
        const char* overloads[] = {"PySide.QtCore.Qt.FocusReason = Qt.OtherFocusReason", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QGraphicsScene.setFocus", overloads);
        return 0;
}

static PyObject* Sbk_QGraphicsSceneFunc_setFocusItem(PyObject* self, PyObject* args, PyObject* kwds)
{
    QGraphicsScene* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsScene* >::toCpp(self);

    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QGraphicsScene.setFocusItem(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QGraphicsScene.setFocusItem(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:setFocusItem", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setFocusItem(QGraphicsItem*,Qt::FocusReason)
    if (Shiboken::Converter< ::QGraphicsItem * >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // setFocusItem(QGraphicsItem*,Qt::FocusReason)
        } else if (Shiboken::Converter< ::Qt::FocusReason >::isConvertible(pyargs[1])) {
            overloadId = 0; // setFocusItem(QGraphicsItem*,Qt::FocusReason)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGraphicsSceneFunc_setFocusItem_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "focusReason");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "focusReason";
                    else if (Shiboken::Converter< ::Qt::FocusReason >::isConvertible(value))
                        pyargs[1] = value;
                    else
                        goto Sbk_QGraphicsSceneFunc_setFocusItem_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QGraphicsScene.setFocusItem(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QGraphicsItem * cppArg0 = Shiboken::Converter<QGraphicsItem * >::toCpp(pyargs[0]);
            Qt::FocusReason cppArg1 = pyargs[1] ? Shiboken::Converter<Qt::FocusReason >::toCpp(pyargs[1]) : Qt::OtherFocusReason;

            if(!PyErr_Occurred()) {
                // setFocusItem(QGraphicsItem*,Qt::FocusReason)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setFocusItem(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                Shiboken::Object::setParent(self, pyargs[0]);
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGraphicsSceneFunc_setFocusItem_TypeError:
        const char* overloads[] = {"PySide.QtGui.QGraphicsItem, PySide.QtCore.Qt.FocusReason = Qt.OtherFocusReason", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QGraphicsScene.setFocusItem", overloads);
        return 0;
}

static PyObject* Sbk_QGraphicsSceneFunc_setFont(PyObject* self, PyObject* arg)
{
    QGraphicsScene* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsScene* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setFont(QFont)
    if (Shiboken::Converter< ::QFont >::isConvertible(arg)) {
        overloadId = 0; // setFont(QFont)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGraphicsSceneFunc_setFont_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QFont cppArg0 = Shiboken::Converter<QFont >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setFont(QFont)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setFont(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGraphicsSceneFunc_setFont_TypeError:
        const char* overloads[] = {"PySide.QtGui.QFont", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsScene.setFont", overloads);
        return 0;
}

static PyObject* Sbk_QGraphicsSceneFunc_setForegroundBrush(PyObject* self, PyObject* arg)
{
    QGraphicsScene* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsScene* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setForegroundBrush(QBrush)
    if (Shiboken::Converter< ::QBrush >::isConvertible(arg)) {
        overloadId = 0; // setForegroundBrush(QBrush)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGraphicsSceneFunc_setForegroundBrush_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QBrush cppArg0 = Shiboken::Converter<QBrush >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setForegroundBrush(QBrush)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setForegroundBrush(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGraphicsSceneFunc_setForegroundBrush_TypeError:
        const char* overloads[] = {"PySide.QtGui.QBrush", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsScene.setForegroundBrush", overloads);
        return 0;
}

static PyObject* Sbk_QGraphicsSceneFunc_setItemIndexMethod(PyObject* self, PyObject* arg)
{
    QGraphicsScene* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsScene* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setItemIndexMethod(QGraphicsScene::ItemIndexMethod)
    if (Shiboken::Converter< ::QGraphicsScene::ItemIndexMethod >::isConvertible(arg)) {
        overloadId = 0; // setItemIndexMethod(QGraphicsScene::ItemIndexMethod)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGraphicsSceneFunc_setItemIndexMethod_TypeError;

    // Call function/method
    {
        {
            QGraphicsScene::ItemIndexMethod cppArg0 = Shiboken::Converter<QGraphicsScene::ItemIndexMethod >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setItemIndexMethod(QGraphicsScene::ItemIndexMethod)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setItemIndexMethod(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGraphicsSceneFunc_setItemIndexMethod_TypeError:
        const char* overloads[] = {"PySide.QtGui.QGraphicsScene.ItemIndexMethod", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsScene.setItemIndexMethod", overloads);
        return 0;
}

static PyObject* Sbk_QGraphicsSceneFunc_setPalette(PyObject* self, PyObject* arg)
{
    QGraphicsScene* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsScene* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setPalette(QPalette)
    if (Shiboken::Converter< ::QPalette >::isConvertible(arg)) {
        overloadId = 0; // setPalette(QPalette)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGraphicsSceneFunc_setPalette_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QPalette cppArg0 = Shiboken::Converter<QPalette >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setPalette(QPalette)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setPalette(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGraphicsSceneFunc_setPalette_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPalette", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsScene.setPalette", overloads);
        return 0;
}

static PyObject* Sbk_QGraphicsSceneFunc_setSceneRect(PyObject* self, PyObject* args)
{
    QGraphicsScene* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsScene* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs == 2 || numArgs == 3)
        goto Sbk_QGraphicsSceneFunc_setSceneRect_TypeError;

    if (!PyArg_UnpackTuple(args, "setSceneRect", 1, 4, &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return 0;


    // Overloaded function decisor
    // 0: setSceneRect(QRectF)
    // 1: setSceneRect(qreal,qreal,qreal,qreal)
    if (numArgs == 4 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2]) && SbkNumber_Check(pyargs[3])) {
        overloadId = 1; // setSceneRect(qreal,qreal,qreal,qreal)
    } else if (numArgs == 1 && Shiboken::Converter< ::QRectF >::isConvertible(pyargs[0])) {
        overloadId = 0; // setSceneRect(QRectF)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGraphicsSceneFunc_setSceneRect_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // setSceneRect(QRectF)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QRectF cppArg0 = Shiboken::Converter<QRectF >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // setSceneRect(QRectF)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setSceneRect(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // setSceneRect(qreal,qreal,qreal,qreal)
            {
                qreal cppArg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
                qreal cppArg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);
                qreal cppArg2 = Shiboken::Converter<qreal >::toCpp(pyargs[2]);
                qreal cppArg3 = Shiboken::Converter<qreal >::toCpp(pyargs[3]);

                if(!PyErr_Occurred()) {
                    // setSceneRect(qreal,qreal,qreal,qreal)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setSceneRect(cppArg0, cppArg1, cppArg2, cppArg3);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGraphicsSceneFunc_setSceneRect_TypeError:
        const char* overloads[] = {"PySide.QtCore.QRectF", "float, float, float, float", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QGraphicsScene.setSceneRect", overloads);
        return 0;
}

static PyObject* Sbk_QGraphicsSceneFunc_setSelectionArea(PyObject* self, PyObject* args)
{
    QGraphicsScene* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsScene* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setSelectionArea", 1, 3, &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: setSelectionArea(QPainterPath)
    // 1: setSelectionArea(QPainterPath,Qt::ItemSelectionMode)
    // 2: setSelectionArea(QPainterPath,Qt::ItemSelectionMode,QTransform)
    // 3: setSelectionArea(QPainterPath,QTransform)
    if (Shiboken::Converter< ::QPainterPath >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // setSelectionArea(QPainterPath)
        } else if (numArgs == 2 && Shiboken::Converter< ::QTransform >::isConvertible(pyargs[1])) {
            overloadId = 3; // setSelectionArea(QPainterPath,QTransform)
        } else if (Shiboken::Converter< ::Qt::ItemSelectionMode >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 1; // setSelectionArea(QPainterPath,Qt::ItemSelectionMode)
            } else if (numArgs == 3 && Shiboken::Converter< ::QTransform >::isConvertible(pyargs[2])) {
                overloadId = 2; // setSelectionArea(QPainterPath,Qt::ItemSelectionMode,QTransform)
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGraphicsSceneFunc_setSelectionArea_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // setSelectionArea(QPainterPath)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QPainterPath cppArg0 = Shiboken::Converter<QPainterPath >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // setSelectionArea(QPainterPath)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setSelectionArea(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // setSelectionArea(QPainterPath,Qt::ItemSelectionMode)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QPainterPath cppArg0 = Shiboken::Converter<QPainterPath >::toCpp(pyargs[0]);
                Qt::ItemSelectionMode cppArg1 = Shiboken::Converter<Qt::ItemSelectionMode >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // setSelectionArea(QPainterPath,Qt::ItemSelectionMode)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setSelectionArea(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 2: // setSelectionArea(QPainterPath,Qt::ItemSelectionMode,QTransform)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QPainterPath cppArg0 = Shiboken::Converter<QPainterPath >::toCpp(pyargs[0]);
                Qt::ItemSelectionMode cppArg1 = Shiboken::Converter<Qt::ItemSelectionMode >::toCpp(pyargs[1]);
                if (!Shiboken::Object::isValid(pyargs[2]))
                    return 0;
                QTransform cppArg2 = Shiboken::Converter<QTransform >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                    // setSelectionArea(QPainterPath,Qt::ItemSelectionMode,QTransform)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setSelectionArea(cppArg0, cppArg1, cppArg2);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 3: // setSelectionArea(QPainterPath,QTransform)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QPainterPath cppArg0 = Shiboken::Converter<QPainterPath >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return 0;
                QTransform cppArg1 = Shiboken::Converter<QTransform >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // setSelectionArea(QPainterPath,QTransform)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setSelectionArea(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGraphicsSceneFunc_setSelectionArea_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPainterPath", "PySide.QtGui.QPainterPath, PySide.QtCore.Qt.ItemSelectionMode", "PySide.QtGui.QPainterPath, PySide.QtCore.Qt.ItemSelectionMode, PySide.QtGui.QTransform", "PySide.QtGui.QPainterPath, PySide.QtGui.QTransform", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QGraphicsScene.setSelectionArea", overloads);
        return 0;
}

static PyObject* Sbk_QGraphicsSceneFunc_setSortCacheEnabled(PyObject* self, PyObject* arg)
{
    QGraphicsScene* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsScene* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setSortCacheEnabled(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setSortCacheEnabled(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGraphicsSceneFunc_setSortCacheEnabled_TypeError;

    // Call function/method
    {
        {
            bool cppArg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setSortCacheEnabled(bool)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setSortCacheEnabled(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGraphicsSceneFunc_setSortCacheEnabled_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsScene.setSortCacheEnabled", overloads);
        return 0;
}

static PyObject* Sbk_QGraphicsSceneFunc_setStickyFocus(PyObject* self, PyObject* arg)
{
    QGraphicsScene* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsScene* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setStickyFocus(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setStickyFocus(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGraphicsSceneFunc_setStickyFocus_TypeError;

    // Call function/method
    {
        {
            bool cppArg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setStickyFocus(bool)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setStickyFocus(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGraphicsSceneFunc_setStickyFocus_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsScene.setStickyFocus", overloads);
        return 0;
}

static PyObject* Sbk_QGraphicsSceneFunc_setStyle(PyObject* self, PyObject* arg)
{
    QGraphicsScene* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsScene* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setStyle(QStyle*)
    if (Shiboken::Converter< ::QStyle * >::isConvertible(arg)) {
        overloadId = 0; // setStyle(QStyle*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGraphicsSceneFunc_setStyle_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QStyle * cppArg0 = Shiboken::Converter<QStyle * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setStyle(QStyle*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setStyle(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGraphicsSceneFunc_setStyle_TypeError:
        const char* overloads[] = {"PySide.QtGui.QStyle", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsScene.setStyle", overloads);
        return 0;
}

static PyObject* Sbk_QGraphicsSceneFunc_stickyFocus(PyObject* self)
{
    QGraphicsScene* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsScene* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // stickyFocus()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QGraphicsScene*>(cppSelf)->stickyFocus();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QGraphicsSceneFunc_style(PyObject* self)
{
    QGraphicsScene* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsScene* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // style()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QStyle * cppResult = const_cast<const QGraphicsScene*>(cppSelf)->style();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QStyle * >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QGraphicsSceneFunc_update(PyObject* self, PyObject* args, PyObject* kwds)
{
    QGraphicsScene* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsScene* >::toCpp(self);

    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 4) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QGraphicsScene.update(): too many arguments");
        return 0;
    } else if (numArgs == 2 || numArgs == 3)
        goto Sbk_QGraphicsSceneFunc_update_TypeError;

    if (!PyArg_ParseTuple(args, "|OOOO:update", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return 0;


    // Overloaded function decisor
    // 0: update(QRectF)
    // 1: update(qreal,qreal,qreal,qreal)
    if (numArgs == 0) {
        overloadId = 0; // update(QRectF)
    } else if (numArgs == 4 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2]) && SbkNumber_Check(pyargs[3])) {
        overloadId = 1; // update(qreal,qreal,qreal,qreal)
    } else if (Shiboken::Converter< ::QRectF >::isConvertible(pyargs[0])) {
        overloadId = 0; // update(QRectF)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGraphicsSceneFunc_update_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // update(QRectF)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "rect");
                    if (value) {
                        if (pyargs[0])
                            errorArgName = "rect";
                        else if (Shiboken::Converter< ::QRectF >::isConvertible(value))
                            pyargs[0] = value;
                        else
                            goto Sbk_QGraphicsSceneFunc_update_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QGraphicsScene.update(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QRectF cppArg0_tmp = QRectF();
                QRectF cppArg0 = pyargs[0] ? Shiboken::Converter<QRectF >::toCpp(pyargs[0]) : cppArg0_tmp;

                if(!PyErr_Occurred()) {
                    // update(QRectF)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->update(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // update(qreal,qreal,qreal,qreal)
            {
                qreal cppArg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
                qreal cppArg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);
                qreal cppArg2 = Shiboken::Converter<qreal >::toCpp(pyargs[2]);
                qreal cppArg3 = Shiboken::Converter<qreal >::toCpp(pyargs[3]);

                if(!PyErr_Occurred()) {
                    // update(qreal,qreal,qreal,qreal)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->update(cppArg0, cppArg1, cppArg2, cppArg3);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGraphicsSceneFunc_update_TypeError:
        const char* overloads[] = {"PySide.QtCore.QRectF = QRectF()", "float, float, float, float", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QGraphicsScene.update", overloads);
        return 0;
}

static PyObject* Sbk_QGraphicsSceneFunc_views(PyObject* self)
{
    QGraphicsScene* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsScene* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // views()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QList<QGraphicsView * > cppResult = const_cast<const QGraphicsScene*>(cppSelf)->views();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QList<QGraphicsView * > >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QGraphicsSceneFunc_wheelEvent(PyObject* self, PyObject* arg)
{
    QGraphicsScene* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsScene* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: wheelEvent(QGraphicsSceneWheelEvent*)
    if (Shiboken::Converter< ::QGraphicsSceneWheelEvent * >::isConvertible(arg)) {
        overloadId = 0; // wheelEvent(QGraphicsSceneWheelEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGraphicsSceneFunc_wheelEvent_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QGraphicsSceneWheelEvent * cppArg0 = Shiboken::Converter<QGraphicsSceneWheelEvent * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // wheelEvent(QGraphicsSceneWheelEvent*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QGraphicsScene::wheelEvent(cppArg0) : cppSelf->wheelEvent(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGraphicsSceneFunc_wheelEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QGraphicsSceneWheelEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsScene.wheelEvent", overloads);
        return 0;
}

static PyObject* Sbk_QGraphicsSceneFunc_width(PyObject* self)
{
    QGraphicsScene* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsScene* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // width()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                qreal cppResult = const_cast<const QGraphicsScene*>(cppSelf)->width();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< double >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef Sbk_QGraphicsScene_methods[] = {
    {"activePanel", (PyCFunction)Sbk_QGraphicsSceneFunc_activePanel, METH_NOARGS},
    {"activeWindow", (PyCFunction)Sbk_QGraphicsSceneFunc_activeWindow, METH_NOARGS},
    {"addEllipse", (PyCFunction)Sbk_QGraphicsSceneFunc_addEllipse, METH_VARARGS|METH_KEYWORDS},
    {"addItem", (PyCFunction)Sbk_QGraphicsSceneFunc_addItem, METH_O},
    {"addLine", (PyCFunction)Sbk_QGraphicsSceneFunc_addLine, METH_VARARGS|METH_KEYWORDS},
    {"addPath", (PyCFunction)Sbk_QGraphicsSceneFunc_addPath, METH_VARARGS|METH_KEYWORDS},
    {"addPixmap", (PyCFunction)Sbk_QGraphicsSceneFunc_addPixmap, METH_O},
    {"addPolygon", (PyCFunction)Sbk_QGraphicsSceneFunc_addPolygon, METH_VARARGS|METH_KEYWORDS},
    {"addRect", (PyCFunction)Sbk_QGraphicsSceneFunc_addRect, METH_VARARGS|METH_KEYWORDS},
    {"addSimpleText", (PyCFunction)Sbk_QGraphicsSceneFunc_addSimpleText, METH_VARARGS|METH_KEYWORDS},
    {"addText", (PyCFunction)Sbk_QGraphicsSceneFunc_addText, METH_VARARGS|METH_KEYWORDS},
    {"addWidget", (PyCFunction)Sbk_QGraphicsSceneFunc_addWidget, METH_VARARGS|METH_KEYWORDS},
    {"advance", (PyCFunction)Sbk_QGraphicsSceneFunc_advance, METH_NOARGS},
    {"backgroundBrush", (PyCFunction)Sbk_QGraphicsSceneFunc_backgroundBrush, METH_NOARGS},
    {"bspTreeDepth", (PyCFunction)Sbk_QGraphicsSceneFunc_bspTreeDepth, METH_NOARGS},
    {"clear", (PyCFunction)Sbk_QGraphicsSceneFunc_clear, METH_NOARGS},
    {"clearFocus", (PyCFunction)Sbk_QGraphicsSceneFunc_clearFocus, METH_NOARGS},
    {"clearSelection", (PyCFunction)Sbk_QGraphicsSceneFunc_clearSelection, METH_NOARGS},
    {"collidingItems", (PyCFunction)Sbk_QGraphicsSceneFunc_collidingItems, METH_VARARGS|METH_KEYWORDS},
    {"contextMenuEvent", (PyCFunction)Sbk_QGraphicsSceneFunc_contextMenuEvent, METH_O},
    {"createItemGroup", (PyCFunction)Sbk_QGraphicsSceneFunc_createItemGroup, METH_O},
    {"destroyItemGroup", (PyCFunction)Sbk_QGraphicsSceneFunc_destroyItemGroup, METH_O},
    {"dragEnterEvent", (PyCFunction)Sbk_QGraphicsSceneFunc_dragEnterEvent, METH_O},
    {"dragLeaveEvent", (PyCFunction)Sbk_QGraphicsSceneFunc_dragLeaveEvent, METH_O},
    {"dragMoveEvent", (PyCFunction)Sbk_QGraphicsSceneFunc_dragMoveEvent, METH_O},
    {"drawBackground", (PyCFunction)Sbk_QGraphicsSceneFunc_drawBackground, METH_VARARGS},
    {"drawForeground", (PyCFunction)Sbk_QGraphicsSceneFunc_drawForeground, METH_VARARGS},
    {"dropEvent", (PyCFunction)Sbk_QGraphicsSceneFunc_dropEvent, METH_O},
    {"event", (PyCFunction)Sbk_QGraphicsSceneFunc_event, METH_O},
    {"eventFilter", (PyCFunction)Sbk_QGraphicsSceneFunc_eventFilter, METH_VARARGS},
    {"focusInEvent", (PyCFunction)Sbk_QGraphicsSceneFunc_focusInEvent, METH_O},
    {"focusItem", (PyCFunction)Sbk_QGraphicsSceneFunc_focusItem, METH_NOARGS},
    {"focusNextPrevChild", (PyCFunction)Sbk_QGraphicsSceneFunc_focusNextPrevChild, METH_O},
    {"focusOutEvent", (PyCFunction)Sbk_QGraphicsSceneFunc_focusOutEvent, METH_O},
    {"font", (PyCFunction)Sbk_QGraphicsSceneFunc_font, METH_NOARGS},
    {"foregroundBrush", (PyCFunction)Sbk_QGraphicsSceneFunc_foregroundBrush, METH_NOARGS},
    {"hasFocus", (PyCFunction)Sbk_QGraphicsSceneFunc_hasFocus, METH_NOARGS},
    {"height", (PyCFunction)Sbk_QGraphicsSceneFunc_height, METH_NOARGS},
    {"helpEvent", (PyCFunction)Sbk_QGraphicsSceneFunc_helpEvent, METH_O},
    {"inputMethodEvent", (PyCFunction)Sbk_QGraphicsSceneFunc_inputMethodEvent, METH_O},
    {"inputMethodQuery", (PyCFunction)Sbk_QGraphicsSceneFunc_inputMethodQuery, METH_O},
    {"invalidate", (PyCFunction)Sbk_QGraphicsSceneFunc_invalidate, METH_VARARGS|METH_KEYWORDS},
    {"isActive", (PyCFunction)Sbk_QGraphicsSceneFunc_isActive, METH_NOARGS},
    {"isSortCacheEnabled", (PyCFunction)Sbk_QGraphicsSceneFunc_isSortCacheEnabled, METH_NOARGS},
    {"itemAt", (PyCFunction)Sbk_QGraphicsSceneFunc_itemAt, METH_VARARGS},
    {"itemIndexMethod", (PyCFunction)Sbk_QGraphicsSceneFunc_itemIndexMethod, METH_NOARGS},
    {"items", (PyCFunction)Sbk_QGraphicsSceneFunc_items, METH_VARARGS|METH_KEYWORDS},
    {"itemsBoundingRect", (PyCFunction)Sbk_QGraphicsSceneFunc_itemsBoundingRect, METH_NOARGS},
    {"keyPressEvent", (PyCFunction)Sbk_QGraphicsSceneFunc_keyPressEvent, METH_O},
    {"keyReleaseEvent", (PyCFunction)Sbk_QGraphicsSceneFunc_keyReleaseEvent, METH_O},
    {"mouseDoubleClickEvent", (PyCFunction)Sbk_QGraphicsSceneFunc_mouseDoubleClickEvent, METH_O},
    {"mouseGrabberItem", (PyCFunction)Sbk_QGraphicsSceneFunc_mouseGrabberItem, METH_NOARGS},
    {"mouseMoveEvent", (PyCFunction)Sbk_QGraphicsSceneFunc_mouseMoveEvent, METH_O},
    {"mousePressEvent", (PyCFunction)Sbk_QGraphicsSceneFunc_mousePressEvent, METH_O},
    {"mouseReleaseEvent", (PyCFunction)Sbk_QGraphicsSceneFunc_mouseReleaseEvent, METH_O},
    {"palette", (PyCFunction)Sbk_QGraphicsSceneFunc_palette, METH_NOARGS},
    {"removeItem", (PyCFunction)Sbk_QGraphicsSceneFunc_removeItem, METH_O},
    {"render", (PyCFunction)Sbk_QGraphicsSceneFunc_render, METH_VARARGS|METH_KEYWORDS},
    {"sceneRect", (PyCFunction)Sbk_QGraphicsSceneFunc_sceneRect, METH_NOARGS},
    {"selectedItems", (PyCFunction)Sbk_QGraphicsSceneFunc_selectedItems, METH_NOARGS},
    {"selectionArea", (PyCFunction)Sbk_QGraphicsSceneFunc_selectionArea, METH_NOARGS},
    {"sendEvent", (PyCFunction)Sbk_QGraphicsSceneFunc_sendEvent, METH_VARARGS},
    {"setActivePanel", (PyCFunction)Sbk_QGraphicsSceneFunc_setActivePanel, METH_O},
    {"setActiveWindow", (PyCFunction)Sbk_QGraphicsSceneFunc_setActiveWindow, METH_O},
    {"setBackgroundBrush", (PyCFunction)Sbk_QGraphicsSceneFunc_setBackgroundBrush, METH_O},
    {"setBspTreeDepth", (PyCFunction)Sbk_QGraphicsSceneFunc_setBspTreeDepth, METH_O},
    {"setFocus", (PyCFunction)Sbk_QGraphicsSceneFunc_setFocus, METH_VARARGS|METH_KEYWORDS},
    {"setFocusItem", (PyCFunction)Sbk_QGraphicsSceneFunc_setFocusItem, METH_VARARGS|METH_KEYWORDS},
    {"setFont", (PyCFunction)Sbk_QGraphicsSceneFunc_setFont, METH_O},
    {"setForegroundBrush", (PyCFunction)Sbk_QGraphicsSceneFunc_setForegroundBrush, METH_O},
    {"setItemIndexMethod", (PyCFunction)Sbk_QGraphicsSceneFunc_setItemIndexMethod, METH_O},
    {"setPalette", (PyCFunction)Sbk_QGraphicsSceneFunc_setPalette, METH_O},
    {"setSceneRect", (PyCFunction)Sbk_QGraphicsSceneFunc_setSceneRect, METH_VARARGS},
    {"setSelectionArea", (PyCFunction)Sbk_QGraphicsSceneFunc_setSelectionArea, METH_VARARGS},
    {"setSortCacheEnabled", (PyCFunction)Sbk_QGraphicsSceneFunc_setSortCacheEnabled, METH_O},
    {"setStickyFocus", (PyCFunction)Sbk_QGraphicsSceneFunc_setStickyFocus, METH_O},
    {"setStyle", (PyCFunction)Sbk_QGraphicsSceneFunc_setStyle, METH_O},
    {"stickyFocus", (PyCFunction)Sbk_QGraphicsSceneFunc_stickyFocus, METH_NOARGS},
    {"style", (PyCFunction)Sbk_QGraphicsSceneFunc_style, METH_NOARGS},
    {"update", (PyCFunction)Sbk_QGraphicsSceneFunc_update, METH_VARARGS|METH_KEYWORDS},
    {"views", (PyCFunction)Sbk_QGraphicsSceneFunc_views, METH_NOARGS},
    {"wheelEvent", (PyCFunction)Sbk_QGraphicsSceneFunc_wheelEvent, METH_O},
    {"width", (PyCFunction)Sbk_QGraphicsSceneFunc_width, METH_NOARGS},

    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QGraphicsScene_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QGraphicsScene",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QGraphicsScene_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QGraphicsScene_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern

static SbkObjectType* Sbk_QGraphicsScene_typeDiscovery(void* cptr, SbkObjectType* instanceType)
{
    if (instanceType == reinterpret_cast<SbkObjectType*>(Shiboken::SbkType<QObject >()) && dynamic_cast<QGraphicsScene*>(reinterpret_cast<QObject*>(cptr)))
        return &Sbk_QGraphicsScene_Type;
    return 0;
}

PyObject* SbkPySide_QtGui_QGraphicsScene_SceneLayer___and__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QGraphicsScene::SceneLayers >::toPython(
        Shiboken::Converter<QGraphicsScene::SceneLayers>::toCpp(self)
        & Shiboken::Converter< QGraphicsScene::SceneLayers >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtGui_QGraphicsScene_SceneLayer___or__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QGraphicsScene::SceneLayers >::toPython(
        Shiboken::Converter<QGraphicsScene::SceneLayers>::toCpp(self)
        | Shiboken::Converter< QGraphicsScene::SceneLayers >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtGui_QGraphicsScene_SceneLayer___xor__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QGraphicsScene::SceneLayers >::toPython(
        Shiboken::Converter<QGraphicsScene::SceneLayers>::toCpp(self)
        ^ Shiboken::Converter< QGraphicsScene::SceneLayers >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtGui_QGraphicsScene_SceneLayer___invert__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QGraphicsScene::SceneLayers >::toPython(
        ~Shiboken::Converter<QGraphicsScene::SceneLayers >::toCpp(self)
    );
}


static PyNumberMethods SbkPySide_QtGui_QGraphicsScene_SceneLayer_as_number = {
    /*nb_add*/                  0,
    /*nb_subtract*/             0,
    /*nb_multiply*/             0,
    /*nb_divide*/               0,
    /*nb_remainder*/            0,
    /*nb_divmod*/               0,
    /*nb_power*/                0,
    /*nb_negative*/             0,
    /*nb_positive*/             0,
    /*nb_absolute*/             0,
    /*nb_nonzero*/              0,
    /*nb_invert*/               (unaryfunc)SbkPySide_QtGui_QGraphicsScene_SceneLayer___invert__,
    /*nb_lshift*/               0,
    /*nb_rshift*/               0,
    /*nb_and*/                  (binaryfunc)SbkPySide_QtGui_QGraphicsScene_SceneLayer___and__,
    /*nb_xor*/                  (binaryfunc)SbkPySide_QtGui_QGraphicsScene_SceneLayer___xor__,
    /*nb_or*/                   (binaryfunc)SbkPySide_QtGui_QGraphicsScene_SceneLayer___or__,
    /*nb_coerce*/               0,
    /*nb_int*/                  0,
    /*nb_long*/                 0,
    /*nb_float*/                0,
    /*nb_oct*/                  0,
    /*nb_hex*/                  0,
    /*nb_inplace_add*/          0,
    /*nb_inplace_subtract*/     0,
    /*nb_inplace_multiply*/     0,
    /*nb_inplace_divide*/       0,
    /*nb_inplace_remainder*/    0,
    /*nb_inplace_power*/        0,
    /*nb_inplace_lshift*/       0,
    /*nb_inplace_rshift*/       0,
    /*nb_inplace_and*/          0,
    /*nb_inplace_xor*/          0,
    /*nb_inplace_or*/           0,
    /*nb_floor_divide*/         0,
    /*nb_true_divide*/          0,
    /*nb_inplace_floor_divide*/ 0,
    /*nb_inplace_true_divide*/  0,
    /*nb_index*/                0
};


// forward declaration of new function
static PyTypeObject SbkPySide_QtGui_QGraphicsScene_SceneLayers_Type = {
    PyObject_HEAD_INIT(&PyType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "SceneLayers",
    /*tp_basicsize*/        0,
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        &SbkPySide_QtGui_QGraphicsScene_SceneLayer_as_number,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT | Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              PyInt_Type.tp_new,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};



void init_QGraphicsScene(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QGRAPHICSSCENE_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QGraphicsScene_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QGraphicsScene_Type);
    Shiboken::ObjectType::setSubTypeInitHook(&Sbk_QGraphicsScene_Type, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(&Sbk_QGraphicsScene_Type, &QGraphicsScene::staticMetaObject);    Sbk_QGraphicsScene_Type.super.ht_type.tp_base = SbkPySide_QtCoreTypes[SBK_QOBJECT_IDX];
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QGraphicsScene_Type, &Shiboken::callCppDestructor<QGraphicsScene >);
    Py_INCREF((PyObject*)&Sbk_QGraphicsScene_Type); //Incref due the 'PyModule_AddObject' steals the reference.
    if (PyType_Ready((PyTypeObject*)&Sbk_QGraphicsScene_Type) < 0)
        return;

    // Fill type discovery information
    Shiboken::ObjectType::setTypeDiscoveryFunction(&Sbk_QGraphicsScene_Type, &Sbk_QGraphicsScene_typeDiscovery);
    Shiboken::BindingManager& bm = Shiboken::BindingManager::instance();
    bm.addClassInheritance(reinterpret_cast<SbkObjectType*>(SbkPySide_QtCoreTypes[SBK_QOBJECT_IDX]), &Sbk_QGraphicsScene_Type);

    Shiboken::ObjectType::setOriginalName(&Sbk_QGraphicsScene_Type, "QGraphicsScene*");
    PyModule_AddObject(module, "QGraphicsScene",
        ((PyObject*)&Sbk_QGraphicsScene_Type));

    // Initialize enums
    PyObject* enumItem;

    // init enum: SceneLayer
    PyTypeObject* SbkPySide_QtGui_QGraphicsScene_SceneLayer = Shiboken::Enum::newType("PySide.QtGui.QGraphicsScene.SceneLayer");
    SbkPySide_QtGui_QGraphicsScene_SceneLayer->tp_as_number = &SbkPySide_QtGui_QGraphicsScene_SceneLayer_as_number;
    SbkPySide_QtGuiTypes[SBK_QGRAPHICSSCENE_SCENELAYER_IDX] = SbkPySide_QtGui_QGraphicsScene_SceneLayer;
    if (PyType_Ready(SbkPySide_QtGui_QGraphicsScene_SceneLayer) < 0)
        return;
    PyDict_SetItemString(Sbk_QGraphicsScene_Type.super.ht_type.tp_dict,
            "SceneLayer",((PyObject*)SbkPySide_QtGui_QGraphicsScene_SceneLayer));

    // init flags class: QFlags<QGraphicsScene::SceneLayer>
    SbkPySide_QtGuiTypes[SBK_QFLAGS_QGRAPHICSSCENE_SCENELAYER__IDX] = &SbkPySide_QtGui_QGraphicsScene_SceneLayers_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtGui_QGraphicsScene_SceneLayers_Type) < 0)
        return;
    PyDict_SetItemString(Sbk_QGraphicsScene_Type.super.ht_type.tp_dict,
            "SceneLayers",((PyObject*)&SbkPySide_QtGui_QGraphicsScene_SceneLayers_Type));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QGraphicsScene_SceneLayer,(long) QGraphicsScene::ItemLayer, "ItemLayer");
    PyDict_SetItemString(Sbk_QGraphicsScene_Type.super.ht_type.tp_dict,"ItemLayer", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QGraphicsScene_SceneLayer->tp_dict,"ItemLayer", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QGraphicsScene_SceneLayer,(long) QGraphicsScene::BackgroundLayer, "BackgroundLayer");
    PyDict_SetItemString(Sbk_QGraphicsScene_Type.super.ht_type.tp_dict,"BackgroundLayer", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QGraphicsScene_SceneLayer->tp_dict,"BackgroundLayer", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QGraphicsScene_SceneLayer,(long) QGraphicsScene::ForegroundLayer, "ForegroundLayer");
    PyDict_SetItemString(Sbk_QGraphicsScene_Type.super.ht_type.tp_dict,"ForegroundLayer", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QGraphicsScene_SceneLayer->tp_dict,"ForegroundLayer", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QGraphicsScene_SceneLayer,(long) QGraphicsScene::AllLayers, "AllLayers");
    PyDict_SetItemString(Sbk_QGraphicsScene_Type.super.ht_type.tp_dict,"AllLayers", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QGraphicsScene_SceneLayer->tp_dict,"AllLayers", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QGraphicsScene::SceneLayer");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::SceneLayer");
    // end of enum SceneLayer

    // init enum: ItemIndexMethod
    PyTypeObject* SbkPySide_QtGui_QGraphicsScene_ItemIndexMethod = Shiboken::Enum::newType("PySide.QtGui.QGraphicsScene.ItemIndexMethod");
    SbkPySide_QtGuiTypes[SBK_QGRAPHICSSCENE_ITEMINDEXMETHOD_IDX] = SbkPySide_QtGui_QGraphicsScene_ItemIndexMethod;
    if (PyType_Ready(SbkPySide_QtGui_QGraphicsScene_ItemIndexMethod) < 0)
        return;
    PyDict_SetItemString(Sbk_QGraphicsScene_Type.super.ht_type.tp_dict,
            "ItemIndexMethod",((PyObject*)SbkPySide_QtGui_QGraphicsScene_ItemIndexMethod));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QGraphicsScene_ItemIndexMethod,(long) QGraphicsScene::BspTreeIndex, "BspTreeIndex");
    PyDict_SetItemString(Sbk_QGraphicsScene_Type.super.ht_type.tp_dict,"BspTreeIndex", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QGraphicsScene_ItemIndexMethod->tp_dict,"BspTreeIndex", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QGraphicsScene_ItemIndexMethod,(long) QGraphicsScene::NoIndex, "NoIndex");
    PyDict_SetItemString(Sbk_QGraphicsScene_Type.super.ht_type.tp_dict,"NoIndex", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QGraphicsScene_ItemIndexMethod->tp_dict,"NoIndex", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QGraphicsScene::ItemIndexMethod");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::ItemIndexMethod");
    // end of enum ItemIndexMethod

    // Initialize signals
    PySideSignal* signal_item;

    signal_item = PySide::Signal::newObject("sceneRectChanged", "QRectF", NULL);
    PySide::Signal::addSignalToWrapper(&Sbk_QGraphicsScene_Type, "sceneRectChanged", signal_item);
    Py_DECREF((PyObject*) signal_item);
    signal_item = PySide::Signal::newObject("selectionChanged", "void", NULL);
    PySide::Signal::addSignalToWrapper(&Sbk_QGraphicsScene_Type, "selectionChanged", signal_item);
    Py_DECREF((PyObject*) signal_item);
    signal_item = PySide::Signal::newObject("changed", "QList<QRectF>", NULL);
    PySide::Signal::addSignalToWrapper(&Sbk_QGraphicsScene_Type, "changed", signal_item);
    Py_DECREF((PyObject*) signal_item);


    Shiboken::TypeResolver::createObjectTypeResolver<QGraphicsScene >("QGraphicsScene*");
    Shiboken::TypeResolver::createObjectTypeResolver<QGraphicsScene >(typeid(QGraphicsScene).name());
    Shiboken::TypeResolver::createObjectTypeResolver<QGraphicsScene >(typeid(QGraphicsSceneWrapper).name());
    qRegisterMetaType< ::QGraphicsScene* >("QGraphicsScene*");
    qRegisterMetaType< ::QGraphicsScene::SceneLayer >("QGraphicsScene::SceneLayer");
    qRegisterMetaType< ::QGraphicsScene::SceneLayers >("QGraphicsScene::SceneLayers");
    qRegisterMetaType< ::QGraphicsScene::ItemIndexMethod >("QGraphicsScene::ItemIndexMethod");
}

