/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <set>
#include "pyside_qtgui_python.h"

#include "qgraphicsview_wrapper.h"

// Extra includes
#include <QList>
#include <QPainterPath>
#include <QVarLengthArray>
#include <autoarraypointer.h>
#include <qaction.h>
#include <qbitmap.h>
#include <qbrush.h>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qcursor.h>
#include <qevent.h>
#include <qfont.h>
#include <qfontinfo.h>
#include <qfontmetrics.h>
#include <qgraphicseffect.h>
#include <qgraphicsitem.h>
#include <qgraphicsproxywidget.h>
#include <qgraphicsscene.h>
#include <qgraphicsview.h>
#include <qicon.h>
#include <qinputcontext.h>
#include <qkeysequence.h>
#include <qlayout.h>
#include <qlocale.h>
#include <qmargins.h>
#include <qmatrix.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qpaintengine.h>
#include <qpainter.h>
#include <qpainterpath.h>
#include <qpalette.h>
#include <qpoint.h>
#include <qpolygon.h>
#include <qrect.h>
#include <qregion.h>
#include <qscrollbar.h>
#include <qsize.h>
#include <qsizepolicy.h>
#include <qstyle.h>
#include <qstyleoption.h>
#include <qtransform.h>
#include <qwidget.h>
#include <qx11info_x11.h>


// Native ---------------------------------------------------------

QGraphicsViewWrapper::QGraphicsViewWrapper(QGraphicsScene * scene, QWidget * parent) : QGraphicsView(scene, parent) {
    // ... middle
}

QGraphicsViewWrapper::QGraphicsViewWrapper(QWidget * parent) : QGraphicsView(parent) {
    // ... middle
}

void QGraphicsViewWrapper::actionEvent(QActionEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "actionEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::actionEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QActionEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QGraphicsViewWrapper::changeEvent(QEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "changeEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QFrame::changeEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QEvent * >::toPython(arg__1)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QGraphicsViewWrapper::childEvent(QChildEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "childEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::childEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QChildEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QGraphicsViewWrapper::closeEvent(QCloseEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "closeEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::closeEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QCloseEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QGraphicsViewWrapper::connectNotify(const char * signal)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "connectNotify"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::connectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QGraphicsViewWrapper::contextMenuEvent(QContextMenuEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "contextMenuEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QGraphicsView::contextMenuEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QContextMenuEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QGraphicsViewWrapper::customEvent(QEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "customEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::customEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

int QGraphicsViewWrapper::devType() const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return int(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "devType"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::devType();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return int(0);
    }
    // Check return type
    bool typeIsValid = PyInt_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QGraphicsView.devType", "int", pyResult->ob_type->tp_name);
        return int(0);
    }
    int cppResult(Shiboken::Converter< int >::toCpp(pyResult));
    return cppResult;
}

void QGraphicsViewWrapper::disconnectNotify(const char * signal)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "disconnectNotify"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::disconnectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QGraphicsViewWrapper::dragEnterEvent(QDragEnterEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "dragEnterEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QGraphicsView::dragEnterEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QDragEnterEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QGraphicsViewWrapper::dragLeaveEvent(QDragLeaveEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "dragLeaveEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QGraphicsView::dragLeaveEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QDragLeaveEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QGraphicsViewWrapper::dragMoveEvent(QDragMoveEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "dragMoveEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QGraphicsView::dragMoveEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QDragMoveEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QGraphicsViewWrapper::drawBackground(QPainter * painter, const QRectF & rect)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "drawBackground"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QGraphicsView::drawBackground(painter, rect);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter< ::QPainter * >::toPython(painter),
        Shiboken::Converter< ::QRectF >::toPython(rect)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QGraphicsViewWrapper::drawForeground(QPainter * painter, const QRectF & rect)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "drawForeground"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QGraphicsView::drawForeground(painter, rect);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter< ::QPainter * >::toPython(painter),
        Shiboken::Converter< ::QRectF >::toPython(rect)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QGraphicsViewWrapper::drawItems(QPainter * painter, int numItems, QGraphicsItem ** items, const QStyleOptionGraphicsItem * options)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "drawItems"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QGraphicsView::drawItems(painter, numItems, items, options);
    }

    // Begin code injection

    Shiboken::AutoDecRef object(PyList_New(0));
    for (int i=0, max=numItems; i < max; i++) {
        PyList_Append(object, Shiboken::Converter<QGraphicsItem* >::toPython(items[i]));
    }
    PyObject *items_out = object.object();

    // End of code injection
    // Begin code injection

    Shiboken::AutoDecRef option_object(PyList_New(0));
    for (int i=0, max=numItems; i < max; i++) {
        PyList_Append(option_object, Shiboken::Converter<QStyleOptionGraphicsItem >::toPython(options[i]));
    }
    PyObject *options_out = option_object.object();

    // End of code injection
    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NNN)",
        Shiboken::Converter< ::QPainter * >::toPython(painter),
        items_out,
        options_out
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QGraphicsViewWrapper::dropEvent(QDropEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "dropEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QGraphicsView::dropEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QDropEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QGraphicsViewWrapper::enterEvent(QEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "enterEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::enterEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

bool QGraphicsViewWrapper::event(QEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return bool(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "event"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QGraphicsView::event(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QEvent * >::toPython(event)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QGraphicsView.event", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    return cppResult;
}

bool QGraphicsViewWrapper::eventFilter(QObject * arg__1, QEvent * arg__2)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return bool(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "eventFilter"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::eventFilter(arg__1, arg__2);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter< ::QObject * >::toPython(arg__1),
        Shiboken::Converter< ::QEvent * >::toPython(arg__2)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QGraphicsView.eventFilter", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    return cppResult;
}

void QGraphicsViewWrapper::focusInEvent(QFocusEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "focusInEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QGraphicsView::focusInEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QFocusEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

bool QGraphicsViewWrapper::focusNextPrevChild(bool next)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return bool(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "focusNextPrevChild"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QGraphicsView::focusNextPrevChild(next);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< bool >::toPython(next)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QGraphicsView.focusNextPrevChild", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    return cppResult;
}

void QGraphicsViewWrapper::focusOutEvent(QFocusEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "focusOutEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QGraphicsView::focusOutEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QFocusEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

int QGraphicsViewWrapper::heightForWidth(int arg__1) const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return int(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "heightForWidth"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::heightForWidth(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(i)",
        arg__1
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return int(0);
    }
    // Check return type
    bool typeIsValid = PyInt_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QGraphicsView.heightForWidth", "int", pyResult->ob_type->tp_name);
        return int(0);
    }
    int cppResult(Shiboken::Converter< int >::toCpp(pyResult));
    return cppResult;
}

void QGraphicsViewWrapper::hideEvent(QHideEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "hideEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::hideEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QHideEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QGraphicsViewWrapper::inputMethodEvent(QInputMethodEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "inputMethodEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QGraphicsView::inputMethodEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QInputMethodEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

QVariant QGraphicsViewWrapper::inputMethodQuery(Qt::InputMethodQuery query) const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return QVariant(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "inputMethodQuery"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QGraphicsView::inputMethodQuery(query);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::Qt::InputMethodQuery >::toPython(query)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QVariant(0);
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< QVariant >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QGraphicsView.inputMethodQuery", "QVariant", pyResult->ob_type->tp_name);
        return QVariant(0);
    }
    QVariant cppResult(Shiboken::Converter< QVariant >::toCpp(pyResult));
    return cppResult;
}

void QGraphicsViewWrapper::keyPressEvent(QKeyEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "keyPressEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QGraphicsView::keyPressEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QKeyEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QGraphicsViewWrapper::keyReleaseEvent(QKeyEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "keyReleaseEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QGraphicsView::keyReleaseEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QKeyEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QGraphicsViewWrapper::languageChange()
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "languageChange"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::languageChange();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QGraphicsViewWrapper::leaveEvent(QEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "leaveEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::leaveEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

int QGraphicsViewWrapper::metric(QPaintDevice::PaintDeviceMetric arg__1) const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return int(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "metric"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::metric(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QPaintDevice::PaintDeviceMetric >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return int(0);
    }
    // Check return type
    bool typeIsValid = PyInt_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QGraphicsView.metric", "int", pyResult->ob_type->tp_name);
        return int(0);
    }
    int cppResult(Shiboken::Converter< int >::toCpp(pyResult));
    return cppResult;
}

QSize QGraphicsViewWrapper::minimumSizeHint() const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return QSize();
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "minimumSizeHint"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QAbstractScrollArea::minimumSizeHint();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QSize();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QSize >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QGraphicsView.minimumSizeHint", Shiboken::SbkType<QSize >()->tp_name, pyResult->ob_type->tp_name);
        return QSize();
    }
    QSize cppResult(Shiboken::Converter< ::QSize >::toCpp(pyResult));
    return cppResult;
}

void QGraphicsViewWrapper::mouseDoubleClickEvent(QMouseEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "mouseDoubleClickEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QGraphicsView::mouseDoubleClickEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QMouseEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QGraphicsViewWrapper::mouseMoveEvent(QMouseEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "mouseMoveEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QGraphicsView::mouseMoveEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QMouseEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QGraphicsViewWrapper::mousePressEvent(QMouseEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "mousePressEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QGraphicsView::mousePressEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QMouseEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QGraphicsViewWrapper::mouseReleaseEvent(QMouseEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "mouseReleaseEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QGraphicsView::mouseReleaseEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QMouseEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QGraphicsViewWrapper::moveEvent(QMoveEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "moveEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::moveEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QMoveEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

QPaintEngine * QGraphicsViewWrapper::paintEngine() const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return 0;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "paintEngine"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::paintEngine();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return 0;
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QPaintEngine * >::isConvertible(pyResult);
    typeIsValid = typeIsValid || (pyResult == Py_None);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QGraphicsView.paintEngine", Shiboken::SbkType<QPaintEngine >()->tp_name, pyResult->ob_type->tp_name);
        return 0;
    }
    QPaintEngine * cppResult(Shiboken::Converter< ::QPaintEngine * >::toCpp(pyResult));
    return cppResult;
}

void QGraphicsViewWrapper::paintEvent(QPaintEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "paintEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QGraphicsView::paintEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QPaintEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QGraphicsViewWrapper::resizeEvent(QResizeEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "resizeEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QGraphicsView::resizeEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QResizeEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QGraphicsViewWrapper::scrollContentsBy(int dx, int dy)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "scrollContentsBy"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QGraphicsView::scrollContentsBy(dx, dy);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(ii)",
        dx,
        dy
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QGraphicsViewWrapper::setVisible(bool visible)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "setVisible"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::setVisible(visible);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< bool >::toPython(visible)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QGraphicsViewWrapper::showEvent(QShowEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "showEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QGraphicsView::showEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QShowEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

QSize QGraphicsViewWrapper::sizeHint() const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return QSize();
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "sizeHint"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QGraphicsView::sizeHint();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QSize();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QSize >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QGraphicsView.sizeHint", Shiboken::SbkType<QSize >()->tp_name, pyResult->ob_type->tp_name);
        return QSize();
    }
    QSize cppResult(Shiboken::Converter< ::QSize >::toCpp(pyResult));
    return cppResult;
}

void QGraphicsViewWrapper::tabletEvent(QTabletEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "tabletEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::tabletEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QTabletEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QGraphicsViewWrapper::timerEvent(QTimerEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "timerEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::timerEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QTimerEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

bool QGraphicsViewWrapper::viewportEvent(QEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return bool(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "viewportEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QGraphicsView::viewportEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QGraphicsView.viewportEvent", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
    return cppResult;
}

void QGraphicsViewWrapper::wheelEvent(QWheelEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "wheelEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QGraphicsView::wheelEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QWheelEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

const QMetaObject* QGraphicsViewWrapper::metaObject() const
{
    SbkObject* pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    return reinterpret_cast<QMetaObject*>(Shiboken::Object::getTypeUserData(pySelf));
}

int QGraphicsViewWrapper::qt_metacall(QMetaObject::Call call, int id, void** args)
{
    int result = QGraphicsView::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

QGraphicsViewWrapper::~QGraphicsViewWrapper()
{
    SbkObject* wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QGraphicsView_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QGraphicsView >()))
        return -1;

    QGraphicsViewWrapper* cptr = 0;
    int overloadId = -1;
    const char* argNames[] = {"parent"};
    const QMetaObject* metaObject;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_ParseTuple(args, "|OO:QGraphicsView", &(pyargs[0]), &(pyargs[1])))
        return -1;

    // Overloaded function decisor
    // 0: QGraphicsView(QGraphicsScene*,QWidget*)
    // 1: QGraphicsView(QWidget*)
    if (numArgs == 0) {
        overloadId = 1; // QGraphicsView(QWidget*)
    } else if (Shiboken::Converter< ::QWidget * >::isConvertible(pyargs[0])) {
        overloadId = 1; // QGraphicsView(QWidget*)
    } else if (Shiboken::Converter< ::QGraphicsScene * >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // QGraphicsView(QGraphicsScene*,QWidget*)
        } else if (Shiboken::Converter< ::QWidget * >::isConvertible(pyargs[1])) {
            overloadId = 0; // QGraphicsView(QGraphicsScene*,QWidget*)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGraphicsView_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QGraphicsView(QGraphicsScene*,QWidget*)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "parent");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "parent";
                        else if (Shiboken::Converter< ::QWidget * >::isConvertible(value))
                            pyargs[1] = value;
                        else
                            goto Sbk_QGraphicsView_Init_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QGraphicsView(): got multiple values for keyword argument '%s'", errorArgName);
                        return -1;
                    }
                }
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QGraphicsScene * cppArg0 = Shiboken::Converter<QGraphicsScene * >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return -1;
                QWidget * cppArg1 = pyargs[1] ? Shiboken::Converter<QWidget * >::toCpp(pyargs[1]) : 0;

                if(!PyErr_Occurred()) {
                    // QGraphicsView(QGraphicsScene*,QWidget*)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QGraphicsViewWrapper(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    Shiboken::Object::setParent(pyargs[1], self);
                }
                break;
            }
            case 1: // QGraphicsView(QWidget*)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "parent");
                    if (value) {
                        if (pyargs[0])
                            errorArgName = "parent";
                        else if (Shiboken::Converter< ::QWidget * >::isConvertible(value))
                            pyargs[0] = value;
                        else
                            goto Sbk_QGraphicsView_Init_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QGraphicsView(): got multiple values for keyword argument '%s'", errorArgName);
                        return -1;
                    }
                }
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QWidget * cppArg0 = pyargs[0] ? Shiboken::Converter<QWidget * >::toCpp(pyargs[0]) : 0;

                if(!PyErr_Occurred()) {
                    // QGraphicsView(QWidget*)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QGraphicsViewWrapper(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    Shiboken::Object::setParent(pyargs[0], self);
                }
                break;
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QGraphicsView >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QGraphicsView_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    metaObject = cptr->metaObject(); // <- init python qt properties
    if (kwds && !PySide::fillQtProperties(self, metaObject, kwds, argNames, 1))
        return -1;


    return 1;

    Sbk_QGraphicsView_Init_TypeError:
        const char* overloads[] = {"PySide.QtGui.QGraphicsScene, PySide.QtGui.QWidget = None", "PySide.QtGui.QWidget = None", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QGraphicsView", overloads);
        return -1;
}

static PyObject* Sbk_QGraphicsViewFunc_alignment(PyObject* self)
{
    QGraphicsView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsView* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // alignment()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QFlags<Qt::AlignmentFlag> cppResult = const_cast<const QGraphicsView*>(cppSelf)->alignment();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QFlags<Qt::AlignmentFlag> >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QGraphicsViewFunc_backgroundBrush(PyObject* self)
{
    QGraphicsView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsView* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // backgroundBrush()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QBrush cppResult = const_cast<const QGraphicsView*>(cppSelf)->backgroundBrush();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QBrush >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QGraphicsViewFunc_cacheMode(PyObject* self)
{
    QGraphicsView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsView* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // cacheMode()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QFlags<QGraphicsView::CacheModeFlag> cppResult = const_cast<const QGraphicsView*>(cppSelf)->cacheMode();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QFlags<QGraphicsView::CacheModeFlag> >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QGraphicsViewFunc_centerOn(PyObject* self, PyObject* args)
{
    QGraphicsView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsView* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "centerOn", 1, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: centerOn(const QGraphicsItem*)
    // 1: centerOn(QPointF)
    // 2: centerOn(qreal,qreal)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 2; // centerOn(qreal,qreal)
    } else if (numArgs == 1 && Shiboken::Converter< ::QPointF >::isConvertible(pyargs[0])) {
        overloadId = 1; // centerOn(QPointF)
    } else if (numArgs == 1 && Shiboken::Converter< ::QGraphicsItem * >::isConvertible(pyargs[0])) {
        overloadId = 0; // centerOn(const QGraphicsItem*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGraphicsViewFunc_centerOn_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // centerOn(const QGraphicsItem*)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QGraphicsItem * cppArg0 = Shiboken::Converter<QGraphicsItem * >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // centerOn(const QGraphicsItem*)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->centerOn(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // centerOn(QPointF)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QPointF cppArg0 = Shiboken::Converter<QPointF >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // centerOn(QPointF)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->centerOn(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 2: // centerOn(qreal,qreal)
            {
                qreal cppArg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
                qreal cppArg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // centerOn(qreal,qreal)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->centerOn(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGraphicsViewFunc_centerOn_TypeError:
        const char* overloads[] = {"PySide.QtGui.QGraphicsItem", "PySide.QtCore.QPointF", "float, float", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QGraphicsView.centerOn", overloads);
        return 0;
}

static PyObject* Sbk_QGraphicsViewFunc_contextMenuEvent(PyObject* self, PyObject* arg)
{
    QGraphicsView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsView* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: contextMenuEvent(QContextMenuEvent*)
    if (Shiboken::Converter< ::QContextMenuEvent * >::isConvertible(arg)) {
        overloadId = 0; // contextMenuEvent(QContextMenuEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGraphicsViewFunc_contextMenuEvent_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QContextMenuEvent * cppArg0 = Shiboken::Converter<QContextMenuEvent * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // contextMenuEvent(QContextMenuEvent*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QGraphicsView::contextMenuEvent(cppArg0) : cppSelf->contextMenuEvent(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGraphicsViewFunc_contextMenuEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QContextMenuEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsView.contextMenuEvent", overloads);
        return 0;
}

static PyObject* Sbk_QGraphicsViewFunc_dragEnterEvent(PyObject* self, PyObject* arg)
{
    QGraphicsView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsView* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: dragEnterEvent(QDragEnterEvent*)
    if (Shiboken::Converter< ::QDragEnterEvent * >::isConvertible(arg)) {
        overloadId = 0; // dragEnterEvent(QDragEnterEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGraphicsViewFunc_dragEnterEvent_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QDragEnterEvent * cppArg0 = Shiboken::Converter<QDragEnterEvent * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // dragEnterEvent(QDragEnterEvent*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QGraphicsView::dragEnterEvent(cppArg0) : cppSelf->dragEnterEvent(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGraphicsViewFunc_dragEnterEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QDragEnterEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsView.dragEnterEvent", overloads);
        return 0;
}

static PyObject* Sbk_QGraphicsViewFunc_dragLeaveEvent(PyObject* self, PyObject* arg)
{
    QGraphicsView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsView* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: dragLeaveEvent(QDragLeaveEvent*)
    if (Shiboken::Converter< ::QDragLeaveEvent * >::isConvertible(arg)) {
        overloadId = 0; // dragLeaveEvent(QDragLeaveEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGraphicsViewFunc_dragLeaveEvent_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QDragLeaveEvent * cppArg0 = Shiboken::Converter<QDragLeaveEvent * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // dragLeaveEvent(QDragLeaveEvent*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QGraphicsView::dragLeaveEvent(cppArg0) : cppSelf->dragLeaveEvent(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGraphicsViewFunc_dragLeaveEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QDragLeaveEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsView.dragLeaveEvent", overloads);
        return 0;
}

static PyObject* Sbk_QGraphicsViewFunc_dragMode(PyObject* self)
{
    QGraphicsView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsView* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // dragMode()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QGraphicsView::DragMode cppResult = const_cast<const QGraphicsView*>(cppSelf)->dragMode();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QGraphicsView::DragMode >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QGraphicsViewFunc_dragMoveEvent(PyObject* self, PyObject* arg)
{
    QGraphicsView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsView* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: dragMoveEvent(QDragMoveEvent*)
    if (Shiboken::Converter< ::QDragMoveEvent * >::isConvertible(arg)) {
        overloadId = 0; // dragMoveEvent(QDragMoveEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGraphicsViewFunc_dragMoveEvent_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QDragMoveEvent * cppArg0 = Shiboken::Converter<QDragMoveEvent * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // dragMoveEvent(QDragMoveEvent*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QGraphicsView::dragMoveEvent(cppArg0) : cppSelf->dragMoveEvent(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGraphicsViewFunc_dragMoveEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QDragMoveEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsView.dragMoveEvent", overloads);
        return 0;
}

static PyObject* Sbk_QGraphicsViewFunc_drawBackground(PyObject* self, PyObject* args)
{
    QGraphicsView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsView* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "drawBackground", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: drawBackground(QPainter*,QRectF)
    if (numArgs == 2 && Shiboken::Converter< ::QPainter * >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QRectF >::isConvertible(pyargs[1])) {
        overloadId = 0; // drawBackground(QPainter*,QRectF)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGraphicsViewFunc_drawBackground_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QPainter * cppArg0 = Shiboken::Converter<QPainter * >::toCpp(pyargs[0]);
            if (!Shiboken::Object::isValid(pyargs[1]))
                return 0;
            QRectF cppArg1 = Shiboken::Converter<QRectF >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // drawBackground(QPainter*,QRectF)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QGraphicsView::drawBackground(cppArg0, cppArg1) : cppSelf->drawBackground(cppArg0, cppArg1));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGraphicsViewFunc_drawBackground_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPainter, PySide.QtCore.QRectF", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QGraphicsView.drawBackground", overloads);
        return 0;
}

static PyObject* Sbk_QGraphicsViewFunc_drawForeground(PyObject* self, PyObject* args)
{
    QGraphicsView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsView* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "drawForeground", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: drawForeground(QPainter*,QRectF)
    if (numArgs == 2 && Shiboken::Converter< ::QPainter * >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QRectF >::isConvertible(pyargs[1])) {
        overloadId = 0; // drawForeground(QPainter*,QRectF)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGraphicsViewFunc_drawForeground_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QPainter * cppArg0 = Shiboken::Converter<QPainter * >::toCpp(pyargs[0]);
            if (!Shiboken::Object::isValid(pyargs[1]))
                return 0;
            QRectF cppArg1 = Shiboken::Converter<QRectF >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // drawForeground(QPainter*,QRectF)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QGraphicsView::drawForeground(cppArg0, cppArg1) : cppSelf->drawForeground(cppArg0, cppArg1));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGraphicsViewFunc_drawForeground_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPainter, PySide.QtCore.QRectF", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QGraphicsView.drawForeground", overloads);
        return 0;
}

static PyObject* Sbk_QGraphicsViewFunc_drawItems(PyObject* self, PyObject* args)
{
    QGraphicsView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsView* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "drawItems", 3, 3, &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: drawItems(QPainter*,int,QGraphicsItem**,const QStyleOptionGraphicsItem*)
    if (numArgs == 3 && Shiboken::Converter< ::QPainter * >::isConvertible(pyargs[0]) && PySequence_Check(pyargs[1]) && PySequence_Check(pyargs[2])) {
        overloadId = 0; // drawItems(QPainter*,int,QGraphicsItem**,const QStyleOptionGraphicsItem*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGraphicsViewFunc_drawItems_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QPainter * cppArg0 = Shiboken::Converter<QPainter * >::toCpp(pyargs[0]);

            if(!PyErr_Occurred()) {
                // drawItems(QPainter*,int,QGraphicsItem**,const QStyleOptionGraphicsItem*)
                // Begin code injection

                int numItems_out = PySequence_Size(pyargs[1-1]);

                // End of code injection
                // Begin code injection

                int numItems = PySequence_Size(pyargs[1-1]);
                PySide::AutoArrayPointer<QGraphicsItem*> items_out(numItems);
                for (int i=0; i < numItems; i++) {
                    items_out[i] = Shiboken::Converter<QGraphicsItem* >::toCpp(PySequence_Fast_GET_ITEM(pyargs[1-1], i));
                }

                // End of code injection
                // Begin code injection

                int numOptions = PySequence_Size(pyargs[2-1]);
                PySide::AutoArrayPointer<QStyleOptionGraphicsItem> options_out(numOptions);
                for (int i=0; i < numOptions; i++) {
                    options_out[i] = Shiboken::Converter<QStyleOptionGraphicsItem >::toCpp(PySequence_Fast_GET_ITEM(pyargs[1-1], i));
                }

                // End of code injection
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QGraphicsView::drawItems(cppArg0, numItems_out, items_out, options_out) : cppSelf->drawItems(cppArg0, numItems_out, items_out, options_out));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGraphicsViewFunc_drawItems_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPainter, int, PySide.QtGui.QGraphicsItem, PySide.QtGui.QStyleOptionGraphicsItem", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QGraphicsView.drawItems", overloads);
        return 0;
}

static PyObject* Sbk_QGraphicsViewFunc_dropEvent(PyObject* self, PyObject* arg)
{
    QGraphicsView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsView* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: dropEvent(QDropEvent*)
    if (Shiboken::Converter< ::QDropEvent * >::isConvertible(arg)) {
        overloadId = 0; // dropEvent(QDropEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGraphicsViewFunc_dropEvent_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QDropEvent * cppArg0 = Shiboken::Converter<QDropEvent * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // dropEvent(QDropEvent*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QGraphicsView::dropEvent(cppArg0) : cppSelf->dropEvent(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGraphicsViewFunc_dropEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QDropEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsView.dropEvent", overloads);
        return 0;
}

static PyObject* Sbk_QGraphicsViewFunc_ensureVisible(PyObject* self, PyObject* args, PyObject* kwds)
{
    QGraphicsView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsView* >::toCpp(self);

    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 6) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QGraphicsView.ensureVisible(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QGraphicsView.ensureVisible(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOOOOO:ensureVisible", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3]), &(pyargs[4]), &(pyargs[5])))
        return 0;


    // Overloaded function decisor
    // 0: ensureVisible(const QGraphicsItem*,int,int)
    // 1: ensureVisible(QRectF,int,int)
    // 2: ensureVisible(qreal,qreal,qreal,qreal,int,int)
    if (numArgs >= 4 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2]) && SbkNumber_Check(pyargs[3])) {
        if (numArgs == 4) {
            overloadId = 2; // ensureVisible(qreal,qreal,qreal,qreal,int,int)
        } else if (SbkNumber_Check(pyargs[4])) {
            if (numArgs == 5) {
                overloadId = 2; // ensureVisible(qreal,qreal,qreal,qreal,int,int)
            } else if (SbkNumber_Check(pyargs[5])) {
                overloadId = 2; // ensureVisible(qreal,qreal,qreal,qreal,int,int)
            }
        }
    } else if (Shiboken::Converter< ::QRectF >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 1; // ensureVisible(QRectF,int,int)
        } else if (SbkNumber_Check(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 1; // ensureVisible(QRectF,int,int)
            } else if (SbkNumber_Check(pyargs[2])) {
                overloadId = 1; // ensureVisible(QRectF,int,int)
            }
        }
    } else if (Shiboken::Converter< ::QGraphicsItem * >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // ensureVisible(const QGraphicsItem*,int,int)
        } else if (SbkNumber_Check(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 0; // ensureVisible(const QGraphicsItem*,int,int)
            } else if (SbkNumber_Check(pyargs[2])) {
                overloadId = 0; // ensureVisible(const QGraphicsItem*,int,int)
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGraphicsViewFunc_ensureVisible_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // ensureVisible(const QGraphicsItem*,int,int)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "xmargin");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "xmargin";
                        else if (SbkNumber_Check(value))
                            pyargs[1] = value;
                        else
                            goto Sbk_QGraphicsViewFunc_ensureVisible_TypeError;
                    }
                    value = PyDict_GetItemString(kwds, "ymargin");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "ymargin";
                        else if (SbkNumber_Check(value))
                            pyargs[2] = value;
                        else
                            goto Sbk_QGraphicsViewFunc_ensureVisible_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QGraphicsView.ensureVisible(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QGraphicsItem * cppArg0 = Shiboken::Converter<QGraphicsItem * >::toCpp(pyargs[0]);
                int cppArg1 = pyargs[1] ? Shiboken::Converter<int >::toCpp(pyargs[1]) : 50;
                int cppArg2 = pyargs[2] ? Shiboken::Converter<int >::toCpp(pyargs[2]) : 50;

                if(!PyErr_Occurred()) {
                    // ensureVisible(const QGraphicsItem*,int,int)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->ensureVisible(cppArg0, cppArg1, cppArg2);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // ensureVisible(QRectF,int,int)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "xmargin");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "xmargin";
                        else if (SbkNumber_Check(value))
                            pyargs[1] = value;
                        else
                            goto Sbk_QGraphicsViewFunc_ensureVisible_TypeError;
                    }
                    value = PyDict_GetItemString(kwds, "ymargin");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "ymargin";
                        else if (SbkNumber_Check(value))
                            pyargs[2] = value;
                        else
                            goto Sbk_QGraphicsViewFunc_ensureVisible_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QGraphicsView.ensureVisible(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QRectF cppArg0 = Shiboken::Converter<QRectF >::toCpp(pyargs[0]);
                int cppArg1 = pyargs[1] ? Shiboken::Converter<int >::toCpp(pyargs[1]) : 50;
                int cppArg2 = pyargs[2] ? Shiboken::Converter<int >::toCpp(pyargs[2]) : 50;

                if(!PyErr_Occurred()) {
                    // ensureVisible(QRectF,int,int)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->ensureVisible(cppArg0, cppArg1, cppArg2);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 2: // ensureVisible(qreal,qreal,qreal,qreal,int,int)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "xmargin");
                    if (value) {
                        if (pyargs[4])
                            errorArgName = "xmargin";
                        else if (SbkNumber_Check(value))
                            pyargs[4] = value;
                        else
                            goto Sbk_QGraphicsViewFunc_ensureVisible_TypeError;
                    }
                    value = PyDict_GetItemString(kwds, "ymargin");
                    if (value) {
                        if (pyargs[5])
                            errorArgName = "ymargin";
                        else if (SbkNumber_Check(value))
                            pyargs[5] = value;
                        else
                            goto Sbk_QGraphicsViewFunc_ensureVisible_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QGraphicsView.ensureVisible(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                qreal cppArg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
                qreal cppArg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);
                qreal cppArg2 = Shiboken::Converter<qreal >::toCpp(pyargs[2]);
                qreal cppArg3 = Shiboken::Converter<qreal >::toCpp(pyargs[3]);
                int cppArg4 = pyargs[4] ? Shiboken::Converter<int >::toCpp(pyargs[4]) : 50;
                int cppArg5 = pyargs[5] ? Shiboken::Converter<int >::toCpp(pyargs[5]) : 50;

                if(!PyErr_Occurred()) {
                    // ensureVisible(qreal,qreal,qreal,qreal,int,int)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->ensureVisible(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGraphicsViewFunc_ensureVisible_TypeError:
        const char* overloads[] = {"PySide.QtGui.QGraphicsItem, int = 50, int = 50", "PySide.QtCore.QRectF, int = 50, int = 50", "float, float, float, float, int = 50, int = 50", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QGraphicsView.ensureVisible", overloads);
        return 0;
}

static PyObject* Sbk_QGraphicsViewFunc_event(PyObject* self, PyObject* arg)
{
    QGraphicsView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsView* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: event(QEvent*)
    if (Shiboken::Converter< ::QEvent * >::isConvertible(arg)) {
        overloadId = 0; // event(QEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGraphicsViewFunc_event_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QEvent * cppArg0 = Shiboken::Converter<QEvent * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // event(QEvent*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = (Shiboken::Object::isUserType(self) ? cppSelf->::QGraphicsView::event(cppArg0) : cppSelf->event(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QGraphicsViewFunc_event_TypeError:
        const char* overloads[] = {"PySide.QtCore.QEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsView.event", overloads);
        return 0;
}

static PyObject* Sbk_QGraphicsViewFunc_fitInView(PyObject* self, PyObject* args, PyObject* kwds)
{
    QGraphicsView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsView* >::toCpp(self);

    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 5) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QGraphicsView.fitInView(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QGraphicsView.fitInView(): not enough arguments");
        return 0;
    } else if (numArgs == 3)
        goto Sbk_QGraphicsViewFunc_fitInView_TypeError;

    if (!PyArg_ParseTuple(args, "|OOOOO:fitInView", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3]), &(pyargs[4])))
        return 0;


    // Overloaded function decisor
    // 0: fitInView(const QGraphicsItem*,Qt::AspectRatioMode)
    // 1: fitInView(QRectF,Qt::AspectRatioMode)
    // 2: fitInView(qreal,qreal,qreal,qreal,Qt::AspectRatioMode)
    if (numArgs >= 4 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2]) && SbkNumber_Check(pyargs[3])) {
        if (numArgs == 4) {
            overloadId = 2; // fitInView(qreal,qreal,qreal,qreal,Qt::AspectRatioMode)
        } else if (Shiboken::Converter< ::Qt::AspectRatioMode >::isConvertible(pyargs[4])) {
            overloadId = 2; // fitInView(qreal,qreal,qreal,qreal,Qt::AspectRatioMode)
        }
    } else if (Shiboken::Converter< ::QRectF >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 1; // fitInView(QRectF,Qt::AspectRatioMode)
        } else if (Shiboken::Converter< ::Qt::AspectRatioMode >::isConvertible(pyargs[1])) {
            overloadId = 1; // fitInView(QRectF,Qt::AspectRatioMode)
        }
    } else if (Shiboken::Converter< ::QGraphicsItem * >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // fitInView(const QGraphicsItem*,Qt::AspectRatioMode)
        } else if (Shiboken::Converter< ::Qt::AspectRatioMode >::isConvertible(pyargs[1])) {
            overloadId = 0; // fitInView(const QGraphicsItem*,Qt::AspectRatioMode)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGraphicsViewFunc_fitInView_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // fitInView(const QGraphicsItem*,Qt::AspectRatioMode)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "aspectRadioMode");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "aspectRadioMode";
                        else if (Shiboken::Converter< ::Qt::AspectRatioMode >::isConvertible(value))
                            pyargs[1] = value;
                        else
                            goto Sbk_QGraphicsViewFunc_fitInView_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QGraphicsView.fitInView(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QGraphicsItem * cppArg0 = Shiboken::Converter<QGraphicsItem * >::toCpp(pyargs[0]);
                Qt::AspectRatioMode cppArg1 = pyargs[1] ? Shiboken::Converter<Qt::AspectRatioMode >::toCpp(pyargs[1]) : Qt::IgnoreAspectRatio;

                if(!PyErr_Occurred()) {
                    // fitInView(const QGraphicsItem*,Qt::AspectRatioMode)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->fitInView(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // fitInView(QRectF,Qt::AspectRatioMode)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "aspectRadioMode");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "aspectRadioMode";
                        else if (Shiboken::Converter< ::Qt::AspectRatioMode >::isConvertible(value))
                            pyargs[1] = value;
                        else
                            goto Sbk_QGraphicsViewFunc_fitInView_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QGraphicsView.fitInView(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QRectF cppArg0 = Shiboken::Converter<QRectF >::toCpp(pyargs[0]);
                Qt::AspectRatioMode cppArg1 = pyargs[1] ? Shiboken::Converter<Qt::AspectRatioMode >::toCpp(pyargs[1]) : Qt::IgnoreAspectRatio;

                if(!PyErr_Occurred()) {
                    // fitInView(QRectF,Qt::AspectRatioMode)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->fitInView(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 2: // fitInView(qreal,qreal,qreal,qreal,Qt::AspectRatioMode)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "aspectRadioMode");
                    if (value) {
                        if (pyargs[4])
                            errorArgName = "aspectRadioMode";
                        else if (Shiboken::Converter< ::Qt::AspectRatioMode >::isConvertible(value))
                            pyargs[4] = value;
                        else
                            goto Sbk_QGraphicsViewFunc_fitInView_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QGraphicsView.fitInView(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                qreal cppArg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
                qreal cppArg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);
                qreal cppArg2 = Shiboken::Converter<qreal >::toCpp(pyargs[2]);
                qreal cppArg3 = Shiboken::Converter<qreal >::toCpp(pyargs[3]);
                Qt::AspectRatioMode cppArg4 = pyargs[4] ? Shiboken::Converter<Qt::AspectRatioMode >::toCpp(pyargs[4]) : Qt::IgnoreAspectRatio;

                if(!PyErr_Occurred()) {
                    // fitInView(qreal,qreal,qreal,qreal,Qt::AspectRatioMode)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->fitInView(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGraphicsViewFunc_fitInView_TypeError:
        const char* overloads[] = {"PySide.QtGui.QGraphicsItem, PySide.QtCore.Qt.AspectRatioMode = Qt.IgnoreAspectRatio", "PySide.QtCore.QRectF, PySide.QtCore.Qt.AspectRatioMode = Qt.IgnoreAspectRatio", "float, float, float, float, PySide.QtCore.Qt.AspectRatioMode = Qt.IgnoreAspectRatio", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QGraphicsView.fitInView", overloads);
        return 0;
}

static PyObject* Sbk_QGraphicsViewFunc_focusInEvent(PyObject* self, PyObject* arg)
{
    QGraphicsView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsView* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: focusInEvent(QFocusEvent*)
    if (Shiboken::Converter< ::QFocusEvent * >::isConvertible(arg)) {
        overloadId = 0; // focusInEvent(QFocusEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGraphicsViewFunc_focusInEvent_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QFocusEvent * cppArg0 = Shiboken::Converter<QFocusEvent * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // focusInEvent(QFocusEvent*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QGraphicsView::focusInEvent(cppArg0) : cppSelf->focusInEvent(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGraphicsViewFunc_focusInEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QFocusEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsView.focusInEvent", overloads);
        return 0;
}

static PyObject* Sbk_QGraphicsViewFunc_focusNextPrevChild(PyObject* self, PyObject* arg)
{
    QGraphicsView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsView* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: focusNextPrevChild(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // focusNextPrevChild(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGraphicsViewFunc_focusNextPrevChild_TypeError;

    // Call function/method
    {
        {
            bool cppArg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // focusNextPrevChild(bool)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = (Shiboken::Object::isUserType(self) ? cppSelf->::QGraphicsView::focusNextPrevChild(cppArg0) : cppSelf->focusNextPrevChild(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QGraphicsViewFunc_focusNextPrevChild_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsView.focusNextPrevChild", overloads);
        return 0;
}

static PyObject* Sbk_QGraphicsViewFunc_focusOutEvent(PyObject* self, PyObject* arg)
{
    QGraphicsView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsView* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: focusOutEvent(QFocusEvent*)
    if (Shiboken::Converter< ::QFocusEvent * >::isConvertible(arg)) {
        overloadId = 0; // focusOutEvent(QFocusEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGraphicsViewFunc_focusOutEvent_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QFocusEvent * cppArg0 = Shiboken::Converter<QFocusEvent * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // focusOutEvent(QFocusEvent*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QGraphicsView::focusOutEvent(cppArg0) : cppSelf->focusOutEvent(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGraphicsViewFunc_focusOutEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QFocusEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsView.focusOutEvent", overloads);
        return 0;
}

static PyObject* Sbk_QGraphicsViewFunc_foregroundBrush(PyObject* self)
{
    QGraphicsView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsView* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // foregroundBrush()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QBrush cppResult = const_cast<const QGraphicsView*>(cppSelf)->foregroundBrush();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QBrush >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QGraphicsViewFunc_inputMethodEvent(PyObject* self, PyObject* arg)
{
    QGraphicsView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsView* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: inputMethodEvent(QInputMethodEvent*)
    if (Shiboken::Converter< ::QInputMethodEvent * >::isConvertible(arg)) {
        overloadId = 0; // inputMethodEvent(QInputMethodEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGraphicsViewFunc_inputMethodEvent_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QInputMethodEvent * cppArg0 = Shiboken::Converter<QInputMethodEvent * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // inputMethodEvent(QInputMethodEvent*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QGraphicsView::inputMethodEvent(cppArg0) : cppSelf->inputMethodEvent(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGraphicsViewFunc_inputMethodEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QInputMethodEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsView.inputMethodEvent", overloads);
        return 0;
}

static PyObject* Sbk_QGraphicsViewFunc_inputMethodQuery(PyObject* self, PyObject* arg)
{
    QGraphicsView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsView* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: inputMethodQuery(Qt::InputMethodQuery)const
    if (Shiboken::Converter< ::Qt::InputMethodQuery >::isConvertible(arg)) {
        overloadId = 0; // inputMethodQuery(Qt::InputMethodQuery)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGraphicsViewFunc_inputMethodQuery_TypeError;

    // Call function/method
    {
        {
            Qt::InputMethodQuery cppArg0 = Shiboken::Converter<Qt::InputMethodQuery >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // inputMethodQuery(Qt::InputMethodQuery)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QVariant cppResult = (Shiboken::Object::isUserType(self) ? const_cast<const QGraphicsView*>(cppSelf)->::QGraphicsView::inputMethodQuery(cppArg0) : const_cast<const QGraphicsView*>(cppSelf)->inputMethodQuery(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QVariant >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QGraphicsViewFunc_inputMethodQuery_TypeError:
        const char* overloads[] = {"PySide.QtCore.Qt.InputMethodQuery", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsView.inputMethodQuery", overloads);
        return 0;
}

static PyObject* Sbk_QGraphicsViewFunc_invalidateScene(PyObject* self, PyObject* args, PyObject* kwds)
{
    QGraphicsView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsView* >::toCpp(self);

    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QGraphicsView.invalidateScene(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:invalidateScene", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: invalidateScene(QRectF,QFlags<QGraphicsScene::SceneLayer>)
    if (numArgs == 0) {
        overloadId = 0; // invalidateScene(QRectF,QFlags<QGraphicsScene::SceneLayer>)
    } else if (Shiboken::Converter< ::QRectF >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // invalidateScene(QRectF,QFlags<QGraphicsScene::SceneLayer>)
        } else if (Shiboken::Converter< ::QFlags<QGraphicsScene::SceneLayer> >::isConvertible(pyargs[1])) {
            overloadId = 0; // invalidateScene(QRectF,QFlags<QGraphicsScene::SceneLayer>)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGraphicsViewFunc_invalidateScene_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "rect");
                if (value) {
                    if (pyargs[0])
                        errorArgName = "rect";
                    else if (Shiboken::Converter< ::QRectF >::isConvertible(value))
                        pyargs[0] = value;
                    else
                        goto Sbk_QGraphicsViewFunc_invalidateScene_TypeError;
                }
                value = PyDict_GetItemString(kwds, "layers");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "layers";
                    else if (Shiboken::Converter< ::QFlags<QGraphicsScene::SceneLayer> >::isConvertible(value))
                        pyargs[1] = value;
                    else
                        goto Sbk_QGraphicsViewFunc_invalidateScene_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QGraphicsView.invalidateScene(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QRectF cppArg0_tmp = QRectF();
            QRectF cppArg0 = pyargs[0] ? Shiboken::Converter<QRectF >::toCpp(pyargs[0]) : cppArg0_tmp;
            QFlags<QGraphicsScene::SceneLayer> cppArg1 = pyargs[1] ? Shiboken::Converter<QFlags<QGraphicsScene::SceneLayer> >::toCpp(pyargs[1]) : QGraphicsScene::AllLayers;

            if(!PyErr_Occurred()) {
                // invalidateScene(QRectF,QFlags<QGraphicsScene::SceneLayer>)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->invalidateScene(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGraphicsViewFunc_invalidateScene_TypeError:
        const char* overloads[] = {"PySide.QtCore.QRectF = QRectF(), PySide.QtGui.QGraphicsScene.SceneLayers = QGraphicsScene.AllLayers", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QGraphicsView.invalidateScene", overloads);
        return 0;
}

static PyObject* Sbk_QGraphicsViewFunc_isInteractive(PyObject* self)
{
    QGraphicsView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsView* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isInteractive()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QGraphicsView*>(cppSelf)->isInteractive();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QGraphicsViewFunc_isTransformed(PyObject* self)
{
    QGraphicsView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsView* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isTransformed()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QGraphicsView*>(cppSelf)->isTransformed();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QGraphicsViewFunc_itemAt(PyObject* self, PyObject* args)
{
    QGraphicsView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsView* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "itemAt", 1, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: itemAt(QPoint)const
    // 1: itemAt(int,int)const
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 1; // itemAt(int,int)const
    } else if (numArgs == 1 && Shiboken::Converter< ::QPoint >::isConvertible(pyargs[0])) {
        overloadId = 0; // itemAt(QPoint)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGraphicsViewFunc_itemAt_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // itemAt(QPoint)const
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QPoint cppArg0 = Shiboken::Converter<QPoint >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // itemAt(QPoint)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QGraphicsItem * cppResult = const_cast<const QGraphicsView*>(cppSelf)->itemAt(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QGraphicsItem * >::toPython(cppResult);

                    // Ownership transferences.
                }
                break;
            }
            case 1: // itemAt(int,int)const
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // itemAt(int,int)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QGraphicsItem * cppResult = const_cast<const QGraphicsView*>(cppSelf)->itemAt(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QGraphicsItem * >::toPython(cppResult);

                    // Ownership transferences.
                }
                break;
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QGraphicsViewFunc_itemAt_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPoint", "int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QGraphicsView.itemAt", overloads);
        return 0;
}

static PyObject* Sbk_QGraphicsViewFunc_items(PyObject* self, PyObject* args, PyObject* kwds)
{
    QGraphicsView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsView* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 5) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QGraphicsView.items(): too many arguments");
        return 0;
    } else if (numArgs == 3)
        goto Sbk_QGraphicsViewFunc_items_TypeError;

    if (!PyArg_ParseTuple(args, "|OOOOO:items", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3]), &(pyargs[4])))
        return 0;


    // Overloaded function decisor
    // 0: items()const
    // 1: items(QPainterPath,Qt::ItemSelectionMode)const
    // 2: items(QPoint)const
    // 3: items(QPolygon,Qt::ItemSelectionMode)const
    // 4: items(QRect,Qt::ItemSelectionMode)const
    // 5: items(int,int)const
    // 6: items(int,int,int,int,Qt::ItemSelectionMode)const
    if (numArgs == 0) {
        overloadId = 0; // items()const
    } else if (numArgs >= 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        if (numArgs == 2) {
            overloadId = 5; // items(int,int)const
        } else if (numArgs >= 4 && SbkNumber_Check(pyargs[2]) && SbkNumber_Check(pyargs[3])) {
            if (numArgs == 4) {
                overloadId = 6; // items(int,int,int,int,Qt::ItemSelectionMode)const
            } else if (Shiboken::Converter< ::Qt::ItemSelectionMode >::isConvertible(pyargs[4])) {
                overloadId = 6; // items(int,int,int,int,Qt::ItemSelectionMode)const
            }
        }
    } else if (Shiboken::Converter< ::QRect >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 4; // items(QRect,Qt::ItemSelectionMode)const
        } else if (Shiboken::Converter< ::Qt::ItemSelectionMode >::isConvertible(pyargs[1])) {
            overloadId = 4; // items(QRect,Qt::ItemSelectionMode)const
        }
    } else if (Shiboken::Converter< ::QPolygon >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 3; // items(QPolygon,Qt::ItemSelectionMode)const
        } else if (Shiboken::Converter< ::Qt::ItemSelectionMode >::isConvertible(pyargs[1])) {
            overloadId = 3; // items(QPolygon,Qt::ItemSelectionMode)const
        }
    } else if (numArgs == 1 && Shiboken::Converter< ::QPoint >::isConvertible(pyargs[0])) {
        overloadId = 2; // items(QPoint)const
    } else if (Shiboken::Converter< ::QPainterPath >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 1; // items(QPainterPath,Qt::ItemSelectionMode)const
        } else if (Shiboken::Converter< ::Qt::ItemSelectionMode >::isConvertible(pyargs[1])) {
            overloadId = 1; // items(QPainterPath,Qt::ItemSelectionMode)const
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGraphicsViewFunc_items_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // items()const
            {

                if(!PyErr_Occurred()) {
                    // items()const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QList<QGraphicsItem * > cppResult = const_cast<const QGraphicsView*>(cppSelf)->items();
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QList<QGraphicsItem * > >::toPython(cppResult);
                }
                break;
            }
            case 1: // items(QPainterPath,Qt::ItemSelectionMode)const
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "mode");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "mode";
                        else if (Shiboken::Converter< ::Qt::ItemSelectionMode >::isConvertible(value))
                            pyargs[1] = value;
                        else
                            goto Sbk_QGraphicsViewFunc_items_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QGraphicsView.items(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QPainterPath cppArg0 = Shiboken::Converter<QPainterPath >::toCpp(pyargs[0]);
                Qt::ItemSelectionMode cppArg1 = pyargs[1] ? Shiboken::Converter<Qt::ItemSelectionMode >::toCpp(pyargs[1]) : Qt::IntersectsItemShape;

                if(!PyErr_Occurred()) {
                    // items(QPainterPath,Qt::ItemSelectionMode)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QList<QGraphicsItem * > cppResult = const_cast<const QGraphicsView*>(cppSelf)->items(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QList<QGraphicsItem * > >::toPython(cppResult);
                }
                break;
            }
            case 2: // items(QPoint)const
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QPoint cppArg0 = Shiboken::Converter<QPoint >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // items(QPoint)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QList<QGraphicsItem * > cppResult = const_cast<const QGraphicsView*>(cppSelf)->items(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QList<QGraphicsItem * > >::toPython(cppResult);
                }
                break;
            }
            case 3: // items(QPolygon,Qt::ItemSelectionMode)const
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "mode");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "mode";
                        else if (Shiboken::Converter< ::Qt::ItemSelectionMode >::isConvertible(value))
                            pyargs[1] = value;
                        else
                            goto Sbk_QGraphicsViewFunc_items_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QGraphicsView.items(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QPolygon cppArg0 = Shiboken::Converter<QPolygon >::toCpp(pyargs[0]);
                Qt::ItemSelectionMode cppArg1 = pyargs[1] ? Shiboken::Converter<Qt::ItemSelectionMode >::toCpp(pyargs[1]) : Qt::IntersectsItemShape;

                if(!PyErr_Occurred()) {
                    // items(QPolygon,Qt::ItemSelectionMode)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QList<QGraphicsItem * > cppResult = const_cast<const QGraphicsView*>(cppSelf)->items(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QList<QGraphicsItem * > >::toPython(cppResult);
                }
                break;
            }
            case 4: // items(QRect,Qt::ItemSelectionMode)const
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "mode");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "mode";
                        else if (Shiboken::Converter< ::Qt::ItemSelectionMode >::isConvertible(value))
                            pyargs[1] = value;
                        else
                            goto Sbk_QGraphicsViewFunc_items_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QGraphicsView.items(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QRect cppArg0 = Shiboken::Converter<QRect >::toCpp(pyargs[0]);
                Qt::ItemSelectionMode cppArg1 = pyargs[1] ? Shiboken::Converter<Qt::ItemSelectionMode >::toCpp(pyargs[1]) : Qt::IntersectsItemShape;

                if(!PyErr_Occurred()) {
                    // items(QRect,Qt::ItemSelectionMode)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QList<QGraphicsItem * > cppResult = const_cast<const QGraphicsView*>(cppSelf)->items(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QList<QGraphicsItem * > >::toPython(cppResult);
                }
                break;
            }
            case 5: // items(int,int)const
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // items(int,int)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QList<QGraphicsItem * > cppResult = const_cast<const QGraphicsView*>(cppSelf)->items(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QList<QGraphicsItem * > >::toPython(cppResult);
                }
                break;
            }
            case 6: // items(int,int,int,int,Qt::ItemSelectionMode)const
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "mode");
                    if (value) {
                        if (pyargs[4])
                            errorArgName = "mode";
                        else if (Shiboken::Converter< ::Qt::ItemSelectionMode >::isConvertible(value))
                            pyargs[4] = value;
                        else
                            goto Sbk_QGraphicsViewFunc_items_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QGraphicsView.items(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                int cppArg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);
                int cppArg3 = Shiboken::Converter<int >::toCpp(pyargs[3]);
                Qt::ItemSelectionMode cppArg4 = pyargs[4] ? Shiboken::Converter<Qt::ItemSelectionMode >::toCpp(pyargs[4]) : Qt::IntersectsItemShape;

                if(!PyErr_Occurred()) {
                    // items(int,int,int,int,Qt::ItemSelectionMode)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QList<QGraphicsItem * > cppResult = const_cast<const QGraphicsView*>(cppSelf)->items(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QList<QGraphicsItem * > >::toPython(cppResult);
                }
                break;
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QGraphicsViewFunc_items_TypeError:
        const char* overloads[] = {"", "PySide.QtGui.QPainterPath, PySide.QtCore.Qt.ItemSelectionMode = Qt.IntersectsItemShape", "PySide.QtCore.QPoint", "PySide.QtGui.QPolygon, PySide.QtCore.Qt.ItemSelectionMode = Qt.IntersectsItemShape", "PySide.QtCore.QRect, PySide.QtCore.Qt.ItemSelectionMode = Qt.IntersectsItemShape", "int, int", "int, int, int, int, PySide.QtCore.Qt.ItemSelectionMode = Qt.IntersectsItemShape", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QGraphicsView.items", overloads);
        return 0;
}

static PyObject* Sbk_QGraphicsViewFunc_keyPressEvent(PyObject* self, PyObject* arg)
{
    QGraphicsView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsView* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: keyPressEvent(QKeyEvent*)
    if (Shiboken::Converter< ::QKeyEvent * >::isConvertible(arg)) {
        overloadId = 0; // keyPressEvent(QKeyEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGraphicsViewFunc_keyPressEvent_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QKeyEvent * cppArg0 = Shiboken::Converter<QKeyEvent * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // keyPressEvent(QKeyEvent*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QGraphicsView::keyPressEvent(cppArg0) : cppSelf->keyPressEvent(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGraphicsViewFunc_keyPressEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QKeyEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsView.keyPressEvent", overloads);
        return 0;
}

static PyObject* Sbk_QGraphicsViewFunc_keyReleaseEvent(PyObject* self, PyObject* arg)
{
    QGraphicsView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsView* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: keyReleaseEvent(QKeyEvent*)
    if (Shiboken::Converter< ::QKeyEvent * >::isConvertible(arg)) {
        overloadId = 0; // keyReleaseEvent(QKeyEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGraphicsViewFunc_keyReleaseEvent_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QKeyEvent * cppArg0 = Shiboken::Converter<QKeyEvent * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // keyReleaseEvent(QKeyEvent*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QGraphicsView::keyReleaseEvent(cppArg0) : cppSelf->keyReleaseEvent(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGraphicsViewFunc_keyReleaseEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QKeyEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsView.keyReleaseEvent", overloads);
        return 0;
}

static PyObject* Sbk_QGraphicsViewFunc_mapFromScene(PyObject* self, PyObject* args)
{
    QGraphicsView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsView* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs == 3)
        goto Sbk_QGraphicsViewFunc_mapFromScene_TypeError;

    if (!PyArg_UnpackTuple(args, "mapFromScene", 1, 4, &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return 0;


    // Overloaded function decisor
    // 0: mapFromScene(QPainterPath)const
    // 1: mapFromScene(QPointF)const
    // 2: mapFromScene(QPolygonF)const
    // 3: mapFromScene(QRectF)const
    // 4: mapFromScene(qreal,qreal)const
    // 5: mapFromScene(qreal,qreal,qreal,qreal)const
    if (numArgs >= 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        if (numArgs == 2) {
            overloadId = 4; // mapFromScene(qreal,qreal)const
        } else if (numArgs == 4 && SbkNumber_Check(pyargs[2]) && SbkNumber_Check(pyargs[3])) {
            overloadId = 5; // mapFromScene(qreal,qreal,qreal,qreal)const
        }
    } else if (numArgs == 1 && Shiboken::Converter< ::QRectF >::isConvertible(pyargs[0])) {
        overloadId = 3; // mapFromScene(QRectF)const
    } else if (numArgs == 1 && Shiboken::Converter< ::QPolygonF >::isConvertible(pyargs[0])) {
        overloadId = 2; // mapFromScene(QPolygonF)const
    } else if (numArgs == 1 && Shiboken::Converter< ::QPointF >::isConvertible(pyargs[0])) {
        overloadId = 1; // mapFromScene(QPointF)const
    } else if (numArgs == 1 && Shiboken::Converter< ::QPainterPath >::isConvertible(pyargs[0])) {
        overloadId = 0; // mapFromScene(QPainterPath)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGraphicsViewFunc_mapFromScene_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // mapFromScene(QPainterPath)const
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QPainterPath cppArg0 = Shiboken::Converter<QPainterPath >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // mapFromScene(QPainterPath)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QPainterPath cppResult = const_cast<const QGraphicsView*>(cppSelf)->mapFromScene(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QPainterPath >::toPython(cppResult);
                }
                break;
            }
            case 1: // mapFromScene(QPointF)const
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QPointF cppArg0 = Shiboken::Converter<QPointF >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // mapFromScene(QPointF)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QPoint cppResult = const_cast<const QGraphicsView*>(cppSelf)->mapFromScene(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QPoint >::toPython(cppResult);
                }
                break;
            }
            case 2: // mapFromScene(QPolygonF)const
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QPolygonF cppArg0 = Shiboken::Converter<QPolygonF >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // mapFromScene(QPolygonF)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QPolygon cppResult = const_cast<const QGraphicsView*>(cppSelf)->mapFromScene(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QPolygon >::toPython(cppResult);
                }
                break;
            }
            case 3: // mapFromScene(QRectF)const
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QRectF cppArg0 = Shiboken::Converter<QRectF >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // mapFromScene(QRectF)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QPolygon cppResult = const_cast<const QGraphicsView*>(cppSelf)->mapFromScene(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QPolygon >::toPython(cppResult);
                }
                break;
            }
            case 4: // mapFromScene(qreal,qreal)const
            {
                qreal cppArg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
                qreal cppArg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // mapFromScene(qreal,qreal)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QPoint cppResult = const_cast<const QGraphicsView*>(cppSelf)->mapFromScene(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QPoint >::toPython(cppResult);
                }
                break;
            }
            case 5: // mapFromScene(qreal,qreal,qreal,qreal)const
            {
                qreal cppArg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
                qreal cppArg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);
                qreal cppArg2 = Shiboken::Converter<qreal >::toCpp(pyargs[2]);
                qreal cppArg3 = Shiboken::Converter<qreal >::toCpp(pyargs[3]);

                if(!PyErr_Occurred()) {
                    // mapFromScene(qreal,qreal,qreal,qreal)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QPolygon cppResult = const_cast<const QGraphicsView*>(cppSelf)->mapFromScene(cppArg0, cppArg1, cppArg2, cppArg3);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QPolygon >::toPython(cppResult);
                }
                break;
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QGraphicsViewFunc_mapFromScene_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPainterPath", "PySide.QtCore.QPointF", "PySide.QtGui.QPolygonF", "PySide.QtCore.QRectF", "float, float", "float, float, float, float", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QGraphicsView.mapFromScene", overloads);
        return 0;
}

static PyObject* Sbk_QGraphicsViewFunc_mapToScene(PyObject* self, PyObject* args)
{
    QGraphicsView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsView* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs == 3)
        goto Sbk_QGraphicsViewFunc_mapToScene_TypeError;

    if (!PyArg_UnpackTuple(args, "mapToScene", 1, 4, &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return 0;


    // Overloaded function decisor
    // 0: mapToScene(QPainterPath)const
    // 1: mapToScene(QPoint)const
    // 2: mapToScene(QPolygon)const
    // 3: mapToScene(QRect)const
    // 4: mapToScene(int,int)const
    // 5: mapToScene(int,int,int,int)const
    if (numArgs >= 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        if (numArgs == 2) {
            overloadId = 4; // mapToScene(int,int)const
        } else if (numArgs == 4 && SbkNumber_Check(pyargs[2]) && SbkNumber_Check(pyargs[3])) {
            overloadId = 5; // mapToScene(int,int,int,int)const
        }
    } else if (numArgs == 1 && Shiboken::Converter< ::QRect >::isConvertible(pyargs[0])) {
        overloadId = 3; // mapToScene(QRect)const
    } else if (numArgs == 1 && Shiboken::Converter< ::QPolygon >::isConvertible(pyargs[0])) {
        overloadId = 2; // mapToScene(QPolygon)const
    } else if (numArgs == 1 && Shiboken::Converter< ::QPoint >::isConvertible(pyargs[0])) {
        overloadId = 1; // mapToScene(QPoint)const
    } else if (numArgs == 1 && Shiboken::Converter< ::QPainterPath >::isConvertible(pyargs[0])) {
        overloadId = 0; // mapToScene(QPainterPath)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGraphicsViewFunc_mapToScene_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // mapToScene(QPainterPath)const
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QPainterPath cppArg0 = Shiboken::Converter<QPainterPath >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // mapToScene(QPainterPath)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QPainterPath cppResult = const_cast<const QGraphicsView*>(cppSelf)->mapToScene(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QPainterPath >::toPython(cppResult);
                }
                break;
            }
            case 1: // mapToScene(QPoint)const
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QPoint cppArg0 = Shiboken::Converter<QPoint >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // mapToScene(QPoint)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QPointF cppResult = const_cast<const QGraphicsView*>(cppSelf)->mapToScene(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QPointF >::toPython(cppResult);
                }
                break;
            }
            case 2: // mapToScene(QPolygon)const
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QPolygon cppArg0 = Shiboken::Converter<QPolygon >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // mapToScene(QPolygon)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QPolygonF cppResult = const_cast<const QGraphicsView*>(cppSelf)->mapToScene(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QPolygonF >::toPython(cppResult);
                }
                break;
            }
            case 3: // mapToScene(QRect)const
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QRect cppArg0 = Shiboken::Converter<QRect >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // mapToScene(QRect)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QPolygonF cppResult = const_cast<const QGraphicsView*>(cppSelf)->mapToScene(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QPolygonF >::toPython(cppResult);
                }
                break;
            }
            case 4: // mapToScene(int,int)const
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // mapToScene(int,int)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QPointF cppResult = const_cast<const QGraphicsView*>(cppSelf)->mapToScene(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QPointF >::toPython(cppResult);
                }
                break;
            }
            case 5: // mapToScene(int,int,int,int)const
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                int cppArg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);
                int cppArg3 = Shiboken::Converter<int >::toCpp(pyargs[3]);

                if(!PyErr_Occurred()) {
                    // mapToScene(int,int,int,int)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QPolygonF cppResult = const_cast<const QGraphicsView*>(cppSelf)->mapToScene(cppArg0, cppArg1, cppArg2, cppArg3);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QPolygonF >::toPython(cppResult);
                }
                break;
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QGraphicsViewFunc_mapToScene_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPainterPath", "PySide.QtCore.QPoint", "PySide.QtGui.QPolygon", "PySide.QtCore.QRect", "int, int", "int, int, int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QGraphicsView.mapToScene", overloads);
        return 0;
}

static PyObject* Sbk_QGraphicsViewFunc_matrix(PyObject* self)
{
    QGraphicsView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsView* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // matrix()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QMatrix cppResult = const_cast<const QGraphicsView*>(cppSelf)->matrix();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QMatrix >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QGraphicsViewFunc_mouseDoubleClickEvent(PyObject* self, PyObject* arg)
{
    QGraphicsView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsView* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: mouseDoubleClickEvent(QMouseEvent*)
    if (Shiboken::Converter< ::QMouseEvent * >::isConvertible(arg)) {
        overloadId = 0; // mouseDoubleClickEvent(QMouseEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGraphicsViewFunc_mouseDoubleClickEvent_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QMouseEvent * cppArg0 = Shiboken::Converter<QMouseEvent * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // mouseDoubleClickEvent(QMouseEvent*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QGraphicsView::mouseDoubleClickEvent(cppArg0) : cppSelf->mouseDoubleClickEvent(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGraphicsViewFunc_mouseDoubleClickEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QMouseEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsView.mouseDoubleClickEvent", overloads);
        return 0;
}

static PyObject* Sbk_QGraphicsViewFunc_mouseMoveEvent(PyObject* self, PyObject* arg)
{
    QGraphicsView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsView* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: mouseMoveEvent(QMouseEvent*)
    if (Shiboken::Converter< ::QMouseEvent * >::isConvertible(arg)) {
        overloadId = 0; // mouseMoveEvent(QMouseEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGraphicsViewFunc_mouseMoveEvent_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QMouseEvent * cppArg0 = Shiboken::Converter<QMouseEvent * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // mouseMoveEvent(QMouseEvent*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QGraphicsView::mouseMoveEvent(cppArg0) : cppSelf->mouseMoveEvent(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGraphicsViewFunc_mouseMoveEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QMouseEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsView.mouseMoveEvent", overloads);
        return 0;
}

static PyObject* Sbk_QGraphicsViewFunc_mousePressEvent(PyObject* self, PyObject* arg)
{
    QGraphicsView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsView* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: mousePressEvent(QMouseEvent*)
    if (Shiboken::Converter< ::QMouseEvent * >::isConvertible(arg)) {
        overloadId = 0; // mousePressEvent(QMouseEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGraphicsViewFunc_mousePressEvent_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QMouseEvent * cppArg0 = Shiboken::Converter<QMouseEvent * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // mousePressEvent(QMouseEvent*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QGraphicsView::mousePressEvent(cppArg0) : cppSelf->mousePressEvent(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGraphicsViewFunc_mousePressEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QMouseEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsView.mousePressEvent", overloads);
        return 0;
}

static PyObject* Sbk_QGraphicsViewFunc_mouseReleaseEvent(PyObject* self, PyObject* arg)
{
    QGraphicsView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsView* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: mouseReleaseEvent(QMouseEvent*)
    if (Shiboken::Converter< ::QMouseEvent * >::isConvertible(arg)) {
        overloadId = 0; // mouseReleaseEvent(QMouseEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGraphicsViewFunc_mouseReleaseEvent_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QMouseEvent * cppArg0 = Shiboken::Converter<QMouseEvent * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // mouseReleaseEvent(QMouseEvent*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QGraphicsView::mouseReleaseEvent(cppArg0) : cppSelf->mouseReleaseEvent(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGraphicsViewFunc_mouseReleaseEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QMouseEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsView.mouseReleaseEvent", overloads);
        return 0;
}

static PyObject* Sbk_QGraphicsViewFunc_optimizationFlags(PyObject* self)
{
    QGraphicsView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsView* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // optimizationFlags()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QFlags<QGraphicsView::OptimizationFlag> cppResult = const_cast<const QGraphicsView*>(cppSelf)->optimizationFlags();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QFlags<QGraphicsView::OptimizationFlag> >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QGraphicsViewFunc_paintEvent(PyObject* self, PyObject* arg)
{
    QGraphicsView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsView* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: paintEvent(QPaintEvent*)
    if (Shiboken::Converter< ::QPaintEvent * >::isConvertible(arg)) {
        overloadId = 0; // paintEvent(QPaintEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGraphicsViewFunc_paintEvent_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QPaintEvent * cppArg0 = Shiboken::Converter<QPaintEvent * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // paintEvent(QPaintEvent*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QGraphicsView::paintEvent(cppArg0) : cppSelf->paintEvent(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGraphicsViewFunc_paintEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPaintEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsView.paintEvent", overloads);
        return 0;
}

static PyObject* Sbk_QGraphicsViewFunc_render(PyObject* self, PyObject* args, PyObject* kwds)
{
    QGraphicsView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsView* >::toCpp(self);

    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 4) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QGraphicsView.render(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QGraphicsView.render(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOOO:render", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return 0;


    // Overloaded function decisor
    // 0: render(QPainter*,QRectF,QRect,Qt::AspectRatioMode)
    if (Shiboken::Converter< ::QPainter * >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // render(QPainter*,QRectF,QRect,Qt::AspectRatioMode)
        } else if (Shiboken::Converter< ::QRectF >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 0; // render(QPainter*,QRectF,QRect,Qt::AspectRatioMode)
            } else if (Shiboken::Converter< ::QRect >::isConvertible(pyargs[2])) {
                if (numArgs == 3) {
                    overloadId = 0; // render(QPainter*,QRectF,QRect,Qt::AspectRatioMode)
                } else if (Shiboken::Converter< ::Qt::AspectRatioMode >::isConvertible(pyargs[3])) {
                    overloadId = 0; // render(QPainter*,QRectF,QRect,Qt::AspectRatioMode)
                }
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGraphicsViewFunc_render_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "target");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "target";
                    else if (Shiboken::Converter< ::QRectF >::isConvertible(value))
                        pyargs[1] = value;
                    else
                        goto Sbk_QGraphicsViewFunc_render_TypeError;
                }
                value = PyDict_GetItemString(kwds, "source");
                if (value) {
                    if (pyargs[2])
                        errorArgName = "source";
                    else if (Shiboken::Converter< ::QRect >::isConvertible(value))
                        pyargs[2] = value;
                    else
                        goto Sbk_QGraphicsViewFunc_render_TypeError;
                }
                value = PyDict_GetItemString(kwds, "aspectRatioMode");
                if (value) {
                    if (pyargs[3])
                        errorArgName = "aspectRatioMode";
                    else if (Shiboken::Converter< ::Qt::AspectRatioMode >::isConvertible(value))
                        pyargs[3] = value;
                    else
                        goto Sbk_QGraphicsViewFunc_render_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QGraphicsView.render(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QPainter * cppArg0 = Shiboken::Converter<QPainter * >::toCpp(pyargs[0]);
            if (!Shiboken::Object::isValid(pyargs[1]))
                return 0;
            QRectF cppArg1_tmp = QRectF();
            QRectF cppArg1 = pyargs[1] ? Shiboken::Converter<QRectF >::toCpp(pyargs[1]) : cppArg1_tmp;
            if (!Shiboken::Object::isValid(pyargs[2]))
                return 0;
            QRect cppArg2_tmp = QRect();
            QRect cppArg2 = pyargs[2] ? Shiboken::Converter<QRect >::toCpp(pyargs[2]) : cppArg2_tmp;
            Qt::AspectRatioMode cppArg3 = pyargs[3] ? Shiboken::Converter<Qt::AspectRatioMode >::toCpp(pyargs[3]) : Qt::KeepAspectRatio;

            if(!PyErr_Occurred()) {
                // render(QPainter*,QRectF,QRect,Qt::AspectRatioMode)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->render(cppArg0, cppArg1, cppArg2, cppArg3);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGraphicsViewFunc_render_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPainter, PySide.QtCore.QRectF = QRectF(), PySide.QtCore.QRect = QRect(), PySide.QtCore.Qt.AspectRatioMode = Qt.KeepAspectRatio", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QGraphicsView.render", overloads);
        return 0;
}

static PyObject* Sbk_QGraphicsViewFunc_renderHints(PyObject* self)
{
    QGraphicsView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsView* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // renderHints()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QFlags<QPainter::RenderHint> cppResult = const_cast<const QGraphicsView*>(cppSelf)->renderHints();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QFlags<QPainter::RenderHint> >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QGraphicsViewFunc_resetCachedContent(PyObject* self)
{
    QGraphicsView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsView* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // resetCachedContent()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->resetCachedContent();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QGraphicsViewFunc_resetMatrix(PyObject* self)
{
    QGraphicsView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsView* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // resetMatrix()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->resetMatrix();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QGraphicsViewFunc_resetTransform(PyObject* self)
{
    QGraphicsView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsView* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // resetTransform()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->resetTransform();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QGraphicsViewFunc_resizeAnchor(PyObject* self)
{
    QGraphicsView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsView* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // resizeAnchor()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QGraphicsView::ViewportAnchor cppResult = const_cast<const QGraphicsView*>(cppSelf)->resizeAnchor();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QGraphicsView::ViewportAnchor >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QGraphicsViewFunc_resizeEvent(PyObject* self, PyObject* arg)
{
    QGraphicsView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsView* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: resizeEvent(QResizeEvent*)
    if (Shiboken::Converter< ::QResizeEvent * >::isConvertible(arg)) {
        overloadId = 0; // resizeEvent(QResizeEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGraphicsViewFunc_resizeEvent_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QResizeEvent * cppArg0 = Shiboken::Converter<QResizeEvent * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // resizeEvent(QResizeEvent*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QGraphicsView::resizeEvent(cppArg0) : cppSelf->resizeEvent(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGraphicsViewFunc_resizeEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QResizeEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsView.resizeEvent", overloads);
        return 0;
}

static PyObject* Sbk_QGraphicsViewFunc_rotate(PyObject* self, PyObject* arg)
{
    QGraphicsView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsView* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: rotate(qreal)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // rotate(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGraphicsViewFunc_rotate_TypeError;

    // Call function/method
    {
        {
            qreal cppArg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // rotate(qreal)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->rotate(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGraphicsViewFunc_rotate_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsView.rotate", overloads);
        return 0;
}

static PyObject* Sbk_QGraphicsViewFunc_rubberBandSelectionMode(PyObject* self)
{
    QGraphicsView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsView* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // rubberBandSelectionMode()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                Qt::ItemSelectionMode cppResult = const_cast<const QGraphicsView*>(cppSelf)->rubberBandSelectionMode();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::Qt::ItemSelectionMode >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QGraphicsViewFunc_scale(PyObject* self, PyObject* args)
{
    QGraphicsView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsView* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "scale", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: scale(qreal,qreal)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 0; // scale(qreal,qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGraphicsViewFunc_scale_TypeError;

    // Call function/method
    {
        {
            qreal cppArg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
            qreal cppArg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // scale(qreal,qreal)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->scale(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGraphicsViewFunc_scale_TypeError:
        const char* overloads[] = {"float, float", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QGraphicsView.scale", overloads);
        return 0;
}

static PyObject* Sbk_QGraphicsViewFunc_scene(PyObject* self)
{
    QGraphicsView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsView* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // scene()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QGraphicsScene * cppResult = const_cast<const QGraphicsView*>(cppSelf)->scene();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QGraphicsScene * >::toPython(cppResult);

                // Ownership transferences.
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QGraphicsViewFunc_sceneRect(PyObject* self)
{
    QGraphicsView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsView* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // sceneRect()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QRectF cppResult = const_cast<const QGraphicsView*>(cppSelf)->sceneRect();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QRectF >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QGraphicsViewFunc_scrollContentsBy(PyObject* self, PyObject* args)
{
    QGraphicsView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsView* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "scrollContentsBy", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: scrollContentsBy(int,int)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 0; // scrollContentsBy(int,int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGraphicsViewFunc_scrollContentsBy_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // scrollContentsBy(int,int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QGraphicsView::scrollContentsBy(cppArg0, cppArg1) : cppSelf->scrollContentsBy(cppArg0, cppArg1));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGraphicsViewFunc_scrollContentsBy_TypeError:
        const char* overloads[] = {"int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QGraphicsView.scrollContentsBy", overloads);
        return 0;
}

static PyObject* Sbk_QGraphicsViewFunc_setAlignment(PyObject* self, PyObject* arg)
{
    QGraphicsView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsView* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setAlignment(QFlags<Qt::AlignmentFlag>)
    if (Shiboken::Converter< ::QFlags<Qt::AlignmentFlag> >::isConvertible(arg)) {
        overloadId = 0; // setAlignment(QFlags<Qt::AlignmentFlag>)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGraphicsViewFunc_setAlignment_TypeError;

    // Call function/method
    {
        {
            QFlags<Qt::AlignmentFlag> cppArg0 = Shiboken::Converter<QFlags<Qt::AlignmentFlag> >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setAlignment(QFlags<Qt::AlignmentFlag>)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setAlignment(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGraphicsViewFunc_setAlignment_TypeError:
        const char* overloads[] = {"PySide.QtCore.Qt.Alignment", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsView.setAlignment", overloads);
        return 0;
}

static PyObject* Sbk_QGraphicsViewFunc_setBackgroundBrush(PyObject* self, PyObject* arg)
{
    QGraphicsView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsView* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setBackgroundBrush(QBrush)
    if (Shiboken::Converter< ::QBrush >::isConvertible(arg)) {
        overloadId = 0; // setBackgroundBrush(QBrush)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGraphicsViewFunc_setBackgroundBrush_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QBrush cppArg0 = Shiboken::Converter<QBrush >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setBackgroundBrush(QBrush)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setBackgroundBrush(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGraphicsViewFunc_setBackgroundBrush_TypeError:
        const char* overloads[] = {"PySide.QtGui.QBrush", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsView.setBackgroundBrush", overloads);
        return 0;
}

static PyObject* Sbk_QGraphicsViewFunc_setCacheMode(PyObject* self, PyObject* arg)
{
    QGraphicsView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsView* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setCacheMode(QFlags<QGraphicsView::CacheModeFlag>)
    if (Shiboken::Converter< ::QFlags<QGraphicsView::CacheModeFlag> >::isConvertible(arg)) {
        overloadId = 0; // setCacheMode(QFlags<QGraphicsView::CacheModeFlag>)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGraphicsViewFunc_setCacheMode_TypeError;

    // Call function/method
    {
        {
            QFlags<QGraphicsView::CacheModeFlag> cppArg0 = Shiboken::Converter<QFlags<QGraphicsView::CacheModeFlag> >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setCacheMode(QFlags<QGraphicsView::CacheModeFlag>)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setCacheMode(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGraphicsViewFunc_setCacheMode_TypeError:
        const char* overloads[] = {"PySide.QtGui.QGraphicsView.CacheMode", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsView.setCacheMode", overloads);
        return 0;
}

static PyObject* Sbk_QGraphicsViewFunc_setDragMode(PyObject* self, PyObject* arg)
{
    QGraphicsView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsView* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setDragMode(QGraphicsView::DragMode)
    if (Shiboken::Converter< ::QGraphicsView::DragMode >::isConvertible(arg)) {
        overloadId = 0; // setDragMode(QGraphicsView::DragMode)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGraphicsViewFunc_setDragMode_TypeError;

    // Call function/method
    {
        {
            QGraphicsView::DragMode cppArg0 = Shiboken::Converter<QGraphicsView::DragMode >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setDragMode(QGraphicsView::DragMode)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setDragMode(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGraphicsViewFunc_setDragMode_TypeError:
        const char* overloads[] = {"PySide.QtGui.QGraphicsView.DragMode", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsView.setDragMode", overloads);
        return 0;
}

static PyObject* Sbk_QGraphicsViewFunc_setForegroundBrush(PyObject* self, PyObject* arg)
{
    QGraphicsView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsView* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setForegroundBrush(QBrush)
    if (Shiboken::Converter< ::QBrush >::isConvertible(arg)) {
        overloadId = 0; // setForegroundBrush(QBrush)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGraphicsViewFunc_setForegroundBrush_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QBrush cppArg0 = Shiboken::Converter<QBrush >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setForegroundBrush(QBrush)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setForegroundBrush(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGraphicsViewFunc_setForegroundBrush_TypeError:
        const char* overloads[] = {"PySide.QtGui.QBrush", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsView.setForegroundBrush", overloads);
        return 0;
}

static PyObject* Sbk_QGraphicsViewFunc_setInteractive(PyObject* self, PyObject* arg)
{
    QGraphicsView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsView* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setInteractive(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setInteractive(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGraphicsViewFunc_setInteractive_TypeError;

    // Call function/method
    {
        {
            bool cppArg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setInteractive(bool)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setInteractive(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGraphicsViewFunc_setInteractive_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsView.setInteractive", overloads);
        return 0;
}

static PyObject* Sbk_QGraphicsViewFunc_setMatrix(PyObject* self, PyObject* args, PyObject* kwds)
{
    QGraphicsView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsView* >::toCpp(self);

    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QGraphicsView.setMatrix(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QGraphicsView.setMatrix(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:setMatrix", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setMatrix(QMatrix,bool)
    if (Shiboken::Converter< ::QMatrix >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // setMatrix(QMatrix,bool)
        } else if (SbkNumber_Check(pyargs[1])) {
            overloadId = 0; // setMatrix(QMatrix,bool)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGraphicsViewFunc_setMatrix_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "combine");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "combine";
                    else if (SbkNumber_Check(value))
                        pyargs[1] = value;
                    else
                        goto Sbk_QGraphicsViewFunc_setMatrix_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QGraphicsView.setMatrix(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QMatrix cppArg0 = Shiboken::Converter<QMatrix >::toCpp(pyargs[0]);
            bool cppArg1 = pyargs[1] ? Shiboken::Converter<bool >::toCpp(pyargs[1]) : false;

            if(!PyErr_Occurred()) {
                // setMatrix(QMatrix,bool)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setMatrix(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGraphicsViewFunc_setMatrix_TypeError:
        const char* overloads[] = {"PySide.QtGui.QMatrix, bool = false", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QGraphicsView.setMatrix", overloads);
        return 0;
}

static PyObject* Sbk_QGraphicsViewFunc_setOptimizationFlag(PyObject* self, PyObject* args, PyObject* kwds)
{
    QGraphicsView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsView* >::toCpp(self);

    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QGraphicsView.setOptimizationFlag(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QGraphicsView.setOptimizationFlag(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:setOptimizationFlag", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setOptimizationFlag(QGraphicsView::OptimizationFlag,bool)
    if (Shiboken::Converter< ::QGraphicsView::OptimizationFlag >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // setOptimizationFlag(QGraphicsView::OptimizationFlag,bool)
        } else if (SbkNumber_Check(pyargs[1])) {
            overloadId = 0; // setOptimizationFlag(QGraphicsView::OptimizationFlag,bool)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGraphicsViewFunc_setOptimizationFlag_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "enabled");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "enabled";
                    else if (SbkNumber_Check(value))
                        pyargs[1] = value;
                    else
                        goto Sbk_QGraphicsViewFunc_setOptimizationFlag_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QGraphicsView.setOptimizationFlag(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QGraphicsView::OptimizationFlag cppArg0 = Shiboken::Converter<QGraphicsView::OptimizationFlag >::toCpp(pyargs[0]);
            bool cppArg1 = pyargs[1] ? Shiboken::Converter<bool >::toCpp(pyargs[1]) : true;

            if(!PyErr_Occurred()) {
                // setOptimizationFlag(QGraphicsView::OptimizationFlag,bool)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setOptimizationFlag(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGraphicsViewFunc_setOptimizationFlag_TypeError:
        const char* overloads[] = {"PySide.QtGui.QGraphicsView.OptimizationFlag, bool = true", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QGraphicsView.setOptimizationFlag", overloads);
        return 0;
}

static PyObject* Sbk_QGraphicsViewFunc_setOptimizationFlags(PyObject* self, PyObject* arg)
{
    QGraphicsView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsView* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setOptimizationFlags(QFlags<QGraphicsView::OptimizationFlag>)
    if (Shiboken::Converter< ::QFlags<QGraphicsView::OptimizationFlag> >::isConvertible(arg)) {
        overloadId = 0; // setOptimizationFlags(QFlags<QGraphicsView::OptimizationFlag>)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGraphicsViewFunc_setOptimizationFlags_TypeError;

    // Call function/method
    {
        {
            QFlags<QGraphicsView::OptimizationFlag> cppArg0 = Shiboken::Converter<QFlags<QGraphicsView::OptimizationFlag> >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setOptimizationFlags(QFlags<QGraphicsView::OptimizationFlag>)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setOptimizationFlags(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGraphicsViewFunc_setOptimizationFlags_TypeError:
        const char* overloads[] = {"PySide.QtGui.QGraphicsView.OptimizationFlags", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsView.setOptimizationFlags", overloads);
        return 0;
}

static PyObject* Sbk_QGraphicsViewFunc_setRenderHint(PyObject* self, PyObject* args, PyObject* kwds)
{
    QGraphicsView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsView* >::toCpp(self);

    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QGraphicsView.setRenderHint(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QGraphicsView.setRenderHint(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:setRenderHint", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setRenderHint(QPainter::RenderHint,bool)
    if (Shiboken::Converter< ::QPainter::RenderHint >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // setRenderHint(QPainter::RenderHint,bool)
        } else if (SbkNumber_Check(pyargs[1])) {
            overloadId = 0; // setRenderHint(QPainter::RenderHint,bool)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGraphicsViewFunc_setRenderHint_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "enabled");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "enabled";
                    else if (SbkNumber_Check(value))
                        pyargs[1] = value;
                    else
                        goto Sbk_QGraphicsViewFunc_setRenderHint_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QGraphicsView.setRenderHint(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QPainter::RenderHint cppArg0 = Shiboken::Converter<QPainter::RenderHint >::toCpp(pyargs[0]);
            bool cppArg1 = pyargs[1] ? Shiboken::Converter<bool >::toCpp(pyargs[1]) : true;

            if(!PyErr_Occurred()) {
                // setRenderHint(QPainter::RenderHint,bool)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setRenderHint(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGraphicsViewFunc_setRenderHint_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPainter.RenderHint, bool = true", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QGraphicsView.setRenderHint", overloads);
        return 0;
}

static PyObject* Sbk_QGraphicsViewFunc_setRenderHints(PyObject* self, PyObject* arg)
{
    QGraphicsView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsView* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setRenderHints(QFlags<QPainter::RenderHint>)
    if (Shiboken::Converter< ::QFlags<QPainter::RenderHint> >::isConvertible(arg)) {
        overloadId = 0; // setRenderHints(QFlags<QPainter::RenderHint>)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGraphicsViewFunc_setRenderHints_TypeError;

    // Call function/method
    {
        {
            QFlags<QPainter::RenderHint> cppArg0 = Shiboken::Converter<QFlags<QPainter::RenderHint> >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setRenderHints(QFlags<QPainter::RenderHint>)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setRenderHints(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGraphicsViewFunc_setRenderHints_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPainter.RenderHints", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsView.setRenderHints", overloads);
        return 0;
}

static PyObject* Sbk_QGraphicsViewFunc_setResizeAnchor(PyObject* self, PyObject* arg)
{
    QGraphicsView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsView* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setResizeAnchor(QGraphicsView::ViewportAnchor)
    if (Shiboken::Converter< ::QGraphicsView::ViewportAnchor >::isConvertible(arg)) {
        overloadId = 0; // setResizeAnchor(QGraphicsView::ViewportAnchor)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGraphicsViewFunc_setResizeAnchor_TypeError;

    // Call function/method
    {
        {
            QGraphicsView::ViewportAnchor cppArg0 = Shiboken::Converter<QGraphicsView::ViewportAnchor >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setResizeAnchor(QGraphicsView::ViewportAnchor)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setResizeAnchor(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGraphicsViewFunc_setResizeAnchor_TypeError:
        const char* overloads[] = {"PySide.QtGui.QGraphicsView.ViewportAnchor", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsView.setResizeAnchor", overloads);
        return 0;
}

static PyObject* Sbk_QGraphicsViewFunc_setRubberBandSelectionMode(PyObject* self, PyObject* arg)
{
    QGraphicsView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsView* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setRubberBandSelectionMode(Qt::ItemSelectionMode)
    if (Shiboken::Converter< ::Qt::ItemSelectionMode >::isConvertible(arg)) {
        overloadId = 0; // setRubberBandSelectionMode(Qt::ItemSelectionMode)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGraphicsViewFunc_setRubberBandSelectionMode_TypeError;

    // Call function/method
    {
        {
            Qt::ItemSelectionMode cppArg0 = Shiboken::Converter<Qt::ItemSelectionMode >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setRubberBandSelectionMode(Qt::ItemSelectionMode)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setRubberBandSelectionMode(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGraphicsViewFunc_setRubberBandSelectionMode_TypeError:
        const char* overloads[] = {"PySide.QtCore.Qt.ItemSelectionMode", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsView.setRubberBandSelectionMode", overloads);
        return 0;
}

static PyObject* Sbk_QGraphicsViewFunc_setScene(PyObject* self, PyObject* arg)
{
    QGraphicsView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsView* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setScene(QGraphicsScene*)
    if (Shiboken::Converter< ::QGraphicsScene * >::isConvertible(arg)) {
        overloadId = 0; // setScene(QGraphicsScene*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGraphicsViewFunc_setScene_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QGraphicsScene * cppArg0 = Shiboken::Converter<QGraphicsScene * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setScene(QGraphicsScene*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setScene(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                Shiboken::Object::keepReference(reinterpret_cast<SbkObject*>(self), "setScene(QGraphicsScene*)1", arg);
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGraphicsViewFunc_setScene_TypeError:
        const char* overloads[] = {"PySide.QtGui.QGraphicsScene", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsView.setScene", overloads);
        return 0;
}

static PyObject* Sbk_QGraphicsViewFunc_setSceneRect(PyObject* self, PyObject* args)
{
    QGraphicsView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsView* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs == 2 || numArgs == 3)
        goto Sbk_QGraphicsViewFunc_setSceneRect_TypeError;

    if (!PyArg_UnpackTuple(args, "setSceneRect", 1, 4, &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return 0;


    // Overloaded function decisor
    // 0: setSceneRect(QRectF)
    // 1: setSceneRect(qreal,qreal,qreal,qreal)
    if (numArgs == 4 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2]) && SbkNumber_Check(pyargs[3])) {
        overloadId = 1; // setSceneRect(qreal,qreal,qreal,qreal)
    } else if (numArgs == 1 && Shiboken::Converter< ::QRectF >::isConvertible(pyargs[0])) {
        overloadId = 0; // setSceneRect(QRectF)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGraphicsViewFunc_setSceneRect_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // setSceneRect(QRectF)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QRectF cppArg0 = Shiboken::Converter<QRectF >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // setSceneRect(QRectF)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setSceneRect(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // setSceneRect(qreal,qreal,qreal,qreal)
            {
                qreal cppArg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
                qreal cppArg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);
                qreal cppArg2 = Shiboken::Converter<qreal >::toCpp(pyargs[2]);
                qreal cppArg3 = Shiboken::Converter<qreal >::toCpp(pyargs[3]);

                if(!PyErr_Occurred()) {
                    // setSceneRect(qreal,qreal,qreal,qreal)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setSceneRect(cppArg0, cppArg1, cppArg2, cppArg3);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGraphicsViewFunc_setSceneRect_TypeError:
        const char* overloads[] = {"PySide.QtCore.QRectF", "float, float, float, float", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QGraphicsView.setSceneRect", overloads);
        return 0;
}

static PyObject* Sbk_QGraphicsViewFunc_setTransform(PyObject* self, PyObject* args, PyObject* kwds)
{
    QGraphicsView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsView* >::toCpp(self);

    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QGraphicsView.setTransform(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QGraphicsView.setTransform(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:setTransform", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setTransform(QTransform,bool)
    if (Shiboken::Converter< ::QTransform >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // setTransform(QTransform,bool)
        } else if (SbkNumber_Check(pyargs[1])) {
            overloadId = 0; // setTransform(QTransform,bool)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGraphicsViewFunc_setTransform_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "combine");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "combine";
                    else if (SbkNumber_Check(value))
                        pyargs[1] = value;
                    else
                        goto Sbk_QGraphicsViewFunc_setTransform_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QGraphicsView.setTransform(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QTransform cppArg0 = Shiboken::Converter<QTransform >::toCpp(pyargs[0]);
            bool cppArg1 = pyargs[1] ? Shiboken::Converter<bool >::toCpp(pyargs[1]) : false;

            if(!PyErr_Occurred()) {
                // setTransform(QTransform,bool)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setTransform(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGraphicsViewFunc_setTransform_TypeError:
        const char* overloads[] = {"PySide.QtGui.QTransform, bool = false", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QGraphicsView.setTransform", overloads);
        return 0;
}

static PyObject* Sbk_QGraphicsViewFunc_setTransformationAnchor(PyObject* self, PyObject* arg)
{
    QGraphicsView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsView* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setTransformationAnchor(QGraphicsView::ViewportAnchor)
    if (Shiboken::Converter< ::QGraphicsView::ViewportAnchor >::isConvertible(arg)) {
        overloadId = 0; // setTransformationAnchor(QGraphicsView::ViewportAnchor)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGraphicsViewFunc_setTransformationAnchor_TypeError;

    // Call function/method
    {
        {
            QGraphicsView::ViewportAnchor cppArg0 = Shiboken::Converter<QGraphicsView::ViewportAnchor >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setTransformationAnchor(QGraphicsView::ViewportAnchor)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setTransformationAnchor(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGraphicsViewFunc_setTransformationAnchor_TypeError:
        const char* overloads[] = {"PySide.QtGui.QGraphicsView.ViewportAnchor", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsView.setTransformationAnchor", overloads);
        return 0;
}

static PyObject* Sbk_QGraphicsViewFunc_setViewportUpdateMode(PyObject* self, PyObject* arg)
{
    QGraphicsView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsView* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setViewportUpdateMode(QGraphicsView::ViewportUpdateMode)
    if (Shiboken::Converter< ::QGraphicsView::ViewportUpdateMode >::isConvertible(arg)) {
        overloadId = 0; // setViewportUpdateMode(QGraphicsView::ViewportUpdateMode)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGraphicsViewFunc_setViewportUpdateMode_TypeError;

    // Call function/method
    {
        {
            QGraphicsView::ViewportUpdateMode cppArg0 = Shiboken::Converter<QGraphicsView::ViewportUpdateMode >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setViewportUpdateMode(QGraphicsView::ViewportUpdateMode)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setViewportUpdateMode(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGraphicsViewFunc_setViewportUpdateMode_TypeError:
        const char* overloads[] = {"PySide.QtGui.QGraphicsView.ViewportUpdateMode", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsView.setViewportUpdateMode", overloads);
        return 0;
}

static PyObject* Sbk_QGraphicsViewFunc_setupViewport(PyObject* self, PyObject* arg)
{
    QGraphicsView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsView* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setupViewport(QWidget*)
    if (Shiboken::Converter< ::QWidget * >::isConvertible(arg)) {
        overloadId = 0; // setupViewport(QWidget*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGraphicsViewFunc_setupViewport_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QWidget * cppArg0 = Shiboken::Converter<QWidget * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setupViewport(QWidget*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setupViewport(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                Shiboken::Object::setParent(self, arg);
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGraphicsViewFunc_setupViewport_TypeError:
        const char* overloads[] = {"PySide.QtGui.QWidget", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsView.setupViewport", overloads);
        return 0;
}

static PyObject* Sbk_QGraphicsViewFunc_shear(PyObject* self, PyObject* args)
{
    QGraphicsView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsView* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "shear", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: shear(qreal,qreal)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 0; // shear(qreal,qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGraphicsViewFunc_shear_TypeError;

    // Call function/method
    {
        {
            qreal cppArg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
            qreal cppArg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // shear(qreal,qreal)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->shear(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGraphicsViewFunc_shear_TypeError:
        const char* overloads[] = {"float, float", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QGraphicsView.shear", overloads);
        return 0;
}

static PyObject* Sbk_QGraphicsViewFunc_showEvent(PyObject* self, PyObject* arg)
{
    QGraphicsView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsView* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: showEvent(QShowEvent*)
    if (Shiboken::Converter< ::QShowEvent * >::isConvertible(arg)) {
        overloadId = 0; // showEvent(QShowEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGraphicsViewFunc_showEvent_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QShowEvent * cppArg0 = Shiboken::Converter<QShowEvent * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // showEvent(QShowEvent*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QGraphicsView::showEvent(cppArg0) : cppSelf->showEvent(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGraphicsViewFunc_showEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QShowEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsView.showEvent", overloads);
        return 0;
}

static PyObject* Sbk_QGraphicsViewFunc_sizeHint(PyObject* self)
{
    QGraphicsView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsView* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // sizeHint()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QSize cppResult = (Shiboken::Object::isUserType(self) ? const_cast<const QGraphicsView*>(cppSelf)->::QGraphicsView::sizeHint() : const_cast<const QGraphicsView*>(cppSelf)->sizeHint());
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QSize >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QGraphicsViewFunc_transform(PyObject* self)
{
    QGraphicsView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsView* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // transform()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QTransform cppResult = const_cast<const QGraphicsView*>(cppSelf)->transform();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QTransform >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QGraphicsViewFunc_transformationAnchor(PyObject* self)
{
    QGraphicsView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsView* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // transformationAnchor()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QGraphicsView::ViewportAnchor cppResult = const_cast<const QGraphicsView*>(cppSelf)->transformationAnchor();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QGraphicsView::ViewportAnchor >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QGraphicsViewFunc_translate(PyObject* self, PyObject* args)
{
    QGraphicsView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsView* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "translate", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: translate(qreal,qreal)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 0; // translate(qreal,qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGraphicsViewFunc_translate_TypeError;

    // Call function/method
    {
        {
            qreal cppArg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
            qreal cppArg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // translate(qreal,qreal)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->translate(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGraphicsViewFunc_translate_TypeError:
        const char* overloads[] = {"float, float", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QGraphicsView.translate", overloads);
        return 0;
}

static PyObject* Sbk_QGraphicsViewFunc_updateScene(PyObject* self, PyObject* arg)
{
    QGraphicsView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsView* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: updateScene(QList<QRectF>)
    if (Shiboken::Converter< ::QList<QRectF > >::isConvertible(arg)) {
        overloadId = 0; // updateScene(QList<QRectF>)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGraphicsViewFunc_updateScene_TypeError;

    // Call function/method
    {
        {
            QList<QRectF > cppArg0 = Shiboken::Converter<QList<QRectF > >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // updateScene(QList<QRectF>)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->updateScene(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGraphicsViewFunc_updateScene_TypeError:
        const char* overloads[] = {"list", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsView.updateScene", overloads);
        return 0;
}

static PyObject* Sbk_QGraphicsViewFunc_updateSceneRect(PyObject* self, PyObject* arg)
{
    QGraphicsView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsView* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: updateSceneRect(QRectF)
    if (Shiboken::Converter< ::QRectF >::isConvertible(arg)) {
        overloadId = 0; // updateSceneRect(QRectF)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGraphicsViewFunc_updateSceneRect_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QRectF cppArg0 = Shiboken::Converter<QRectF >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // updateSceneRect(QRectF)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->updateSceneRect(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGraphicsViewFunc_updateSceneRect_TypeError:
        const char* overloads[] = {"PySide.QtCore.QRectF", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsView.updateSceneRect", overloads);
        return 0;
}

static PyObject* Sbk_QGraphicsViewFunc_viewportEvent(PyObject* self, PyObject* arg)
{
    QGraphicsView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsView* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: viewportEvent(QEvent*)
    if (Shiboken::Converter< ::QEvent * >::isConvertible(arg)) {
        overloadId = 0; // viewportEvent(QEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGraphicsViewFunc_viewportEvent_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QEvent * cppArg0 = Shiboken::Converter<QEvent * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // viewportEvent(QEvent*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = (Shiboken::Object::isUserType(self) ? cppSelf->::QGraphicsView::viewportEvent(cppArg0) : cppSelf->viewportEvent(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QGraphicsViewFunc_viewportEvent_TypeError:
        const char* overloads[] = {"PySide.QtCore.QEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsView.viewportEvent", overloads);
        return 0;
}

static PyObject* Sbk_QGraphicsViewFunc_viewportTransform(PyObject* self)
{
    QGraphicsView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsView* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // viewportTransform()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QTransform cppResult = const_cast<const QGraphicsView*>(cppSelf)->viewportTransform();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QTransform >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QGraphicsViewFunc_viewportUpdateMode(PyObject* self)
{
    QGraphicsView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsView* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // viewportUpdateMode()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QGraphicsView::ViewportUpdateMode cppResult = const_cast<const QGraphicsView*>(cppSelf)->viewportUpdateMode();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QGraphicsView::ViewportUpdateMode >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QGraphicsViewFunc_wheelEvent(PyObject* self, PyObject* arg)
{
    QGraphicsView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsView* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: wheelEvent(QWheelEvent*)
    if (Shiboken::Converter< ::QWheelEvent * >::isConvertible(arg)) {
        overloadId = 0; // wheelEvent(QWheelEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGraphicsViewFunc_wheelEvent_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QWheelEvent * cppArg0 = Shiboken::Converter<QWheelEvent * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // wheelEvent(QWheelEvent*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QGraphicsView::wheelEvent(cppArg0) : cppSelf->wheelEvent(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGraphicsViewFunc_wheelEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QWheelEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsView.wheelEvent", overloads);
        return 0;
}

static PyMethodDef Sbk_QGraphicsView_methods[] = {
    {"alignment", (PyCFunction)Sbk_QGraphicsViewFunc_alignment, METH_NOARGS},
    {"backgroundBrush", (PyCFunction)Sbk_QGraphicsViewFunc_backgroundBrush, METH_NOARGS},
    {"cacheMode", (PyCFunction)Sbk_QGraphicsViewFunc_cacheMode, METH_NOARGS},
    {"centerOn", (PyCFunction)Sbk_QGraphicsViewFunc_centerOn, METH_VARARGS},
    {"contextMenuEvent", (PyCFunction)Sbk_QGraphicsViewFunc_contextMenuEvent, METH_O},
    {"dragEnterEvent", (PyCFunction)Sbk_QGraphicsViewFunc_dragEnterEvent, METH_O},
    {"dragLeaveEvent", (PyCFunction)Sbk_QGraphicsViewFunc_dragLeaveEvent, METH_O},
    {"dragMode", (PyCFunction)Sbk_QGraphicsViewFunc_dragMode, METH_NOARGS},
    {"dragMoveEvent", (PyCFunction)Sbk_QGraphicsViewFunc_dragMoveEvent, METH_O},
    {"drawBackground", (PyCFunction)Sbk_QGraphicsViewFunc_drawBackground, METH_VARARGS},
    {"drawForeground", (PyCFunction)Sbk_QGraphicsViewFunc_drawForeground, METH_VARARGS},
    {"drawItems", (PyCFunction)Sbk_QGraphicsViewFunc_drawItems, METH_VARARGS},
    {"dropEvent", (PyCFunction)Sbk_QGraphicsViewFunc_dropEvent, METH_O},
    {"ensureVisible", (PyCFunction)Sbk_QGraphicsViewFunc_ensureVisible, METH_VARARGS|METH_KEYWORDS},
    {"event", (PyCFunction)Sbk_QGraphicsViewFunc_event, METH_O},
    {"fitInView", (PyCFunction)Sbk_QGraphicsViewFunc_fitInView, METH_VARARGS|METH_KEYWORDS},
    {"focusInEvent", (PyCFunction)Sbk_QGraphicsViewFunc_focusInEvent, METH_O},
    {"focusNextPrevChild", (PyCFunction)Sbk_QGraphicsViewFunc_focusNextPrevChild, METH_O},
    {"focusOutEvent", (PyCFunction)Sbk_QGraphicsViewFunc_focusOutEvent, METH_O},
    {"foregroundBrush", (PyCFunction)Sbk_QGraphicsViewFunc_foregroundBrush, METH_NOARGS},
    {"inputMethodEvent", (PyCFunction)Sbk_QGraphicsViewFunc_inputMethodEvent, METH_O},
    {"inputMethodQuery", (PyCFunction)Sbk_QGraphicsViewFunc_inputMethodQuery, METH_O},
    {"invalidateScene", (PyCFunction)Sbk_QGraphicsViewFunc_invalidateScene, METH_VARARGS|METH_KEYWORDS},
    {"isInteractive", (PyCFunction)Sbk_QGraphicsViewFunc_isInteractive, METH_NOARGS},
    {"isTransformed", (PyCFunction)Sbk_QGraphicsViewFunc_isTransformed, METH_NOARGS},
    {"itemAt", (PyCFunction)Sbk_QGraphicsViewFunc_itemAt, METH_VARARGS},
    {"items", (PyCFunction)Sbk_QGraphicsViewFunc_items, METH_VARARGS|METH_KEYWORDS},
    {"keyPressEvent", (PyCFunction)Sbk_QGraphicsViewFunc_keyPressEvent, METH_O},
    {"keyReleaseEvent", (PyCFunction)Sbk_QGraphicsViewFunc_keyReleaseEvent, METH_O},
    {"mapFromScene", (PyCFunction)Sbk_QGraphicsViewFunc_mapFromScene, METH_VARARGS},
    {"mapToScene", (PyCFunction)Sbk_QGraphicsViewFunc_mapToScene, METH_VARARGS},
    {"matrix", (PyCFunction)Sbk_QGraphicsViewFunc_matrix, METH_NOARGS},
    {"mouseDoubleClickEvent", (PyCFunction)Sbk_QGraphicsViewFunc_mouseDoubleClickEvent, METH_O},
    {"mouseMoveEvent", (PyCFunction)Sbk_QGraphicsViewFunc_mouseMoveEvent, METH_O},
    {"mousePressEvent", (PyCFunction)Sbk_QGraphicsViewFunc_mousePressEvent, METH_O},
    {"mouseReleaseEvent", (PyCFunction)Sbk_QGraphicsViewFunc_mouseReleaseEvent, METH_O},
    {"optimizationFlags", (PyCFunction)Sbk_QGraphicsViewFunc_optimizationFlags, METH_NOARGS},
    {"paintEvent", (PyCFunction)Sbk_QGraphicsViewFunc_paintEvent, METH_O},
    {"render", (PyCFunction)Sbk_QGraphicsViewFunc_render, METH_VARARGS|METH_KEYWORDS},
    {"renderHints", (PyCFunction)Sbk_QGraphicsViewFunc_renderHints, METH_NOARGS},
    {"resetCachedContent", (PyCFunction)Sbk_QGraphicsViewFunc_resetCachedContent, METH_NOARGS},
    {"resetMatrix", (PyCFunction)Sbk_QGraphicsViewFunc_resetMatrix, METH_NOARGS},
    {"resetTransform", (PyCFunction)Sbk_QGraphicsViewFunc_resetTransform, METH_NOARGS},
    {"resizeAnchor", (PyCFunction)Sbk_QGraphicsViewFunc_resizeAnchor, METH_NOARGS},
    {"resizeEvent", (PyCFunction)Sbk_QGraphicsViewFunc_resizeEvent, METH_O},
    {"rotate", (PyCFunction)Sbk_QGraphicsViewFunc_rotate, METH_O},
    {"rubberBandSelectionMode", (PyCFunction)Sbk_QGraphicsViewFunc_rubberBandSelectionMode, METH_NOARGS},
    {"scale", (PyCFunction)Sbk_QGraphicsViewFunc_scale, METH_VARARGS},
    {"scene", (PyCFunction)Sbk_QGraphicsViewFunc_scene, METH_NOARGS},
    {"sceneRect", (PyCFunction)Sbk_QGraphicsViewFunc_sceneRect, METH_NOARGS},
    {"scrollContentsBy", (PyCFunction)Sbk_QGraphicsViewFunc_scrollContentsBy, METH_VARARGS},
    {"setAlignment", (PyCFunction)Sbk_QGraphicsViewFunc_setAlignment, METH_O},
    {"setBackgroundBrush", (PyCFunction)Sbk_QGraphicsViewFunc_setBackgroundBrush, METH_O},
    {"setCacheMode", (PyCFunction)Sbk_QGraphicsViewFunc_setCacheMode, METH_O},
    {"setDragMode", (PyCFunction)Sbk_QGraphicsViewFunc_setDragMode, METH_O},
    {"setForegroundBrush", (PyCFunction)Sbk_QGraphicsViewFunc_setForegroundBrush, METH_O},
    {"setInteractive", (PyCFunction)Sbk_QGraphicsViewFunc_setInteractive, METH_O},
    {"setMatrix", (PyCFunction)Sbk_QGraphicsViewFunc_setMatrix, METH_VARARGS|METH_KEYWORDS},
    {"setOptimizationFlag", (PyCFunction)Sbk_QGraphicsViewFunc_setOptimizationFlag, METH_VARARGS|METH_KEYWORDS},
    {"setOptimizationFlags", (PyCFunction)Sbk_QGraphicsViewFunc_setOptimizationFlags, METH_O},
    {"setRenderHint", (PyCFunction)Sbk_QGraphicsViewFunc_setRenderHint, METH_VARARGS|METH_KEYWORDS},
    {"setRenderHints", (PyCFunction)Sbk_QGraphicsViewFunc_setRenderHints, METH_O},
    {"setResizeAnchor", (PyCFunction)Sbk_QGraphicsViewFunc_setResizeAnchor, METH_O},
    {"setRubberBandSelectionMode", (PyCFunction)Sbk_QGraphicsViewFunc_setRubberBandSelectionMode, METH_O},
    {"setScene", (PyCFunction)Sbk_QGraphicsViewFunc_setScene, METH_O},
    {"setSceneRect", (PyCFunction)Sbk_QGraphicsViewFunc_setSceneRect, METH_VARARGS},
    {"setTransform", (PyCFunction)Sbk_QGraphicsViewFunc_setTransform, METH_VARARGS|METH_KEYWORDS},
    {"setTransformationAnchor", (PyCFunction)Sbk_QGraphicsViewFunc_setTransformationAnchor, METH_O},
    {"setViewportUpdateMode", (PyCFunction)Sbk_QGraphicsViewFunc_setViewportUpdateMode, METH_O},
    {"setupViewport", (PyCFunction)Sbk_QGraphicsViewFunc_setupViewport, METH_O},
    {"shear", (PyCFunction)Sbk_QGraphicsViewFunc_shear, METH_VARARGS},
    {"showEvent", (PyCFunction)Sbk_QGraphicsViewFunc_showEvent, METH_O},
    {"sizeHint", (PyCFunction)Sbk_QGraphicsViewFunc_sizeHint, METH_NOARGS},
    {"transform", (PyCFunction)Sbk_QGraphicsViewFunc_transform, METH_NOARGS},
    {"transformationAnchor", (PyCFunction)Sbk_QGraphicsViewFunc_transformationAnchor, METH_NOARGS},
    {"translate", (PyCFunction)Sbk_QGraphicsViewFunc_translate, METH_VARARGS},
    {"updateScene", (PyCFunction)Sbk_QGraphicsViewFunc_updateScene, METH_O},
    {"updateSceneRect", (PyCFunction)Sbk_QGraphicsViewFunc_updateSceneRect, METH_O},
    {"viewportEvent", (PyCFunction)Sbk_QGraphicsViewFunc_viewportEvent, METH_O},
    {"viewportTransform", (PyCFunction)Sbk_QGraphicsViewFunc_viewportTransform, METH_NOARGS},
    {"viewportUpdateMode", (PyCFunction)Sbk_QGraphicsViewFunc_viewportUpdateMode, METH_NOARGS},
    {"wheelEvent", (PyCFunction)Sbk_QGraphicsViewFunc_wheelEvent, METH_O},

    {0} // Sentinel
};

} // extern "C"

static void* Sbk_QGraphicsViewSpecialCastFunction(void* obj, SbkObjectType* desiredType)
{
    QGraphicsView* me = reinterpret_cast<QGraphicsView*>(obj);
    if (desiredType == reinterpret_cast<SbkObjectType*>(SbkPySide_QtGuiTypes[SBK_QABSTRACTSCROLLAREA_IDX]))
        return static_cast<QAbstractScrollArea*>(me);
    else if (desiredType == reinterpret_cast<SbkObjectType*>(SbkPySide_QtGuiTypes[SBK_QFRAME_IDX]))
        return static_cast<QFrame*>(me);
    else if (desiredType == reinterpret_cast<SbkObjectType*>(SbkPySide_QtGuiTypes[SBK_QWIDGET_IDX]))
        return static_cast<QWidget*>(me);
    else if (desiredType == reinterpret_cast<SbkObjectType*>(SbkPySide_QtCoreTypes[SBK_QOBJECT_IDX]))
        return static_cast<QObject*>(me);
    else if (desiredType == reinterpret_cast<SbkObjectType*>(SbkPySide_QtGuiTypes[SBK_QPAINTDEVICE_IDX]))
        return static_cast<QPaintDevice*>(me);
    return me;
}


// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QGraphicsView_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QGraphicsView",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QGraphicsView_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QGraphicsView_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern

static SbkObjectType* Sbk_QGraphicsView_typeDiscovery(void* cptr, SbkObjectType* instanceType)
{
    if (instanceType == reinterpret_cast<SbkObjectType*>(Shiboken::SbkType<QObject >()) && dynamic_cast<QGraphicsView*>(reinterpret_cast<QObject*>(cptr)))
        return &Sbk_QGraphicsView_Type;
    if (instanceType == reinterpret_cast<SbkObjectType*>(Shiboken::SbkType<QPaintDevice >()) && dynamic_cast<QGraphicsView*>(reinterpret_cast<QPaintDevice*>(cptr)))
        return &Sbk_QGraphicsView_Type;
    return 0;
}

PyObject* SbkPySide_QtGui_QGraphicsView_OptimizationFlag___and__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QGraphicsView::OptimizationFlags >::toPython(
        Shiboken::Converter<QGraphicsView::OptimizationFlags>::toCpp(self)
        & Shiboken::Converter< QGraphicsView::OptimizationFlags >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtGui_QGraphicsView_OptimizationFlag___or__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QGraphicsView::OptimizationFlags >::toPython(
        Shiboken::Converter<QGraphicsView::OptimizationFlags>::toCpp(self)
        | Shiboken::Converter< QGraphicsView::OptimizationFlags >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtGui_QGraphicsView_OptimizationFlag___xor__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QGraphicsView::OptimizationFlags >::toPython(
        Shiboken::Converter<QGraphicsView::OptimizationFlags>::toCpp(self)
        ^ Shiboken::Converter< QGraphicsView::OptimizationFlags >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtGui_QGraphicsView_OptimizationFlag___invert__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QGraphicsView::OptimizationFlags >::toPython(
        ~Shiboken::Converter<QGraphicsView::OptimizationFlags >::toCpp(self)
    );
}


static PyNumberMethods SbkPySide_QtGui_QGraphicsView_OptimizationFlag_as_number = {
    /*nb_add*/                  0,
    /*nb_subtract*/             0,
    /*nb_multiply*/             0,
    /*nb_divide*/               0,
    /*nb_remainder*/            0,
    /*nb_divmod*/               0,
    /*nb_power*/                0,
    /*nb_negative*/             0,
    /*nb_positive*/             0,
    /*nb_absolute*/             0,
    /*nb_nonzero*/              0,
    /*nb_invert*/               (unaryfunc)SbkPySide_QtGui_QGraphicsView_OptimizationFlag___invert__,
    /*nb_lshift*/               0,
    /*nb_rshift*/               0,
    /*nb_and*/                  (binaryfunc)SbkPySide_QtGui_QGraphicsView_OptimizationFlag___and__,
    /*nb_xor*/                  (binaryfunc)SbkPySide_QtGui_QGraphicsView_OptimizationFlag___xor__,
    /*nb_or*/                   (binaryfunc)SbkPySide_QtGui_QGraphicsView_OptimizationFlag___or__,
    /*nb_coerce*/               0,
    /*nb_int*/                  0,
    /*nb_long*/                 0,
    /*nb_float*/                0,
    /*nb_oct*/                  0,
    /*nb_hex*/                  0,
    /*nb_inplace_add*/          0,
    /*nb_inplace_subtract*/     0,
    /*nb_inplace_multiply*/     0,
    /*nb_inplace_divide*/       0,
    /*nb_inplace_remainder*/    0,
    /*nb_inplace_power*/        0,
    /*nb_inplace_lshift*/       0,
    /*nb_inplace_rshift*/       0,
    /*nb_inplace_and*/          0,
    /*nb_inplace_xor*/          0,
    /*nb_inplace_or*/           0,
    /*nb_floor_divide*/         0,
    /*nb_true_divide*/          0,
    /*nb_inplace_floor_divide*/ 0,
    /*nb_inplace_true_divide*/  0,
    /*nb_index*/                0
};


// forward declaration of new function
static PyTypeObject SbkPySide_QtGui_QGraphicsView_OptimizationFlags_Type = {
    PyObject_HEAD_INIT(&PyType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "OptimizationFlags",
    /*tp_basicsize*/        0,
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        &SbkPySide_QtGui_QGraphicsView_OptimizationFlag_as_number,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT | Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              PyInt_Type.tp_new,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};


PyObject* SbkPySide_QtGui_QGraphicsView_CacheModeFlag___and__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QGraphicsView::CacheMode >::toPython(
        Shiboken::Converter<QGraphicsView::CacheMode>::toCpp(self)
        & Shiboken::Converter< QGraphicsView::CacheMode >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtGui_QGraphicsView_CacheModeFlag___or__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QGraphicsView::CacheMode >::toPython(
        Shiboken::Converter<QGraphicsView::CacheMode>::toCpp(self)
        | Shiboken::Converter< QGraphicsView::CacheMode >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtGui_QGraphicsView_CacheModeFlag___xor__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QGraphicsView::CacheMode >::toPython(
        Shiboken::Converter<QGraphicsView::CacheMode>::toCpp(self)
        ^ Shiboken::Converter< QGraphicsView::CacheMode >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtGui_QGraphicsView_CacheModeFlag___invert__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QGraphicsView::CacheMode >::toPython(
        ~Shiboken::Converter<QGraphicsView::CacheMode >::toCpp(self)
    );
}


static PyNumberMethods SbkPySide_QtGui_QGraphicsView_CacheModeFlag_as_number = {
    /*nb_add*/                  0,
    /*nb_subtract*/             0,
    /*nb_multiply*/             0,
    /*nb_divide*/               0,
    /*nb_remainder*/            0,
    /*nb_divmod*/               0,
    /*nb_power*/                0,
    /*nb_negative*/             0,
    /*nb_positive*/             0,
    /*nb_absolute*/             0,
    /*nb_nonzero*/              0,
    /*nb_invert*/               (unaryfunc)SbkPySide_QtGui_QGraphicsView_CacheModeFlag___invert__,
    /*nb_lshift*/               0,
    /*nb_rshift*/               0,
    /*nb_and*/                  (binaryfunc)SbkPySide_QtGui_QGraphicsView_CacheModeFlag___and__,
    /*nb_xor*/                  (binaryfunc)SbkPySide_QtGui_QGraphicsView_CacheModeFlag___xor__,
    /*nb_or*/                   (binaryfunc)SbkPySide_QtGui_QGraphicsView_CacheModeFlag___or__,
    /*nb_coerce*/               0,
    /*nb_int*/                  0,
    /*nb_long*/                 0,
    /*nb_float*/                0,
    /*nb_oct*/                  0,
    /*nb_hex*/                  0,
    /*nb_inplace_add*/          0,
    /*nb_inplace_subtract*/     0,
    /*nb_inplace_multiply*/     0,
    /*nb_inplace_divide*/       0,
    /*nb_inplace_remainder*/    0,
    /*nb_inplace_power*/        0,
    /*nb_inplace_lshift*/       0,
    /*nb_inplace_rshift*/       0,
    /*nb_inplace_and*/          0,
    /*nb_inplace_xor*/          0,
    /*nb_inplace_or*/           0,
    /*nb_floor_divide*/         0,
    /*nb_true_divide*/          0,
    /*nb_inplace_floor_divide*/ 0,
    /*nb_inplace_true_divide*/  0,
    /*nb_index*/                0
};


// forward declaration of new function
static PyTypeObject SbkPySide_QtGui_QGraphicsView_CacheMode_Type = {
    PyObject_HEAD_INIT(&PyType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "CacheMode",
    /*tp_basicsize*/        0,
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        &SbkPySide_QtGui_QGraphicsView_CacheModeFlag_as_number,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT | Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              PyInt_Type.tp_new,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};



void init_QGraphicsView(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QGRAPHICSVIEW_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QGraphicsView_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QGraphicsView_Type);
    Shiboken::ObjectType::setSubTypeInitHook(&Sbk_QGraphicsView_Type, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(&Sbk_QGraphicsView_Type, &QGraphicsView::staticMetaObject);    Sbk_QGraphicsView_Type.super.ht_type.tp_base = SbkPySide_QtGuiTypes[SBK_QABSTRACTSCROLLAREA_IDX];
    MultipleInheritanceInitFunction func;
    func = Shiboken::ObjectType::getMultipleIheritanceFunction(reinterpret_cast<SbkObjectType*>(SbkPySide_QtGuiTypes[SBK_QWIDGET_IDX]));
    Shiboken::ObjectType::setMultipleIheritanceFunction(&Sbk_QGraphicsView_Type, func);
    Shiboken::ObjectType::setCastFunction(&Sbk_QGraphicsView_Type, &Sbk_QGraphicsViewSpecialCastFunction);
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QGraphicsView_Type, &Shiboken::callCppDestructor<QGraphicsView >);
    Py_INCREF((PyObject*)&Sbk_QGraphicsView_Type); //Incref due the 'PyModule_AddObject' steals the reference.
    if (PyType_Ready((PyTypeObject*)&Sbk_QGraphicsView_Type) < 0)
        return;

    // Fill type discovery information
    Shiboken::ObjectType::setTypeDiscoveryFunction(&Sbk_QGraphicsView_Type, &Sbk_QGraphicsView_typeDiscovery);
    Shiboken::BindingManager& bm = Shiboken::BindingManager::instance();
    bm.addClassInheritance(reinterpret_cast<SbkObjectType*>(SbkPySide_QtGuiTypes[SBK_QABSTRACTSCROLLAREA_IDX]), &Sbk_QGraphicsView_Type);

    Shiboken::ObjectType::setOriginalName(&Sbk_QGraphicsView_Type, "QGraphicsView*");
    PyModule_AddObject(module, "QGraphicsView",
        ((PyObject*)&Sbk_QGraphicsView_Type));

    // Initialize enums
    PyObject* enumItem;

    // init enum: OptimizationFlag
    PyTypeObject* SbkPySide_QtGui_QGraphicsView_OptimizationFlag = Shiboken::Enum::newType("PySide.QtGui.QGraphicsView.OptimizationFlag");
    SbkPySide_QtGui_QGraphicsView_OptimizationFlag->tp_as_number = &SbkPySide_QtGui_QGraphicsView_OptimizationFlag_as_number;
    SbkPySide_QtGuiTypes[SBK_QGRAPHICSVIEW_OPTIMIZATIONFLAG_IDX] = SbkPySide_QtGui_QGraphicsView_OptimizationFlag;
    if (PyType_Ready(SbkPySide_QtGui_QGraphicsView_OptimizationFlag) < 0)
        return;
    PyDict_SetItemString(Sbk_QGraphicsView_Type.super.ht_type.tp_dict,
            "OptimizationFlag",((PyObject*)SbkPySide_QtGui_QGraphicsView_OptimizationFlag));

    // init flags class: QFlags<QGraphicsView::OptimizationFlag>
    SbkPySide_QtGuiTypes[SBK_QFLAGS_QGRAPHICSVIEW_OPTIMIZATIONFLAG__IDX] = &SbkPySide_QtGui_QGraphicsView_OptimizationFlags_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtGui_QGraphicsView_OptimizationFlags_Type) < 0)
        return;
    PyDict_SetItemString(Sbk_QGraphicsView_Type.super.ht_type.tp_dict,
            "OptimizationFlags",((PyObject*)&SbkPySide_QtGui_QGraphicsView_OptimizationFlags_Type));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QGraphicsView_OptimizationFlag,(long) QGraphicsView::DontClipPainter, "DontClipPainter");
    PyDict_SetItemString(Sbk_QGraphicsView_Type.super.ht_type.tp_dict,"DontClipPainter", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QGraphicsView_OptimizationFlag->tp_dict,"DontClipPainter", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QGraphicsView_OptimizationFlag,(long) QGraphicsView::DontSavePainterState, "DontSavePainterState");
    PyDict_SetItemString(Sbk_QGraphicsView_Type.super.ht_type.tp_dict,"DontSavePainterState", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QGraphicsView_OptimizationFlag->tp_dict,"DontSavePainterState", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QGraphicsView_OptimizationFlag,(long) QGraphicsView::DontAdjustForAntialiasing, "DontAdjustForAntialiasing");
    PyDict_SetItemString(Sbk_QGraphicsView_Type.super.ht_type.tp_dict,"DontAdjustForAntialiasing", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QGraphicsView_OptimizationFlag->tp_dict,"DontAdjustForAntialiasing", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QGraphicsView_OptimizationFlag,(long) QGraphicsView::IndirectPainting, "IndirectPainting");
    PyDict_SetItemString(Sbk_QGraphicsView_Type.super.ht_type.tp_dict,"IndirectPainting", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QGraphicsView_OptimizationFlag->tp_dict,"IndirectPainting", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QGraphicsView::OptimizationFlag");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::OptimizationFlag");
    // end of enum OptimizationFlag

    // init enum: ViewportAnchor
    PyTypeObject* SbkPySide_QtGui_QGraphicsView_ViewportAnchor = Shiboken::Enum::newType("PySide.QtGui.QGraphicsView.ViewportAnchor");
    SbkPySide_QtGuiTypes[SBK_QGRAPHICSVIEW_VIEWPORTANCHOR_IDX] = SbkPySide_QtGui_QGraphicsView_ViewportAnchor;
    if (PyType_Ready(SbkPySide_QtGui_QGraphicsView_ViewportAnchor) < 0)
        return;
    PyDict_SetItemString(Sbk_QGraphicsView_Type.super.ht_type.tp_dict,
            "ViewportAnchor",((PyObject*)SbkPySide_QtGui_QGraphicsView_ViewportAnchor));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QGraphicsView_ViewportAnchor,(long) QGraphicsView::NoAnchor, "NoAnchor");
    PyDict_SetItemString(Sbk_QGraphicsView_Type.super.ht_type.tp_dict,"NoAnchor", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QGraphicsView_ViewportAnchor->tp_dict,"NoAnchor", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QGraphicsView_ViewportAnchor,(long) QGraphicsView::AnchorViewCenter, "AnchorViewCenter");
    PyDict_SetItemString(Sbk_QGraphicsView_Type.super.ht_type.tp_dict,"AnchorViewCenter", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QGraphicsView_ViewportAnchor->tp_dict,"AnchorViewCenter", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QGraphicsView_ViewportAnchor,(long) QGraphicsView::AnchorUnderMouse, "AnchorUnderMouse");
    PyDict_SetItemString(Sbk_QGraphicsView_Type.super.ht_type.tp_dict,"AnchorUnderMouse", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QGraphicsView_ViewportAnchor->tp_dict,"AnchorUnderMouse", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QGraphicsView::ViewportAnchor");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::ViewportAnchor");
    // end of enum ViewportAnchor

    // init enum: ViewportUpdateMode
    PyTypeObject* SbkPySide_QtGui_QGraphicsView_ViewportUpdateMode = Shiboken::Enum::newType("PySide.QtGui.QGraphicsView.ViewportUpdateMode");
    SbkPySide_QtGuiTypes[SBK_QGRAPHICSVIEW_VIEWPORTUPDATEMODE_IDX] = SbkPySide_QtGui_QGraphicsView_ViewportUpdateMode;
    if (PyType_Ready(SbkPySide_QtGui_QGraphicsView_ViewportUpdateMode) < 0)
        return;
    PyDict_SetItemString(Sbk_QGraphicsView_Type.super.ht_type.tp_dict,
            "ViewportUpdateMode",((PyObject*)SbkPySide_QtGui_QGraphicsView_ViewportUpdateMode));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QGraphicsView_ViewportUpdateMode,(long) QGraphicsView::FullViewportUpdate, "FullViewportUpdate");
    PyDict_SetItemString(Sbk_QGraphicsView_Type.super.ht_type.tp_dict,"FullViewportUpdate", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QGraphicsView_ViewportUpdateMode->tp_dict,"FullViewportUpdate", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QGraphicsView_ViewportUpdateMode,(long) QGraphicsView::MinimalViewportUpdate, "MinimalViewportUpdate");
    PyDict_SetItemString(Sbk_QGraphicsView_Type.super.ht_type.tp_dict,"MinimalViewportUpdate", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QGraphicsView_ViewportUpdateMode->tp_dict,"MinimalViewportUpdate", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QGraphicsView_ViewportUpdateMode,(long) QGraphicsView::SmartViewportUpdate, "SmartViewportUpdate");
    PyDict_SetItemString(Sbk_QGraphicsView_Type.super.ht_type.tp_dict,"SmartViewportUpdate", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QGraphicsView_ViewportUpdateMode->tp_dict,"SmartViewportUpdate", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QGraphicsView_ViewportUpdateMode,(long) QGraphicsView::NoViewportUpdate, "NoViewportUpdate");
    PyDict_SetItemString(Sbk_QGraphicsView_Type.super.ht_type.tp_dict,"NoViewportUpdate", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QGraphicsView_ViewportUpdateMode->tp_dict,"NoViewportUpdate", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QGraphicsView_ViewportUpdateMode,(long) QGraphicsView::BoundingRectViewportUpdate, "BoundingRectViewportUpdate");
    PyDict_SetItemString(Sbk_QGraphicsView_Type.super.ht_type.tp_dict,"BoundingRectViewportUpdate", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QGraphicsView_ViewportUpdateMode->tp_dict,"BoundingRectViewportUpdate", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QGraphicsView::ViewportUpdateMode");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::ViewportUpdateMode");
    // end of enum ViewportUpdateMode

    // init enum: CacheModeFlag
    PyTypeObject* SbkPySide_QtGui_QGraphicsView_CacheModeFlag = Shiboken::Enum::newType("PySide.QtGui.QGraphicsView.CacheModeFlag");
    SbkPySide_QtGui_QGraphicsView_CacheModeFlag->tp_as_number = &SbkPySide_QtGui_QGraphicsView_CacheModeFlag_as_number;
    SbkPySide_QtGuiTypes[SBK_QGRAPHICSVIEW_CACHEMODEFLAG_IDX] = SbkPySide_QtGui_QGraphicsView_CacheModeFlag;
    if (PyType_Ready(SbkPySide_QtGui_QGraphicsView_CacheModeFlag) < 0)
        return;
    PyDict_SetItemString(Sbk_QGraphicsView_Type.super.ht_type.tp_dict,
            "CacheModeFlag",((PyObject*)SbkPySide_QtGui_QGraphicsView_CacheModeFlag));

    // init flags class: QFlags<QGraphicsView::CacheModeFlag>
    SbkPySide_QtGuiTypes[SBK_QFLAGS_QGRAPHICSVIEW_CACHEMODEFLAG__IDX] = &SbkPySide_QtGui_QGraphicsView_CacheMode_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtGui_QGraphicsView_CacheMode_Type) < 0)
        return;
    PyDict_SetItemString(Sbk_QGraphicsView_Type.super.ht_type.tp_dict,
            "CacheMode",((PyObject*)&SbkPySide_QtGui_QGraphicsView_CacheMode_Type));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QGraphicsView_CacheModeFlag,(long) QGraphicsView::CacheNone, "CacheNone");
    PyDict_SetItemString(Sbk_QGraphicsView_Type.super.ht_type.tp_dict,"CacheNone", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QGraphicsView_CacheModeFlag->tp_dict,"CacheNone", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QGraphicsView_CacheModeFlag,(long) QGraphicsView::CacheBackground, "CacheBackground");
    PyDict_SetItemString(Sbk_QGraphicsView_Type.super.ht_type.tp_dict,"CacheBackground", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QGraphicsView_CacheModeFlag->tp_dict,"CacheBackground", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QGraphicsView::CacheModeFlag");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::CacheModeFlag");
    // end of enum CacheModeFlag

    // init enum: DragMode
    PyTypeObject* SbkPySide_QtGui_QGraphicsView_DragMode = Shiboken::Enum::newType("PySide.QtGui.QGraphicsView.DragMode");
    SbkPySide_QtGuiTypes[SBK_QGRAPHICSVIEW_DRAGMODE_IDX] = SbkPySide_QtGui_QGraphicsView_DragMode;
    if (PyType_Ready(SbkPySide_QtGui_QGraphicsView_DragMode) < 0)
        return;
    PyDict_SetItemString(Sbk_QGraphicsView_Type.super.ht_type.tp_dict,
            "DragMode",((PyObject*)SbkPySide_QtGui_QGraphicsView_DragMode));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QGraphicsView_DragMode,(long) QGraphicsView::NoDrag, "NoDrag");
    PyDict_SetItemString(Sbk_QGraphicsView_Type.super.ht_type.tp_dict,"NoDrag", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QGraphicsView_DragMode->tp_dict,"NoDrag", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QGraphicsView_DragMode,(long) QGraphicsView::ScrollHandDrag, "ScrollHandDrag");
    PyDict_SetItemString(Sbk_QGraphicsView_Type.super.ht_type.tp_dict,"ScrollHandDrag", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QGraphicsView_DragMode->tp_dict,"ScrollHandDrag", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QGraphicsView_DragMode,(long) QGraphicsView::RubberBandDrag, "RubberBandDrag");
    PyDict_SetItemString(Sbk_QGraphicsView_Type.super.ht_type.tp_dict,"RubberBandDrag", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QGraphicsView_DragMode->tp_dict,"RubberBandDrag", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QGraphicsView::DragMode");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::DragMode");
    // end of enum DragMode


    Shiboken::TypeResolver::createObjectTypeResolver<QGraphicsView >("QGraphicsView*");
    Shiboken::TypeResolver::createObjectTypeResolver<QGraphicsView >(typeid(QGraphicsView).name());
    Shiboken::TypeResolver::createObjectTypeResolver<QGraphicsView >(typeid(QGraphicsViewWrapper).name());
    qRegisterMetaType< ::QGraphicsView* >("QGraphicsView*");
    qRegisterMetaType< ::QGraphicsView::OptimizationFlag >("QGraphicsView::OptimizationFlag");
    qRegisterMetaType< ::QGraphicsView::OptimizationFlags >("QGraphicsView::OptimizationFlags");
    qRegisterMetaType< ::QGraphicsView::ViewportAnchor >("QGraphicsView::ViewportAnchor");
    qRegisterMetaType< ::QGraphicsView::ViewportUpdateMode >("QGraphicsView::ViewportUpdateMode");
    qRegisterMetaType< ::QGraphicsView::CacheModeFlag >("QGraphicsView::CacheModeFlag");
    qRegisterMetaType< ::QGraphicsView::CacheMode >("QGraphicsView::CacheMode");
    qRegisterMetaType< ::QGraphicsView::DragMode >("QGraphicsView::DragMode");
}

