/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <set>
#include "pyside_qtgui_python.h"

#include "qlistview_wrapper.h"

// Extra includes
#include <QList>
#include <qabstractitemdelegate.h>
#include <qabstractitemmodel.h>
#include <qaction.h>
#include <qbitmap.h>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qcursor.h>
#include <qevent.h>
#include <qfont.h>
#include <qfontinfo.h>
#include <qfontmetrics.h>
#include <qgraphicseffect.h>
#include <qgraphicsproxywidget.h>
#include <qicon.h>
#include <qinputcontext.h>
#include <qitemselectionmodel.h>
#include <qkeysequence.h>
#include <qlayout.h>
#include <qlistview.h>
#include <qlocale.h>
#include <qmargins.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qpaintdevice.h>
#include <qpaintengine.h>
#include <qpainter.h>
#include <qpalette.h>
#include <qpoint.h>
#include <qrect.h>
#include <qregion.h>
#include <qscrollbar.h>
#include <qsize.h>
#include <qsizepolicy.h>
#include <qstyle.h>
#include <qstyleoption.h>
#include <qwidget.h>
#include <qx11info_x11.h>


// Native ---------------------------------------------------------

QListViewWrapper::QListViewWrapper(QWidget * parent) : QListView(parent) {
    // ... middle
}

void QListViewWrapper::actionEvent(QActionEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "actionEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::actionEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QActionEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QListViewWrapper::changeEvent(QEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "changeEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QFrame::changeEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QEvent * >::toPython(arg__1)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QListViewWrapper::childEvent(QChildEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "childEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::childEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QChildEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QListViewWrapper::closeEditor(QWidget * editor, QAbstractItemDelegate::EndEditHint hint)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "closeEditor"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QAbstractItemView::closeEditor(editor, hint);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter< ::QWidget * >::toPython(editor),
        Shiboken::Converter< ::QAbstractItemDelegate::EndEditHint >::toPython(hint)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QListViewWrapper::closeEvent(QCloseEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "closeEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::closeEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QCloseEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QListViewWrapper::commitData(QWidget * editor)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "commitData"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QAbstractItemView::commitData(editor);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QWidget * >::toPython(editor)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QListViewWrapper::connectNotify(const char * signal)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "connectNotify"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::connectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QListViewWrapper::contextMenuEvent(QContextMenuEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "contextMenuEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QAbstractScrollArea::contextMenuEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QContextMenuEvent * >::toPython(arg__1)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QListViewWrapper::currentChanged(const QModelIndex & current, const QModelIndex & previous)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "currentChanged"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QListView::currentChanged(current, previous);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter< ::QModelIndex >::toPython(current),
        Shiboken::Converter< ::QModelIndex >::toPython(previous)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QListViewWrapper::customEvent(QEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "customEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::customEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QListViewWrapper::dataChanged(const QModelIndex & topLeft, const QModelIndex & bottomRight)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "dataChanged"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QListView::dataChanged(topLeft, bottomRight);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter< ::QModelIndex >::toPython(topLeft),
        Shiboken::Converter< ::QModelIndex >::toPython(bottomRight)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

int QListViewWrapper::devType() const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return int(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "devType"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::devType();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return int(0);
    }
    // Check return type
    bool typeIsValid = PyInt_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QListView.devType", "int", pyResult->ob_type->tp_name);
        return int(0);
    }
    int cppResult(Shiboken::Converter< int >::toCpp(pyResult));
    return cppResult;
}

void QListViewWrapper::disconnectNotify(const char * signal)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "disconnectNotify"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::disconnectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QListViewWrapper::doItemsLayout()
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "doItemsLayout"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QListView::doItemsLayout();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QListViewWrapper::dragEnterEvent(QDragEnterEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "dragEnterEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QAbstractItemView::dragEnterEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QDragEnterEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QListViewWrapper::dragLeaveEvent(QDragLeaveEvent * e)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "dragLeaveEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QListView::dragLeaveEvent(e);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QDragLeaveEvent * >::toPython(e)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QListViewWrapper::dragMoveEvent(QDragMoveEvent * e)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "dragMoveEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QListView::dragMoveEvent(e);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QDragMoveEvent * >::toPython(e)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QListViewWrapper::dropEvent(QDropEvent * e)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "dropEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QListView::dropEvent(e);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QDropEvent * >::toPython(e)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

bool QListViewWrapper::edit(const QModelIndex & index, QAbstractItemView::EditTrigger trigger, QEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return bool(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "edit"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QAbstractItemView::edit(index, trigger, event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NNN)",
        Shiboken::Converter< ::QModelIndex >::toPython(index),
        Shiboken::Converter< ::QAbstractItemView::EditTrigger >::toPython(trigger),
        Shiboken::Converter< ::QEvent * >::toPython(event)
    ));
    bool invalidadeArg3 = PyTuple_GET_ITEM(pyargs, 2)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QListView.edit", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    if (invalidadeArg3)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 2));
    return cppResult;
}

void QListViewWrapper::editorDestroyed(QObject * editor)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "editorDestroyed"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QAbstractItemView::editorDestroyed(editor);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QObject * >::toPython(editor)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QListViewWrapper::enterEvent(QEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "enterEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::enterEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

bool QListViewWrapper::event(QEvent * e)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return bool(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "event"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QListView::event(e);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QEvent * >::toPython(e)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QListView.event", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    return cppResult;
}

bool QListViewWrapper::eventFilter(QObject * arg__1, QEvent * arg__2)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return bool(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "eventFilter"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::eventFilter(arg__1, arg__2);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter< ::QObject * >::toPython(arg__1),
        Shiboken::Converter< ::QEvent * >::toPython(arg__2)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QListView.eventFilter", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    return cppResult;
}

void QListViewWrapper::focusInEvent(QFocusEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "focusInEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QAbstractItemView::focusInEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QFocusEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

bool QListViewWrapper::focusNextPrevChild(bool next)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return bool(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "focusNextPrevChild"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QAbstractItemView::focusNextPrevChild(next);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< bool >::toPython(next)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QListView.focusNextPrevChild", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    return cppResult;
}

void QListViewWrapper::focusOutEvent(QFocusEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "focusOutEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QAbstractItemView::focusOutEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QFocusEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

int QListViewWrapper::heightForWidth(int arg__1) const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return int(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "heightForWidth"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::heightForWidth(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(i)",
        arg__1
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return int(0);
    }
    // Check return type
    bool typeIsValid = PyInt_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QListView.heightForWidth", "int", pyResult->ob_type->tp_name);
        return int(0);
    }
    int cppResult(Shiboken::Converter< int >::toCpp(pyResult));
    return cppResult;
}

void QListViewWrapper::hideEvent(QHideEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "hideEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::hideEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QHideEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

int QListViewWrapper::horizontalOffset() const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return int(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "horizontalOffset"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QListView::horizontalOffset();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return int(0);
    }
    // Check return type
    bool typeIsValid = PyInt_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QListView.horizontalOffset", "int", pyResult->ob_type->tp_name);
        return int(0);
    }
    int cppResult(Shiboken::Converter< int >::toCpp(pyResult));
    return cppResult;
}

void QListViewWrapper::horizontalScrollbarAction(int action)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "horizontalScrollbarAction"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QAbstractItemView::horizontalScrollbarAction(action);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(i)",
        action
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QListViewWrapper::horizontalScrollbarValueChanged(int value)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "horizontalScrollbarValueChanged"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QAbstractItemView::horizontalScrollbarValueChanged(value);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(i)",
        value
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

QModelIndex QListViewWrapper::indexAt(const QPoint & p) const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return QModelIndex();
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "indexAt"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QListView::indexAt(p);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QPoint >::toPython(p)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QModelIndex();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QModelIndex >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QListView.indexAt", Shiboken::SbkType<QModelIndex >()->tp_name, pyResult->ob_type->tp_name);
        return QModelIndex();
    }
    QModelIndex cppResult(Shiboken::Converter< ::QModelIndex >::toCpp(pyResult));
    return cppResult;
}

void QListViewWrapper::inputMethodEvent(QInputMethodEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "inputMethodEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QAbstractItemView::inputMethodEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QInputMethodEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

QVariant QListViewWrapper::inputMethodQuery(Qt::InputMethodQuery query) const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return QVariant(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "inputMethodQuery"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QAbstractItemView::inputMethodQuery(query);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::Qt::InputMethodQuery >::toPython(query)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QVariant(0);
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< QVariant >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QListView.inputMethodQuery", "QVariant", pyResult->ob_type->tp_name);
        return QVariant(0);
    }
    QVariant cppResult(Shiboken::Converter< QVariant >::toCpp(pyResult));
    return cppResult;
}

bool QListViewWrapper::isIndexHidden(const QModelIndex & index) const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return bool(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "isIndexHidden"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QListView::isIndexHidden(index);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QModelIndex >::toPython(index)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QListView.isIndexHidden", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    return cppResult;
}

void QListViewWrapper::keyPressEvent(QKeyEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "keyPressEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QAbstractItemView::keyPressEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QKeyEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QListViewWrapper::keyReleaseEvent(QKeyEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "keyReleaseEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::keyReleaseEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QKeyEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QListViewWrapper::keyboardSearch(const QString & search)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "keyboardSearch"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QAbstractItemView::keyboardSearch(search);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< QString >::toPython(search)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QListViewWrapper::languageChange()
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "languageChange"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::languageChange();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QListViewWrapper::leaveEvent(QEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "leaveEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::leaveEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

int QListViewWrapper::metric(QPaintDevice::PaintDeviceMetric arg__1) const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return int(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "metric"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::metric(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QPaintDevice::PaintDeviceMetric >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return int(0);
    }
    // Check return type
    bool typeIsValid = PyInt_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QListView.metric", "int", pyResult->ob_type->tp_name);
        return int(0);
    }
    int cppResult(Shiboken::Converter< int >::toCpp(pyResult));
    return cppResult;
}

QSize QListViewWrapper::minimumSizeHint() const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return QSize();
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "minimumSizeHint"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QAbstractScrollArea::minimumSizeHint();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QSize();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QSize >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QListView.minimumSizeHint", Shiboken::SbkType<QSize >()->tp_name, pyResult->ob_type->tp_name);
        return QSize();
    }
    QSize cppResult(Shiboken::Converter< ::QSize >::toCpp(pyResult));
    return cppResult;
}

void QListViewWrapper::mouseDoubleClickEvent(QMouseEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "mouseDoubleClickEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QAbstractItemView::mouseDoubleClickEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QMouseEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QListViewWrapper::mouseMoveEvent(QMouseEvent * e)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "mouseMoveEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QListView::mouseMoveEvent(e);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QMouseEvent * >::toPython(e)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QListViewWrapper::mousePressEvent(QMouseEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "mousePressEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QAbstractItemView::mousePressEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QMouseEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QListViewWrapper::mouseReleaseEvent(QMouseEvent * e)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "mouseReleaseEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QListView::mouseReleaseEvent(e);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QMouseEvent * >::toPython(e)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QListViewWrapper::moveEvent(QMoveEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "moveEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::moveEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QMoveEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

QPaintEngine * QListViewWrapper::paintEngine() const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return 0;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "paintEngine"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::paintEngine();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return 0;
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QPaintEngine * >::isConvertible(pyResult);
    typeIsValid = typeIsValid || (pyResult == Py_None);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QListView.paintEngine", Shiboken::SbkType<QPaintEngine >()->tp_name, pyResult->ob_type->tp_name);
        return 0;
    }
    QPaintEngine * cppResult(Shiboken::Converter< ::QPaintEngine * >::toCpp(pyResult));
    return cppResult;
}

void QListViewWrapper::paintEvent(QPaintEvent * e)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "paintEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QListView::paintEvent(e);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QPaintEvent * >::toPython(e)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QListViewWrapper::reset()
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "reset"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QListView::reset();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QListViewWrapper::resizeEvent(QResizeEvent * e)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "resizeEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QListView::resizeEvent(e);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QResizeEvent * >::toPython(e)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QListViewWrapper::rowsAboutToBeRemoved(const QModelIndex & parent, int start, int end)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "rowsAboutToBeRemoved"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QListView::rowsAboutToBeRemoved(parent, start, end);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(Nii)",
        Shiboken::Converter< ::QModelIndex >::toPython(parent),
        start,
        end
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QListViewWrapper::rowsInserted(const QModelIndex & parent, int start, int end)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "rowsInserted"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QListView::rowsInserted(parent, start, end);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(Nii)",
        Shiboken::Converter< ::QModelIndex >::toPython(parent),
        start,
        end
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QListViewWrapper::scrollContentsBy(int dx, int dy)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "scrollContentsBy"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QListView::scrollContentsBy(dx, dy);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(ii)",
        dx,
        dy
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QListViewWrapper::scrollTo(const QModelIndex & index, QAbstractItemView::ScrollHint hint)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "scrollTo"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QListView::scrollTo(index, hint);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter< ::QModelIndex >::toPython(index),
        Shiboken::Converter< ::QAbstractItemView::ScrollHint >::toPython(hint)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QListViewWrapper::selectAll()
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "selectAll"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QAbstractItemView::selectAll();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

QList<QModelIndex > QListViewWrapper::selectedIndexes() const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return QList<QModelIndex >();
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "selectedIndexes"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QListView::selectedIndexes();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QList<QModelIndex >();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QList<QModelIndex > >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QListView.selectedIndexes", "list", pyResult->ob_type->tp_name);
        return QList<QModelIndex >();
    }
    QList<QModelIndex > cppResult(Shiboken::Converter< ::QList<QModelIndex > >::toCpp(pyResult));
    return cppResult;
}

void QListViewWrapper::selectionChanged(const QItemSelection & selected, const QItemSelection & deselected)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "selectionChanged"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QListView::selectionChanged(selected, deselected);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter< ::QItemSelection >::toPython(selected),
        Shiboken::Converter< ::QItemSelection >::toPython(deselected)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

QFlags<QItemSelectionModel::SelectionFlag> QListViewWrapper::selectionCommand(const QModelIndex & index, const QEvent * event) const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return QFlags<QItemSelectionModel::SelectionFlag>();
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "selectionCommand"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QAbstractItemView::selectionCommand(index, event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter< ::QModelIndex >::toPython(index),
        Shiboken::Converter< ::QEvent * >::toPython(event)
    ));
    bool invalidadeArg2 = PyTuple_GET_ITEM(pyargs, 1)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QFlags<QItemSelectionModel::SelectionFlag>();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QFlags<QItemSelectionModel::SelectionFlag> >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QListView.selectionCommand", Shiboken::SbkType<QFlags<QItemSelectionModel::SelectionFlag> >()->tp_name, pyResult->ob_type->tp_name);
        return QFlags<QItemSelectionModel::SelectionFlag>();
    }
    QFlags<QItemSelectionModel::SelectionFlag> cppResult(Shiboken::Converter< ::QFlags<QItemSelectionModel::SelectionFlag> >::toCpp(pyResult));
    if (invalidadeArg2)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 1));
    return cppResult;
}

void QListViewWrapper::setModel(QAbstractItemModel * model)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "setModel"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QAbstractItemView::setModel(model);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QAbstractItemModel * >::toPython(model)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QListViewWrapper::setRootIndex(const QModelIndex & index)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "setRootIndex"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QListView::setRootIndex(index);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QModelIndex >::toPython(index)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QListViewWrapper::setSelection(const QRect & rect, QFlags<QItemSelectionModel::SelectionFlag> command)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "setSelection"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QListView::setSelection(rect, command);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter< ::QRect >::toPython(rect),
        Shiboken::Converter< ::QFlags<QItemSelectionModel::SelectionFlag> >::toPython(command)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QListViewWrapper::setSelectionModel(QItemSelectionModel * selectionModel)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "setSelectionModel"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QAbstractItemView::setSelectionModel(selectionModel);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QItemSelectionModel * >::toPython(selectionModel)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QListViewWrapper::setVisible(bool visible)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "setVisible"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::setVisible(visible);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< bool >::toPython(visible)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QListViewWrapper::showEvent(QShowEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "showEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::showEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QShowEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

QSize QListViewWrapper::sizeHint() const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return QSize();
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "sizeHint"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QAbstractScrollArea::sizeHint();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QSize();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QSize >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QListView.sizeHint", Shiboken::SbkType<QSize >()->tp_name, pyResult->ob_type->tp_name);
        return QSize();
    }
    QSize cppResult(Shiboken::Converter< ::QSize >::toCpp(pyResult));
    return cppResult;
}

int QListViewWrapper::sizeHintForColumn(int column) const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return int(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "sizeHintForColumn"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QAbstractItemView::sizeHintForColumn(column);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(i)",
        column
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return int(0);
    }
    // Check return type
    bool typeIsValid = PyInt_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QListView.sizeHintForColumn", "int", pyResult->ob_type->tp_name);
        return int(0);
    }
    int cppResult(Shiboken::Converter< int >::toCpp(pyResult));
    return cppResult;
}

int QListViewWrapper::sizeHintForRow(int row) const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return int(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "sizeHintForRow"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QAbstractItemView::sizeHintForRow(row);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(i)",
        row
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return int(0);
    }
    // Check return type
    bool typeIsValid = PyInt_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QListView.sizeHintForRow", "int", pyResult->ob_type->tp_name);
        return int(0);
    }
    int cppResult(Shiboken::Converter< int >::toCpp(pyResult));
    return cppResult;
}

void QListViewWrapper::startDrag(QFlags<Qt::DropAction> supportedActions)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "startDrag"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QListView::startDrag(supportedActions);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QFlags<Qt::DropAction> >::toPython(supportedActions)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QListViewWrapper::tabletEvent(QTabletEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "tabletEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::tabletEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QTabletEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QListViewWrapper::timerEvent(QTimerEvent * e)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "timerEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QListView::timerEvent(e);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QTimerEvent * >::toPython(e)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QListViewWrapper::updateEditorData()
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "updateEditorData"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QAbstractItemView::updateEditorData();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QListViewWrapper::updateEditorGeometries()
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "updateEditorGeometries"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QAbstractItemView::updateEditorGeometries();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QListViewWrapper::updateGeometries()
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "updateGeometries"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QListView::updateGeometries();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

int QListViewWrapper::verticalOffset() const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return int(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "verticalOffset"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QListView::verticalOffset();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return int(0);
    }
    // Check return type
    bool typeIsValid = PyInt_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QListView.verticalOffset", "int", pyResult->ob_type->tp_name);
        return int(0);
    }
    int cppResult(Shiboken::Converter< int >::toCpp(pyResult));
    return cppResult;
}

void QListViewWrapper::verticalScrollbarAction(int action)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "verticalScrollbarAction"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QAbstractItemView::verticalScrollbarAction(action);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(i)",
        action
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QListViewWrapper::verticalScrollbarValueChanged(int value)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "verticalScrollbarValueChanged"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QAbstractItemView::verticalScrollbarValueChanged(value);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(i)",
        value
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

QStyleOptionViewItem QListViewWrapper::viewOptions() const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return QStyleOptionViewItem();
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "viewOptions"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QListView::viewOptions();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QStyleOptionViewItem();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QStyleOptionViewItem >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QListView.viewOptions", Shiboken::SbkType<QStyleOptionViewItem >()->tp_name, pyResult->ob_type->tp_name);
        return QStyleOptionViewItem();
    }
    QStyleOptionViewItem cppResult(Shiboken::Converter< ::QStyleOptionViewItem >::toCpp(pyResult));
    return cppResult;
}

bool QListViewWrapper::viewportEvent(QEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return bool(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "viewportEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QAbstractItemView::viewportEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QListView.viewportEvent", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
    return cppResult;
}

QRect QListViewWrapper::visualRect(const QModelIndex & index) const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return QRect();
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "visualRect"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QListView::visualRect(index);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QModelIndex >::toPython(index)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QRect();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QRect >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QListView.visualRect", Shiboken::SbkType<QRect >()->tp_name, pyResult->ob_type->tp_name);
        return QRect();
    }
    QRect cppResult(Shiboken::Converter< ::QRect >::toCpp(pyResult));
    return cppResult;
}

QRegion QListViewWrapper::visualRegionForSelection(const QItemSelection & selection) const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return QRegion();
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "visualRegionForSelection"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QListView::visualRegionForSelection(selection);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QItemSelection >::toPython(selection)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QRegion();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QRegion >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QListView.visualRegionForSelection", Shiboken::SbkType<QRegion >()->tp_name, pyResult->ob_type->tp_name);
        return QRegion();
    }
    QRegion cppResult(Shiboken::Converter< ::QRegion >::toCpp(pyResult));
    return cppResult;
}

void QListViewWrapper::wheelEvent(QWheelEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "wheelEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QAbstractScrollArea::wheelEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QWheelEvent * >::toPython(arg__1)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

const QMetaObject* QListViewWrapper::metaObject() const
{
    SbkObject* pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    return reinterpret_cast<QMetaObject*>(Shiboken::Object::getTypeUserData(pySelf));
}

int QListViewWrapper::qt_metacall(QMetaObject::Call call, int id, void** args)
{
    int result = QListView::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

QListViewWrapper::~QListViewWrapper()
{
    SbkObject* wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QListView_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QListView >()))
        return -1;

    QListViewWrapper* cptr = 0;
    int overloadId = -1;
    const char* argNames[] = {"parent"};
    const QMetaObject* metaObject;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths


    if (!PyArg_ParseTuple(args, "|O:QListView", &(pyargs[0])))
        return -1;

    // Overloaded function decisor
    // 0: QListView(QWidget*)
    if (numArgs == 0) {
        overloadId = 0; // QListView(QWidget*)
    } else if (Shiboken::Converter< ::QWidget * >::isConvertible(pyargs[0])) {
        overloadId = 0; // QListView(QWidget*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QListView_Init_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "parent");
                if (value) {
                    if (pyargs[0])
                        errorArgName = "parent";
                    else if (Shiboken::Converter< ::QWidget * >::isConvertible(value))
                        pyargs[0] = value;
                    else
                        goto Sbk_QListView_Init_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QListView(): got multiple values for keyword argument '%s'", errorArgName);
                    return -1;
                }
            }
            if (!Shiboken::Object::isValid(pyargs[0]))
                return -1;
            QWidget * cppArg0 = pyargs[0] ? Shiboken::Converter<QWidget * >::toCpp(pyargs[0]) : 0;

            if(!PyErr_Occurred()) {
                // QListView(QWidget*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new QListViewWrapper(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                Shiboken::Object::setParent(pyargs[0], self);
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QListView >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QListView_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    metaObject = cptr->metaObject(); // <- init python qt properties
    if (kwds && !PySide::fillQtProperties(self, metaObject, kwds, argNames, 1))
        return -1;


    return 1;

    Sbk_QListView_Init_TypeError:
        const char* overloads[] = {"PySide.QtGui.QWidget = None", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QListView", overloads);
        return -1;
}

static PyObject* Sbk_QListViewFunc_batchSize(PyObject* self)
{
    QListView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QListView* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // batchSize()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QListView*>(cppSelf)->batchSize();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QListViewFunc_clearPropertyFlags(PyObject* self)
{
    QListView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QListView* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // clearPropertyFlags()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->clearPropertyFlags();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QListViewFunc_contentsSize(PyObject* self)
{
    QListView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QListView* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // contentsSize()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QSize cppResult = const_cast<const QListView*>(cppSelf)->contentsSize();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QSize >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QListViewFunc_currentChanged(PyObject* self, PyObject* args)
{
    QListView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QListView* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "currentChanged", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: currentChanged(QModelIndex,QModelIndex)
    if (numArgs == 2 && Shiboken::Converter< ::QModelIndex >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QModelIndex >::isConvertible(pyargs[1])) {
        overloadId = 0; // currentChanged(QModelIndex,QModelIndex)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QListViewFunc_currentChanged_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QModelIndex cppArg0 = Shiboken::Converter<QModelIndex >::toCpp(pyargs[0]);
            if (!Shiboken::Object::isValid(pyargs[1]))
                return 0;
            QModelIndex cppArg1 = Shiboken::Converter<QModelIndex >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // currentChanged(QModelIndex,QModelIndex)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QListView::currentChanged(cppArg0, cppArg1) : cppSelf->currentChanged(cppArg0, cppArg1));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QListViewFunc_currentChanged_TypeError:
        const char* overloads[] = {"PySide.QtCore.QModelIndex, PySide.QtCore.QModelIndex", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QListView.currentChanged", overloads);
        return 0;
}

static PyObject* Sbk_QListViewFunc_dataChanged(PyObject* self, PyObject* args)
{
    QListView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QListView* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "dataChanged", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: dataChanged(QModelIndex,QModelIndex)
    if (numArgs == 2 && Shiboken::Converter< ::QModelIndex >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QModelIndex >::isConvertible(pyargs[1])) {
        overloadId = 0; // dataChanged(QModelIndex,QModelIndex)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QListViewFunc_dataChanged_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QModelIndex cppArg0 = Shiboken::Converter<QModelIndex >::toCpp(pyargs[0]);
            if (!Shiboken::Object::isValid(pyargs[1]))
                return 0;
            QModelIndex cppArg1 = Shiboken::Converter<QModelIndex >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // dataChanged(QModelIndex,QModelIndex)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QListView::dataChanged(cppArg0, cppArg1) : cppSelf->dataChanged(cppArg0, cppArg1));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QListViewFunc_dataChanged_TypeError:
        const char* overloads[] = {"PySide.QtCore.QModelIndex, PySide.QtCore.QModelIndex", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QListView.dataChanged", overloads);
        return 0;
}

static PyObject* Sbk_QListViewFunc_doItemsLayout(PyObject* self)
{
    QListView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QListView* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // doItemsLayout()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QListView::doItemsLayout() : cppSelf->doItemsLayout());
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QListViewFunc_dragLeaveEvent(PyObject* self, PyObject* arg)
{
    QListView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QListView* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: dragLeaveEvent(QDragLeaveEvent*)
    if (Shiboken::Converter< ::QDragLeaveEvent * >::isConvertible(arg)) {
        overloadId = 0; // dragLeaveEvent(QDragLeaveEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QListViewFunc_dragLeaveEvent_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QDragLeaveEvent * cppArg0 = Shiboken::Converter<QDragLeaveEvent * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // dragLeaveEvent(QDragLeaveEvent*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QListView::dragLeaveEvent(cppArg0) : cppSelf->dragLeaveEvent(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QListViewFunc_dragLeaveEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QDragLeaveEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QListView.dragLeaveEvent", overloads);
        return 0;
}

static PyObject* Sbk_QListViewFunc_dragMoveEvent(PyObject* self, PyObject* arg)
{
    QListView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QListView* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: dragMoveEvent(QDragMoveEvent*)
    if (Shiboken::Converter< ::QDragMoveEvent * >::isConvertible(arg)) {
        overloadId = 0; // dragMoveEvent(QDragMoveEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QListViewFunc_dragMoveEvent_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QDragMoveEvent * cppArg0 = Shiboken::Converter<QDragMoveEvent * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // dragMoveEvent(QDragMoveEvent*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QListView::dragMoveEvent(cppArg0) : cppSelf->dragMoveEvent(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QListViewFunc_dragMoveEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QDragMoveEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QListView.dragMoveEvent", overloads);
        return 0;
}

static PyObject* Sbk_QListViewFunc_dropEvent(PyObject* self, PyObject* arg)
{
    QListView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QListView* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: dropEvent(QDropEvent*)
    if (Shiboken::Converter< ::QDropEvent * >::isConvertible(arg)) {
        overloadId = 0; // dropEvent(QDropEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QListViewFunc_dropEvent_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QDropEvent * cppArg0 = Shiboken::Converter<QDropEvent * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // dropEvent(QDropEvent*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QListView::dropEvent(cppArg0) : cppSelf->dropEvent(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QListViewFunc_dropEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QDropEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QListView.dropEvent", overloads);
        return 0;
}

static PyObject* Sbk_QListViewFunc_event(PyObject* self, PyObject* arg)
{
    QListView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QListView* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: event(QEvent*)
    if (Shiboken::Converter< ::QEvent * >::isConvertible(arg)) {
        overloadId = 0; // event(QEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QListViewFunc_event_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QEvent * cppArg0 = Shiboken::Converter<QEvent * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // event(QEvent*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = (Shiboken::Object::isUserType(self) ? cppSelf->::QListView::event(cppArg0) : cppSelf->event(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QListViewFunc_event_TypeError:
        const char* overloads[] = {"PySide.QtCore.QEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QListView.event", overloads);
        return 0;
}

static PyObject* Sbk_QListViewFunc_flow(PyObject* self)
{
    QListView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QListView* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // flow()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QListView::Flow cppResult = const_cast<const QListView*>(cppSelf)->flow();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QListView::Flow >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QListViewFunc_gridSize(PyObject* self)
{
    QListView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QListView* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // gridSize()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QSize cppResult = const_cast<const QListView*>(cppSelf)->gridSize();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QSize >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QListViewFunc_horizontalOffset(PyObject* self)
{
    QListView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QListView* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // horizontalOffset()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = (Shiboken::Object::isUserType(self) ? const_cast<const QListView*>(cppSelf)->::QListView::horizontalOffset() : const_cast<const QListView*>(cppSelf)->horizontalOffset());
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QListViewFunc_indexAt(PyObject* self, PyObject* arg)
{
    QListView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QListView* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: indexAt(QPoint)const
    if (Shiboken::Converter< ::QPoint >::isConvertible(arg)) {
        overloadId = 0; // indexAt(QPoint)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QListViewFunc_indexAt_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QPoint cppArg0 = Shiboken::Converter<QPoint >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // indexAt(QPoint)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QModelIndex cppResult = (Shiboken::Object::isUserType(self) ? const_cast<const QListView*>(cppSelf)->::QListView::indexAt(cppArg0) : const_cast<const QListView*>(cppSelf)->indexAt(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QModelIndex >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QListViewFunc_indexAt_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPoint", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QListView.indexAt", overloads);
        return 0;
}

static PyObject* Sbk_QListViewFunc_internalDrag(PyObject* self, PyObject* arg)
{
    QListView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QListView* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: internalDrag(QFlags<Qt::DropAction>)
    if (Shiboken::Converter< ::QFlags<Qt::DropAction> >::isConvertible(arg)) {
        overloadId = 0; // internalDrag(QFlags<Qt::DropAction>)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QListViewFunc_internalDrag_TypeError;

    // Call function/method
    {
        {
            QFlags<Qt::DropAction> cppArg0 = Shiboken::Converter<QFlags<Qt::DropAction> >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // internalDrag(QFlags<Qt::DropAction>)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->internalDrag(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QListViewFunc_internalDrag_TypeError:
        const char* overloads[] = {"PySide.QtCore.Qt.DropActions", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QListView.internalDrag", overloads);
        return 0;
}

static PyObject* Sbk_QListViewFunc_internalDrop(PyObject* self, PyObject* arg)
{
    QListView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QListView* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: internalDrop(QDropEvent*)
    if (Shiboken::Converter< ::QDropEvent * >::isConvertible(arg)) {
        overloadId = 0; // internalDrop(QDropEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QListViewFunc_internalDrop_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QDropEvent * cppArg0 = Shiboken::Converter<QDropEvent * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // internalDrop(QDropEvent*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->internalDrop(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QListViewFunc_internalDrop_TypeError:
        const char* overloads[] = {"PySide.QtGui.QDropEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QListView.internalDrop", overloads);
        return 0;
}

static PyObject* Sbk_QListViewFunc_isIndexHidden(PyObject* self, PyObject* arg)
{
    QListView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QListView* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: isIndexHidden(QModelIndex)const
    if (Shiboken::Converter< ::QModelIndex >::isConvertible(arg)) {
        overloadId = 0; // isIndexHidden(QModelIndex)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QListViewFunc_isIndexHidden_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QModelIndex cppArg0 = Shiboken::Converter<QModelIndex >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // isIndexHidden(QModelIndex)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = (Shiboken::Object::isUserType(self) ? const_cast<const QListView*>(cppSelf)->::QListView::isIndexHidden(cppArg0) : const_cast<const QListView*>(cppSelf)->isIndexHidden(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QListViewFunc_isIndexHidden_TypeError:
        const char* overloads[] = {"PySide.QtCore.QModelIndex", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QListView.isIndexHidden", overloads);
        return 0;
}

static PyObject* Sbk_QListViewFunc_isRowHidden(PyObject* self, PyObject* arg)
{
    QListView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QListView* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: isRowHidden(int)const
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // isRowHidden(int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QListViewFunc_isRowHidden_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // isRowHidden(int)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QListView*>(cppSelf)->isRowHidden(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QListViewFunc_isRowHidden_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QListView.isRowHidden", overloads);
        return 0;
}

static PyObject* Sbk_QListViewFunc_isSelectionRectVisible(PyObject* self)
{
    QListView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QListView* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isSelectionRectVisible()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QListView*>(cppSelf)->isSelectionRectVisible();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QListViewFunc_isWrapping(PyObject* self)
{
    QListView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QListView* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isWrapping()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QListView*>(cppSelf)->isWrapping();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QListViewFunc_layoutMode(PyObject* self)
{
    QListView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QListView* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // layoutMode()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QListView::LayoutMode cppResult = const_cast<const QListView*>(cppSelf)->layoutMode();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QListView::LayoutMode >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QListViewFunc_modelColumn(PyObject* self)
{
    QListView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QListView* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // modelColumn()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QListView*>(cppSelf)->modelColumn();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QListViewFunc_mouseMoveEvent(PyObject* self, PyObject* arg)
{
    QListView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QListView* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: mouseMoveEvent(QMouseEvent*)
    if (Shiboken::Converter< ::QMouseEvent * >::isConvertible(arg)) {
        overloadId = 0; // mouseMoveEvent(QMouseEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QListViewFunc_mouseMoveEvent_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QMouseEvent * cppArg0 = Shiboken::Converter<QMouseEvent * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // mouseMoveEvent(QMouseEvent*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QListView::mouseMoveEvent(cppArg0) : cppSelf->mouseMoveEvent(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QListViewFunc_mouseMoveEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QMouseEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QListView.mouseMoveEvent", overloads);
        return 0;
}

static PyObject* Sbk_QListViewFunc_mouseReleaseEvent(PyObject* self, PyObject* arg)
{
    QListView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QListView* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: mouseReleaseEvent(QMouseEvent*)
    if (Shiboken::Converter< ::QMouseEvent * >::isConvertible(arg)) {
        overloadId = 0; // mouseReleaseEvent(QMouseEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QListViewFunc_mouseReleaseEvent_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QMouseEvent * cppArg0 = Shiboken::Converter<QMouseEvent * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // mouseReleaseEvent(QMouseEvent*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QListView::mouseReleaseEvent(cppArg0) : cppSelf->mouseReleaseEvent(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QListViewFunc_mouseReleaseEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QMouseEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QListView.mouseReleaseEvent", overloads);
        return 0;
}

static PyObject* Sbk_QListViewFunc_movement(PyObject* self)
{
    QListView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QListView* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // movement()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QListView::Movement cppResult = const_cast<const QListView*>(cppSelf)->movement();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QListView::Movement >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QListViewFunc_paintEvent(PyObject* self, PyObject* arg)
{
    QListView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QListView* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: paintEvent(QPaintEvent*)
    if (Shiboken::Converter< ::QPaintEvent * >::isConvertible(arg)) {
        overloadId = 0; // paintEvent(QPaintEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QListViewFunc_paintEvent_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QPaintEvent * cppArg0 = Shiboken::Converter<QPaintEvent * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // paintEvent(QPaintEvent*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QListView::paintEvent(cppArg0) : cppSelf->paintEvent(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QListViewFunc_paintEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPaintEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QListView.paintEvent", overloads);
        return 0;
}

static PyObject* Sbk_QListViewFunc_rectForIndex(PyObject* self, PyObject* arg)
{
    QListView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QListView* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: rectForIndex(QModelIndex)const
    if (Shiboken::Converter< ::QModelIndex >::isConvertible(arg)) {
        overloadId = 0; // rectForIndex(QModelIndex)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QListViewFunc_rectForIndex_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QModelIndex cppArg0 = Shiboken::Converter<QModelIndex >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // rectForIndex(QModelIndex)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QRect cppResult = const_cast<const QListView*>(cppSelf)->rectForIndex(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QRect >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QListViewFunc_rectForIndex_TypeError:
        const char* overloads[] = {"PySide.QtCore.QModelIndex", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QListView.rectForIndex", overloads);
        return 0;
}

static PyObject* Sbk_QListViewFunc_reset(PyObject* self)
{
    QListView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QListView* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // reset()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QListView::reset() : cppSelf->reset());
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QListViewFunc_resizeContents(PyObject* self, PyObject* args)
{
    QListView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QListView* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "resizeContents", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: resizeContents(int,int)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 0; // resizeContents(int,int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QListViewFunc_resizeContents_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // resizeContents(int,int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->resizeContents(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QListViewFunc_resizeContents_TypeError:
        const char* overloads[] = {"int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QListView.resizeContents", overloads);
        return 0;
}

static PyObject* Sbk_QListViewFunc_resizeEvent(PyObject* self, PyObject* arg)
{
    QListView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QListView* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: resizeEvent(QResizeEvent*)
    if (Shiboken::Converter< ::QResizeEvent * >::isConvertible(arg)) {
        overloadId = 0; // resizeEvent(QResizeEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QListViewFunc_resizeEvent_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QResizeEvent * cppArg0 = Shiboken::Converter<QResizeEvent * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // resizeEvent(QResizeEvent*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QListView::resizeEvent(cppArg0) : cppSelf->resizeEvent(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QListViewFunc_resizeEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QResizeEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QListView.resizeEvent", overloads);
        return 0;
}

static PyObject* Sbk_QListViewFunc_resizeMode(PyObject* self)
{
    QListView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QListView* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // resizeMode()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QListView::ResizeMode cppResult = const_cast<const QListView*>(cppSelf)->resizeMode();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QListView::ResizeMode >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QListViewFunc_rowsAboutToBeRemoved(PyObject* self, PyObject* args)
{
    QListView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QListView* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "rowsAboutToBeRemoved", 3, 3, &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: rowsAboutToBeRemoved(QModelIndex,int,int)
    if (numArgs == 3 && Shiboken::Converter< ::QModelIndex >::isConvertible(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
        overloadId = 0; // rowsAboutToBeRemoved(QModelIndex,int,int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QListViewFunc_rowsAboutToBeRemoved_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QModelIndex cppArg0 = Shiboken::Converter<QModelIndex >::toCpp(pyargs[0]);
            int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
            int cppArg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);

            if(!PyErr_Occurred()) {
                // rowsAboutToBeRemoved(QModelIndex,int,int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QListView::rowsAboutToBeRemoved(cppArg0, cppArg1, cppArg2) : cppSelf->rowsAboutToBeRemoved(cppArg0, cppArg1, cppArg2));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QListViewFunc_rowsAboutToBeRemoved_TypeError:
        const char* overloads[] = {"PySide.QtCore.QModelIndex, int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QListView.rowsAboutToBeRemoved", overloads);
        return 0;
}

static PyObject* Sbk_QListViewFunc_rowsInserted(PyObject* self, PyObject* args)
{
    QListView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QListView* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "rowsInserted", 3, 3, &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: rowsInserted(QModelIndex,int,int)
    if (numArgs == 3 && Shiboken::Converter< ::QModelIndex >::isConvertible(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
        overloadId = 0; // rowsInserted(QModelIndex,int,int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QListViewFunc_rowsInserted_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QModelIndex cppArg0 = Shiboken::Converter<QModelIndex >::toCpp(pyargs[0]);
            int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
            int cppArg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);

            if(!PyErr_Occurred()) {
                // rowsInserted(QModelIndex,int,int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QListView::rowsInserted(cppArg0, cppArg1, cppArg2) : cppSelf->rowsInserted(cppArg0, cppArg1, cppArg2));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QListViewFunc_rowsInserted_TypeError:
        const char* overloads[] = {"PySide.QtCore.QModelIndex, int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QListView.rowsInserted", overloads);
        return 0;
}

static PyObject* Sbk_QListViewFunc_scrollContentsBy(PyObject* self, PyObject* args)
{
    QListView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QListView* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "scrollContentsBy", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: scrollContentsBy(int,int)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 0; // scrollContentsBy(int,int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QListViewFunc_scrollContentsBy_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // scrollContentsBy(int,int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QListView::scrollContentsBy(cppArg0, cppArg1) : cppSelf->scrollContentsBy(cppArg0, cppArg1));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QListViewFunc_scrollContentsBy_TypeError:
        const char* overloads[] = {"int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QListView.scrollContentsBy", overloads);
        return 0;
}

static PyObject* Sbk_QListViewFunc_scrollTo(PyObject* self, PyObject* args, PyObject* kwds)
{
    QListView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QListView* >::toCpp(self);

    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QListView.scrollTo(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QListView.scrollTo(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:scrollTo", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: scrollTo(QModelIndex,QAbstractItemView::ScrollHint)
    if (Shiboken::Converter< ::QModelIndex >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // scrollTo(QModelIndex,QAbstractItemView::ScrollHint)
        } else if (Shiboken::Converter< ::QAbstractItemView::ScrollHint >::isConvertible(pyargs[1])) {
            overloadId = 0; // scrollTo(QModelIndex,QAbstractItemView::ScrollHint)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QListViewFunc_scrollTo_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "hint");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "hint";
                    else if (Shiboken::Converter< ::QAbstractItemView::ScrollHint >::isConvertible(value))
                        pyargs[1] = value;
                    else
                        goto Sbk_QListViewFunc_scrollTo_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QListView.scrollTo(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QModelIndex cppArg0 = Shiboken::Converter<QModelIndex >::toCpp(pyargs[0]);
            QAbstractItemView::ScrollHint cppArg1 = pyargs[1] ? Shiboken::Converter<QAbstractItemView::ScrollHint >::toCpp(pyargs[1]) : QAbstractItemView::EnsureVisible;

            if(!PyErr_Occurred()) {
                // scrollTo(QModelIndex,QAbstractItemView::ScrollHint)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QListView::scrollTo(cppArg0, cppArg1) : cppSelf->scrollTo(cppArg0, cppArg1));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QListViewFunc_scrollTo_TypeError:
        const char* overloads[] = {"PySide.QtCore.QModelIndex, PySide.QtGui.QAbstractItemView.ScrollHint = EnsureVisible", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QListView.scrollTo", overloads);
        return 0;
}

static PyObject* Sbk_QListViewFunc_selectedIndexes(PyObject* self)
{
    QListView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QListView* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // selectedIndexes()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QList<QModelIndex > cppResult = (Shiboken::Object::isUserType(self) ? const_cast<const QListView*>(cppSelf)->::QListView::selectedIndexes() : const_cast<const QListView*>(cppSelf)->selectedIndexes());
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QList<QModelIndex > >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QListViewFunc_selectionChanged(PyObject* self, PyObject* args)
{
    QListView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QListView* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "selectionChanged", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: selectionChanged(QItemSelection,QItemSelection)
    if (numArgs == 2 && Shiboken::Converter< ::QItemSelection >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QItemSelection >::isConvertible(pyargs[1])) {
        overloadId = 0; // selectionChanged(QItemSelection,QItemSelection)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QListViewFunc_selectionChanged_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QItemSelection cppArg0 = Shiboken::Converter<QItemSelection >::toCpp(pyargs[0]);
            if (!Shiboken::Object::isValid(pyargs[1]))
                return 0;
            QItemSelection cppArg1 = Shiboken::Converter<QItemSelection >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // selectionChanged(QItemSelection,QItemSelection)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QListView::selectionChanged(cppArg0, cppArg1) : cppSelf->selectionChanged(cppArg0, cppArg1));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QListViewFunc_selectionChanged_TypeError:
        const char* overloads[] = {"PySide.QtGui.QItemSelection, PySide.QtGui.QItemSelection", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QListView.selectionChanged", overloads);
        return 0;
}

static PyObject* Sbk_QListViewFunc_setBatchSize(PyObject* self, PyObject* arg)
{
    QListView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QListView* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setBatchSize(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setBatchSize(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QListViewFunc_setBatchSize_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setBatchSize(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setBatchSize(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QListViewFunc_setBatchSize_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QListView.setBatchSize", overloads);
        return 0;
}

static PyObject* Sbk_QListViewFunc_setFlow(PyObject* self, PyObject* arg)
{
    QListView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QListView* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setFlow(QListView::Flow)
    if (Shiboken::Converter< ::QListView::Flow >::isConvertible(arg)) {
        overloadId = 0; // setFlow(QListView::Flow)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QListViewFunc_setFlow_TypeError;

    // Call function/method
    {
        {
            QListView::Flow cppArg0 = Shiboken::Converter<QListView::Flow >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setFlow(QListView::Flow)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setFlow(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QListViewFunc_setFlow_TypeError:
        const char* overloads[] = {"PySide.QtGui.QListView.Flow", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QListView.setFlow", overloads);
        return 0;
}

static PyObject* Sbk_QListViewFunc_setGridSize(PyObject* self, PyObject* arg)
{
    QListView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QListView* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setGridSize(QSize)
    if (Shiboken::Converter< ::QSize >::isConvertible(arg)) {
        overloadId = 0; // setGridSize(QSize)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QListViewFunc_setGridSize_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QSize cppArg0 = Shiboken::Converter<QSize >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setGridSize(QSize)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setGridSize(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QListViewFunc_setGridSize_TypeError:
        const char* overloads[] = {"PySide.QtCore.QSize", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QListView.setGridSize", overloads);
        return 0;
}

static PyObject* Sbk_QListViewFunc_setLayoutMode(PyObject* self, PyObject* arg)
{
    QListView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QListView* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setLayoutMode(QListView::LayoutMode)
    if (Shiboken::Converter< ::QListView::LayoutMode >::isConvertible(arg)) {
        overloadId = 0; // setLayoutMode(QListView::LayoutMode)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QListViewFunc_setLayoutMode_TypeError;

    // Call function/method
    {
        {
            QListView::LayoutMode cppArg0 = Shiboken::Converter<QListView::LayoutMode >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setLayoutMode(QListView::LayoutMode)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setLayoutMode(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QListViewFunc_setLayoutMode_TypeError:
        const char* overloads[] = {"PySide.QtGui.QListView.LayoutMode", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QListView.setLayoutMode", overloads);
        return 0;
}

static PyObject* Sbk_QListViewFunc_setModelColumn(PyObject* self, PyObject* arg)
{
    QListView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QListView* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setModelColumn(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setModelColumn(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QListViewFunc_setModelColumn_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setModelColumn(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setModelColumn(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QListViewFunc_setModelColumn_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QListView.setModelColumn", overloads);
        return 0;
}

static PyObject* Sbk_QListViewFunc_setMovement(PyObject* self, PyObject* arg)
{
    QListView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QListView* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setMovement(QListView::Movement)
    if (Shiboken::Converter< ::QListView::Movement >::isConvertible(arg)) {
        overloadId = 0; // setMovement(QListView::Movement)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QListViewFunc_setMovement_TypeError;

    // Call function/method
    {
        {
            QListView::Movement cppArg0 = Shiboken::Converter<QListView::Movement >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setMovement(QListView::Movement)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setMovement(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QListViewFunc_setMovement_TypeError:
        const char* overloads[] = {"PySide.QtGui.QListView.Movement", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QListView.setMovement", overloads);
        return 0;
}

static PyObject* Sbk_QListViewFunc_setPositionForIndex(PyObject* self, PyObject* args)
{
    QListView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QListView* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setPositionForIndex", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setPositionForIndex(QPoint,QModelIndex)
    if (numArgs == 2 && Shiboken::Converter< ::QPoint >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QModelIndex >::isConvertible(pyargs[1])) {
        overloadId = 0; // setPositionForIndex(QPoint,QModelIndex)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QListViewFunc_setPositionForIndex_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QPoint cppArg0 = Shiboken::Converter<QPoint >::toCpp(pyargs[0]);
            if (!Shiboken::Object::isValid(pyargs[1]))
                return 0;
            QModelIndex cppArg1 = Shiboken::Converter<QModelIndex >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // setPositionForIndex(QPoint,QModelIndex)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setPositionForIndex(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QListViewFunc_setPositionForIndex_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPoint, PySide.QtCore.QModelIndex", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QListView.setPositionForIndex", overloads);
        return 0;
}

static PyObject* Sbk_QListViewFunc_setResizeMode(PyObject* self, PyObject* arg)
{
    QListView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QListView* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setResizeMode(QListView::ResizeMode)
    if (Shiboken::Converter< ::QListView::ResizeMode >::isConvertible(arg)) {
        overloadId = 0; // setResizeMode(QListView::ResizeMode)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QListViewFunc_setResizeMode_TypeError;

    // Call function/method
    {
        {
            QListView::ResizeMode cppArg0 = Shiboken::Converter<QListView::ResizeMode >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setResizeMode(QListView::ResizeMode)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setResizeMode(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QListViewFunc_setResizeMode_TypeError:
        const char* overloads[] = {"PySide.QtGui.QListView.ResizeMode", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QListView.setResizeMode", overloads);
        return 0;
}

static PyObject* Sbk_QListViewFunc_setRootIndex(PyObject* self, PyObject* arg)
{
    QListView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QListView* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setRootIndex(QModelIndex)
    if (Shiboken::Converter< ::QModelIndex >::isConvertible(arg)) {
        overloadId = 0; // setRootIndex(QModelIndex)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QListViewFunc_setRootIndex_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QModelIndex cppArg0 = Shiboken::Converter<QModelIndex >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setRootIndex(QModelIndex)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QListView::setRootIndex(cppArg0) : cppSelf->setRootIndex(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QListViewFunc_setRootIndex_TypeError:
        const char* overloads[] = {"PySide.QtCore.QModelIndex", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QListView.setRootIndex", overloads);
        return 0;
}

static PyObject* Sbk_QListViewFunc_setRowHidden(PyObject* self, PyObject* args)
{
    QListView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QListView* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setRowHidden", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setRowHidden(int,bool)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 0; // setRowHidden(int,bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QListViewFunc_setRowHidden_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            bool cppArg1 = Shiboken::Converter<bool >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // setRowHidden(int,bool)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setRowHidden(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QListViewFunc_setRowHidden_TypeError:
        const char* overloads[] = {"int, bool", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QListView.setRowHidden", overloads);
        return 0;
}

static PyObject* Sbk_QListViewFunc_setSelection(PyObject* self, PyObject* args)
{
    QListView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QListView* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setSelection", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setSelection(QRect,QFlags<QItemSelectionModel::SelectionFlag>)
    if (numArgs == 2 && Shiboken::Converter< ::QRect >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QFlags<QItemSelectionModel::SelectionFlag> >::isConvertible(pyargs[1])) {
        overloadId = 0; // setSelection(QRect,QFlags<QItemSelectionModel::SelectionFlag>)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QListViewFunc_setSelection_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QRect cppArg0 = Shiboken::Converter<QRect >::toCpp(pyargs[0]);
            QFlags<QItemSelectionModel::SelectionFlag> cppArg1 = Shiboken::Converter<QFlags<QItemSelectionModel::SelectionFlag> >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // setSelection(QRect,QFlags<QItemSelectionModel::SelectionFlag>)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QListView::setSelection(cppArg0, cppArg1) : cppSelf->setSelection(cppArg0, cppArg1));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QListViewFunc_setSelection_TypeError:
        const char* overloads[] = {"PySide.QtCore.QRect, PySide.QtGui.QItemSelectionModel.SelectionFlags", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QListView.setSelection", overloads);
        return 0;
}

static PyObject* Sbk_QListViewFunc_setSelectionRectVisible(PyObject* self, PyObject* arg)
{
    QListView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QListView* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setSelectionRectVisible(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setSelectionRectVisible(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QListViewFunc_setSelectionRectVisible_TypeError;

    // Call function/method
    {
        {
            bool cppArg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setSelectionRectVisible(bool)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setSelectionRectVisible(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QListViewFunc_setSelectionRectVisible_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QListView.setSelectionRectVisible", overloads);
        return 0;
}

static PyObject* Sbk_QListViewFunc_setSpacing(PyObject* self, PyObject* arg)
{
    QListView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QListView* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setSpacing(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setSpacing(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QListViewFunc_setSpacing_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setSpacing(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setSpacing(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QListViewFunc_setSpacing_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QListView.setSpacing", overloads);
        return 0;
}

static PyObject* Sbk_QListViewFunc_setUniformItemSizes(PyObject* self, PyObject* arg)
{
    QListView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QListView* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setUniformItemSizes(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setUniformItemSizes(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QListViewFunc_setUniformItemSizes_TypeError;

    // Call function/method
    {
        {
            bool cppArg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setUniformItemSizes(bool)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setUniformItemSizes(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QListViewFunc_setUniformItemSizes_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QListView.setUniformItemSizes", overloads);
        return 0;
}

static PyObject* Sbk_QListViewFunc_setViewMode(PyObject* self, PyObject* arg)
{
    QListView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QListView* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setViewMode(QListView::ViewMode)
    if (Shiboken::Converter< ::QListView::ViewMode >::isConvertible(arg)) {
        overloadId = 0; // setViewMode(QListView::ViewMode)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QListViewFunc_setViewMode_TypeError;

    // Call function/method
    {
        {
            QListView::ViewMode cppArg0 = Shiboken::Converter<QListView::ViewMode >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setViewMode(QListView::ViewMode)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setViewMode(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QListViewFunc_setViewMode_TypeError:
        const char* overloads[] = {"PySide.QtGui.QListView.ViewMode", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QListView.setViewMode", overloads);
        return 0;
}

static PyObject* Sbk_QListViewFunc_setWordWrap(PyObject* self, PyObject* arg)
{
    QListView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QListView* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setWordWrap(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setWordWrap(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QListViewFunc_setWordWrap_TypeError;

    // Call function/method
    {
        {
            bool cppArg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setWordWrap(bool)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setWordWrap(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QListViewFunc_setWordWrap_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QListView.setWordWrap", overloads);
        return 0;
}

static PyObject* Sbk_QListViewFunc_setWrapping(PyObject* self, PyObject* arg)
{
    QListView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QListView* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setWrapping(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setWrapping(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QListViewFunc_setWrapping_TypeError;

    // Call function/method
    {
        {
            bool cppArg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setWrapping(bool)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setWrapping(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QListViewFunc_setWrapping_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QListView.setWrapping", overloads);
        return 0;
}

static PyObject* Sbk_QListViewFunc_spacing(PyObject* self)
{
    QListView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QListView* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // spacing()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QListView*>(cppSelf)->spacing();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QListViewFunc_startDrag(PyObject* self, PyObject* arg)
{
    QListView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QListView* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: startDrag(QFlags<Qt::DropAction>)
    if (Shiboken::Converter< ::QFlags<Qt::DropAction> >::isConvertible(arg)) {
        overloadId = 0; // startDrag(QFlags<Qt::DropAction>)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QListViewFunc_startDrag_TypeError;

    // Call function/method
    {
        {
            QFlags<Qt::DropAction> cppArg0 = Shiboken::Converter<QFlags<Qt::DropAction> >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // startDrag(QFlags<Qt::DropAction>)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QListView::startDrag(cppArg0) : cppSelf->startDrag(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QListViewFunc_startDrag_TypeError:
        const char* overloads[] = {"PySide.QtCore.Qt.DropActions", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QListView.startDrag", overloads);
        return 0;
}

static PyObject* Sbk_QListViewFunc_timerEvent(PyObject* self, PyObject* arg)
{
    QListView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QListView* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: timerEvent(QTimerEvent*)
    if (Shiboken::Converter< ::QTimerEvent * >::isConvertible(arg)) {
        overloadId = 0; // timerEvent(QTimerEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QListViewFunc_timerEvent_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QTimerEvent * cppArg0 = Shiboken::Converter<QTimerEvent * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // timerEvent(QTimerEvent*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QListView::timerEvent(cppArg0) : cppSelf->timerEvent(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QListViewFunc_timerEvent_TypeError:
        const char* overloads[] = {"PySide.QtCore.QTimerEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QListView.timerEvent", overloads);
        return 0;
}

static PyObject* Sbk_QListViewFunc_uniformItemSizes(PyObject* self)
{
    QListView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QListView* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // uniformItemSizes()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QListView*>(cppSelf)->uniformItemSizes();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QListViewFunc_updateGeometries(PyObject* self)
{
    QListView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QListView* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // updateGeometries()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QListView::updateGeometries() : cppSelf->updateGeometries());
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QListViewFunc_verticalOffset(PyObject* self)
{
    QListView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QListView* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // verticalOffset()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = (Shiboken::Object::isUserType(self) ? const_cast<const QListView*>(cppSelf)->::QListView::verticalOffset() : const_cast<const QListView*>(cppSelf)->verticalOffset());
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QListViewFunc_viewMode(PyObject* self)
{
    QListView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QListView* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // viewMode()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QListView::ViewMode cppResult = const_cast<const QListView*>(cppSelf)->viewMode();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QListView::ViewMode >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QListViewFunc_viewOptions(PyObject* self)
{
    QListView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QListView* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // viewOptions()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QStyleOptionViewItem cppResult = (Shiboken::Object::isUserType(self) ? const_cast<const QListView*>(cppSelf)->::QListView::viewOptions() : const_cast<const QListView*>(cppSelf)->viewOptions());
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QStyleOptionViewItem >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QListViewFunc_visualRect(PyObject* self, PyObject* arg)
{
    QListView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QListView* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: visualRect(QModelIndex)const
    if (Shiboken::Converter< ::QModelIndex >::isConvertible(arg)) {
        overloadId = 0; // visualRect(QModelIndex)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QListViewFunc_visualRect_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QModelIndex cppArg0 = Shiboken::Converter<QModelIndex >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // visualRect(QModelIndex)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QRect cppResult = (Shiboken::Object::isUserType(self) ? const_cast<const QListView*>(cppSelf)->::QListView::visualRect(cppArg0) : const_cast<const QListView*>(cppSelf)->visualRect(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QRect >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QListViewFunc_visualRect_TypeError:
        const char* overloads[] = {"PySide.QtCore.QModelIndex", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QListView.visualRect", overloads);
        return 0;
}

static PyObject* Sbk_QListViewFunc_visualRegionForSelection(PyObject* self, PyObject* arg)
{
    QListView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QListView* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: visualRegionForSelection(QItemSelection)const
    if (Shiboken::Converter< ::QItemSelection >::isConvertible(arg)) {
        overloadId = 0; // visualRegionForSelection(QItemSelection)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QListViewFunc_visualRegionForSelection_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QItemSelection cppArg0 = Shiboken::Converter<QItemSelection >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // visualRegionForSelection(QItemSelection)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QRegion cppResult = (Shiboken::Object::isUserType(self) ? const_cast<const QListView*>(cppSelf)->::QListView::visualRegionForSelection(cppArg0) : const_cast<const QListView*>(cppSelf)->visualRegionForSelection(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QRegion >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QListViewFunc_visualRegionForSelection_TypeError:
        const char* overloads[] = {"PySide.QtGui.QItemSelection", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QListView.visualRegionForSelection", overloads);
        return 0;
}

static PyObject* Sbk_QListViewFunc_wordWrap(PyObject* self)
{
    QListView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QListView* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // wordWrap()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QListView*>(cppSelf)->wordWrap();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef Sbk_QListView_methods[] = {
    {"batchSize", (PyCFunction)Sbk_QListViewFunc_batchSize, METH_NOARGS},
    {"clearPropertyFlags", (PyCFunction)Sbk_QListViewFunc_clearPropertyFlags, METH_NOARGS},
    {"contentsSize", (PyCFunction)Sbk_QListViewFunc_contentsSize, METH_NOARGS},
    {"currentChanged", (PyCFunction)Sbk_QListViewFunc_currentChanged, METH_VARARGS},
    {"dataChanged", (PyCFunction)Sbk_QListViewFunc_dataChanged, METH_VARARGS},
    {"doItemsLayout", (PyCFunction)Sbk_QListViewFunc_doItemsLayout, METH_NOARGS},
    {"dragLeaveEvent", (PyCFunction)Sbk_QListViewFunc_dragLeaveEvent, METH_O},
    {"dragMoveEvent", (PyCFunction)Sbk_QListViewFunc_dragMoveEvent, METH_O},
    {"dropEvent", (PyCFunction)Sbk_QListViewFunc_dropEvent, METH_O},
    {"event", (PyCFunction)Sbk_QListViewFunc_event, METH_O},
    {"flow", (PyCFunction)Sbk_QListViewFunc_flow, METH_NOARGS},
    {"gridSize", (PyCFunction)Sbk_QListViewFunc_gridSize, METH_NOARGS},
    {"horizontalOffset", (PyCFunction)Sbk_QListViewFunc_horizontalOffset, METH_NOARGS},
    {"indexAt", (PyCFunction)Sbk_QListViewFunc_indexAt, METH_O},
    {"internalDrag", (PyCFunction)Sbk_QListViewFunc_internalDrag, METH_O},
    {"internalDrop", (PyCFunction)Sbk_QListViewFunc_internalDrop, METH_O},
    {"isIndexHidden", (PyCFunction)Sbk_QListViewFunc_isIndexHidden, METH_O},
    {"isRowHidden", (PyCFunction)Sbk_QListViewFunc_isRowHidden, METH_O},
    {"isSelectionRectVisible", (PyCFunction)Sbk_QListViewFunc_isSelectionRectVisible, METH_NOARGS},
    {"isWrapping", (PyCFunction)Sbk_QListViewFunc_isWrapping, METH_NOARGS},
    {"layoutMode", (PyCFunction)Sbk_QListViewFunc_layoutMode, METH_NOARGS},
    {"modelColumn", (PyCFunction)Sbk_QListViewFunc_modelColumn, METH_NOARGS},
    {"mouseMoveEvent", (PyCFunction)Sbk_QListViewFunc_mouseMoveEvent, METH_O},
    {"mouseReleaseEvent", (PyCFunction)Sbk_QListViewFunc_mouseReleaseEvent, METH_O},
    {"movement", (PyCFunction)Sbk_QListViewFunc_movement, METH_NOARGS},
    {"paintEvent", (PyCFunction)Sbk_QListViewFunc_paintEvent, METH_O},
    {"rectForIndex", (PyCFunction)Sbk_QListViewFunc_rectForIndex, METH_O},
    {"reset", (PyCFunction)Sbk_QListViewFunc_reset, METH_NOARGS},
    {"resizeContents", (PyCFunction)Sbk_QListViewFunc_resizeContents, METH_VARARGS},
    {"resizeEvent", (PyCFunction)Sbk_QListViewFunc_resizeEvent, METH_O},
    {"resizeMode", (PyCFunction)Sbk_QListViewFunc_resizeMode, METH_NOARGS},
    {"rowsAboutToBeRemoved", (PyCFunction)Sbk_QListViewFunc_rowsAboutToBeRemoved, METH_VARARGS},
    {"rowsInserted", (PyCFunction)Sbk_QListViewFunc_rowsInserted, METH_VARARGS},
    {"scrollContentsBy", (PyCFunction)Sbk_QListViewFunc_scrollContentsBy, METH_VARARGS},
    {"scrollTo", (PyCFunction)Sbk_QListViewFunc_scrollTo, METH_VARARGS|METH_KEYWORDS},
    {"selectedIndexes", (PyCFunction)Sbk_QListViewFunc_selectedIndexes, METH_NOARGS},
    {"selectionChanged", (PyCFunction)Sbk_QListViewFunc_selectionChanged, METH_VARARGS},
    {"setBatchSize", (PyCFunction)Sbk_QListViewFunc_setBatchSize, METH_O},
    {"setFlow", (PyCFunction)Sbk_QListViewFunc_setFlow, METH_O},
    {"setGridSize", (PyCFunction)Sbk_QListViewFunc_setGridSize, METH_O},
    {"setLayoutMode", (PyCFunction)Sbk_QListViewFunc_setLayoutMode, METH_O},
    {"setModelColumn", (PyCFunction)Sbk_QListViewFunc_setModelColumn, METH_O},
    {"setMovement", (PyCFunction)Sbk_QListViewFunc_setMovement, METH_O},
    {"setPositionForIndex", (PyCFunction)Sbk_QListViewFunc_setPositionForIndex, METH_VARARGS},
    {"setResizeMode", (PyCFunction)Sbk_QListViewFunc_setResizeMode, METH_O},
    {"setRootIndex", (PyCFunction)Sbk_QListViewFunc_setRootIndex, METH_O},
    {"setRowHidden", (PyCFunction)Sbk_QListViewFunc_setRowHidden, METH_VARARGS},
    {"setSelection", (PyCFunction)Sbk_QListViewFunc_setSelection, METH_VARARGS},
    {"setSelectionRectVisible", (PyCFunction)Sbk_QListViewFunc_setSelectionRectVisible, METH_O},
    {"setSpacing", (PyCFunction)Sbk_QListViewFunc_setSpacing, METH_O},
    {"setUniformItemSizes", (PyCFunction)Sbk_QListViewFunc_setUniformItemSizes, METH_O},
    {"setViewMode", (PyCFunction)Sbk_QListViewFunc_setViewMode, METH_O},
    {"setWordWrap", (PyCFunction)Sbk_QListViewFunc_setWordWrap, METH_O},
    {"setWrapping", (PyCFunction)Sbk_QListViewFunc_setWrapping, METH_O},
    {"spacing", (PyCFunction)Sbk_QListViewFunc_spacing, METH_NOARGS},
    {"startDrag", (PyCFunction)Sbk_QListViewFunc_startDrag, METH_O},
    {"timerEvent", (PyCFunction)Sbk_QListViewFunc_timerEvent, METH_O},
    {"uniformItemSizes", (PyCFunction)Sbk_QListViewFunc_uniformItemSizes, METH_NOARGS},
    {"updateGeometries", (PyCFunction)Sbk_QListViewFunc_updateGeometries, METH_NOARGS},
    {"verticalOffset", (PyCFunction)Sbk_QListViewFunc_verticalOffset, METH_NOARGS},
    {"viewMode", (PyCFunction)Sbk_QListViewFunc_viewMode, METH_NOARGS},
    {"viewOptions", (PyCFunction)Sbk_QListViewFunc_viewOptions, METH_NOARGS},
    {"visualRect", (PyCFunction)Sbk_QListViewFunc_visualRect, METH_O},
    {"visualRegionForSelection", (PyCFunction)Sbk_QListViewFunc_visualRegionForSelection, METH_O},
    {"wordWrap", (PyCFunction)Sbk_QListViewFunc_wordWrap, METH_NOARGS},

    {0} // Sentinel
};

} // extern "C"

static void* Sbk_QListViewSpecialCastFunction(void* obj, SbkObjectType* desiredType)
{
    QListView* me = reinterpret_cast<QListView*>(obj);
    if (desiredType == reinterpret_cast<SbkObjectType*>(SbkPySide_QtGuiTypes[SBK_QABSTRACTITEMVIEW_IDX]))
        return static_cast<QAbstractItemView*>(me);
    else if (desiredType == reinterpret_cast<SbkObjectType*>(SbkPySide_QtGuiTypes[SBK_QABSTRACTSCROLLAREA_IDX]))
        return static_cast<QAbstractScrollArea*>(me);
    else if (desiredType == reinterpret_cast<SbkObjectType*>(SbkPySide_QtGuiTypes[SBK_QFRAME_IDX]))
        return static_cast<QFrame*>(me);
    else if (desiredType == reinterpret_cast<SbkObjectType*>(SbkPySide_QtGuiTypes[SBK_QWIDGET_IDX]))
        return static_cast<QWidget*>(me);
    else if (desiredType == reinterpret_cast<SbkObjectType*>(SbkPySide_QtCoreTypes[SBK_QOBJECT_IDX]))
        return static_cast<QObject*>(me);
    else if (desiredType == reinterpret_cast<SbkObjectType*>(SbkPySide_QtGuiTypes[SBK_QPAINTDEVICE_IDX]))
        return static_cast<QPaintDevice*>(me);
    return me;
}


// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QListView_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QListView",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QListView_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QListView_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern

static SbkObjectType* Sbk_QListView_typeDiscovery(void* cptr, SbkObjectType* instanceType)
{
    if (instanceType == reinterpret_cast<SbkObjectType*>(Shiboken::SbkType<QObject >()) && dynamic_cast<QListView*>(reinterpret_cast<QObject*>(cptr)))
        return &Sbk_QListView_Type;
    if (instanceType == reinterpret_cast<SbkObjectType*>(Shiboken::SbkType<QPaintDevice >()) && dynamic_cast<QListView*>(reinterpret_cast<QPaintDevice*>(cptr)))
        return &Sbk_QListView_Type;
    return 0;
}


void init_QListView(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QLISTVIEW_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QListView_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QListView_Type);
    Shiboken::ObjectType::setSubTypeInitHook(&Sbk_QListView_Type, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(&Sbk_QListView_Type, &QListView::staticMetaObject);    Sbk_QListView_Type.super.ht_type.tp_base = SbkPySide_QtGuiTypes[SBK_QABSTRACTITEMVIEW_IDX];
    MultipleInheritanceInitFunction func;
    func = Shiboken::ObjectType::getMultipleIheritanceFunction(reinterpret_cast<SbkObjectType*>(SbkPySide_QtGuiTypes[SBK_QWIDGET_IDX]));
    Shiboken::ObjectType::setMultipleIheritanceFunction(&Sbk_QListView_Type, func);
    Shiboken::ObjectType::setCastFunction(&Sbk_QListView_Type, &Sbk_QListViewSpecialCastFunction);
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QListView_Type, &Shiboken::callCppDestructor<QListView >);
    Py_INCREF((PyObject*)&Sbk_QListView_Type); //Incref due the 'PyModule_AddObject' steals the reference.
    if (PyType_Ready((PyTypeObject*)&Sbk_QListView_Type) < 0)
        return;

    // Fill type discovery information
    Shiboken::ObjectType::setTypeDiscoveryFunction(&Sbk_QListView_Type, &Sbk_QListView_typeDiscovery);
    Shiboken::BindingManager& bm = Shiboken::BindingManager::instance();
    bm.addClassInheritance(reinterpret_cast<SbkObjectType*>(SbkPySide_QtGuiTypes[SBK_QABSTRACTITEMVIEW_IDX]), &Sbk_QListView_Type);

    Shiboken::ObjectType::setOriginalName(&Sbk_QListView_Type, "QListView*");
    PyModule_AddObject(module, "QListView",
        ((PyObject*)&Sbk_QListView_Type));

    // Initialize enums
    PyObject* enumItem;

    // init enum: ResizeMode
    PyTypeObject* SbkPySide_QtGui_QListView_ResizeMode = Shiboken::Enum::newType("PySide.QtGui.QListView.ResizeMode");
    SbkPySide_QtGuiTypes[SBK_QLISTVIEW_RESIZEMODE_IDX] = SbkPySide_QtGui_QListView_ResizeMode;
    if (PyType_Ready(SbkPySide_QtGui_QListView_ResizeMode) < 0)
        return;
    PyDict_SetItemString(Sbk_QListView_Type.super.ht_type.tp_dict,
            "ResizeMode",((PyObject*)SbkPySide_QtGui_QListView_ResizeMode));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QListView_ResizeMode,(long) QListView::Fixed, "Fixed");
    PyDict_SetItemString(Sbk_QListView_Type.super.ht_type.tp_dict,"Fixed", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QListView_ResizeMode->tp_dict,"Fixed", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QListView_ResizeMode,(long) QListView::Adjust, "Adjust");
    PyDict_SetItemString(Sbk_QListView_Type.super.ht_type.tp_dict,"Adjust", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QListView_ResizeMode->tp_dict,"Adjust", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QListView::ResizeMode");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::ResizeMode");
    // end of enum ResizeMode

    // init enum: LayoutMode
    PyTypeObject* SbkPySide_QtGui_QListView_LayoutMode = Shiboken::Enum::newType("PySide.QtGui.QListView.LayoutMode");
    SbkPySide_QtGuiTypes[SBK_QLISTVIEW_LAYOUTMODE_IDX] = SbkPySide_QtGui_QListView_LayoutMode;
    if (PyType_Ready(SbkPySide_QtGui_QListView_LayoutMode) < 0)
        return;
    PyDict_SetItemString(Sbk_QListView_Type.super.ht_type.tp_dict,
            "LayoutMode",((PyObject*)SbkPySide_QtGui_QListView_LayoutMode));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QListView_LayoutMode,(long) QListView::SinglePass, "SinglePass");
    PyDict_SetItemString(Sbk_QListView_Type.super.ht_type.tp_dict,"SinglePass", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QListView_LayoutMode->tp_dict,"SinglePass", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QListView_LayoutMode,(long) QListView::Batched, "Batched");
    PyDict_SetItemString(Sbk_QListView_Type.super.ht_type.tp_dict,"Batched", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QListView_LayoutMode->tp_dict,"Batched", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QListView::LayoutMode");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::LayoutMode");
    // end of enum LayoutMode

    // init enum: ViewMode
    PyTypeObject* SbkPySide_QtGui_QListView_ViewMode = Shiboken::Enum::newType("PySide.QtGui.QListView.ViewMode");
    SbkPySide_QtGuiTypes[SBK_QLISTVIEW_VIEWMODE_IDX] = SbkPySide_QtGui_QListView_ViewMode;
    if (PyType_Ready(SbkPySide_QtGui_QListView_ViewMode) < 0)
        return;
    PyDict_SetItemString(Sbk_QListView_Type.super.ht_type.tp_dict,
            "ViewMode",((PyObject*)SbkPySide_QtGui_QListView_ViewMode));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QListView_ViewMode,(long) QListView::ListMode, "ListMode");
    PyDict_SetItemString(Sbk_QListView_Type.super.ht_type.tp_dict,"ListMode", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QListView_ViewMode->tp_dict,"ListMode", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QListView_ViewMode,(long) QListView::IconMode, "IconMode");
    PyDict_SetItemString(Sbk_QListView_Type.super.ht_type.tp_dict,"IconMode", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QListView_ViewMode->tp_dict,"IconMode", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QListView::ViewMode");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::ViewMode");
    // end of enum ViewMode

    // init enum: Flow
    PyTypeObject* SbkPySide_QtGui_QListView_Flow = Shiboken::Enum::newType("PySide.QtGui.QListView.Flow");
    SbkPySide_QtGuiTypes[SBK_QLISTVIEW_FLOW_IDX] = SbkPySide_QtGui_QListView_Flow;
    if (PyType_Ready(SbkPySide_QtGui_QListView_Flow) < 0)
        return;
    PyDict_SetItemString(Sbk_QListView_Type.super.ht_type.tp_dict,
            "Flow",((PyObject*)SbkPySide_QtGui_QListView_Flow));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QListView_Flow,(long) QListView::LeftToRight, "LeftToRight");
    PyDict_SetItemString(Sbk_QListView_Type.super.ht_type.tp_dict,"LeftToRight", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QListView_Flow->tp_dict,"LeftToRight", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QListView_Flow,(long) QListView::TopToBottom, "TopToBottom");
    PyDict_SetItemString(Sbk_QListView_Type.super.ht_type.tp_dict,"TopToBottom", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QListView_Flow->tp_dict,"TopToBottom", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QListView::Flow");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::Flow");
    // end of enum Flow

    // init enum: Movement
    PyTypeObject* SbkPySide_QtGui_QListView_Movement = Shiboken::Enum::newType("PySide.QtGui.QListView.Movement");
    SbkPySide_QtGuiTypes[SBK_QLISTVIEW_MOVEMENT_IDX] = SbkPySide_QtGui_QListView_Movement;
    if (PyType_Ready(SbkPySide_QtGui_QListView_Movement) < 0)
        return;
    PyDict_SetItemString(Sbk_QListView_Type.super.ht_type.tp_dict,
            "Movement",((PyObject*)SbkPySide_QtGui_QListView_Movement));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QListView_Movement,(long) QListView::Static, "Static");
    PyDict_SetItemString(Sbk_QListView_Type.super.ht_type.tp_dict,"Static", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QListView_Movement->tp_dict,"Static", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QListView_Movement,(long) QListView::Free, "Free");
    PyDict_SetItemString(Sbk_QListView_Type.super.ht_type.tp_dict,"Free", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QListView_Movement->tp_dict,"Free", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QListView_Movement,(long) QListView::Snap, "Snap");
    PyDict_SetItemString(Sbk_QListView_Type.super.ht_type.tp_dict,"Snap", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QListView_Movement->tp_dict,"Snap", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QListView::Movement");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::Movement");
    // end of enum Movement

    Shiboken::TypeResolver::createValueTypeResolver<QList<QModelIndex > >("QModelIndexList const&");
    // Initialize signals
    PySideSignal* signal_item;

    signal_item = PySide::Signal::newObject("indexesMoved", "QModelIndexList", NULL);
    PySide::Signal::addSignalToWrapper(&Sbk_QListView_Type, "indexesMoved", signal_item);
    Py_DECREF((PyObject*) signal_item);


    Shiboken::TypeResolver::createObjectTypeResolver<QListView >("QListView*");
    Shiboken::TypeResolver::createObjectTypeResolver<QListView >(typeid(QListView).name());
    Shiboken::TypeResolver::createObjectTypeResolver<QListView >(typeid(QListViewWrapper).name());
    qRegisterMetaType< ::QListView* >("QListView*");
    qRegisterMetaType< ::QListView::ResizeMode >("QListView::ResizeMode");
    qRegisterMetaType< ::QListView::LayoutMode >("QListView::LayoutMode");
    qRegisterMetaType< ::QListView::ViewMode >("QListView::ViewMode");
    qRegisterMetaType< ::QListView::Flow >("QListView::Flow");
    qRegisterMetaType< ::QListView::Movement >("QListView::Movement");
}

