/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtgui_python.h"

#include "qpainter_wrapper.h"

// Extra includes
#include <QPainterPath>
#include <QPixmap>
#include <QVector>
#include <QWidget>
#include <qbrush.h>
#include <qcolor.h>
#include <qfont.h>
#include <qfontinfo.h>
#include <qfontmetrics.h>
#include <qimage.h>
#include <qline.h>
#include <qmatrix.h>
#include <qpaintdevice.h>
#include <qpaintengine.h>
#include <qpainter.h>
#include <qpainterpath.h>
#include <qpen.h>
#include <qpicture.h>
#include <qpixmap.h>
#include <qpoint.h>
#include <qpolygon.h>
#include <qrect.h>
#include <qregion.h>
#include <qtextoption.h>
#include <qtransform.h>
#include <qwidget.h>



// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QPainter_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QPainter >()))
        return -1;

    QPainter* cptr = 0;
    int overloadId = -1;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QPainter", 0, 1, &(pyargs[0])))
        return -1;

    // Overloaded function decisor
    // 0: QPainter()
    // 1: QPainter(QPaintDevice*)
    if (numArgs == 0) {
        overloadId = 0; // QPainter()
    } else if (numArgs == 1 && Shiboken::Converter< ::QPaintDevice * >::isConvertible(pyargs[0])) {
        overloadId = 1; // QPainter(QPaintDevice*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPainter_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QPainter()
            {

                if(!PyErr_Occurred()) {
                    // QPainter()
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QPainter();
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // QPainter(QPaintDevice*)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QPaintDevice * cppArg0 = Shiboken::Converter<QPaintDevice * >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QPainter(QPaintDevice*)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QPainter(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QPainter >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QPainter_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QPainter_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtGui.QPaintDevice", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPainter", overloads);
        return -1;
}

static PyObject* Sbk_QPainterFunc_background(PyObject* self)
{
    QPainter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPainter* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // background()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                const QBrush & cppResult = const_cast<const QPainter*>(cppSelf)->background();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QBrush >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QPainterFunc_backgroundMode(PyObject* self)
{
    QPainter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPainter* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // backgroundMode()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                Qt::BGMode cppResult = const_cast<const QPainter*>(cppSelf)->backgroundMode();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::Qt::BGMode >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QPainterFunc_begin(PyObject* self, PyObject* arg)
{
    QPainter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPainter* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: begin(QPaintDevice*)
    if (Shiboken::Converter< ::QPaintDevice * >::isConvertible(arg)) {
        overloadId = 0; // begin(QPaintDevice*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPainterFunc_begin_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QPaintDevice * cppArg0 = Shiboken::Converter<QPaintDevice * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // begin(QPaintDevice*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->begin(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QPainterFunc_begin_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPaintDevice", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPainter.begin", overloads);
        return 0;
}

static PyObject* Sbk_QPainterFunc_beginNativePainting(PyObject* self)
{
    QPainter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPainter* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // beginNativePainting()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->beginNativePainting();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QPainterFunc_boundingRect(PyObject* self, PyObject* args, PyObject* kwds)
{
    QPainter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPainter* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 6) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QPainter.boundingRect(): too many arguments");
        return 0;
    } else if (numArgs < 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QPainter.boundingRect(): not enough arguments");
        return 0;
    } else if (numArgs == 4 || numArgs == 5)
        goto Sbk_QPainterFunc_boundingRect_TypeError;

    if (!PyArg_ParseTuple(args, "|OOOOOO:boundingRect", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3]), &(pyargs[4]), &(pyargs[5])))
        return 0;


    // Overloaded function decisor
    // 0: boundingRect(QRect,int,QString)
    // 1: boundingRect(QRectF,QString,QTextOption)
    // 2: boundingRect(QRectF,int,QString)
    // 3: boundingRect(int,int,int,int,int,QString)
    if (numArgs == 6 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2]) && SbkNumber_Check(pyargs[3]) && SbkNumber_Check(pyargs[4]) && Shiboken::Converter< QString >::isConvertible(pyargs[5])) {
        overloadId = 3; // boundingRect(int,int,int,int,int,QString)
    } else if (numArgs == 3 && Shiboken::Converter< ::QRect >::isConvertible(pyargs[0]) && SbkNumber_Check(pyargs[1]) && Shiboken::Converter< QString >::isConvertible(pyargs[2])) {
        overloadId = 0; // boundingRect(QRect,int,QString)
    } else if (Shiboken::Converter< ::QRectF >::isConvertible(pyargs[0])) {
        if (numArgs == 3 && SbkNumber_Check(pyargs[1]) && Shiboken::Converter< QString >::isConvertible(pyargs[2])) {
            overloadId = 2; // boundingRect(QRectF,int,QString)
        } else if (Shiboken::Converter< QString >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 1; // boundingRect(QRectF,QString,QTextOption)
            } else if (Shiboken::Converter< ::QTextOption >::isConvertible(pyargs[2])) {
                overloadId = 1; // boundingRect(QRectF,QString,QTextOption)
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPainterFunc_boundingRect_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // boundingRect(QRect,int,QString)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QRect cppArg0 = Shiboken::Converter<QRect >::toCpp(pyargs[0]);
                int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                QString cppArg2 = Shiboken::Converter<QString >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                    // boundingRect(QRect,int,QString)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QRect cppResult = cppSelf->boundingRect(cppArg0, cppArg1, cppArg2);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QRect >::toPython(cppResult);
                }
                break;
            }
            case 1: // boundingRect(QRectF,QString,QTextOption)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "o");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "o";
                        else if (Shiboken::Converter< ::QTextOption >::isConvertible(value))
                            pyargs[2] = value;
                        else
                            goto Sbk_QPainterFunc_boundingRect_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QPainter.boundingRect(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QRectF cppArg0 = Shiboken::Converter<QRectF >::toCpp(pyargs[0]);
                QString cppArg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);
                if (!Shiboken::Object::isValid(pyargs[2]))
                    return 0;
                QTextOption cppArg2_tmp = QTextOption();
                QTextOption cppArg2 = pyargs[2] ? Shiboken::Converter<QTextOption >::toCpp(pyargs[2]) : cppArg2_tmp;

                if(!PyErr_Occurred()) {
                    // boundingRect(QRectF,QString,QTextOption)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QRectF cppResult = cppSelf->boundingRect(cppArg0, cppArg1, cppArg2);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QRectF >::toPython(cppResult);
                }
                break;
            }
            case 2: // boundingRect(QRectF,int,QString)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QRectF cppArg0 = Shiboken::Converter<QRectF >::toCpp(pyargs[0]);
                int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                QString cppArg2 = Shiboken::Converter<QString >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                    // boundingRect(QRectF,int,QString)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QRectF cppResult = cppSelf->boundingRect(cppArg0, cppArg1, cppArg2);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QRectF >::toPython(cppResult);
                }
                break;
            }
            case 3: // boundingRect(int,int,int,int,int,QString)
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                int cppArg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);
                int cppArg3 = Shiboken::Converter<int >::toCpp(pyargs[3]);
                int cppArg4 = Shiboken::Converter<int >::toCpp(pyargs[4]);
                QString cppArg5 = Shiboken::Converter<QString >::toCpp(pyargs[5]);

                if(!PyErr_Occurred()) {
                    // boundingRect(int,int,int,int,int,QString)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QRect cppResult = cppSelf->boundingRect(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QRect >::toPython(cppResult);
                }
                break;
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QPainterFunc_boundingRect_TypeError:
        const char* overloads[] = {"PySide.QtCore.QRect, int, QString", "PySide.QtCore.QRectF, QString, PySide.QtGui.QTextOption = QTextOption()", "PySide.QtCore.QRectF, int, QString", "int, int, int, int, int, QString", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPainter.boundingRect", overloads);
        return 0;
}

static PyObject* Sbk_QPainterFunc_brush(PyObject* self)
{
    QPainter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPainter* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // brush()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                const QBrush & cppResult = const_cast<const QPainter*>(cppSelf)->brush();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QBrush >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QPainterFunc_brushOrigin(PyObject* self)
{
    QPainter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPainter* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // brushOrigin()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QPoint cppResult = const_cast<const QPainter*>(cppSelf)->brushOrigin();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QPoint >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QPainterFunc_clipPath(PyObject* self)
{
    QPainter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPainter* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // clipPath()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QPainterPath cppResult = const_cast<const QPainter*>(cppSelf)->clipPath();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QPainterPath >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QPainterFunc_clipRegion(PyObject* self)
{
    QPainter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPainter* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // clipRegion()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QRegion cppResult = const_cast<const QPainter*>(cppSelf)->clipRegion();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QRegion >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QPainterFunc_combinedMatrix(PyObject* self)
{
    QPainter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPainter* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // combinedMatrix()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QMatrix cppResult = const_cast<const QPainter*>(cppSelf)->combinedMatrix();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QMatrix >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QPainterFunc_combinedTransform(PyObject* self)
{
    QPainter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPainter* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // combinedTransform()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QTransform cppResult = const_cast<const QPainter*>(cppSelf)->combinedTransform();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QTransform >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QPainterFunc_compositionMode(PyObject* self)
{
    QPainter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPainter* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // compositionMode()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QPainter::CompositionMode cppResult = const_cast<const QPainter*>(cppSelf)->compositionMode();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QPainter::CompositionMode >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QPainterFunc_device(PyObject* self)
{
    QPainter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPainter* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // device()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QPaintDevice * cppResult = const_cast<const QPainter*>(cppSelf)->device();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QPaintDevice * >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QPainterFunc_deviceMatrix(PyObject* self)
{
    QPainter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPainter* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // deviceMatrix()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                const QMatrix & cppResult = const_cast<const QPainter*>(cppSelf)->deviceMatrix();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QMatrix >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QPainterFunc_deviceTransform(PyObject* self)
{
    QPainter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPainter* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // deviceTransform()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                const QTransform & cppResult = const_cast<const QPainter*>(cppSelf)->deviceTransform();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QTransform >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QPainterFunc_drawArc(PyObject* self, PyObject* args)
{
    QPainter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPainter* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs == 4 || numArgs == 5)
        goto Sbk_QPainterFunc_drawArc_TypeError;

    if (!PyArg_UnpackTuple(args, "drawArc", 3, 6, &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3]), &(pyargs[4]), &(pyargs[5])))
        return 0;


    // Overloaded function decisor
    // 0: drawArc(QRect,int,int)
    // 1: drawArc(QRectF,int,int)
    // 2: drawArc(int,int,int,int,int,int)
    if (numArgs == 6 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2]) && SbkNumber_Check(pyargs[3]) && SbkNumber_Check(pyargs[4]) && SbkNumber_Check(pyargs[5])) {
        overloadId = 2; // drawArc(int,int,int,int,int,int)
    } else if (numArgs == 3 && Shiboken::Converter< ::QRect >::isConvertible(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
        overloadId = 0; // drawArc(QRect,int,int)
    } else if (numArgs == 3 && Shiboken::Converter< ::QRectF >::isConvertible(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
        overloadId = 1; // drawArc(QRectF,int,int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPainterFunc_drawArc_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // drawArc(QRect,int,int)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QRect cppArg0 = Shiboken::Converter<QRect >::toCpp(pyargs[0]);
                int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                int cppArg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                    // drawArc(QRect,int,int)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->drawArc(cppArg0, cppArg1, cppArg2);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // drawArc(QRectF,int,int)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QRectF cppArg0 = Shiboken::Converter<QRectF >::toCpp(pyargs[0]);
                int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                int cppArg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                    // drawArc(QRectF,int,int)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->drawArc(cppArg0, cppArg1, cppArg2);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 2: // drawArc(int,int,int,int,int,int)
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                int cppArg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);
                int cppArg3 = Shiboken::Converter<int >::toCpp(pyargs[3]);
                int cppArg4 = Shiboken::Converter<int >::toCpp(pyargs[4]);
                int cppArg5 = Shiboken::Converter<int >::toCpp(pyargs[5]);

                if(!PyErr_Occurred()) {
                    // drawArc(int,int,int,int,int,int)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->drawArc(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QPainterFunc_drawArc_TypeError:
        const char* overloads[] = {"PySide.QtCore.QRect, int, int", "PySide.QtCore.QRectF, int, int", "int, int, int, int, int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPainter.drawArc", overloads);
        return 0;
}

static PyObject* Sbk_QPainterFunc_drawChord(PyObject* self, PyObject* args)
{
    QPainter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPainter* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs == 4 || numArgs == 5)
        goto Sbk_QPainterFunc_drawChord_TypeError;

    if (!PyArg_UnpackTuple(args, "drawChord", 3, 6, &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3]), &(pyargs[4]), &(pyargs[5])))
        return 0;


    // Overloaded function decisor
    // 0: drawChord(QRect,int,int)
    // 1: drawChord(QRectF,int,int)
    // 2: drawChord(int,int,int,int,int,int)
    if (numArgs == 6 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2]) && SbkNumber_Check(pyargs[3]) && SbkNumber_Check(pyargs[4]) && SbkNumber_Check(pyargs[5])) {
        overloadId = 2; // drawChord(int,int,int,int,int,int)
    } else if (numArgs == 3 && Shiboken::Converter< ::QRect >::isConvertible(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
        overloadId = 0; // drawChord(QRect,int,int)
    } else if (numArgs == 3 && Shiboken::Converter< ::QRectF >::isConvertible(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
        overloadId = 1; // drawChord(QRectF,int,int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPainterFunc_drawChord_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // drawChord(QRect,int,int)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QRect cppArg0 = Shiboken::Converter<QRect >::toCpp(pyargs[0]);
                int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                int cppArg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                    // drawChord(QRect,int,int)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->drawChord(cppArg0, cppArg1, cppArg2);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // drawChord(QRectF,int,int)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QRectF cppArg0 = Shiboken::Converter<QRectF >::toCpp(pyargs[0]);
                int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                int cppArg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                    // drawChord(QRectF,int,int)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->drawChord(cppArg0, cppArg1, cppArg2);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 2: // drawChord(int,int,int,int,int,int)
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                int cppArg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);
                int cppArg3 = Shiboken::Converter<int >::toCpp(pyargs[3]);
                int cppArg4 = Shiboken::Converter<int >::toCpp(pyargs[4]);
                int cppArg5 = Shiboken::Converter<int >::toCpp(pyargs[5]);

                if(!PyErr_Occurred()) {
                    // drawChord(int,int,int,int,int,int)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->drawChord(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QPainterFunc_drawChord_TypeError:
        const char* overloads[] = {"PySide.QtCore.QRect, int, int", "PySide.QtCore.QRectF, int, int", "int, int, int, int, int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPainter.drawChord", overloads);
        return 0;
}

static PyObject* Sbk_QPainterFunc_drawConvexPolygon(PyObject* self, PyObject* arg)
{
    QPainter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPainter* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: drawConvexPolygon(QVector<QPoint>)
    // 1: drawConvexPolygon(QVector<QPointF>)
    // 2: drawConvexPolygon(QPolygon)
    // 3: drawConvexPolygon(QPolygonF)
    if (Shiboken::Converter< ::QVector<QPoint > >::isConvertible(arg)) {
        overloadId = 0; // drawConvexPolygon(QVector<QPoint>)
    } else if (Shiboken::Converter< ::QPolygon >::isConvertible(arg)) {
        overloadId = 2; // drawConvexPolygon(QPolygon)
    } else if (Shiboken::Converter< ::QVector<QPointF > >::isConvertible(arg)) {
        overloadId = 1; // drawConvexPolygon(QVector<QPointF>)
    } else if (Shiboken::Converter< ::QPolygonF >::isConvertible(arg)) {
        overloadId = 3; // drawConvexPolygon(QPolygonF)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPainterFunc_drawConvexPolygon_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // drawConvexPolygon(QVector<QPoint>)
            {
                QVector<QPoint > cppArg0 = Shiboken::Converter<QVector<QPoint > >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // drawConvexPolygon(QVector<QPoint>)
                    // Begin code injection

                    // TEMPLATE - qpainter_drawlist - START
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->drawConvexPolygon(cppArg0.data(), cppArg0.size());
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    // TEMPLATE - qpainter_drawlist - END

                    // End of code injection


                }
                break;
            }
            case 1: // drawConvexPolygon(QVector<QPointF>)
            {
                QVector<QPointF > cppArg0 = Shiboken::Converter<QVector<QPointF > >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // drawConvexPolygon(QVector<QPointF>)
                    // Begin code injection

                    // TEMPLATE - qpainter_drawlist - START
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->drawConvexPolygon(cppArg0.data(), cppArg0.size());
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    // TEMPLATE - qpainter_drawlist - END

                    // End of code injection


                }
                break;
            }
            case 2: // drawConvexPolygon(QPolygon)
            {
                if (!Shiboken::Object::isValid(arg))
                    return 0;
                QPolygon cppArg0 = Shiboken::Converter<QPolygon >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // drawConvexPolygon(QPolygon)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->drawConvexPolygon(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 3: // drawConvexPolygon(QPolygonF)
            {
                if (!Shiboken::Object::isValid(arg))
                    return 0;
                QPolygonF cppArg0 = Shiboken::Converter<QPolygonF >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // drawConvexPolygon(QPolygonF)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->drawConvexPolygon(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QPainterFunc_drawConvexPolygon_TypeError:
        const char* overloads[] = {"list", "list", "PySide.QtGui.QPolygon", "PySide.QtGui.QPolygonF", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPainter.drawConvexPolygon", overloads);
        return 0;
}

static PyObject* Sbk_QPainterFunc_drawEllipse(PyObject* self, PyObject* args)
{
    QPainter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPainter* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs == 2)
        goto Sbk_QPainterFunc_drawEllipse_TypeError;

    if (!PyArg_UnpackTuple(args, "drawEllipse", 1, 4, &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return 0;


    // Overloaded function decisor
    // 0: drawEllipse(QPoint,int,int)
    // 1: drawEllipse(QPointF,qreal,qreal)
    // 2: drawEllipse(QRect)
    // 3: drawEllipse(QRectF)
    // 4: drawEllipse(int,int,int,int)
    if (numArgs == 4 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2]) && SbkNumber_Check(pyargs[3])) {
        overloadId = 4; // drawEllipse(int,int,int,int)
    } else if (numArgs == 1 && Shiboken::Converter< ::QRect >::isConvertible(pyargs[0])) {
        overloadId = 2; // drawEllipse(QRect)
    } else if (numArgs == 1 && Shiboken::Converter< ::QRectF >::isConvertible(pyargs[0])) {
        overloadId = 3; // drawEllipse(QRectF)
    } else if (numArgs == 3 && Shiboken::Converter< ::QPoint >::isConvertible(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
        overloadId = 0; // drawEllipse(QPoint,int,int)
    } else if (numArgs == 3 && Shiboken::Converter< ::QPointF >::isConvertible(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
        overloadId = 1; // drawEllipse(QPointF,qreal,qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPainterFunc_drawEllipse_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // drawEllipse(QPoint,int,int)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QPoint cppArg0 = Shiboken::Converter<QPoint >::toCpp(pyargs[0]);
                int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                int cppArg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                    // drawEllipse(QPoint,int,int)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->drawEllipse(cppArg0, cppArg1, cppArg2);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // drawEllipse(QPointF,qreal,qreal)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QPointF cppArg0 = Shiboken::Converter<QPointF >::toCpp(pyargs[0]);
                qreal cppArg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);
                qreal cppArg2 = Shiboken::Converter<qreal >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                    // drawEllipse(QPointF,qreal,qreal)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->drawEllipse(cppArg0, cppArg1, cppArg2);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 2: // drawEllipse(QRect)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QRect cppArg0 = Shiboken::Converter<QRect >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // drawEllipse(QRect)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->drawEllipse(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 3: // drawEllipse(QRectF)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QRectF cppArg0 = Shiboken::Converter<QRectF >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // drawEllipse(QRectF)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->drawEllipse(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 4: // drawEllipse(int,int,int,int)
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                int cppArg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);
                int cppArg3 = Shiboken::Converter<int >::toCpp(pyargs[3]);

                if(!PyErr_Occurred()) {
                    // drawEllipse(int,int,int,int)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->drawEllipse(cppArg0, cppArg1, cppArg2, cppArg3);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QPainterFunc_drawEllipse_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPoint, int, int", "PySide.QtCore.QPointF, float, float", "PySide.QtCore.QRect", "PySide.QtCore.QRectF", "int, int, int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPainter.drawEllipse", overloads);
        return 0;
}

static PyObject* Sbk_QPainterFunc_drawImage(PyObject* self, PyObject* args, PyObject* kwds)
{
    QPainter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPainter* >::toCpp(self);

    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0, 0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 8) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QPainter.drawImage(): too many arguments");
        return 0;
    } else if (numArgs < 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QPainter.drawImage(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOOOOOOO:drawImage", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3]), &(pyargs[4]), &(pyargs[5]), &(pyargs[6]), &(pyargs[7])))
        return 0;


    // Overloaded function decisor
    // 0: drawImage(QPoint,QImage)
    // 1: drawImage(QPoint,QImage,QRect,QFlags<Qt::ImageConversionFlag>)
    // 2: drawImage(QPointF,QImage)
    // 3: drawImage(QPointF,QImage,QRectF,QFlags<Qt::ImageConversionFlag>)
    // 4: drawImage(QRect,QImage)
    // 5: drawImage(QRect,QImage,QRect,QFlags<Qt::ImageConversionFlag>)
    // 6: drawImage(QRectF,QImage)
    // 7: drawImage(QRectF,QImage,QRectF,QFlags<Qt::ImageConversionFlag>)
    // 8: drawImage(int,int,QImage,int,int,int,int,QFlags<Qt::ImageConversionFlag>)
    if (numArgs >= 3 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && Shiboken::Converter< ::QImage >::isConvertible(pyargs[2])) {
        if (numArgs == 3) {
            overloadId = 8; // drawImage(int,int,QImage,int,int,int,int,QFlags<Qt::ImageConversionFlag>)
        } else if (SbkNumber_Check(pyargs[3])) {
            if (numArgs == 4) {
                overloadId = 8; // drawImage(int,int,QImage,int,int,int,int,QFlags<Qt::ImageConversionFlag>)
            } else if (SbkNumber_Check(pyargs[4])) {
                if (numArgs == 5) {
                    overloadId = 8; // drawImage(int,int,QImage,int,int,int,int,QFlags<Qt::ImageConversionFlag>)
                } else if (SbkNumber_Check(pyargs[5])) {
                    if (numArgs == 6) {
                        overloadId = 8; // drawImage(int,int,QImage,int,int,int,int,QFlags<Qt::ImageConversionFlag>)
                    } else if (SbkNumber_Check(pyargs[6])) {
                        if (numArgs == 7) {
                            overloadId = 8; // drawImage(int,int,QImage,int,int,int,int,QFlags<Qt::ImageConversionFlag>)
                        } else if (Shiboken::Converter< ::QFlags<Qt::ImageConversionFlag> >::isConvertible(pyargs[7])) {
                            overloadId = 8; // drawImage(int,int,QImage,int,int,int,int,QFlags<Qt::ImageConversionFlag>)
                        }
                    }
                }
            }
        }
    } else if (numArgs >= 2 && Shiboken::Converter< ::QRect >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QImage >::isConvertible(pyargs[1])) {
        if (numArgs == 2) {
            overloadId = 4; // drawImage(QRect,QImage)
        } else if (Shiboken::Converter< ::QRect >::isConvertible(pyargs[2])) {
            if (numArgs == 3) {
                overloadId = 5; // drawImage(QRect,QImage,QRect,QFlags<Qt::ImageConversionFlag>)
            } else if (Shiboken::Converter< ::QFlags<Qt::ImageConversionFlag> >::isConvertible(pyargs[3])) {
                overloadId = 5; // drawImage(QRect,QImage,QRect,QFlags<Qt::ImageConversionFlag>)
            }
        }
    } else if (numArgs >= 2 && Shiboken::Converter< ::QRectF >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QImage >::isConvertible(pyargs[1])) {
        if (numArgs == 2) {
            overloadId = 6; // drawImage(QRectF,QImage)
        } else if (Shiboken::Converter< ::QRectF >::isConvertible(pyargs[2])) {
            if (numArgs == 3) {
                overloadId = 7; // drawImage(QRectF,QImage,QRectF,QFlags<Qt::ImageConversionFlag>)
            } else if (Shiboken::Converter< ::QFlags<Qt::ImageConversionFlag> >::isConvertible(pyargs[3])) {
                overloadId = 7; // drawImage(QRectF,QImage,QRectF,QFlags<Qt::ImageConversionFlag>)
            }
        }
    } else if (numArgs >= 2 && Shiboken::Converter< ::QPoint >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QImage >::isConvertible(pyargs[1])) {
        if (numArgs == 2) {
            overloadId = 0; // drawImage(QPoint,QImage)
        } else if (Shiboken::Converter< ::QRect >::isConvertible(pyargs[2])) {
            if (numArgs == 3) {
                overloadId = 1; // drawImage(QPoint,QImage,QRect,QFlags<Qt::ImageConversionFlag>)
            } else if (Shiboken::Converter< ::QFlags<Qt::ImageConversionFlag> >::isConvertible(pyargs[3])) {
                overloadId = 1; // drawImage(QPoint,QImage,QRect,QFlags<Qt::ImageConversionFlag>)
            }
        }
    } else if (numArgs >= 2 && Shiboken::Converter< ::QPointF >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QImage >::isConvertible(pyargs[1])) {
        if (numArgs == 2) {
            overloadId = 2; // drawImage(QPointF,QImage)
        } else if (Shiboken::Converter< ::QRectF >::isConvertible(pyargs[2])) {
            if (numArgs == 3) {
                overloadId = 3; // drawImage(QPointF,QImage,QRectF,QFlags<Qt::ImageConversionFlag>)
            } else if (Shiboken::Converter< ::QFlags<Qt::ImageConversionFlag> >::isConvertible(pyargs[3])) {
                overloadId = 3; // drawImage(QPointF,QImage,QRectF,QFlags<Qt::ImageConversionFlag>)
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPainterFunc_drawImage_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // drawImage(QPoint,QImage)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QPoint cppArg0 = Shiboken::Converter<QPoint >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return 0;
                QImage cppArg1 = Shiboken::Converter<QImage >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // drawImage(QPoint,QImage)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->drawImage(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // drawImage(QPoint,QImage,QRect,QFlags<Qt::ImageConversionFlag>)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "flags");
                    if (value) {
                        if (pyargs[3])
                            errorArgName = "flags";
                        else if (Shiboken::Converter< ::QFlags<Qt::ImageConversionFlag> >::isConvertible(value))
                            pyargs[3] = value;
                        else
                            goto Sbk_QPainterFunc_drawImage_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QPainter.drawImage(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QPoint cppArg0 = Shiboken::Converter<QPoint >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return 0;
                QImage cppArg1 = Shiboken::Converter<QImage >::toCpp(pyargs[1]);
                if (!Shiboken::Object::isValid(pyargs[2]))
                    return 0;
                QRect cppArg2 = Shiboken::Converter<QRect >::toCpp(pyargs[2]);
                QFlags<Qt::ImageConversionFlag> cppArg3 = pyargs[3] ? Shiboken::Converter<QFlags<Qt::ImageConversionFlag> >::toCpp(pyargs[3]) : Qt::AutoColor;

                if(!PyErr_Occurred()) {
                    // drawImage(QPoint,QImage,QRect,QFlags<Qt::ImageConversionFlag>)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->drawImage(cppArg0, cppArg1, cppArg2, cppArg3);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 2: // drawImage(QPointF,QImage)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QPointF cppArg0 = Shiboken::Converter<QPointF >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return 0;
                QImage cppArg1 = Shiboken::Converter<QImage >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // drawImage(QPointF,QImage)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->drawImage(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 3: // drawImage(QPointF,QImage,QRectF,QFlags<Qt::ImageConversionFlag>)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "flags");
                    if (value) {
                        if (pyargs[3])
                            errorArgName = "flags";
                        else if (Shiboken::Converter< ::QFlags<Qt::ImageConversionFlag> >::isConvertible(value))
                            pyargs[3] = value;
                        else
                            goto Sbk_QPainterFunc_drawImage_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QPainter.drawImage(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QPointF cppArg0 = Shiboken::Converter<QPointF >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return 0;
                QImage cppArg1 = Shiboken::Converter<QImage >::toCpp(pyargs[1]);
                if (!Shiboken::Object::isValid(pyargs[2]))
                    return 0;
                QRectF cppArg2 = Shiboken::Converter<QRectF >::toCpp(pyargs[2]);
                QFlags<Qt::ImageConversionFlag> cppArg3 = pyargs[3] ? Shiboken::Converter<QFlags<Qt::ImageConversionFlag> >::toCpp(pyargs[3]) : Qt::AutoColor;

                if(!PyErr_Occurred()) {
                    // drawImage(QPointF,QImage,QRectF,QFlags<Qt::ImageConversionFlag>)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->drawImage(cppArg0, cppArg1, cppArg2, cppArg3);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 4: // drawImage(QRect,QImage)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QRect cppArg0 = Shiboken::Converter<QRect >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return 0;
                QImage cppArg1 = Shiboken::Converter<QImage >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // drawImage(QRect,QImage)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->drawImage(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 5: // drawImage(QRect,QImage,QRect,QFlags<Qt::ImageConversionFlag>)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "flags");
                    if (value) {
                        if (pyargs[3])
                            errorArgName = "flags";
                        else if (Shiboken::Converter< ::QFlags<Qt::ImageConversionFlag> >::isConvertible(value))
                            pyargs[3] = value;
                        else
                            goto Sbk_QPainterFunc_drawImage_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QPainter.drawImage(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QRect cppArg0 = Shiboken::Converter<QRect >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return 0;
                QImage cppArg1 = Shiboken::Converter<QImage >::toCpp(pyargs[1]);
                if (!Shiboken::Object::isValid(pyargs[2]))
                    return 0;
                QRect cppArg2 = Shiboken::Converter<QRect >::toCpp(pyargs[2]);
                QFlags<Qt::ImageConversionFlag> cppArg3 = pyargs[3] ? Shiboken::Converter<QFlags<Qt::ImageConversionFlag> >::toCpp(pyargs[3]) : Qt::AutoColor;

                if(!PyErr_Occurred()) {
                    // drawImage(QRect,QImage,QRect,QFlags<Qt::ImageConversionFlag>)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->drawImage(cppArg0, cppArg1, cppArg2, cppArg3);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 6: // drawImage(QRectF,QImage)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QRectF cppArg0 = Shiboken::Converter<QRectF >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return 0;
                QImage cppArg1 = Shiboken::Converter<QImage >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // drawImage(QRectF,QImage)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->drawImage(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 7: // drawImage(QRectF,QImage,QRectF,QFlags<Qt::ImageConversionFlag>)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "flags");
                    if (value) {
                        if (pyargs[3])
                            errorArgName = "flags";
                        else if (Shiboken::Converter< ::QFlags<Qt::ImageConversionFlag> >::isConvertible(value))
                            pyargs[3] = value;
                        else
                            goto Sbk_QPainterFunc_drawImage_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QPainter.drawImage(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QRectF cppArg0 = Shiboken::Converter<QRectF >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return 0;
                QImage cppArg1 = Shiboken::Converter<QImage >::toCpp(pyargs[1]);
                if (!Shiboken::Object::isValid(pyargs[2]))
                    return 0;
                QRectF cppArg2 = Shiboken::Converter<QRectF >::toCpp(pyargs[2]);
                QFlags<Qt::ImageConversionFlag> cppArg3 = pyargs[3] ? Shiboken::Converter<QFlags<Qt::ImageConversionFlag> >::toCpp(pyargs[3]) : Qt::AutoColor;

                if(!PyErr_Occurred()) {
                    // drawImage(QRectF,QImage,QRectF,QFlags<Qt::ImageConversionFlag>)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->drawImage(cppArg0, cppArg1, cppArg2, cppArg3);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 8: // drawImage(int,int,QImage,int,int,int,int,QFlags<Qt::ImageConversionFlag>)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "sx");
                    if (value) {
                        if (pyargs[3])
                            errorArgName = "sx";
                        else if (SbkNumber_Check(value))
                            pyargs[3] = value;
                        else
                            goto Sbk_QPainterFunc_drawImage_TypeError;
                    }
                    value = PyDict_GetItemString(kwds, "sy");
                    if (value) {
                        if (pyargs[4])
                            errorArgName = "sy";
                        else if (SbkNumber_Check(value))
                            pyargs[4] = value;
                        else
                            goto Sbk_QPainterFunc_drawImage_TypeError;
                    }
                    value = PyDict_GetItemString(kwds, "sw");
                    if (value) {
                        if (pyargs[5])
                            errorArgName = "sw";
                        else if (SbkNumber_Check(value))
                            pyargs[5] = value;
                        else
                            goto Sbk_QPainterFunc_drawImage_TypeError;
                    }
                    value = PyDict_GetItemString(kwds, "sh");
                    if (value) {
                        if (pyargs[6])
                            errorArgName = "sh";
                        else if (SbkNumber_Check(value))
                            pyargs[6] = value;
                        else
                            goto Sbk_QPainterFunc_drawImage_TypeError;
                    }
                    value = PyDict_GetItemString(kwds, "flags");
                    if (value) {
                        if (pyargs[7])
                            errorArgName = "flags";
                        else if (Shiboken::Converter< ::QFlags<Qt::ImageConversionFlag> >::isConvertible(value))
                            pyargs[7] = value;
                        else
                            goto Sbk_QPainterFunc_drawImage_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QPainter.drawImage(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                if (!Shiboken::Object::isValid(pyargs[2]))
                    return 0;
                QImage cppArg2 = Shiboken::Converter<QImage >::toCpp(pyargs[2]);
                int cppArg3 = pyargs[3] ? Shiboken::Converter<int >::toCpp(pyargs[3]) : 0;
                int cppArg4 = pyargs[4] ? Shiboken::Converter<int >::toCpp(pyargs[4]) : 0;
                int cppArg5 = pyargs[5] ? Shiboken::Converter<int >::toCpp(pyargs[5]) : -1;
                int cppArg6 = pyargs[6] ? Shiboken::Converter<int >::toCpp(pyargs[6]) : -1;
                QFlags<Qt::ImageConversionFlag> cppArg7 = pyargs[7] ? Shiboken::Converter<QFlags<Qt::ImageConversionFlag> >::toCpp(pyargs[7]) : Qt::AutoColor;

                if(!PyErr_Occurred()) {
                    // drawImage(int,int,QImage,int,int,int,int,QFlags<Qt::ImageConversionFlag>)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->drawImage(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5, cppArg6, cppArg7);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QPainterFunc_drawImage_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPoint, PySide.QtGui.QImage", "PySide.QtCore.QPoint, PySide.QtGui.QImage, PySide.QtCore.QRect, PySide.QtCore.Qt.ImageConversionFlags = Qt.AutoColor", "PySide.QtCore.QPointF, PySide.QtGui.QImage", "PySide.QtCore.QPointF, PySide.QtGui.QImage, PySide.QtCore.QRectF, PySide.QtCore.Qt.ImageConversionFlags = Qt.AutoColor", "PySide.QtCore.QRect, PySide.QtGui.QImage", "PySide.QtCore.QRect, PySide.QtGui.QImage, PySide.QtCore.QRect, PySide.QtCore.Qt.ImageConversionFlags = Qt.AutoColor", "PySide.QtCore.QRectF, PySide.QtGui.QImage", "PySide.QtCore.QRectF, PySide.QtGui.QImage, PySide.QtCore.QRectF, PySide.QtCore.Qt.ImageConversionFlags = Qt.AutoColor", "int, int, PySide.QtGui.QImage, int = 0, int = 0, int = -1, int = -1, PySide.QtCore.Qt.ImageConversionFlags = Qt.AutoColor", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPainter.drawImage", overloads);
        return 0;
}

static PyObject* Sbk_QPainterFunc_drawLine(PyObject* self, PyObject* args)
{
    QPainter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPainter* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs == 3)
        goto Sbk_QPainterFunc_drawLine_TypeError;

    if (!PyArg_UnpackTuple(args, "drawLine", 1, 4, &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return 0;


    // Overloaded function decisor
    // 0: drawLine(QLine)
    // 1: drawLine(QLineF)
    // 2: drawLine(QPoint,QPoint)
    // 3: drawLine(QPointF,QPointF)
    // 4: drawLine(int,int,int,int)
    if (numArgs == 4 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2]) && SbkNumber_Check(pyargs[3])) {
        overloadId = 4; // drawLine(int,int,int,int)
    } else if (numArgs == 2 && Shiboken::Converter< ::QPoint >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QPoint >::isConvertible(pyargs[1])) {
        overloadId = 2; // drawLine(QPoint,QPoint)
    } else if (numArgs == 2 && Shiboken::Converter< ::QPointF >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QPointF >::isConvertible(pyargs[1])) {
        overloadId = 3; // drawLine(QPointF,QPointF)
    } else if (numArgs == 1 && Shiboken::Converter< ::QLine >::isConvertible(pyargs[0])) {
        overloadId = 0; // drawLine(QLine)
    } else if (numArgs == 1 && Shiboken::Converter< ::QLineF >::isConvertible(pyargs[0])) {
        overloadId = 1; // drawLine(QLineF)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPainterFunc_drawLine_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // drawLine(QLine)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QLine cppArg0 = Shiboken::Converter<QLine >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // drawLine(QLine)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->drawLine(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // drawLine(QLineF)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QLineF cppArg0 = Shiboken::Converter<QLineF >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // drawLine(QLineF)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->drawLine(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 2: // drawLine(QPoint,QPoint)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QPoint cppArg0 = Shiboken::Converter<QPoint >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return 0;
                QPoint cppArg1 = Shiboken::Converter<QPoint >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // drawLine(QPoint,QPoint)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->drawLine(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 3: // drawLine(QPointF,QPointF)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QPointF cppArg0 = Shiboken::Converter<QPointF >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return 0;
                QPointF cppArg1 = Shiboken::Converter<QPointF >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // drawLine(QPointF,QPointF)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->drawLine(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 4: // drawLine(int,int,int,int)
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                int cppArg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);
                int cppArg3 = Shiboken::Converter<int >::toCpp(pyargs[3]);

                if(!PyErr_Occurred()) {
                    // drawLine(int,int,int,int)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->drawLine(cppArg0, cppArg1, cppArg2, cppArg3);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QPainterFunc_drawLine_TypeError:
        const char* overloads[] = {"PySide.QtCore.QLine", "PySide.QtCore.QLineF", "PySide.QtCore.QPoint, PySide.QtCore.QPoint", "PySide.QtCore.QPointF, PySide.QtCore.QPointF", "int, int, int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPainter.drawLine", overloads);
        return 0;
}

static PyObject* Sbk_QPainterFunc_drawLines(PyObject* self, PyObject* arg)
{
    QPainter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPainter* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: drawLines(QVector<QLine>)
    // 1: drawLines(QVector<QLineF>)
    // 2: drawLines(QVector<QPoint>)
    // 3: drawLines(QVector<QPointF>)
    if (Shiboken::Converter< ::QVector<QPoint > >::isConvertible(arg)) {
        overloadId = 2; // drawLines(QVector<QPoint>)
    } else if (Shiboken::Converter< ::QVector<QPointF > >::isConvertible(arg)) {
        overloadId = 3; // drawLines(QVector<QPointF>)
    } else if (Shiboken::Converter< ::QVector<QLine > >::isConvertible(arg)) {
        overloadId = 0; // drawLines(QVector<QLine>)
    } else if (Shiboken::Converter< ::QVector<QLineF > >::isConvertible(arg)) {
        overloadId = 1; // drawLines(QVector<QLineF>)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPainterFunc_drawLines_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // drawLines(QVector<QLine>)
            {
                QVector<QLine > cppArg0 = Shiboken::Converter<QVector<QLine > >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // drawLines(QVector<QLine>)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->drawLines(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // drawLines(QVector<QLineF>)
            {
                QVector<QLineF > cppArg0 = Shiboken::Converter<QVector<QLineF > >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // drawLines(QVector<QLineF>)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->drawLines(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 2: // drawLines(QVector<QPoint>)
            {
                QVector<QPoint > cppArg0 = Shiboken::Converter<QVector<QPoint > >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // drawLines(QVector<QPoint>)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->drawLines(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 3: // drawLines(QVector<QPointF>)
            {
                QVector<QPointF > cppArg0 = Shiboken::Converter<QVector<QPointF > >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // drawLines(QVector<QPointF>)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->drawLines(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QPainterFunc_drawLines_TypeError:
        const char* overloads[] = {"list", "list", "list", "list", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPainter.drawLines", overloads);
        return 0;
}

static PyObject* Sbk_QPainterFunc_drawPath(PyObject* self, PyObject* arg)
{
    QPainter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPainter* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: drawPath(QPainterPath)
    if (Shiboken::Converter< ::QPainterPath >::isConvertible(arg)) {
        overloadId = 0; // drawPath(QPainterPath)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPainterFunc_drawPath_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QPainterPath cppArg0 = Shiboken::Converter<QPainterPath >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // drawPath(QPainterPath)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->drawPath(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QPainterFunc_drawPath_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPainterPath", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPainter.drawPath", overloads);
        return 0;
}

static PyObject* Sbk_QPainterFunc_drawPicture(PyObject* self, PyObject* args)
{
    QPainter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPainter* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "drawPicture", 2, 3, &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: drawPicture(QPoint,QPicture)
    // 1: drawPicture(QPointF,QPicture)
    // 2: drawPicture(int,int,QPicture)
    if (numArgs == 3 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && Shiboken::Converter< ::QPicture >::isConvertible(pyargs[2])) {
        overloadId = 2; // drawPicture(int,int,QPicture)
    } else if (numArgs == 2 && Shiboken::Converter< ::QPoint >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QPicture >::isConvertible(pyargs[1])) {
        overloadId = 0; // drawPicture(QPoint,QPicture)
    } else if (numArgs == 2 && Shiboken::Converter< ::QPointF >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QPicture >::isConvertible(pyargs[1])) {
        overloadId = 1; // drawPicture(QPointF,QPicture)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPainterFunc_drawPicture_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // drawPicture(QPoint,QPicture)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QPoint cppArg0 = Shiboken::Converter<QPoint >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return 0;
                QPicture cppArg1 = Shiboken::Converter<QPicture >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // drawPicture(QPoint,QPicture)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->drawPicture(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // drawPicture(QPointF,QPicture)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QPointF cppArg0 = Shiboken::Converter<QPointF >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return 0;
                QPicture cppArg1 = Shiboken::Converter<QPicture >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // drawPicture(QPointF,QPicture)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->drawPicture(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 2: // drawPicture(int,int,QPicture)
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                if (!Shiboken::Object::isValid(pyargs[2]))
                    return 0;
                QPicture cppArg2 = Shiboken::Converter<QPicture >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                    // drawPicture(int,int,QPicture)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->drawPicture(cppArg0, cppArg1, cppArg2);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QPainterFunc_drawPicture_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPoint, PySide.QtGui.QPicture", "PySide.QtCore.QPointF, PySide.QtGui.QPicture", "int, int, PySide.QtGui.QPicture", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPainter.drawPicture", overloads);
        return 0;
}

static PyObject* Sbk_QPainterFunc_drawPie(PyObject* self, PyObject* args)
{
    QPainter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPainter* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs == 4 || numArgs == 5)
        goto Sbk_QPainterFunc_drawPie_TypeError;

    if (!PyArg_UnpackTuple(args, "drawPie", 3, 6, &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3]), &(pyargs[4]), &(pyargs[5])))
        return 0;


    // Overloaded function decisor
    // 0: drawPie(QRect,int,int)
    // 1: drawPie(QRectF,int,int)
    // 2: drawPie(int,int,int,int,int,int)
    if (numArgs == 6 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2]) && SbkNumber_Check(pyargs[3]) && SbkNumber_Check(pyargs[4]) && SbkNumber_Check(pyargs[5])) {
        overloadId = 2; // drawPie(int,int,int,int,int,int)
    } else if (numArgs == 3 && Shiboken::Converter< ::QRect >::isConvertible(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
        overloadId = 0; // drawPie(QRect,int,int)
    } else if (numArgs == 3 && Shiboken::Converter< ::QRectF >::isConvertible(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
        overloadId = 1; // drawPie(QRectF,int,int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPainterFunc_drawPie_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // drawPie(QRect,int,int)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QRect cppArg0 = Shiboken::Converter<QRect >::toCpp(pyargs[0]);
                int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                int cppArg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                    // drawPie(QRect,int,int)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->drawPie(cppArg0, cppArg1, cppArg2);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // drawPie(QRectF,int,int)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QRectF cppArg0 = Shiboken::Converter<QRectF >::toCpp(pyargs[0]);
                int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                int cppArg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                    // drawPie(QRectF,int,int)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->drawPie(cppArg0, cppArg1, cppArg2);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 2: // drawPie(int,int,int,int,int,int)
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                int cppArg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);
                int cppArg3 = Shiboken::Converter<int >::toCpp(pyargs[3]);
                int cppArg4 = Shiboken::Converter<int >::toCpp(pyargs[4]);
                int cppArg5 = Shiboken::Converter<int >::toCpp(pyargs[5]);

                if(!PyErr_Occurred()) {
                    // drawPie(int,int,int,int,int,int)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->drawPie(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QPainterFunc_drawPie_TypeError:
        const char* overloads[] = {"PySide.QtCore.QRect, int, int", "PySide.QtCore.QRectF, int, int", "int, int, int, int, int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPainter.drawPie", overloads);
        return 0;
}

static PyObject* Sbk_QPainterFunc_drawPixmap(PyObject* self, PyObject* args)
{
    QPainter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPainter* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0, 0, 0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs == 4 || numArgs == 6 || numArgs == 8)
        goto Sbk_QPainterFunc_drawPixmap_TypeError;

    if (!PyArg_UnpackTuple(args, "drawPixmap", 2, 9, &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3]), &(pyargs[4]), &(pyargs[5]), &(pyargs[6]), &(pyargs[7]), &(pyargs[8])))
        return 0;


    // Overloaded function decisor
    // 0: drawPixmap(QPoint,QPixmap)
    // 1: drawPixmap(QPoint,QPixmap,QRect)
    // 2: drawPixmap(QPointF,QPixmap)
    // 3: drawPixmap(QPointF,QPixmap,QRectF)
    // 4: drawPixmap(QRect,QPixmap)
    // 5: drawPixmap(QRect,QPixmap,QRect)
    // 6: drawPixmap(QRectF,QPixmap,QRectF)
    // 7: drawPixmap(int,int,QPixmap)
    // 8: drawPixmap(int,int,QPixmap,int,int,int,int)
    // 9: drawPixmap(int,int,int,int,QPixmap)
    // 10: drawPixmap(int,int,int,int,QPixmap,int,int,int,int)
    if (numArgs >= 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        if (numArgs >= 5 && SbkNumber_Check(pyargs[2]) && SbkNumber_Check(pyargs[3]) && Shiboken::Converter< ::QPixmap >::isConvertible(pyargs[4])) {
            if (numArgs == 5) {
                overloadId = 9; // drawPixmap(int,int,int,int,QPixmap)
            } else if (numArgs == 9 && SbkNumber_Check(pyargs[5]) && SbkNumber_Check(pyargs[6]) && SbkNumber_Check(pyargs[7]) && SbkNumber_Check(pyargs[8])) {
                overloadId = 10; // drawPixmap(int,int,int,int,QPixmap,int,int,int,int)
            }
        } else if (Shiboken::Converter< ::QPixmap >::isConvertible(pyargs[2])) {
            if (numArgs == 3) {
                overloadId = 7; // drawPixmap(int,int,QPixmap)
            } else if (numArgs == 7 && SbkNumber_Check(pyargs[3]) && SbkNumber_Check(pyargs[4]) && SbkNumber_Check(pyargs[5]) && SbkNumber_Check(pyargs[6])) {
                overloadId = 8; // drawPixmap(int,int,QPixmap,int,int,int,int)
            }
        }
    } else if (numArgs >= 2 && Shiboken::Converter< ::QRect >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QPixmap >::isConvertible(pyargs[1])) {
        if (numArgs == 2) {
            overloadId = 4; // drawPixmap(QRect,QPixmap)
        } else if (numArgs == 3 && Shiboken::Converter< ::QRect >::isConvertible(pyargs[2])) {
            overloadId = 5; // drawPixmap(QRect,QPixmap,QRect)
        }
    } else if (numArgs == 3 && Shiboken::Converter< ::QRectF >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QPixmap >::isConvertible(pyargs[1]) && Shiboken::Converter< ::QRectF >::isConvertible(pyargs[2])) {
        overloadId = 6; // drawPixmap(QRectF,QPixmap,QRectF)
    } else if (numArgs >= 2 && Shiboken::Converter< ::QPoint >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QPixmap >::isConvertible(pyargs[1])) {
        if (numArgs == 2) {
            overloadId = 0; // drawPixmap(QPoint,QPixmap)
        } else if (numArgs == 3 && Shiboken::Converter< ::QRect >::isConvertible(pyargs[2])) {
            overloadId = 1; // drawPixmap(QPoint,QPixmap,QRect)
        }
    } else if (numArgs >= 2 && Shiboken::Converter< ::QPointF >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QPixmap >::isConvertible(pyargs[1])) {
        if (numArgs == 2) {
            overloadId = 2; // drawPixmap(QPointF,QPixmap)
        } else if (numArgs == 3 && Shiboken::Converter< ::QRectF >::isConvertible(pyargs[2])) {
            overloadId = 3; // drawPixmap(QPointF,QPixmap,QRectF)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPainterFunc_drawPixmap_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // drawPixmap(QPoint,QPixmap)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QPoint cppArg0 = Shiboken::Converter<QPoint >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return 0;
                QPixmap cppArg1 = Shiboken::Converter<QPixmap >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // drawPixmap(QPoint,QPixmap)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->drawPixmap(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // drawPixmap(QPoint,QPixmap,QRect)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QPoint cppArg0 = Shiboken::Converter<QPoint >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return 0;
                QPixmap cppArg1 = Shiboken::Converter<QPixmap >::toCpp(pyargs[1]);
                if (!Shiboken::Object::isValid(pyargs[2]))
                    return 0;
                QRect cppArg2 = Shiboken::Converter<QRect >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                    // drawPixmap(QPoint,QPixmap,QRect)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->drawPixmap(cppArg0, cppArg1, cppArg2);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 2: // drawPixmap(QPointF,QPixmap)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QPointF cppArg0 = Shiboken::Converter<QPointF >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return 0;
                QPixmap cppArg1 = Shiboken::Converter<QPixmap >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // drawPixmap(QPointF,QPixmap)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->drawPixmap(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 3: // drawPixmap(QPointF,QPixmap,QRectF)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QPointF cppArg0 = Shiboken::Converter<QPointF >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return 0;
                QPixmap cppArg1 = Shiboken::Converter<QPixmap >::toCpp(pyargs[1]);
                if (!Shiboken::Object::isValid(pyargs[2]))
                    return 0;
                QRectF cppArg2 = Shiboken::Converter<QRectF >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                    // drawPixmap(QPointF,QPixmap,QRectF)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->drawPixmap(cppArg0, cppArg1, cppArg2);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 4: // drawPixmap(QRect,QPixmap)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QRect cppArg0 = Shiboken::Converter<QRect >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return 0;
                QPixmap cppArg1 = Shiboken::Converter<QPixmap >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // drawPixmap(QRect,QPixmap)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->drawPixmap(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 5: // drawPixmap(QRect,QPixmap,QRect)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QRect cppArg0 = Shiboken::Converter<QRect >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return 0;
                QPixmap cppArg1 = Shiboken::Converter<QPixmap >::toCpp(pyargs[1]);
                if (!Shiboken::Object::isValid(pyargs[2]))
                    return 0;
                QRect cppArg2 = Shiboken::Converter<QRect >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                    // drawPixmap(QRect,QPixmap,QRect)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->drawPixmap(cppArg0, cppArg1, cppArg2);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 6: // drawPixmap(QRectF,QPixmap,QRectF)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QRectF cppArg0 = Shiboken::Converter<QRectF >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return 0;
                QPixmap cppArg1 = Shiboken::Converter<QPixmap >::toCpp(pyargs[1]);
                if (!Shiboken::Object::isValid(pyargs[2]))
                    return 0;
                QRectF cppArg2 = Shiboken::Converter<QRectF >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                    // drawPixmap(QRectF,QPixmap,QRectF)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->drawPixmap(cppArg0, cppArg1, cppArg2);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 7: // drawPixmap(int,int,QPixmap)
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                if (!Shiboken::Object::isValid(pyargs[2]))
                    return 0;
                QPixmap cppArg2 = Shiboken::Converter<QPixmap >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                    // drawPixmap(int,int,QPixmap)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->drawPixmap(cppArg0, cppArg1, cppArg2);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 8: // drawPixmap(int,int,QPixmap,int,int,int,int)
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                if (!Shiboken::Object::isValid(pyargs[2]))
                    return 0;
                QPixmap cppArg2 = Shiboken::Converter<QPixmap >::toCpp(pyargs[2]);
                int cppArg3 = Shiboken::Converter<int >::toCpp(pyargs[3]);
                int cppArg4 = Shiboken::Converter<int >::toCpp(pyargs[4]);
                int cppArg5 = Shiboken::Converter<int >::toCpp(pyargs[5]);
                int cppArg6 = Shiboken::Converter<int >::toCpp(pyargs[6]);

                if(!PyErr_Occurred()) {
                    // drawPixmap(int,int,QPixmap,int,int,int,int)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->drawPixmap(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5, cppArg6);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 9: // drawPixmap(int,int,int,int,QPixmap)
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                int cppArg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);
                int cppArg3 = Shiboken::Converter<int >::toCpp(pyargs[3]);
                if (!Shiboken::Object::isValid(pyargs[4]))
                    return 0;
                QPixmap cppArg4 = Shiboken::Converter<QPixmap >::toCpp(pyargs[4]);

                if(!PyErr_Occurred()) {
                    // drawPixmap(int,int,int,int,QPixmap)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->drawPixmap(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 10: // drawPixmap(int,int,int,int,QPixmap,int,int,int,int)
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                int cppArg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);
                int cppArg3 = Shiboken::Converter<int >::toCpp(pyargs[3]);
                if (!Shiboken::Object::isValid(pyargs[4]))
                    return 0;
                QPixmap cppArg4 = Shiboken::Converter<QPixmap >::toCpp(pyargs[4]);
                int cppArg5 = Shiboken::Converter<int >::toCpp(pyargs[5]);
                int cppArg6 = Shiboken::Converter<int >::toCpp(pyargs[6]);
                int cppArg7 = Shiboken::Converter<int >::toCpp(pyargs[7]);
                int cppArg8 = Shiboken::Converter<int >::toCpp(pyargs[8]);

                if(!PyErr_Occurred()) {
                    // drawPixmap(int,int,int,int,QPixmap,int,int,int,int)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->drawPixmap(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5, cppArg6, cppArg7, cppArg8);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QPainterFunc_drawPixmap_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPoint, PySide.QtGui.QPixmap", "PySide.QtCore.QPoint, PySide.QtGui.QPixmap, PySide.QtCore.QRect", "PySide.QtCore.QPointF, PySide.QtGui.QPixmap", "PySide.QtCore.QPointF, PySide.QtGui.QPixmap, PySide.QtCore.QRectF", "PySide.QtCore.QRect, PySide.QtGui.QPixmap", "PySide.QtCore.QRect, PySide.QtGui.QPixmap, PySide.QtCore.QRect", "PySide.QtCore.QRectF, PySide.QtGui.QPixmap, PySide.QtCore.QRectF", "int, int, PySide.QtGui.QPixmap", "int, int, PySide.QtGui.QPixmap, int, int, int, int", "int, int, int, int, PySide.QtGui.QPixmap", "int, int, int, int, PySide.QtGui.QPixmap, int, int, int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPainter.drawPixmap", overloads);
        return 0;
}

static PyObject* Sbk_QPainterFunc_drawPoint(PyObject* self, PyObject* args)
{
    QPainter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPainter* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "drawPoint", 1, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: drawPoint(QPoint)
    // 1: drawPoint(QPointF)
    // 2: drawPoint(int,int)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 2; // drawPoint(int,int)
    } else if (numArgs == 1 && Shiboken::Converter< ::QPoint >::isConvertible(pyargs[0])) {
        overloadId = 0; // drawPoint(QPoint)
    } else if (numArgs == 1 && Shiboken::Converter< ::QPointF >::isConvertible(pyargs[0])) {
        overloadId = 1; // drawPoint(QPointF)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPainterFunc_drawPoint_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // drawPoint(QPoint)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QPoint cppArg0 = Shiboken::Converter<QPoint >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // drawPoint(QPoint)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->drawPoint(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // drawPoint(QPointF)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QPointF cppArg0 = Shiboken::Converter<QPointF >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // drawPoint(QPointF)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->drawPoint(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 2: // drawPoint(int,int)
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // drawPoint(int,int)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->drawPoint(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QPainterFunc_drawPoint_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPoint", "PySide.QtCore.QPointF", "int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPainter.drawPoint", overloads);
        return 0;
}

static PyObject* Sbk_QPainterFunc_drawPoints(PyObject* self, PyObject* arg)
{
    QPainter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPainter* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: drawPoints(QVector<QPoint>)
    // 1: drawPoints(QVector<QPointF>)
    // 2: drawPoints(QPolygon)
    // 3: drawPoints(QPolygonF)
    if (Shiboken::Converter< ::QVector<QPoint > >::isConvertible(arg)) {
        overloadId = 0; // drawPoints(QVector<QPoint>)
    } else if (Shiboken::Converter< ::QPolygon >::isConvertible(arg)) {
        overloadId = 2; // drawPoints(QPolygon)
    } else if (Shiboken::Converter< ::QVector<QPointF > >::isConvertible(arg)) {
        overloadId = 1; // drawPoints(QVector<QPointF>)
    } else if (Shiboken::Converter< ::QPolygonF >::isConvertible(arg)) {
        overloadId = 3; // drawPoints(QPolygonF)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPainterFunc_drawPoints_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // drawPoints(QVector<QPoint>)
            {
                QVector<QPoint > cppArg0 = Shiboken::Converter<QVector<QPoint > >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // drawPoints(QVector<QPoint>)
                    // Begin code injection

                    // TEMPLATE - qpainter_drawlist - START
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->drawPoints(cppArg0.data(), cppArg0.size());
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    // TEMPLATE - qpainter_drawlist - END

                    // End of code injection


                }
                break;
            }
            case 1: // drawPoints(QVector<QPointF>)
            {
                QVector<QPointF > cppArg0 = Shiboken::Converter<QVector<QPointF > >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // drawPoints(QVector<QPointF>)
                    // Begin code injection

                    // TEMPLATE - qpainter_drawlist - START
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->drawPoints(cppArg0.data(), cppArg0.size());
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    // TEMPLATE - qpainter_drawlist - END

                    // End of code injection


                }
                break;
            }
            case 2: // drawPoints(QPolygon)
            {
                if (!Shiboken::Object::isValid(arg))
                    return 0;
                QPolygon cppArg0 = Shiboken::Converter<QPolygon >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // drawPoints(QPolygon)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->drawPoints(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 3: // drawPoints(QPolygonF)
            {
                if (!Shiboken::Object::isValid(arg))
                    return 0;
                QPolygonF cppArg0 = Shiboken::Converter<QPolygonF >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // drawPoints(QPolygonF)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->drawPoints(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QPainterFunc_drawPoints_TypeError:
        const char* overloads[] = {"list", "list", "PySide.QtGui.QPolygon", "PySide.QtGui.QPolygonF", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPainter.drawPoints", overloads);
        return 0;
}

static PyObject* Sbk_QPainterFunc_drawPolygon(PyObject* self, PyObject* args, PyObject* kwds)
{
    QPainter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPainter* >::toCpp(self);

    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QPainter.drawPolygon(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QPainter.drawPolygon(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:drawPolygon", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: drawPolygon(QVector<QPoint>,Qt::FillRule)
    // 1: drawPolygon(QVector<QPointF>,Qt::FillRule)
    // 2: drawPolygon(QPolygon,Qt::FillRule)
    // 3: drawPolygon(QPolygonF,Qt::FillRule)
    if (numArgs == 2 && Shiboken::Converter< ::QVector<QPoint > >::isConvertible(pyargs[0]) && Shiboken::Converter< ::Qt::FillRule >::isConvertible(pyargs[1])) {
        overloadId = 0; // drawPolygon(QVector<QPoint>,Qt::FillRule)
    } else if (Shiboken::Converter< ::QPolygon >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 2; // drawPolygon(QPolygon,Qt::FillRule)
        } else if (Shiboken::Converter< ::Qt::FillRule >::isConvertible(pyargs[1])) {
            overloadId = 2; // drawPolygon(QPolygon,Qt::FillRule)
        }
    } else if (numArgs == 2 && Shiboken::Converter< ::QVector<QPointF > >::isConvertible(pyargs[0]) && Shiboken::Converter< ::Qt::FillRule >::isConvertible(pyargs[1])) {
        overloadId = 1; // drawPolygon(QVector<QPointF>,Qt::FillRule)
    } else if (Shiboken::Converter< ::QPolygonF >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 3; // drawPolygon(QPolygonF,Qt::FillRule)
        } else if (Shiboken::Converter< ::Qt::FillRule >::isConvertible(pyargs[1])) {
            overloadId = 3; // drawPolygon(QPolygonF,Qt::FillRule)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPainterFunc_drawPolygon_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // drawPolygon(QVector<QPoint>,Qt::FillRule)
            {
                QVector<QPoint > cppArg0 = Shiboken::Converter<QVector<QPoint > >::toCpp(pyargs[0]);
                Qt::FillRule cppArg1 = Shiboken::Converter<Qt::FillRule >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // drawPolygon(QVector<QPoint>,Qt::FillRule)
                    // Begin code injection

                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->drawPolygon(cppArg0.data(), cppArg0.size(), cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS

                    // End of code injection


                }
                break;
            }
            case 1: // drawPolygon(QVector<QPointF>,Qt::FillRule)
            {
                QVector<QPointF > cppArg0 = Shiboken::Converter<QVector<QPointF > >::toCpp(pyargs[0]);
                Qt::FillRule cppArg1 = Shiboken::Converter<Qt::FillRule >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // drawPolygon(QVector<QPointF>,Qt::FillRule)
                    // Begin code injection

                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->drawPolygon(cppArg0.data(), cppArg0.size(), cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS

                    // End of code injection


                }
                break;
            }
            case 2: // drawPolygon(QPolygon,Qt::FillRule)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "fillRule");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "fillRule";
                        else if (Shiboken::Converter< ::Qt::FillRule >::isConvertible(value))
                            pyargs[1] = value;
                        else
                            goto Sbk_QPainterFunc_drawPolygon_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QPainter.drawPolygon(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QPolygon cppArg0 = Shiboken::Converter<QPolygon >::toCpp(pyargs[0]);
                Qt::FillRule cppArg1 = pyargs[1] ? Shiboken::Converter<Qt::FillRule >::toCpp(pyargs[1]) : Qt::OddEvenFill;

                if(!PyErr_Occurred()) {
                    // drawPolygon(QPolygon,Qt::FillRule)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->drawPolygon(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 3: // drawPolygon(QPolygonF,Qt::FillRule)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "fillRule");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "fillRule";
                        else if (Shiboken::Converter< ::Qt::FillRule >::isConvertible(value))
                            pyargs[1] = value;
                        else
                            goto Sbk_QPainterFunc_drawPolygon_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QPainter.drawPolygon(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QPolygonF cppArg0 = Shiboken::Converter<QPolygonF >::toCpp(pyargs[0]);
                Qt::FillRule cppArg1 = pyargs[1] ? Shiboken::Converter<Qt::FillRule >::toCpp(pyargs[1]) : Qt::OddEvenFill;

                if(!PyErr_Occurred()) {
                    // drawPolygon(QPolygonF,Qt::FillRule)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->drawPolygon(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QPainterFunc_drawPolygon_TypeError:
        const char* overloads[] = {"list, PySide.QtCore.Qt.FillRule", "list, PySide.QtCore.Qt.FillRule", "PySide.QtGui.QPolygon, PySide.QtCore.Qt.FillRule = Qt.OddEvenFill", "PySide.QtGui.QPolygonF, PySide.QtCore.Qt.FillRule = Qt.OddEvenFill", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPainter.drawPolygon", overloads);
        return 0;
}

static PyObject* Sbk_QPainterFunc_drawPolyline(PyObject* self, PyObject* arg)
{
    QPainter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPainter* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: drawPolyline(QVector<QPoint>)
    // 1: drawPolyline(QVector<QPointF>)
    // 2: drawPolyline(QPolygon)
    // 3: drawPolyline(QPolygonF)
    if (Shiboken::Converter< ::QVector<QPoint > >::isConvertible(arg)) {
        overloadId = 0; // drawPolyline(QVector<QPoint>)
    } else if (Shiboken::Converter< ::QPolygon >::isConvertible(arg)) {
        overloadId = 2; // drawPolyline(QPolygon)
    } else if (Shiboken::Converter< ::QVector<QPointF > >::isConvertible(arg)) {
        overloadId = 1; // drawPolyline(QVector<QPointF>)
    } else if (Shiboken::Converter< ::QPolygonF >::isConvertible(arg)) {
        overloadId = 3; // drawPolyline(QPolygonF)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPainterFunc_drawPolyline_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // drawPolyline(QVector<QPoint>)
            {
                QVector<QPoint > cppArg0 = Shiboken::Converter<QVector<QPoint > >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // drawPolyline(QVector<QPoint>)
                    // Begin code injection

                    // TEMPLATE - qpainter_drawlist - START
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->drawPolyline(cppArg0.data(), cppArg0.size());
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    // TEMPLATE - qpainter_drawlist - END

                    // End of code injection


                }
                break;
            }
            case 1: // drawPolyline(QVector<QPointF>)
            {
                QVector<QPointF > cppArg0 = Shiboken::Converter<QVector<QPointF > >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // drawPolyline(QVector<QPointF>)
                    // Begin code injection

                    // TEMPLATE - qpainter_drawlist - START
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->drawPolyline(cppArg0.data(), cppArg0.size());
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    // TEMPLATE - qpainter_drawlist - END

                    // End of code injection


                }
                break;
            }
            case 2: // drawPolyline(QPolygon)
            {
                if (!Shiboken::Object::isValid(arg))
                    return 0;
                QPolygon cppArg0 = Shiboken::Converter<QPolygon >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // drawPolyline(QPolygon)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->drawPolyline(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 3: // drawPolyline(QPolygonF)
            {
                if (!Shiboken::Object::isValid(arg))
                    return 0;
                QPolygonF cppArg0 = Shiboken::Converter<QPolygonF >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // drawPolyline(QPolygonF)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->drawPolyline(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QPainterFunc_drawPolyline_TypeError:
        const char* overloads[] = {"list", "list", "PySide.QtGui.QPolygon", "PySide.QtGui.QPolygonF", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPainter.drawPolyline", overloads);
        return 0;
}

static PyObject* Sbk_QPainterFunc_drawRect(PyObject* self, PyObject* args)
{
    QPainter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPainter* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs == 2 || numArgs == 3)
        goto Sbk_QPainterFunc_drawRect_TypeError;

    if (!PyArg_UnpackTuple(args, "drawRect", 1, 4, &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return 0;


    // Overloaded function decisor
    // 0: drawRect(QRect)
    // 1: drawRect(QRectF)
    // 2: drawRect(int,int,int,int)
    if (numArgs == 4 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2]) && SbkNumber_Check(pyargs[3])) {
        overloadId = 2; // drawRect(int,int,int,int)
    } else if (numArgs == 1 && Shiboken::Converter< ::QRect >::isConvertible(pyargs[0])) {
        overloadId = 0; // drawRect(QRect)
    } else if (numArgs == 1 && Shiboken::Converter< ::QRectF >::isConvertible(pyargs[0])) {
        overloadId = 1; // drawRect(QRectF)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPainterFunc_drawRect_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // drawRect(QRect)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QRect cppArg0 = Shiboken::Converter<QRect >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // drawRect(QRect)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->drawRect(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // drawRect(QRectF)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QRectF cppArg0 = Shiboken::Converter<QRectF >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // drawRect(QRectF)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->drawRect(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 2: // drawRect(int,int,int,int)
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                int cppArg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);
                int cppArg3 = Shiboken::Converter<int >::toCpp(pyargs[3]);

                if(!PyErr_Occurred()) {
                    // drawRect(int,int,int,int)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->drawRect(cppArg0, cppArg1, cppArg2, cppArg3);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QPainterFunc_drawRect_TypeError:
        const char* overloads[] = {"PySide.QtCore.QRect", "PySide.QtCore.QRectF", "int, int, int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPainter.drawRect", overloads);
        return 0;
}

static PyObject* Sbk_QPainterFunc_drawRects(PyObject* self, PyObject* arg)
{
    QPainter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPainter* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: drawRects(QVector<QRect>)
    // 1: drawRects(QVector<QRectF>)
    if (Shiboken::Converter< ::QVector<QRect > >::isConvertible(arg)) {
        overloadId = 0; // drawRects(QVector<QRect>)
    } else if (Shiboken::Converter< ::QVector<QRectF > >::isConvertible(arg)) {
        overloadId = 1; // drawRects(QVector<QRectF>)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPainterFunc_drawRects_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // drawRects(QVector<QRect>)
            {
                QVector<QRect > cppArg0 = Shiboken::Converter<QVector<QRect > >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // drawRects(QVector<QRect>)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->drawRects(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // drawRects(QVector<QRectF>)
            {
                QVector<QRectF > cppArg0 = Shiboken::Converter<QVector<QRectF > >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // drawRects(QVector<QRectF>)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->drawRects(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QPainterFunc_drawRects_TypeError:
        const char* overloads[] = {"list", "list", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPainter.drawRects", overloads);
        return 0;
}

static PyObject* Sbk_QPainterFunc_drawRoundRect(PyObject* self, PyObject* args, PyObject* kwds)
{
    QPainter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPainter* >::toCpp(self);

    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 6) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QPainter.drawRoundRect(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QPainter.drawRoundRect(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOOOOO:drawRoundRect", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3]), &(pyargs[4]), &(pyargs[5])))
        return 0;


    // Overloaded function decisor
    // 0: drawRoundRect(QRect,int,int)
    // 1: drawRoundRect(QRectF,int,int)
    // 2: drawRoundRect(int,int,int,int,int,int)
    if (numArgs >= 4 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2]) && SbkNumber_Check(pyargs[3])) {
        if (numArgs == 4) {
            overloadId = 2; // drawRoundRect(int,int,int,int,int,int)
        } else if (SbkNumber_Check(pyargs[4])) {
            if (numArgs == 5) {
                overloadId = 2; // drawRoundRect(int,int,int,int,int,int)
            } else if (SbkNumber_Check(pyargs[5])) {
                overloadId = 2; // drawRoundRect(int,int,int,int,int,int)
            }
        }
    } else if (Shiboken::Converter< ::QRect >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // drawRoundRect(QRect,int,int)
        } else if (SbkNumber_Check(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 0; // drawRoundRect(QRect,int,int)
            } else if (SbkNumber_Check(pyargs[2])) {
                overloadId = 0; // drawRoundRect(QRect,int,int)
            }
        }
    } else if (Shiboken::Converter< ::QRectF >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 1; // drawRoundRect(QRectF,int,int)
        } else if (SbkNumber_Check(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 1; // drawRoundRect(QRectF,int,int)
            } else if (SbkNumber_Check(pyargs[2])) {
                overloadId = 1; // drawRoundRect(QRectF,int,int)
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPainterFunc_drawRoundRect_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // drawRoundRect(QRect,int,int)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "xround");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "xround";
                        else if (SbkNumber_Check(value))
                            pyargs[1] = value;
                        else
                            goto Sbk_QPainterFunc_drawRoundRect_TypeError;
                    }
                    value = PyDict_GetItemString(kwds, "yround");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "yround";
                        else if (SbkNumber_Check(value))
                            pyargs[2] = value;
                        else
                            goto Sbk_QPainterFunc_drawRoundRect_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QPainter.drawRoundRect(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QRect cppArg0 = Shiboken::Converter<QRect >::toCpp(pyargs[0]);
                int cppArg1 = pyargs[1] ? Shiboken::Converter<int >::toCpp(pyargs[1]) : 25;
                int cppArg2 = pyargs[2] ? Shiboken::Converter<int >::toCpp(pyargs[2]) : 25;

                if(!PyErr_Occurred()) {
                    // drawRoundRect(QRect,int,int)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->drawRoundRect(cppArg0, cppArg1, cppArg2);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // drawRoundRect(QRectF,int,int)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "xround");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "xround";
                        else if (SbkNumber_Check(value))
                            pyargs[1] = value;
                        else
                            goto Sbk_QPainterFunc_drawRoundRect_TypeError;
                    }
                    value = PyDict_GetItemString(kwds, "yround");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "yround";
                        else if (SbkNumber_Check(value))
                            pyargs[2] = value;
                        else
                            goto Sbk_QPainterFunc_drawRoundRect_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QPainter.drawRoundRect(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QRectF cppArg0 = Shiboken::Converter<QRectF >::toCpp(pyargs[0]);
                int cppArg1 = pyargs[1] ? Shiboken::Converter<int >::toCpp(pyargs[1]) : 25;
                int cppArg2 = pyargs[2] ? Shiboken::Converter<int >::toCpp(pyargs[2]) : 25;

                if(!PyErr_Occurred()) {
                    // drawRoundRect(QRectF,int,int)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->drawRoundRect(cppArg0, cppArg1, cppArg2);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 2: // drawRoundRect(int,int,int,int,int,int)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "xRound");
                    if (value) {
                        if (pyargs[4])
                            errorArgName = "xRound";
                        else if (SbkNumber_Check(value))
                            pyargs[4] = value;
                        else
                            goto Sbk_QPainterFunc_drawRoundRect_TypeError;
                    }
                    value = PyDict_GetItemString(kwds, "yRound");
                    if (value) {
                        if (pyargs[5])
                            errorArgName = "yRound";
                        else if (SbkNumber_Check(value))
                            pyargs[5] = value;
                        else
                            goto Sbk_QPainterFunc_drawRoundRect_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QPainter.drawRoundRect(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                int cppArg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);
                int cppArg3 = Shiboken::Converter<int >::toCpp(pyargs[3]);
                int cppArg4 = pyargs[4] ? Shiboken::Converter<int >::toCpp(pyargs[4]) : 25;
                int cppArg5 = pyargs[5] ? Shiboken::Converter<int >::toCpp(pyargs[5]) : 25;

                if(!PyErr_Occurred()) {
                    // drawRoundRect(int,int,int,int,int,int)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->drawRoundRect(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QPainterFunc_drawRoundRect_TypeError:
        const char* overloads[] = {"PySide.QtCore.QRect, int = 25, int = 25", "PySide.QtCore.QRectF, int = 25, int = 25", "int, int, int, int, int = 25, int = 25", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPainter.drawRoundRect", overloads);
        return 0;
}

static PyObject* Sbk_QPainterFunc_drawRoundedRect(PyObject* self, PyObject* args, PyObject* kwds)
{
    QPainter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPainter* >::toCpp(self);

    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 7) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QPainter.drawRoundedRect(): too many arguments");
        return 0;
    } else if (numArgs < 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QPainter.drawRoundedRect(): not enough arguments");
        return 0;
    } else if (numArgs == 5)
        goto Sbk_QPainterFunc_drawRoundedRect_TypeError;

    if (!PyArg_ParseTuple(args, "|OOOOOOO:drawRoundedRect", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3]), &(pyargs[4]), &(pyargs[5]), &(pyargs[6])))
        return 0;


    // Overloaded function decisor
    // 0: drawRoundedRect(QRect,qreal,qreal,Qt::SizeMode)
    // 1: drawRoundedRect(QRectF,qreal,qreal,Qt::SizeMode)
    // 2: drawRoundedRect(int,int,int,int,qreal,qreal,Qt::SizeMode)
    if (numArgs >= 6 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2]) && SbkNumber_Check(pyargs[3]) && SbkNumber_Check(pyargs[4]) && SbkNumber_Check(pyargs[5])) {
        if (numArgs == 6) {
            overloadId = 2; // drawRoundedRect(int,int,int,int,qreal,qreal,Qt::SizeMode)
        } else if (Shiboken::Converter< ::Qt::SizeMode >::isConvertible(pyargs[6])) {
            overloadId = 2; // drawRoundedRect(int,int,int,int,qreal,qreal,Qt::SizeMode)
        }
    } else if (numArgs >= 3 && Shiboken::Converter< ::QRect >::isConvertible(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
        if (numArgs == 3) {
            overloadId = 0; // drawRoundedRect(QRect,qreal,qreal,Qt::SizeMode)
        } else if (Shiboken::Converter< ::Qt::SizeMode >::isConvertible(pyargs[3])) {
            overloadId = 0; // drawRoundedRect(QRect,qreal,qreal,Qt::SizeMode)
        }
    } else if (numArgs >= 3 && Shiboken::Converter< ::QRectF >::isConvertible(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
        if (numArgs == 3) {
            overloadId = 1; // drawRoundedRect(QRectF,qreal,qreal,Qt::SizeMode)
        } else if (Shiboken::Converter< ::Qt::SizeMode >::isConvertible(pyargs[3])) {
            overloadId = 1; // drawRoundedRect(QRectF,qreal,qreal,Qt::SizeMode)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPainterFunc_drawRoundedRect_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // drawRoundedRect(QRect,qreal,qreal,Qt::SizeMode)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "mode");
                    if (value) {
                        if (pyargs[3])
                            errorArgName = "mode";
                        else if (Shiboken::Converter< ::Qt::SizeMode >::isConvertible(value))
                            pyargs[3] = value;
                        else
                            goto Sbk_QPainterFunc_drawRoundedRect_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QPainter.drawRoundedRect(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QRect cppArg0 = Shiboken::Converter<QRect >::toCpp(pyargs[0]);
                qreal cppArg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);
                qreal cppArg2 = Shiboken::Converter<qreal >::toCpp(pyargs[2]);
                Qt::SizeMode cppArg3 = pyargs[3] ? Shiboken::Converter<Qt::SizeMode >::toCpp(pyargs[3]) : Qt::AbsoluteSize;

                if(!PyErr_Occurred()) {
                    // drawRoundedRect(QRect,qreal,qreal,Qt::SizeMode)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->drawRoundedRect(cppArg0, cppArg1, cppArg2, cppArg3);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // drawRoundedRect(QRectF,qreal,qreal,Qt::SizeMode)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "mode");
                    if (value) {
                        if (pyargs[3])
                            errorArgName = "mode";
                        else if (Shiboken::Converter< ::Qt::SizeMode >::isConvertible(value))
                            pyargs[3] = value;
                        else
                            goto Sbk_QPainterFunc_drawRoundedRect_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QPainter.drawRoundedRect(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QRectF cppArg0 = Shiboken::Converter<QRectF >::toCpp(pyargs[0]);
                qreal cppArg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);
                qreal cppArg2 = Shiboken::Converter<qreal >::toCpp(pyargs[2]);
                Qt::SizeMode cppArg3 = pyargs[3] ? Shiboken::Converter<Qt::SizeMode >::toCpp(pyargs[3]) : Qt::AbsoluteSize;

                if(!PyErr_Occurred()) {
                    // drawRoundedRect(QRectF,qreal,qreal,Qt::SizeMode)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->drawRoundedRect(cppArg0, cppArg1, cppArg2, cppArg3);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 2: // drawRoundedRect(int,int,int,int,qreal,qreal,Qt::SizeMode)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "mode");
                    if (value) {
                        if (pyargs[6])
                            errorArgName = "mode";
                        else if (Shiboken::Converter< ::Qt::SizeMode >::isConvertible(value))
                            pyargs[6] = value;
                        else
                            goto Sbk_QPainterFunc_drawRoundedRect_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QPainter.drawRoundedRect(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                int cppArg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);
                int cppArg3 = Shiboken::Converter<int >::toCpp(pyargs[3]);
                qreal cppArg4 = Shiboken::Converter<qreal >::toCpp(pyargs[4]);
                qreal cppArg5 = Shiboken::Converter<qreal >::toCpp(pyargs[5]);
                Qt::SizeMode cppArg6 = pyargs[6] ? Shiboken::Converter<Qt::SizeMode >::toCpp(pyargs[6]) : Qt::AbsoluteSize;

                if(!PyErr_Occurred()) {
                    // drawRoundedRect(int,int,int,int,qreal,qreal,Qt::SizeMode)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->drawRoundedRect(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5, cppArg6);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QPainterFunc_drawRoundedRect_TypeError:
        const char* overloads[] = {"PySide.QtCore.QRect, float, float, PySide.QtCore.Qt.SizeMode = Qt.AbsoluteSize", "PySide.QtCore.QRectF, float, float, PySide.QtCore.Qt.SizeMode = Qt.AbsoluteSize", "int, int, int, int, float, float, PySide.QtCore.Qt.SizeMode = Qt.AbsoluteSize", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPainter.drawRoundedRect", overloads);
        return 0;
}

static PyObject* Sbk_QPainterFunc_drawText(PyObject* self, PyObject* args, PyObject* kwds)
{
    QPainter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPainter* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 6) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QPainter.drawText(): too many arguments");
        return 0;
    } else if (numArgs < 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QPainter.drawText(): not enough arguments");
        return 0;
    } else if (numArgs == 4 || numArgs == 5)
        goto Sbk_QPainterFunc_drawText_TypeError;

    if (!PyArg_ParseTuple(args, "|OOOOOO:drawText", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3]), &(pyargs[4]), &(pyargs[5])))
        return 0;


    // Overloaded function decisor
    // 0: drawText(QPoint,QString)
    // 1: drawText(QPointF,QString)
    // 2: drawText(QRect,int,QString,QRect*)
    // 3: drawText(QRectF,QString,QTextOption)
    // 4: drawText(QRectF,int,QString,QRectF*)
    // 5: drawText(int,int,QString)
    // 6: drawText(int,int,int,int,int,QString,QRect*)
    if (numArgs >= 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        if (numArgs == 6 && SbkNumber_Check(pyargs[2]) && SbkNumber_Check(pyargs[3]) && SbkNumber_Check(pyargs[4]) && Shiboken::Converter< QString >::isConvertible(pyargs[5])) {
            overloadId = 6; // drawText(int,int,int,int,int,QString,QRect*)
        } else if (numArgs == 3 && Shiboken::Converter< QString >::isConvertible(pyargs[2])) {
            overloadId = 5; // drawText(int,int,QString)
        }
    } else if (numArgs == 3 && Shiboken::Converter< ::QRect >::isConvertible(pyargs[0]) && SbkNumber_Check(pyargs[1]) && Shiboken::Converter< QString >::isConvertible(pyargs[2])) {
        overloadId = 2; // drawText(QRect,int,QString,QRect*)
    } else if (Shiboken::Converter< ::QRectF >::isConvertible(pyargs[0])) {
        if (numArgs == 3 && SbkNumber_Check(pyargs[1]) && Shiboken::Converter< QString >::isConvertible(pyargs[2])) {
            overloadId = 4; // drawText(QRectF,int,QString,QRectF*)
        } else if (Shiboken::Converter< QString >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 3; // drawText(QRectF,QString,QTextOption)
            } else if (Shiboken::Converter< ::QTextOption >::isConvertible(pyargs[2])) {
                overloadId = 3; // drawText(QRectF,QString,QTextOption)
            }
        }
    } else if (numArgs == 2 && Shiboken::Converter< ::QPoint >::isConvertible(pyargs[0]) && Shiboken::Converter< QString >::isConvertible(pyargs[1])) {
        overloadId = 0; // drawText(QPoint,QString)
    } else if (numArgs == 2 && Shiboken::Converter< ::QPointF >::isConvertible(pyargs[0]) && Shiboken::Converter< QString >::isConvertible(pyargs[1])) {
        overloadId = 1; // drawText(QPointF,QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPainterFunc_drawText_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // drawText(QPoint,QString)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QPoint cppArg0 = Shiboken::Converter<QPoint >::toCpp(pyargs[0]);
                QString cppArg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // drawText(QPoint,QString)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->drawText(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Py_None;
                    Py_INCREF(Py_None);
                }
                break;
            }
            case 1: // drawText(QPointF,QString)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QPointF cppArg0 = Shiboken::Converter<QPointF >::toCpp(pyargs[0]);
                QString cppArg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // drawText(QPointF,QString)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->drawText(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Py_None;
                    Py_INCREF(Py_None);
                }
                break;
            }
            case 2: // drawText(QRect,int,QString,QRect*)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QRect cppArg0 = Shiboken::Converter<QRect >::toCpp(pyargs[0]);
                int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                QString cppArg2 = Shiboken::Converter<QString >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                    // drawText(QRect,int,QString,QRect*)
                    // Begin code injection

                    // TEMPLATE - fix_args,QRect* - START
                    QRect rect_;
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->drawText(cppArg0, cppArg1, cppArg2, &rect_);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter<QRect >::toPython(rect_);
                    // TEMPLATE - fix_args,QRect* - END

                    // End of code injection


                }
                break;
            }
            case 3: // drawText(QRectF,QString,QTextOption)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "o");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "o";
                        else if (Shiboken::Converter< ::QTextOption >::isConvertible(value))
                            pyargs[2] = value;
                        else
                            goto Sbk_QPainterFunc_drawText_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QPainter.drawText(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QRectF cppArg0 = Shiboken::Converter<QRectF >::toCpp(pyargs[0]);
                QString cppArg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);
                if (!Shiboken::Object::isValid(pyargs[2]))
                    return 0;
                QTextOption cppArg2_tmp = QTextOption();
                QTextOption cppArg2 = pyargs[2] ? Shiboken::Converter<QTextOption >::toCpp(pyargs[2]) : cppArg2_tmp;

                if(!PyErr_Occurred()) {
                    // drawText(QRectF,QString,QTextOption)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->drawText(cppArg0, cppArg1, cppArg2);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Py_None;
                    Py_INCREF(Py_None);
                }
                break;
            }
            case 4: // drawText(QRectF,int,QString,QRectF*)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QRectF cppArg0 = Shiboken::Converter<QRectF >::toCpp(pyargs[0]);
                int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                QString cppArg2 = Shiboken::Converter<QString >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                    // drawText(QRectF,int,QString,QRectF*)
                    // Begin code injection

                    // TEMPLATE - fix_args,QRectF* - START
                    QRectF rect_;
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->drawText(cppArg0, cppArg1, cppArg2, &rect_);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter<QRectF >::toPython(rect_);
                    // TEMPLATE - fix_args,QRectF* - END

                    // End of code injection


                }
                break;
            }
            case 5: // drawText(int,int,QString)
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                QString cppArg2 = Shiboken::Converter<QString >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                    // drawText(int,int,QString)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->drawText(cppArg0, cppArg1, cppArg2);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Py_None;
                    Py_INCREF(Py_None);
                }
                break;
            }
            case 6: // drawText(int,int,int,int,int,QString,QRect*)
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                int cppArg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);
                int cppArg3 = Shiboken::Converter<int >::toCpp(pyargs[3]);
                int cppArg4 = Shiboken::Converter<int >::toCpp(pyargs[4]);
                QString cppArg5 = Shiboken::Converter<QString >::toCpp(pyargs[5]);

                if(!PyErr_Occurred()) {
                    // drawText(int,int,int,int,int,QString,QRect*)
                    // Begin code injection

                    // TEMPLATE - fix_args,QRect* - START
                    QRect rect_;
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->drawText(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5, &rect_);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter<QRect >::toPython(rect_);
                    // TEMPLATE - fix_args,QRect* - END

                    // End of code injection


                }
                break;
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QPainterFunc_drawText_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPoint, QString", "PySide.QtCore.QPointF, QString", "PySide.QtCore.QRect, int, QString, PySide.QtCore.QRect", "PySide.QtCore.QRectF, QString, PySide.QtGui.QTextOption = QTextOption()", "PySide.QtCore.QRectF, int, QString, PySide.QtCore.QRectF", "int, int, QString", "int, int, int, int, int, QString, PySide.QtCore.QRect", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPainter.drawText", overloads);
        return 0;
}

static PyObject* Sbk_QPainterFunc_drawTextItem(PyObject* self, PyObject* args)
{
    QPainter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPainter* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "drawTextItem", 2, 3, &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: drawTextItem(QPoint,QTextItem)
    // 1: drawTextItem(QPointF,QTextItem)
    // 2: drawTextItem(int,int,QTextItem)
    if (numArgs == 3 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && Shiboken::Converter< ::QTextItem >::isConvertible(pyargs[2])) {
        overloadId = 2; // drawTextItem(int,int,QTextItem)
    } else if (numArgs == 2 && Shiboken::Converter< ::QPoint >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QTextItem >::isConvertible(pyargs[1])) {
        overloadId = 0; // drawTextItem(QPoint,QTextItem)
    } else if (numArgs == 2 && Shiboken::Converter< ::QPointF >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QTextItem >::isConvertible(pyargs[1])) {
        overloadId = 1; // drawTextItem(QPointF,QTextItem)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPainterFunc_drawTextItem_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // drawTextItem(QPoint,QTextItem)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QPoint cppArg0 = Shiboken::Converter<QPoint >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return 0;
                const QTextItem & cppArg1 = Shiboken::Converter<const QTextItem & >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // drawTextItem(QPoint,QTextItem)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->drawTextItem(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // drawTextItem(QPointF,QTextItem)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QPointF cppArg0 = Shiboken::Converter<QPointF >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return 0;
                const QTextItem & cppArg1 = Shiboken::Converter<const QTextItem & >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // drawTextItem(QPointF,QTextItem)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->drawTextItem(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 2: // drawTextItem(int,int,QTextItem)
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                if (!Shiboken::Object::isValid(pyargs[2]))
                    return 0;
                const QTextItem & cppArg2 = Shiboken::Converter<const QTextItem & >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                    // drawTextItem(int,int,QTextItem)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->drawTextItem(cppArg0, cppArg1, cppArg2);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QPainterFunc_drawTextItem_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPoint, PySide.QtGui.QTextItem", "PySide.QtCore.QPointF, PySide.QtGui.QTextItem", "int, int, PySide.QtGui.QTextItem", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPainter.drawTextItem", overloads);
        return 0;
}

static PyObject* Sbk_QPainterFunc_drawTiledPixmap(PyObject* self, PyObject* args, PyObject* kwds)
{
    QPainter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPainter* >::toCpp(self);

    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 7) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QPainter.drawTiledPixmap(): too many arguments");
        return 0;
    } else if (numArgs < 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QPainter.drawTiledPixmap(): not enough arguments");
        return 0;
    } else if (numArgs == 4)
        goto Sbk_QPainterFunc_drawTiledPixmap_TypeError;

    if (!PyArg_ParseTuple(args, "|OOOOOOO:drawTiledPixmap", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3]), &(pyargs[4]), &(pyargs[5]), &(pyargs[6])))
        return 0;


    // Overloaded function decisor
    // 0: drawTiledPixmap(QRect,QPixmap,QPoint)
    // 1: drawTiledPixmap(QRectF,QPixmap,QPointF)
    // 2: drawTiledPixmap(int,int,int,int,QPixmap,int,int)
    if (numArgs >= 5 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2]) && SbkNumber_Check(pyargs[3]) && Shiboken::Converter< ::QPixmap >::isConvertible(pyargs[4])) {
        if (numArgs == 5) {
            overloadId = 2; // drawTiledPixmap(int,int,int,int,QPixmap,int,int)
        } else if (SbkNumber_Check(pyargs[5])) {
            if (numArgs == 6) {
                overloadId = 2; // drawTiledPixmap(int,int,int,int,QPixmap,int,int)
            } else if (SbkNumber_Check(pyargs[6])) {
                overloadId = 2; // drawTiledPixmap(int,int,int,int,QPixmap,int,int)
            }
        }
    } else if (numArgs >= 2 && Shiboken::Converter< ::QRect >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QPixmap >::isConvertible(pyargs[1])) {
        if (numArgs == 2) {
            overloadId = 0; // drawTiledPixmap(QRect,QPixmap,QPoint)
        } else if (Shiboken::Converter< ::QPoint >::isConvertible(pyargs[2])) {
            overloadId = 0; // drawTiledPixmap(QRect,QPixmap,QPoint)
        }
    } else if (numArgs >= 2 && Shiboken::Converter< ::QRectF >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QPixmap >::isConvertible(pyargs[1])) {
        if (numArgs == 2) {
            overloadId = 1; // drawTiledPixmap(QRectF,QPixmap,QPointF)
        } else if (Shiboken::Converter< ::QPointF >::isConvertible(pyargs[2])) {
            overloadId = 1; // drawTiledPixmap(QRectF,QPixmap,QPointF)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPainterFunc_drawTiledPixmap_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // drawTiledPixmap(QRect,QPixmap,QPoint)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "pos");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "pos";
                        else if (Shiboken::Converter< ::QPoint >::isConvertible(value))
                            pyargs[2] = value;
                        else
                            goto Sbk_QPainterFunc_drawTiledPixmap_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QPainter.drawTiledPixmap(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QRect cppArg0 = Shiboken::Converter<QRect >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return 0;
                QPixmap cppArg1 = Shiboken::Converter<QPixmap >::toCpp(pyargs[1]);
                if (!Shiboken::Object::isValid(pyargs[2]))
                    return 0;
                QPoint cppArg2_tmp = QPoint();
                QPoint cppArg2 = pyargs[2] ? Shiboken::Converter<QPoint >::toCpp(pyargs[2]) : cppArg2_tmp;

                if(!PyErr_Occurred()) {
                    // drawTiledPixmap(QRect,QPixmap,QPoint)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->drawTiledPixmap(cppArg0, cppArg1, cppArg2);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // drawTiledPixmap(QRectF,QPixmap,QPointF)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "offset");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "offset";
                        else if (Shiboken::Converter< ::QPointF >::isConvertible(value))
                            pyargs[2] = value;
                        else
                            goto Sbk_QPainterFunc_drawTiledPixmap_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QPainter.drawTiledPixmap(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QRectF cppArg0 = Shiboken::Converter<QRectF >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return 0;
                QPixmap cppArg1 = Shiboken::Converter<QPixmap >::toCpp(pyargs[1]);
                if (!Shiboken::Object::isValid(pyargs[2]))
                    return 0;
                QPointF cppArg2_tmp = QPointF();
                QPointF cppArg2 = pyargs[2] ? Shiboken::Converter<QPointF >::toCpp(pyargs[2]) : cppArg2_tmp;

                if(!PyErr_Occurred()) {
                    // drawTiledPixmap(QRectF,QPixmap,QPointF)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->drawTiledPixmap(cppArg0, cppArg1, cppArg2);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 2: // drawTiledPixmap(int,int,int,int,QPixmap,int,int)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "sx");
                    if (value) {
                        if (pyargs[5])
                            errorArgName = "sx";
                        else if (SbkNumber_Check(value))
                            pyargs[5] = value;
                        else
                            goto Sbk_QPainterFunc_drawTiledPixmap_TypeError;
                    }
                    value = PyDict_GetItemString(kwds, "sy");
                    if (value) {
                        if (pyargs[6])
                            errorArgName = "sy";
                        else if (SbkNumber_Check(value))
                            pyargs[6] = value;
                        else
                            goto Sbk_QPainterFunc_drawTiledPixmap_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QPainter.drawTiledPixmap(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                int cppArg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);
                int cppArg3 = Shiboken::Converter<int >::toCpp(pyargs[3]);
                if (!Shiboken::Object::isValid(pyargs[4]))
                    return 0;
                QPixmap cppArg4 = Shiboken::Converter<QPixmap >::toCpp(pyargs[4]);
                int cppArg5 = pyargs[5] ? Shiboken::Converter<int >::toCpp(pyargs[5]) : 0;
                int cppArg6 = pyargs[6] ? Shiboken::Converter<int >::toCpp(pyargs[6]) : 0;

                if(!PyErr_Occurred()) {
                    // drawTiledPixmap(int,int,int,int,QPixmap,int,int)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->drawTiledPixmap(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5, cppArg6);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QPainterFunc_drawTiledPixmap_TypeError:
        const char* overloads[] = {"PySide.QtCore.QRect, PySide.QtGui.QPixmap, PySide.QtCore.QPoint = QPoint()", "PySide.QtCore.QRectF, PySide.QtGui.QPixmap, PySide.QtCore.QPointF = QPointF()", "int, int, int, int, PySide.QtGui.QPixmap, int = 0, int = 0", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPainter.drawTiledPixmap", overloads);
        return 0;
}

static PyObject* Sbk_QPainterFunc_end(PyObject* self)
{
    QPainter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPainter* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // end()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->end();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QPainterFunc_endNativePainting(PyObject* self)
{
    QPainter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPainter* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // endNativePainting()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->endNativePainting();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QPainterFunc_eraseRect(PyObject* self, PyObject* args)
{
    QPainter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPainter* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs == 2 || numArgs == 3)
        goto Sbk_QPainterFunc_eraseRect_TypeError;

    if (!PyArg_UnpackTuple(args, "eraseRect", 1, 4, &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return 0;


    // Overloaded function decisor
    // 0: eraseRect(QRect)
    // 1: eraseRect(QRectF)
    // 2: eraseRect(int,int,int,int)
    if (numArgs == 4 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2]) && SbkNumber_Check(pyargs[3])) {
        overloadId = 2; // eraseRect(int,int,int,int)
    } else if (numArgs == 1 && Shiboken::Converter< ::QRect >::isConvertible(pyargs[0])) {
        overloadId = 0; // eraseRect(QRect)
    } else if (numArgs == 1 && Shiboken::Converter< ::QRectF >::isConvertible(pyargs[0])) {
        overloadId = 1; // eraseRect(QRectF)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPainterFunc_eraseRect_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // eraseRect(QRect)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QRect cppArg0 = Shiboken::Converter<QRect >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // eraseRect(QRect)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->eraseRect(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // eraseRect(QRectF)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QRectF cppArg0 = Shiboken::Converter<QRectF >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // eraseRect(QRectF)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->eraseRect(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 2: // eraseRect(int,int,int,int)
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                int cppArg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);
                int cppArg3 = Shiboken::Converter<int >::toCpp(pyargs[3]);

                if(!PyErr_Occurred()) {
                    // eraseRect(int,int,int,int)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->eraseRect(cppArg0, cppArg1, cppArg2, cppArg3);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QPainterFunc_eraseRect_TypeError:
        const char* overloads[] = {"PySide.QtCore.QRect", "PySide.QtCore.QRectF", "int, int, int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPainter.eraseRect", overloads);
        return 0;
}

static PyObject* Sbk_QPainterFunc_fillPath(PyObject* self, PyObject* args)
{
    QPainter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPainter* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "fillPath", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: fillPath(QPainterPath,QBrush)
    if (numArgs == 2 && Shiboken::Converter< ::QPainterPath >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QBrush >::isConvertible(pyargs[1])) {
        overloadId = 0; // fillPath(QPainterPath,QBrush)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPainterFunc_fillPath_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QPainterPath cppArg0 = Shiboken::Converter<QPainterPath >::toCpp(pyargs[0]);
            if (!Shiboken::Object::isValid(pyargs[1]))
                return 0;
            QBrush cppArg1 = Shiboken::Converter<QBrush >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // fillPath(QPainterPath,QBrush)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->fillPath(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QPainterFunc_fillPath_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPainterPath, PySide.QtGui.QBrush", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPainter.fillPath", overloads);
        return 0;
}

static PyObject* Sbk_QPainterFunc_fillRect(PyObject* self, PyObject* args)
{
    QPainter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPainter* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs == 3 || numArgs == 4)
        goto Sbk_QPainterFunc_fillRect_TypeError;

    if (!PyArg_UnpackTuple(args, "fillRect", 2, 5, &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3]), &(pyargs[4])))
        return 0;


    // Overloaded function decisor
    // 0: fillRect(QRect,QBrush)
    // 1: fillRect(QRect,QColor)
    // 2: fillRect(QRect,Qt::BrushStyle)
    // 3: fillRect(QRect,Qt::GlobalColor)
    // 4: fillRect(QRectF,QBrush)
    // 5: fillRect(QRectF,QColor)
    // 6: fillRect(QRectF,Qt::BrushStyle)
    // 7: fillRect(QRectF,Qt::GlobalColor)
    // 8: fillRect(int,int,int,int,Qt::BrushStyle)
    // 9: fillRect(int,int,int,int,Qt::GlobalColor)
    // 10: fillRect(int,int,int,int,QBrush)
    // 11: fillRect(int,int,int,int,QColor)
    if (numArgs >= 4 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2]) && SbkNumber_Check(pyargs[3])) {
        if (numArgs == 5 && Shiboken::Converter< ::Qt::GlobalColor >::isConvertible(pyargs[4])) {
            overloadId = 9; // fillRect(int,int,int,int,Qt::GlobalColor)
        } else if (numArgs == 5 && Shiboken::Converter< ::Qt::BrushStyle >::isConvertible(pyargs[4])) {
            overloadId = 8; // fillRect(int,int,int,int,Qt::BrushStyle)
        } else if (numArgs == 5 && Shiboken::Converter< ::QColor >::isConvertible(pyargs[4])) {
            overloadId = 11; // fillRect(int,int,int,int,QColor)
        } else if (numArgs == 5 && Shiboken::Converter< ::QBrush >::isConvertible(pyargs[4])) {
            overloadId = 10; // fillRect(int,int,int,int,QBrush)
        }
    } else if (Shiboken::Converter< ::QRect >::isConvertible(pyargs[0])) {
        if (numArgs == 2 && Shiboken::Converter< ::Qt::GlobalColor >::isConvertible(pyargs[1])) {
            overloadId = 3; // fillRect(QRect,Qt::GlobalColor)
        } else if (numArgs == 2 && Shiboken::Converter< ::Qt::BrushStyle >::isConvertible(pyargs[1])) {
            overloadId = 2; // fillRect(QRect,Qt::BrushStyle)
        } else if (numArgs == 2 && Shiboken::Converter< ::QColor >::isConvertible(pyargs[1])) {
            overloadId = 1; // fillRect(QRect,QColor)
        } else if (numArgs == 2 && Shiboken::Converter< ::QBrush >::isConvertible(pyargs[1])) {
            overloadId = 0; // fillRect(QRect,QBrush)
        }
    } else if (Shiboken::Converter< ::QRectF >::isConvertible(pyargs[0])) {
        if (numArgs == 2 && Shiboken::Converter< ::Qt::GlobalColor >::isConvertible(pyargs[1])) {
            overloadId = 7; // fillRect(QRectF,Qt::GlobalColor)
        } else if (numArgs == 2 && Shiboken::Converter< ::Qt::BrushStyle >::isConvertible(pyargs[1])) {
            overloadId = 6; // fillRect(QRectF,Qt::BrushStyle)
        } else if (numArgs == 2 && Shiboken::Converter< ::QColor >::isConvertible(pyargs[1])) {
            overloadId = 5; // fillRect(QRectF,QColor)
        } else if (numArgs == 2 && Shiboken::Converter< ::QBrush >::isConvertible(pyargs[1])) {
            overloadId = 4; // fillRect(QRectF,QBrush)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPainterFunc_fillRect_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // fillRect(QRect,QBrush)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QRect cppArg0 = Shiboken::Converter<QRect >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return 0;
                QBrush cppArg1 = Shiboken::Converter<QBrush >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // fillRect(QRect,QBrush)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->fillRect(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // fillRect(QRect,QColor)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QRect cppArg0 = Shiboken::Converter<QRect >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return 0;
                QColor cppArg1 = Shiboken::Converter<QColor >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // fillRect(QRect,QColor)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->fillRect(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 2: // fillRect(QRect,Qt::BrushStyle)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QRect cppArg0 = Shiboken::Converter<QRect >::toCpp(pyargs[0]);
                Qt::BrushStyle cppArg1 = Shiboken::Converter<Qt::BrushStyle >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // fillRect(QRect,Qt::BrushStyle)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->fillRect(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 3: // fillRect(QRect,Qt::GlobalColor)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QRect cppArg0 = Shiboken::Converter<QRect >::toCpp(pyargs[0]);
                Qt::GlobalColor cppArg1 = Shiboken::Converter<Qt::GlobalColor >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // fillRect(QRect,Qt::GlobalColor)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->fillRect(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 4: // fillRect(QRectF,QBrush)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QRectF cppArg0 = Shiboken::Converter<QRectF >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return 0;
                QBrush cppArg1 = Shiboken::Converter<QBrush >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // fillRect(QRectF,QBrush)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->fillRect(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 5: // fillRect(QRectF,QColor)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QRectF cppArg0 = Shiboken::Converter<QRectF >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return 0;
                QColor cppArg1 = Shiboken::Converter<QColor >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // fillRect(QRectF,QColor)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->fillRect(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 6: // fillRect(QRectF,Qt::BrushStyle)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QRectF cppArg0 = Shiboken::Converter<QRectF >::toCpp(pyargs[0]);
                Qt::BrushStyle cppArg1 = Shiboken::Converter<Qt::BrushStyle >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // fillRect(QRectF,Qt::BrushStyle)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->fillRect(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 7: // fillRect(QRectF,Qt::GlobalColor)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QRectF cppArg0 = Shiboken::Converter<QRectF >::toCpp(pyargs[0]);
                Qt::GlobalColor cppArg1 = Shiboken::Converter<Qt::GlobalColor >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // fillRect(QRectF,Qt::GlobalColor)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->fillRect(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 8: // fillRect(int,int,int,int,Qt::BrushStyle)
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                int cppArg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);
                int cppArg3 = Shiboken::Converter<int >::toCpp(pyargs[3]);
                Qt::BrushStyle cppArg4 = Shiboken::Converter<Qt::BrushStyle >::toCpp(pyargs[4]);

                if(!PyErr_Occurred()) {
                    // fillRect(int,int,int,int,Qt::BrushStyle)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->fillRect(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 9: // fillRect(int,int,int,int,Qt::GlobalColor)
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                int cppArg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);
                int cppArg3 = Shiboken::Converter<int >::toCpp(pyargs[3]);
                Qt::GlobalColor cppArg4 = Shiboken::Converter<Qt::GlobalColor >::toCpp(pyargs[4]);

                if(!PyErr_Occurred()) {
                    // fillRect(int,int,int,int,Qt::GlobalColor)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->fillRect(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 10: // fillRect(int,int,int,int,QBrush)
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                int cppArg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);
                int cppArg3 = Shiboken::Converter<int >::toCpp(pyargs[3]);
                if (!Shiboken::Object::isValid(pyargs[4]))
                    return 0;
                QBrush cppArg4 = Shiboken::Converter<QBrush >::toCpp(pyargs[4]);

                if(!PyErr_Occurred()) {
                    // fillRect(int,int,int,int,QBrush)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->fillRect(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 11: // fillRect(int,int,int,int,QColor)
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                int cppArg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);
                int cppArg3 = Shiboken::Converter<int >::toCpp(pyargs[3]);
                if (!Shiboken::Object::isValid(pyargs[4]))
                    return 0;
                QColor cppArg4 = Shiboken::Converter<QColor >::toCpp(pyargs[4]);

                if(!PyErr_Occurred()) {
                    // fillRect(int,int,int,int,QColor)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->fillRect(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QPainterFunc_fillRect_TypeError:
        const char* overloads[] = {"PySide.QtCore.QRect, PySide.QtGui.QBrush", "PySide.QtCore.QRect, PySide.QtGui.QColor", "PySide.QtCore.QRect, PySide.QtCore.Qt.BrushStyle", "PySide.QtCore.QRect, PySide.QtCore.Qt.GlobalColor", "PySide.QtCore.QRectF, PySide.QtGui.QBrush", "PySide.QtCore.QRectF, PySide.QtGui.QColor", "PySide.QtCore.QRectF, PySide.QtCore.Qt.BrushStyle", "PySide.QtCore.QRectF, PySide.QtCore.Qt.GlobalColor", "int, int, int, int, PySide.QtCore.Qt.BrushStyle", "int, int, int, int, PySide.QtCore.Qt.GlobalColor", "int, int, int, int, PySide.QtGui.QBrush", "int, int, int, int, PySide.QtGui.QColor", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPainter.fillRect", overloads);
        return 0;
}

static PyObject* Sbk_QPainterFunc_font(PyObject* self)
{
    QPainter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPainter* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // font()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                const QFont & cppResult = const_cast<const QPainter*>(cppSelf)->font();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QFont >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QPainterFunc_fontInfo(PyObject* self)
{
    QPainter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPainter* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // fontInfo()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QFontInfo cppResult = const_cast<const QPainter*>(cppSelf)->fontInfo();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QFontInfo >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QPainterFunc_fontMetrics(PyObject* self)
{
    QPainter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPainter* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // fontMetrics()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QFontMetrics cppResult = const_cast<const QPainter*>(cppSelf)->fontMetrics();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QFontMetrics >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QPainterFunc_hasClipping(PyObject* self)
{
    QPainter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPainter* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // hasClipping()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QPainter*>(cppSelf)->hasClipping();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QPainterFunc_initFrom(PyObject* self, PyObject* arg)
{
    QPainter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPainter* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: initFrom(const QWidget*)
    if (Shiboken::Converter< ::QWidget * >::isConvertible(arg)) {
        overloadId = 0; // initFrom(const QWidget*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPainterFunc_initFrom_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QWidget * cppArg0 = Shiboken::Converter<QWidget * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // initFrom(const QWidget*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->initFrom(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QPainterFunc_initFrom_TypeError:
        const char* overloads[] = {"PySide.QtGui.QWidget", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPainter.initFrom", overloads);
        return 0;
}

static PyObject* Sbk_QPainterFunc_isActive(PyObject* self)
{
    QPainter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPainter* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isActive()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QPainter*>(cppSelf)->isActive();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QPainterFunc_layoutDirection(PyObject* self)
{
    QPainter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPainter* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // layoutDirection()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                Qt::LayoutDirection cppResult = const_cast<const QPainter*>(cppSelf)->layoutDirection();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::Qt::LayoutDirection >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QPainterFunc_opacity(PyObject* self)
{
    QPainter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPainter* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // opacity()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                qreal cppResult = const_cast<const QPainter*>(cppSelf)->opacity();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< double >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QPainterFunc_paintEngine(PyObject* self)
{
    QPainter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPainter* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // paintEngine()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QPaintEngine * cppResult = const_cast<const QPainter*>(cppSelf)->paintEngine();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QPaintEngine * >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QPainterFunc_pen(PyObject* self)
{
    QPainter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPainter* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // pen()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                const QPen & cppResult = const_cast<const QPainter*>(cppSelf)->pen();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QPen >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QPainterFunc_renderHints(PyObject* self)
{
    QPainter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPainter* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // renderHints()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QFlags<QPainter::RenderHint> cppResult = const_cast<const QPainter*>(cppSelf)->renderHints();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QFlags<QPainter::RenderHint> >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QPainterFunc_resetMatrix(PyObject* self)
{
    QPainter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPainter* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // resetMatrix()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->resetMatrix();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QPainterFunc_resetTransform(PyObject* self)
{
    QPainter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPainter* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // resetTransform()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->resetTransform();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QPainterFunc_restore(PyObject* self)
{
    QPainter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPainter* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // restore()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->restore();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QPainterFunc_restoreRedirected(PyObject* self, PyObject* arg)
{
    int overloadId = -1;

    // Overloaded function decisor
    // 0: restoreRedirected(const QPaintDevice*)
    if (Shiboken::Converter< ::QPaintDevice * >::isConvertible(arg)) {
        overloadId = 0; // restoreRedirected(const QPaintDevice*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPainterFunc_restoreRedirected_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QPaintDevice * cppArg0 = Shiboken::Converter<QPaintDevice * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // restoreRedirected(const QPaintDevice*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QPainter::restoreRedirected(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QPainterFunc_restoreRedirected_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPaintDevice", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPainter.restoreRedirected", overloads);
        return 0;
}

static PyObject* Sbk_QPainterFunc_rotate(PyObject* self, PyObject* arg)
{
    QPainter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPainter* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: rotate(qreal)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // rotate(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPainterFunc_rotate_TypeError;

    // Call function/method
    {
        {
            qreal cppArg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // rotate(qreal)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->rotate(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QPainterFunc_rotate_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPainter.rotate", overloads);
        return 0;
}

static PyObject* Sbk_QPainterFunc_save(PyObject* self)
{
    QPainter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPainter* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // save()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->save();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QPainterFunc_scale(PyObject* self, PyObject* args)
{
    QPainter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPainter* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "scale", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: scale(qreal,qreal)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 0; // scale(qreal,qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPainterFunc_scale_TypeError;

    // Call function/method
    {
        {
            qreal cppArg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
            qreal cppArg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // scale(qreal,qreal)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->scale(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QPainterFunc_scale_TypeError:
        const char* overloads[] = {"float, float", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPainter.scale", overloads);
        return 0;
}

static PyObject* Sbk_QPainterFunc_setBackground(PyObject* self, PyObject* arg)
{
    QPainter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPainter* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setBackground(QBrush)
    if (Shiboken::Converter< ::QBrush >::isConvertible(arg)) {
        overloadId = 0; // setBackground(QBrush)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPainterFunc_setBackground_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QBrush cppArg0 = Shiboken::Converter<QBrush >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setBackground(QBrush)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setBackground(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QPainterFunc_setBackground_TypeError:
        const char* overloads[] = {"PySide.QtGui.QBrush", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPainter.setBackground", overloads);
        return 0;
}

static PyObject* Sbk_QPainterFunc_setBackgroundMode(PyObject* self, PyObject* arg)
{
    QPainter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPainter* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setBackgroundMode(Qt::BGMode)
    if (Shiboken::Converter< ::Qt::BGMode >::isConvertible(arg)) {
        overloadId = 0; // setBackgroundMode(Qt::BGMode)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPainterFunc_setBackgroundMode_TypeError;

    // Call function/method
    {
        {
            Qt::BGMode cppArg0 = Shiboken::Converter<Qt::BGMode >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setBackgroundMode(Qt::BGMode)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setBackgroundMode(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QPainterFunc_setBackgroundMode_TypeError:
        const char* overloads[] = {"PySide.QtCore.Qt.BGMode", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPainter.setBackgroundMode", overloads);
        return 0;
}

static PyObject* Sbk_QPainterFunc_setBrush(PyObject* self, PyObject* arg)
{
    QPainter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPainter* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setBrush(Qt::BrushStyle)
    // 1: setBrush(QBrush)
    if (Shiboken::Converter< ::Qt::BrushStyle >::isConvertible(arg)) {
        overloadId = 0; // setBrush(Qt::BrushStyle)
    } else if (Shiboken::Converter< ::QBrush >::isConvertible(arg)) {
        overloadId = 1; // setBrush(QBrush)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPainterFunc_setBrush_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // setBrush(Qt::BrushStyle)
            {
                Qt::BrushStyle cppArg0 = Shiboken::Converter<Qt::BrushStyle >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // setBrush(Qt::BrushStyle)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setBrush(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // setBrush(QBrush)
            {
                if (!Shiboken::Object::isValid(arg))
                    return 0;
                QBrush cppArg0 = Shiboken::Converter<QBrush >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // setBrush(QBrush)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setBrush(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QPainterFunc_setBrush_TypeError:
        const char* overloads[] = {"PySide.QtCore.Qt.BrushStyle", "PySide.QtGui.QBrush", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPainter.setBrush", overloads);
        return 0;
}

static PyObject* Sbk_QPainterFunc_setBrushOrigin(PyObject* self, PyObject* args)
{
    QPainter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPainter* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setBrushOrigin", 1, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setBrushOrigin(QPoint)
    // 1: setBrushOrigin(QPointF)
    // 2: setBrushOrigin(int,int)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 2; // setBrushOrigin(int,int)
    } else if (numArgs == 1 && Shiboken::Converter< ::QPoint >::isConvertible(pyargs[0])) {
        overloadId = 0; // setBrushOrigin(QPoint)
    } else if (numArgs == 1 && Shiboken::Converter< ::QPointF >::isConvertible(pyargs[0])) {
        overloadId = 1; // setBrushOrigin(QPointF)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPainterFunc_setBrushOrigin_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // setBrushOrigin(QPoint)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QPoint cppArg0 = Shiboken::Converter<QPoint >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // setBrushOrigin(QPoint)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setBrushOrigin(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // setBrushOrigin(QPointF)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QPointF cppArg0 = Shiboken::Converter<QPointF >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // setBrushOrigin(QPointF)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setBrushOrigin(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 2: // setBrushOrigin(int,int)
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // setBrushOrigin(int,int)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setBrushOrigin(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QPainterFunc_setBrushOrigin_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPoint", "PySide.QtCore.QPointF", "int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPainter.setBrushOrigin", overloads);
        return 0;
}

static PyObject* Sbk_QPainterFunc_setClipPath(PyObject* self, PyObject* args, PyObject* kwds)
{
    QPainter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPainter* >::toCpp(self);

    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QPainter.setClipPath(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QPainter.setClipPath(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:setClipPath", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setClipPath(QPainterPath,Qt::ClipOperation)
    if (Shiboken::Converter< ::QPainterPath >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // setClipPath(QPainterPath,Qt::ClipOperation)
        } else if (Shiboken::Converter< ::Qt::ClipOperation >::isConvertible(pyargs[1])) {
            overloadId = 0; // setClipPath(QPainterPath,Qt::ClipOperation)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPainterFunc_setClipPath_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "op");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "op";
                    else if (Shiboken::Converter< ::Qt::ClipOperation >::isConvertible(value))
                        pyargs[1] = value;
                    else
                        goto Sbk_QPainterFunc_setClipPath_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QPainter.setClipPath(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QPainterPath cppArg0 = Shiboken::Converter<QPainterPath >::toCpp(pyargs[0]);
            Qt::ClipOperation cppArg1 = pyargs[1] ? Shiboken::Converter<Qt::ClipOperation >::toCpp(pyargs[1]) : Qt::ReplaceClip;

            if(!PyErr_Occurred()) {
                // setClipPath(QPainterPath,Qt::ClipOperation)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setClipPath(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QPainterFunc_setClipPath_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPainterPath, PySide.QtCore.Qt.ClipOperation = Qt.ReplaceClip", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPainter.setClipPath", overloads);
        return 0;
}

static PyObject* Sbk_QPainterFunc_setClipRect(PyObject* self, PyObject* args, PyObject* kwds)
{
    QPainter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPainter* >::toCpp(self);

    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 5) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QPainter.setClipRect(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QPainter.setClipRect(): not enough arguments");
        return 0;
    } else if (numArgs == 3)
        goto Sbk_QPainterFunc_setClipRect_TypeError;

    if (!PyArg_ParseTuple(args, "|OOOOO:setClipRect", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3]), &(pyargs[4])))
        return 0;


    // Overloaded function decisor
    // 0: setClipRect(QRect,Qt::ClipOperation)
    // 1: setClipRect(QRectF,Qt::ClipOperation)
    // 2: setClipRect(int,int,int,int,Qt::ClipOperation)
    if (numArgs >= 4 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2]) && SbkNumber_Check(pyargs[3])) {
        if (numArgs == 4) {
            overloadId = 2; // setClipRect(int,int,int,int,Qt::ClipOperation)
        } else if (Shiboken::Converter< ::Qt::ClipOperation >::isConvertible(pyargs[4])) {
            overloadId = 2; // setClipRect(int,int,int,int,Qt::ClipOperation)
        }
    } else if (Shiboken::Converter< ::QRect >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // setClipRect(QRect,Qt::ClipOperation)
        } else if (Shiboken::Converter< ::Qt::ClipOperation >::isConvertible(pyargs[1])) {
            overloadId = 0; // setClipRect(QRect,Qt::ClipOperation)
        }
    } else if (Shiboken::Converter< ::QRectF >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 1; // setClipRect(QRectF,Qt::ClipOperation)
        } else if (Shiboken::Converter< ::Qt::ClipOperation >::isConvertible(pyargs[1])) {
            overloadId = 1; // setClipRect(QRectF,Qt::ClipOperation)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPainterFunc_setClipRect_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // setClipRect(QRect,Qt::ClipOperation)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "op");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "op";
                        else if (Shiboken::Converter< ::Qt::ClipOperation >::isConvertible(value))
                            pyargs[1] = value;
                        else
                            goto Sbk_QPainterFunc_setClipRect_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QPainter.setClipRect(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QRect cppArg0 = Shiboken::Converter<QRect >::toCpp(pyargs[0]);
                Qt::ClipOperation cppArg1 = pyargs[1] ? Shiboken::Converter<Qt::ClipOperation >::toCpp(pyargs[1]) : Qt::ReplaceClip;

                if(!PyErr_Occurred()) {
                    // setClipRect(QRect,Qt::ClipOperation)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setClipRect(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // setClipRect(QRectF,Qt::ClipOperation)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "op");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "op";
                        else if (Shiboken::Converter< ::Qt::ClipOperation >::isConvertible(value))
                            pyargs[1] = value;
                        else
                            goto Sbk_QPainterFunc_setClipRect_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QPainter.setClipRect(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QRectF cppArg0 = Shiboken::Converter<QRectF >::toCpp(pyargs[0]);
                Qt::ClipOperation cppArg1 = pyargs[1] ? Shiboken::Converter<Qt::ClipOperation >::toCpp(pyargs[1]) : Qt::ReplaceClip;

                if(!PyErr_Occurred()) {
                    // setClipRect(QRectF,Qt::ClipOperation)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setClipRect(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 2: // setClipRect(int,int,int,int,Qt::ClipOperation)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "op");
                    if (value) {
                        if (pyargs[4])
                            errorArgName = "op";
                        else if (Shiboken::Converter< ::Qt::ClipOperation >::isConvertible(value))
                            pyargs[4] = value;
                        else
                            goto Sbk_QPainterFunc_setClipRect_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QPainter.setClipRect(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                int cppArg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);
                int cppArg3 = Shiboken::Converter<int >::toCpp(pyargs[3]);
                Qt::ClipOperation cppArg4 = pyargs[4] ? Shiboken::Converter<Qt::ClipOperation >::toCpp(pyargs[4]) : Qt::ReplaceClip;

                if(!PyErr_Occurred()) {
                    // setClipRect(int,int,int,int,Qt::ClipOperation)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setClipRect(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QPainterFunc_setClipRect_TypeError:
        const char* overloads[] = {"PySide.QtCore.QRect, PySide.QtCore.Qt.ClipOperation = Qt.ReplaceClip", "PySide.QtCore.QRectF, PySide.QtCore.Qt.ClipOperation = Qt.ReplaceClip", "int, int, int, int, PySide.QtCore.Qt.ClipOperation = Qt.ReplaceClip", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPainter.setClipRect", overloads);
        return 0;
}

static PyObject* Sbk_QPainterFunc_setClipRegion(PyObject* self, PyObject* args, PyObject* kwds)
{
    QPainter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPainter* >::toCpp(self);

    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QPainter.setClipRegion(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QPainter.setClipRegion(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:setClipRegion", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setClipRegion(QRegion,Qt::ClipOperation)
    if (Shiboken::Converter< ::QRegion >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // setClipRegion(QRegion,Qt::ClipOperation)
        } else if (Shiboken::Converter< ::Qt::ClipOperation >::isConvertible(pyargs[1])) {
            overloadId = 0; // setClipRegion(QRegion,Qt::ClipOperation)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPainterFunc_setClipRegion_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "op");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "op";
                    else if (Shiboken::Converter< ::Qt::ClipOperation >::isConvertible(value))
                        pyargs[1] = value;
                    else
                        goto Sbk_QPainterFunc_setClipRegion_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QPainter.setClipRegion(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QRegion cppArg0 = Shiboken::Converter<QRegion >::toCpp(pyargs[0]);
            Qt::ClipOperation cppArg1 = pyargs[1] ? Shiboken::Converter<Qt::ClipOperation >::toCpp(pyargs[1]) : Qt::ReplaceClip;

            if(!PyErr_Occurred()) {
                // setClipRegion(QRegion,Qt::ClipOperation)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setClipRegion(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QPainterFunc_setClipRegion_TypeError:
        const char* overloads[] = {"PySide.QtGui.QRegion, PySide.QtCore.Qt.ClipOperation = Qt.ReplaceClip", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPainter.setClipRegion", overloads);
        return 0;
}

static PyObject* Sbk_QPainterFunc_setClipping(PyObject* self, PyObject* arg)
{
    QPainter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPainter* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setClipping(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setClipping(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPainterFunc_setClipping_TypeError;

    // Call function/method
    {
        {
            bool cppArg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setClipping(bool)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setClipping(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QPainterFunc_setClipping_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPainter.setClipping", overloads);
        return 0;
}

static PyObject* Sbk_QPainterFunc_setCompositionMode(PyObject* self, PyObject* arg)
{
    QPainter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPainter* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setCompositionMode(QPainter::CompositionMode)
    if (Shiboken::Converter< ::QPainter::CompositionMode >::isConvertible(arg)) {
        overloadId = 0; // setCompositionMode(QPainter::CompositionMode)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPainterFunc_setCompositionMode_TypeError;

    // Call function/method
    {
        {
            QPainter::CompositionMode cppArg0 = Shiboken::Converter<QPainter::CompositionMode >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setCompositionMode(QPainter::CompositionMode)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setCompositionMode(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QPainterFunc_setCompositionMode_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPainter.CompositionMode", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPainter.setCompositionMode", overloads);
        return 0;
}

static PyObject* Sbk_QPainterFunc_setFont(PyObject* self, PyObject* arg)
{
    QPainter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPainter* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setFont(QFont)
    if (Shiboken::Converter< ::QFont >::isConvertible(arg)) {
        overloadId = 0; // setFont(QFont)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPainterFunc_setFont_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QFont cppArg0 = Shiboken::Converter<QFont >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setFont(QFont)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setFont(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QPainterFunc_setFont_TypeError:
        const char* overloads[] = {"PySide.QtGui.QFont", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPainter.setFont", overloads);
        return 0;
}

static PyObject* Sbk_QPainterFunc_setLayoutDirection(PyObject* self, PyObject* arg)
{
    QPainter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPainter* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setLayoutDirection(Qt::LayoutDirection)
    if (Shiboken::Converter< ::Qt::LayoutDirection >::isConvertible(arg)) {
        overloadId = 0; // setLayoutDirection(Qt::LayoutDirection)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPainterFunc_setLayoutDirection_TypeError;

    // Call function/method
    {
        {
            Qt::LayoutDirection cppArg0 = Shiboken::Converter<Qt::LayoutDirection >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setLayoutDirection(Qt::LayoutDirection)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setLayoutDirection(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QPainterFunc_setLayoutDirection_TypeError:
        const char* overloads[] = {"PySide.QtCore.Qt.LayoutDirection", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPainter.setLayoutDirection", overloads);
        return 0;
}

static PyObject* Sbk_QPainterFunc_setOpacity(PyObject* self, PyObject* arg)
{
    QPainter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPainter* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setOpacity(qreal)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setOpacity(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPainterFunc_setOpacity_TypeError;

    // Call function/method
    {
        {
            qreal cppArg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setOpacity(qreal)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setOpacity(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QPainterFunc_setOpacity_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPainter.setOpacity", overloads);
        return 0;
}

static PyObject* Sbk_QPainterFunc_setPen(PyObject* self, PyObject* arg)
{
    QPainter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPainter* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setPen(Qt::PenStyle)
    // 1: setPen(QColor)
    // 2: setPen(QPen)
    if (Shiboken::Converter< ::Qt::PenStyle >::isConvertible(arg)) {
        overloadId = 0; // setPen(Qt::PenStyle)
    } else if (Shiboken::Converter< ::QColor >::isConvertible(arg)) {
        overloadId = 1; // setPen(QColor)
    } else if (Shiboken::Converter< ::QPen >::isConvertible(arg)) {
        overloadId = 2; // setPen(QPen)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPainterFunc_setPen_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // setPen(Qt::PenStyle)
            {
                Qt::PenStyle cppArg0 = Shiboken::Converter<Qt::PenStyle >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // setPen(Qt::PenStyle)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setPen(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // setPen(QColor)
            {
                if (!Shiboken::Object::isValid(arg))
                    return 0;
                QColor cppArg0 = Shiboken::Converter<QColor >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // setPen(QColor)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setPen(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 2: // setPen(QPen)
            {
                if (!Shiboken::Object::isValid(arg))
                    return 0;
                QPen cppArg0 = Shiboken::Converter<QPen >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // setPen(QPen)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setPen(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QPainterFunc_setPen_TypeError:
        const char* overloads[] = {"PySide.QtCore.Qt.PenStyle", "PySide.QtGui.QColor", "PySide.QtGui.QPen", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPainter.setPen", overloads);
        return 0;
}

static PyObject* Sbk_QPainterFunc_setRedirected(PyObject* self, PyObject* args, PyObject* kwds)
{
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QPainter.setRedirected(): too many arguments");
        return 0;
    } else if (numArgs < 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QPainter.setRedirected(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOO:setRedirected", &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: setRedirected(const QPaintDevice*,QPaintDevice*,QPoint)
    if (numArgs >= 2 && Shiboken::Converter< ::QPaintDevice * >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QPaintDevice * >::isConvertible(pyargs[1])) {
        if (numArgs == 2) {
            overloadId = 0; // setRedirected(const QPaintDevice*,QPaintDevice*,QPoint)
        } else if (Shiboken::Converter< ::QPoint >::isConvertible(pyargs[2])) {
            overloadId = 0; // setRedirected(const QPaintDevice*,QPaintDevice*,QPoint)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPainterFunc_setRedirected_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "offset");
                if (value) {
                    if (pyargs[2])
                        errorArgName = "offset";
                    else if (Shiboken::Converter< ::QPoint >::isConvertible(value))
                        pyargs[2] = value;
                    else
                        goto Sbk_QPainterFunc_setRedirected_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QPainter.setRedirected(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QPaintDevice * cppArg0 = Shiboken::Converter<QPaintDevice * >::toCpp(pyargs[0]);
            if (!Shiboken::Object::isValid(pyargs[1]))
                return 0;
            QPaintDevice * cppArg1 = Shiboken::Converter<QPaintDevice * >::toCpp(pyargs[1]);
            if (!Shiboken::Object::isValid(pyargs[2]))
                return 0;
            QPoint cppArg2_tmp = QPoint();
            QPoint cppArg2 = pyargs[2] ? Shiboken::Converter<QPoint >::toCpp(pyargs[2]) : cppArg2_tmp;

            if(!PyErr_Occurred()) {
                // setRedirected(const QPaintDevice*,QPaintDevice*,QPoint)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QPainter::setRedirected(cppArg0, cppArg1, cppArg2);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QPainterFunc_setRedirected_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPaintDevice, PySide.QtGui.QPaintDevice, PySide.QtCore.QPoint = QPoint()", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPainter.setRedirected", overloads);
        return 0;
}

static PyObject* Sbk_QPainterFunc_setRenderHint(PyObject* self, PyObject* args, PyObject* kwds)
{
    QPainter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPainter* >::toCpp(self);

    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QPainter.setRenderHint(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QPainter.setRenderHint(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:setRenderHint", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setRenderHint(QPainter::RenderHint,bool)
    if (Shiboken::Converter< ::QPainter::RenderHint >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // setRenderHint(QPainter::RenderHint,bool)
        } else if (SbkNumber_Check(pyargs[1])) {
            overloadId = 0; // setRenderHint(QPainter::RenderHint,bool)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPainterFunc_setRenderHint_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "on");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "on";
                    else if (SbkNumber_Check(value))
                        pyargs[1] = value;
                    else
                        goto Sbk_QPainterFunc_setRenderHint_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QPainter.setRenderHint(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QPainter::RenderHint cppArg0 = Shiboken::Converter<QPainter::RenderHint >::toCpp(pyargs[0]);
            bool cppArg1 = pyargs[1] ? Shiboken::Converter<bool >::toCpp(pyargs[1]) : true;

            if(!PyErr_Occurred()) {
                // setRenderHint(QPainter::RenderHint,bool)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setRenderHint(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QPainterFunc_setRenderHint_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPainter.RenderHint, bool = true", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPainter.setRenderHint", overloads);
        return 0;
}

static PyObject* Sbk_QPainterFunc_setRenderHints(PyObject* self, PyObject* args, PyObject* kwds)
{
    QPainter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPainter* >::toCpp(self);

    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QPainter.setRenderHints(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QPainter.setRenderHints(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:setRenderHints", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setRenderHints(QFlags<QPainter::RenderHint>,bool)
    if (Shiboken::Converter< ::QFlags<QPainter::RenderHint> >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // setRenderHints(QFlags<QPainter::RenderHint>,bool)
        } else if (SbkNumber_Check(pyargs[1])) {
            overloadId = 0; // setRenderHints(QFlags<QPainter::RenderHint>,bool)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPainterFunc_setRenderHints_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "on");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "on";
                    else if (SbkNumber_Check(value))
                        pyargs[1] = value;
                    else
                        goto Sbk_QPainterFunc_setRenderHints_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QPainter.setRenderHints(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QFlags<QPainter::RenderHint> cppArg0 = Shiboken::Converter<QFlags<QPainter::RenderHint> >::toCpp(pyargs[0]);
            bool cppArg1 = pyargs[1] ? Shiboken::Converter<bool >::toCpp(pyargs[1]) : true;

            if(!PyErr_Occurred()) {
                // setRenderHints(QFlags<QPainter::RenderHint>,bool)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setRenderHints(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QPainterFunc_setRenderHints_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPainter.RenderHints, bool = true", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPainter.setRenderHints", overloads);
        return 0;
}

static PyObject* Sbk_QPainterFunc_setTransform(PyObject* self, PyObject* args, PyObject* kwds)
{
    QPainter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPainter* >::toCpp(self);

    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QPainter.setTransform(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QPainter.setTransform(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:setTransform", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setTransform(QTransform,bool)
    if (Shiboken::Converter< ::QTransform >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // setTransform(QTransform,bool)
        } else if (SbkNumber_Check(pyargs[1])) {
            overloadId = 0; // setTransform(QTransform,bool)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPainterFunc_setTransform_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "combine");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "combine";
                    else if (SbkNumber_Check(value))
                        pyargs[1] = value;
                    else
                        goto Sbk_QPainterFunc_setTransform_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QPainter.setTransform(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QTransform cppArg0 = Shiboken::Converter<QTransform >::toCpp(pyargs[0]);
            bool cppArg1 = pyargs[1] ? Shiboken::Converter<bool >::toCpp(pyargs[1]) : false;

            if(!PyErr_Occurred()) {
                // setTransform(QTransform,bool)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setTransform(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QPainterFunc_setTransform_TypeError:
        const char* overloads[] = {"PySide.QtGui.QTransform, bool = false", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPainter.setTransform", overloads);
        return 0;
}

static PyObject* Sbk_QPainterFunc_setViewTransformEnabled(PyObject* self, PyObject* arg)
{
    QPainter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPainter* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setViewTransformEnabled(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setViewTransformEnabled(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPainterFunc_setViewTransformEnabled_TypeError;

    // Call function/method
    {
        {
            bool cppArg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setViewTransformEnabled(bool)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setViewTransformEnabled(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QPainterFunc_setViewTransformEnabled_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPainter.setViewTransformEnabled", overloads);
        return 0;
}

static PyObject* Sbk_QPainterFunc_setViewport(PyObject* self, PyObject* args)
{
    QPainter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPainter* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs == 2 || numArgs == 3)
        goto Sbk_QPainterFunc_setViewport_TypeError;

    if (!PyArg_UnpackTuple(args, "setViewport", 1, 4, &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return 0;


    // Overloaded function decisor
    // 0: setViewport(QRect)
    // 1: setViewport(int,int,int,int)
    if (numArgs == 4 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2]) && SbkNumber_Check(pyargs[3])) {
        overloadId = 1; // setViewport(int,int,int,int)
    } else if (numArgs == 1 && Shiboken::Converter< ::QRect >::isConvertible(pyargs[0])) {
        overloadId = 0; // setViewport(QRect)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPainterFunc_setViewport_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // setViewport(QRect)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QRect cppArg0 = Shiboken::Converter<QRect >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // setViewport(QRect)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setViewport(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // setViewport(int,int,int,int)
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                int cppArg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);
                int cppArg3 = Shiboken::Converter<int >::toCpp(pyargs[3]);

                if(!PyErr_Occurred()) {
                    // setViewport(int,int,int,int)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setViewport(cppArg0, cppArg1, cppArg2, cppArg3);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QPainterFunc_setViewport_TypeError:
        const char* overloads[] = {"PySide.QtCore.QRect", "int, int, int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPainter.setViewport", overloads);
        return 0;
}

static PyObject* Sbk_QPainterFunc_setWindow(PyObject* self, PyObject* args)
{
    QPainter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPainter* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs == 2 || numArgs == 3)
        goto Sbk_QPainterFunc_setWindow_TypeError;

    if (!PyArg_UnpackTuple(args, "setWindow", 1, 4, &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return 0;


    // Overloaded function decisor
    // 0: setWindow(QRect)
    // 1: setWindow(int,int,int,int)
    if (numArgs == 4 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2]) && SbkNumber_Check(pyargs[3])) {
        overloadId = 1; // setWindow(int,int,int,int)
    } else if (numArgs == 1 && Shiboken::Converter< ::QRect >::isConvertible(pyargs[0])) {
        overloadId = 0; // setWindow(QRect)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPainterFunc_setWindow_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // setWindow(QRect)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QRect cppArg0 = Shiboken::Converter<QRect >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // setWindow(QRect)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setWindow(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // setWindow(int,int,int,int)
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                int cppArg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);
                int cppArg3 = Shiboken::Converter<int >::toCpp(pyargs[3]);

                if(!PyErr_Occurred()) {
                    // setWindow(int,int,int,int)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setWindow(cppArg0, cppArg1, cppArg2, cppArg3);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QPainterFunc_setWindow_TypeError:
        const char* overloads[] = {"PySide.QtCore.QRect", "int, int, int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPainter.setWindow", overloads);
        return 0;
}

static PyObject* Sbk_QPainterFunc_setWorldMatrix(PyObject* self, PyObject* args, PyObject* kwds)
{
    QPainter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPainter* >::toCpp(self);

    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QPainter.setWorldMatrix(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QPainter.setWorldMatrix(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:setWorldMatrix", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setWorldMatrix(QMatrix,bool)
    if (Shiboken::Converter< ::QMatrix >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // setWorldMatrix(QMatrix,bool)
        } else if (SbkNumber_Check(pyargs[1])) {
            overloadId = 0; // setWorldMatrix(QMatrix,bool)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPainterFunc_setWorldMatrix_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "combine");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "combine";
                    else if (SbkNumber_Check(value))
                        pyargs[1] = value;
                    else
                        goto Sbk_QPainterFunc_setWorldMatrix_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QPainter.setWorldMatrix(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QMatrix cppArg0 = Shiboken::Converter<QMatrix >::toCpp(pyargs[0]);
            bool cppArg1 = pyargs[1] ? Shiboken::Converter<bool >::toCpp(pyargs[1]) : false;

            if(!PyErr_Occurred()) {
                // setWorldMatrix(QMatrix,bool)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setWorldMatrix(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QPainterFunc_setWorldMatrix_TypeError:
        const char* overloads[] = {"PySide.QtGui.QMatrix, bool = false", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPainter.setWorldMatrix", overloads);
        return 0;
}

static PyObject* Sbk_QPainterFunc_setWorldMatrixEnabled(PyObject* self, PyObject* arg)
{
    QPainter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPainter* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setWorldMatrixEnabled(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setWorldMatrixEnabled(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPainterFunc_setWorldMatrixEnabled_TypeError;

    // Call function/method
    {
        {
            bool cppArg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setWorldMatrixEnabled(bool)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setWorldMatrixEnabled(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QPainterFunc_setWorldMatrixEnabled_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPainter.setWorldMatrixEnabled", overloads);
        return 0;
}

static PyObject* Sbk_QPainterFunc_setWorldTransform(PyObject* self, PyObject* args, PyObject* kwds)
{
    QPainter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPainter* >::toCpp(self);

    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QPainter.setWorldTransform(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QPainter.setWorldTransform(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:setWorldTransform", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setWorldTransform(QTransform,bool)
    if (Shiboken::Converter< ::QTransform >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // setWorldTransform(QTransform,bool)
        } else if (SbkNumber_Check(pyargs[1])) {
            overloadId = 0; // setWorldTransform(QTransform,bool)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPainterFunc_setWorldTransform_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "combine");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "combine";
                    else if (SbkNumber_Check(value))
                        pyargs[1] = value;
                    else
                        goto Sbk_QPainterFunc_setWorldTransform_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QPainter.setWorldTransform(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QTransform cppArg0 = Shiboken::Converter<QTransform >::toCpp(pyargs[0]);
            bool cppArg1 = pyargs[1] ? Shiboken::Converter<bool >::toCpp(pyargs[1]) : false;

            if(!PyErr_Occurred()) {
                // setWorldTransform(QTransform,bool)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setWorldTransform(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QPainterFunc_setWorldTransform_TypeError:
        const char* overloads[] = {"PySide.QtGui.QTransform, bool = false", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPainter.setWorldTransform", overloads);
        return 0;
}

static PyObject* Sbk_QPainterFunc_shear(PyObject* self, PyObject* args)
{
    QPainter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPainter* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "shear", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: shear(qreal,qreal)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 0; // shear(qreal,qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPainterFunc_shear_TypeError;

    // Call function/method
    {
        {
            qreal cppArg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
            qreal cppArg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // shear(qreal,qreal)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->shear(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QPainterFunc_shear_TypeError:
        const char* overloads[] = {"float, float", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPainter.shear", overloads);
        return 0;
}

static PyObject* Sbk_QPainterFunc_strokePath(PyObject* self, PyObject* args)
{
    QPainter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPainter* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "strokePath", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: strokePath(QPainterPath,QPen)
    if (numArgs == 2 && Shiboken::Converter< ::QPainterPath >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QPen >::isConvertible(pyargs[1])) {
        overloadId = 0; // strokePath(QPainterPath,QPen)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPainterFunc_strokePath_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QPainterPath cppArg0 = Shiboken::Converter<QPainterPath >::toCpp(pyargs[0]);
            if (!Shiboken::Object::isValid(pyargs[1]))
                return 0;
            QPen cppArg1 = Shiboken::Converter<QPen >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // strokePath(QPainterPath,QPen)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->strokePath(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QPainterFunc_strokePath_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPainterPath, PySide.QtGui.QPen", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPainter.strokePath", overloads);
        return 0;
}

static PyObject* Sbk_QPainterFunc_testRenderHint(PyObject* self, PyObject* arg)
{
    QPainter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPainter* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: testRenderHint(QPainter::RenderHint)const
    if (Shiboken::Converter< ::QPainter::RenderHint >::isConvertible(arg)) {
        overloadId = 0; // testRenderHint(QPainter::RenderHint)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPainterFunc_testRenderHint_TypeError;

    // Call function/method
    {
        {
            QPainter::RenderHint cppArg0 = Shiboken::Converter<QPainter::RenderHint >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // testRenderHint(QPainter::RenderHint)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QPainter*>(cppSelf)->testRenderHint(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QPainterFunc_testRenderHint_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPainter.RenderHint", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPainter.testRenderHint", overloads);
        return 0;
}

static PyObject* Sbk_QPainterFunc_transform(PyObject* self)
{
    QPainter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPainter* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // transform()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                const QTransform & cppResult = const_cast<const QPainter*>(cppSelf)->transform();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QTransform >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QPainterFunc_translate(PyObject* self, PyObject* args)
{
    QPainter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPainter* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "translate", 1, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: translate(QPoint)
    // 1: translate(QPointF)
    // 2: translate(qreal,qreal)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 2; // translate(qreal,qreal)
    } else if (numArgs == 1 && Shiboken::Converter< ::QPoint >::isConvertible(pyargs[0])) {
        overloadId = 0; // translate(QPoint)
    } else if (numArgs == 1 && Shiboken::Converter< ::QPointF >::isConvertible(pyargs[0])) {
        overloadId = 1; // translate(QPointF)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPainterFunc_translate_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // translate(QPoint)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QPoint cppArg0 = Shiboken::Converter<QPoint >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // translate(QPoint)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->translate(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // translate(QPointF)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QPointF cppArg0 = Shiboken::Converter<QPointF >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // translate(QPointF)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->translate(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 2: // translate(qreal,qreal)
            {
                qreal cppArg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
                qreal cppArg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // translate(qreal,qreal)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->translate(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QPainterFunc_translate_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPoint", "PySide.QtCore.QPointF", "float, float", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPainter.translate", overloads);
        return 0;
}

static PyObject* Sbk_QPainterFunc_viewTransformEnabled(PyObject* self)
{
    QPainter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPainter* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // viewTransformEnabled()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QPainter*>(cppSelf)->viewTransformEnabled();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QPainterFunc_viewport(PyObject* self)
{
    QPainter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPainter* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // viewport()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QRect cppResult = const_cast<const QPainter*>(cppSelf)->viewport();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QRect >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QPainterFunc_window(PyObject* self)
{
    QPainter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPainter* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // window()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QRect cppResult = const_cast<const QPainter*>(cppSelf)->window();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QRect >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QPainterFunc_worldMatrix(PyObject* self)
{
    QPainter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPainter* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // worldMatrix()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                const QMatrix & cppResult = const_cast<const QPainter*>(cppSelf)->worldMatrix();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QMatrix >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QPainterFunc_worldMatrixEnabled(PyObject* self)
{
    QPainter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPainter* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // worldMatrixEnabled()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QPainter*>(cppSelf)->worldMatrixEnabled();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QPainterFunc_worldTransform(PyObject* self)
{
    QPainter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPainter* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // worldTransform()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                const QTransform & cppResult = const_cast<const QPainter*>(cppSelf)->worldTransform();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QTransform >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef Sbk_QPainter_methods[] = {
    {"background", (PyCFunction)Sbk_QPainterFunc_background, METH_NOARGS},
    {"backgroundMode", (PyCFunction)Sbk_QPainterFunc_backgroundMode, METH_NOARGS},
    {"begin", (PyCFunction)Sbk_QPainterFunc_begin, METH_O},
    {"beginNativePainting", (PyCFunction)Sbk_QPainterFunc_beginNativePainting, METH_NOARGS},
    {"boundingRect", (PyCFunction)Sbk_QPainterFunc_boundingRect, METH_VARARGS|METH_KEYWORDS},
    {"brush", (PyCFunction)Sbk_QPainterFunc_brush, METH_NOARGS},
    {"brushOrigin", (PyCFunction)Sbk_QPainterFunc_brushOrigin, METH_NOARGS},
    {"clipPath", (PyCFunction)Sbk_QPainterFunc_clipPath, METH_NOARGS},
    {"clipRegion", (PyCFunction)Sbk_QPainterFunc_clipRegion, METH_NOARGS},
    {"combinedMatrix", (PyCFunction)Sbk_QPainterFunc_combinedMatrix, METH_NOARGS},
    {"combinedTransform", (PyCFunction)Sbk_QPainterFunc_combinedTransform, METH_NOARGS},
    {"compositionMode", (PyCFunction)Sbk_QPainterFunc_compositionMode, METH_NOARGS},
    {"device", (PyCFunction)Sbk_QPainterFunc_device, METH_NOARGS},
    {"deviceMatrix", (PyCFunction)Sbk_QPainterFunc_deviceMatrix, METH_NOARGS},
    {"deviceTransform", (PyCFunction)Sbk_QPainterFunc_deviceTransform, METH_NOARGS},
    {"drawArc", (PyCFunction)Sbk_QPainterFunc_drawArc, METH_VARARGS},
    {"drawChord", (PyCFunction)Sbk_QPainterFunc_drawChord, METH_VARARGS},
    {"drawConvexPolygon", (PyCFunction)Sbk_QPainterFunc_drawConvexPolygon, METH_O},
    {"drawEllipse", (PyCFunction)Sbk_QPainterFunc_drawEllipse, METH_VARARGS},
    {"drawImage", (PyCFunction)Sbk_QPainterFunc_drawImage, METH_VARARGS|METH_KEYWORDS},
    {"drawLine", (PyCFunction)Sbk_QPainterFunc_drawLine, METH_VARARGS},
    {"drawLines", (PyCFunction)Sbk_QPainterFunc_drawLines, METH_O},
    {"drawPath", (PyCFunction)Sbk_QPainterFunc_drawPath, METH_O},
    {"drawPicture", (PyCFunction)Sbk_QPainterFunc_drawPicture, METH_VARARGS},
    {"drawPie", (PyCFunction)Sbk_QPainterFunc_drawPie, METH_VARARGS},
    {"drawPixmap", (PyCFunction)Sbk_QPainterFunc_drawPixmap, METH_VARARGS},
    {"drawPoint", (PyCFunction)Sbk_QPainterFunc_drawPoint, METH_VARARGS},
    {"drawPoints", (PyCFunction)Sbk_QPainterFunc_drawPoints, METH_O},
    {"drawPolygon", (PyCFunction)Sbk_QPainterFunc_drawPolygon, METH_VARARGS|METH_KEYWORDS},
    {"drawPolyline", (PyCFunction)Sbk_QPainterFunc_drawPolyline, METH_O},
    {"drawRect", (PyCFunction)Sbk_QPainterFunc_drawRect, METH_VARARGS},
    {"drawRects", (PyCFunction)Sbk_QPainterFunc_drawRects, METH_O},
    {"drawRoundRect", (PyCFunction)Sbk_QPainterFunc_drawRoundRect, METH_VARARGS|METH_KEYWORDS},
    {"drawRoundedRect", (PyCFunction)Sbk_QPainterFunc_drawRoundedRect, METH_VARARGS|METH_KEYWORDS},
    {"drawText", (PyCFunction)Sbk_QPainterFunc_drawText, METH_VARARGS|METH_KEYWORDS},
    {"drawTextItem", (PyCFunction)Sbk_QPainterFunc_drawTextItem, METH_VARARGS},
    {"drawTiledPixmap", (PyCFunction)Sbk_QPainterFunc_drawTiledPixmap, METH_VARARGS|METH_KEYWORDS},
    {"end", (PyCFunction)Sbk_QPainterFunc_end, METH_NOARGS},
    {"endNativePainting", (PyCFunction)Sbk_QPainterFunc_endNativePainting, METH_NOARGS},
    {"eraseRect", (PyCFunction)Sbk_QPainterFunc_eraseRect, METH_VARARGS},
    {"fillPath", (PyCFunction)Sbk_QPainterFunc_fillPath, METH_VARARGS},
    {"fillRect", (PyCFunction)Sbk_QPainterFunc_fillRect, METH_VARARGS},
    {"font", (PyCFunction)Sbk_QPainterFunc_font, METH_NOARGS},
    {"fontInfo", (PyCFunction)Sbk_QPainterFunc_fontInfo, METH_NOARGS},
    {"fontMetrics", (PyCFunction)Sbk_QPainterFunc_fontMetrics, METH_NOARGS},
    {"hasClipping", (PyCFunction)Sbk_QPainterFunc_hasClipping, METH_NOARGS},
    {"initFrom", (PyCFunction)Sbk_QPainterFunc_initFrom, METH_O},
    {"isActive", (PyCFunction)Sbk_QPainterFunc_isActive, METH_NOARGS},
    {"layoutDirection", (PyCFunction)Sbk_QPainterFunc_layoutDirection, METH_NOARGS},
    {"opacity", (PyCFunction)Sbk_QPainterFunc_opacity, METH_NOARGS},
    {"paintEngine", (PyCFunction)Sbk_QPainterFunc_paintEngine, METH_NOARGS},
    {"pen", (PyCFunction)Sbk_QPainterFunc_pen, METH_NOARGS},
    {"renderHints", (PyCFunction)Sbk_QPainterFunc_renderHints, METH_NOARGS},
    {"resetMatrix", (PyCFunction)Sbk_QPainterFunc_resetMatrix, METH_NOARGS},
    {"resetTransform", (PyCFunction)Sbk_QPainterFunc_resetTransform, METH_NOARGS},
    {"restore", (PyCFunction)Sbk_QPainterFunc_restore, METH_NOARGS},
    {"restoreRedirected", (PyCFunction)Sbk_QPainterFunc_restoreRedirected, METH_O|METH_STATIC},
    {"rotate", (PyCFunction)Sbk_QPainterFunc_rotate, METH_O},
    {"save", (PyCFunction)Sbk_QPainterFunc_save, METH_NOARGS},
    {"scale", (PyCFunction)Sbk_QPainterFunc_scale, METH_VARARGS},
    {"setBackground", (PyCFunction)Sbk_QPainterFunc_setBackground, METH_O},
    {"setBackgroundMode", (PyCFunction)Sbk_QPainterFunc_setBackgroundMode, METH_O},
    {"setBrush", (PyCFunction)Sbk_QPainterFunc_setBrush, METH_O},
    {"setBrushOrigin", (PyCFunction)Sbk_QPainterFunc_setBrushOrigin, METH_VARARGS},
    {"setClipPath", (PyCFunction)Sbk_QPainterFunc_setClipPath, METH_VARARGS|METH_KEYWORDS},
    {"setClipRect", (PyCFunction)Sbk_QPainterFunc_setClipRect, METH_VARARGS|METH_KEYWORDS},
    {"setClipRegion", (PyCFunction)Sbk_QPainterFunc_setClipRegion, METH_VARARGS|METH_KEYWORDS},
    {"setClipping", (PyCFunction)Sbk_QPainterFunc_setClipping, METH_O},
    {"setCompositionMode", (PyCFunction)Sbk_QPainterFunc_setCompositionMode, METH_O},
    {"setFont", (PyCFunction)Sbk_QPainterFunc_setFont, METH_O},
    {"setLayoutDirection", (PyCFunction)Sbk_QPainterFunc_setLayoutDirection, METH_O},
    {"setOpacity", (PyCFunction)Sbk_QPainterFunc_setOpacity, METH_O},
    {"setPen", (PyCFunction)Sbk_QPainterFunc_setPen, METH_O},
    {"setRedirected", (PyCFunction)Sbk_QPainterFunc_setRedirected, METH_VARARGS|METH_KEYWORDS|METH_STATIC},
    {"setRenderHint", (PyCFunction)Sbk_QPainterFunc_setRenderHint, METH_VARARGS|METH_KEYWORDS},
    {"setRenderHints", (PyCFunction)Sbk_QPainterFunc_setRenderHints, METH_VARARGS|METH_KEYWORDS},
    {"setTransform", (PyCFunction)Sbk_QPainterFunc_setTransform, METH_VARARGS|METH_KEYWORDS},
    {"setViewTransformEnabled", (PyCFunction)Sbk_QPainterFunc_setViewTransformEnabled, METH_O},
    {"setViewport", (PyCFunction)Sbk_QPainterFunc_setViewport, METH_VARARGS},
    {"setWindow", (PyCFunction)Sbk_QPainterFunc_setWindow, METH_VARARGS},
    {"setWorldMatrix", (PyCFunction)Sbk_QPainterFunc_setWorldMatrix, METH_VARARGS|METH_KEYWORDS},
    {"setWorldMatrixEnabled", (PyCFunction)Sbk_QPainterFunc_setWorldMatrixEnabled, METH_O},
    {"setWorldTransform", (PyCFunction)Sbk_QPainterFunc_setWorldTransform, METH_VARARGS|METH_KEYWORDS},
    {"shear", (PyCFunction)Sbk_QPainterFunc_shear, METH_VARARGS},
    {"strokePath", (PyCFunction)Sbk_QPainterFunc_strokePath, METH_VARARGS},
    {"testRenderHint", (PyCFunction)Sbk_QPainterFunc_testRenderHint, METH_O},
    {"transform", (PyCFunction)Sbk_QPainterFunc_transform, METH_NOARGS},
    {"translate", (PyCFunction)Sbk_QPainterFunc_translate, METH_VARARGS},
    {"viewTransformEnabled", (PyCFunction)Sbk_QPainterFunc_viewTransformEnabled, METH_NOARGS},
    {"viewport", (PyCFunction)Sbk_QPainterFunc_viewport, METH_NOARGS},
    {"window", (PyCFunction)Sbk_QPainterFunc_window, METH_NOARGS},
    {"worldMatrix", (PyCFunction)Sbk_QPainterFunc_worldMatrix, METH_NOARGS},
    {"worldMatrixEnabled", (PyCFunction)Sbk_QPainterFunc_worldMatrixEnabled, METH_NOARGS},
    {"worldTransform", (PyCFunction)Sbk_QPainterFunc_worldTransform, METH_NOARGS},

    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QPainter_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QPainter",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QPainter_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&SbkObject_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QPainter_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern

PyObject* SbkPySide_QtGui_QPainter_RenderHint___and__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QPainter::RenderHints >::toPython(
        Shiboken::Converter<QPainter::RenderHints>::toCpp(self)
        & Shiboken::Converter< QPainter::RenderHints >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtGui_QPainter_RenderHint___or__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QPainter::RenderHints >::toPython(
        Shiboken::Converter<QPainter::RenderHints>::toCpp(self)
        | Shiboken::Converter< QPainter::RenderHints >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtGui_QPainter_RenderHint___xor__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QPainter::RenderHints >::toPython(
        Shiboken::Converter<QPainter::RenderHints>::toCpp(self)
        ^ Shiboken::Converter< QPainter::RenderHints >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtGui_QPainter_RenderHint___invert__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QPainter::RenderHints >::toPython(
        ~Shiboken::Converter<QPainter::RenderHints >::toCpp(self)
    );
}


static PyNumberMethods SbkPySide_QtGui_QPainter_RenderHint_as_number = {
    /*nb_add*/                  0,
    /*nb_subtract*/             0,
    /*nb_multiply*/             0,
    /*nb_divide*/               0,
    /*nb_remainder*/            0,
    /*nb_divmod*/               0,
    /*nb_power*/                0,
    /*nb_negative*/             0,
    /*nb_positive*/             0,
    /*nb_absolute*/             0,
    /*nb_nonzero*/              0,
    /*nb_invert*/               (unaryfunc)SbkPySide_QtGui_QPainter_RenderHint___invert__,
    /*nb_lshift*/               0,
    /*nb_rshift*/               0,
    /*nb_and*/                  (binaryfunc)SbkPySide_QtGui_QPainter_RenderHint___and__,
    /*nb_xor*/                  (binaryfunc)SbkPySide_QtGui_QPainter_RenderHint___xor__,
    /*nb_or*/                   (binaryfunc)SbkPySide_QtGui_QPainter_RenderHint___or__,
    /*nb_coerce*/               0,
    /*nb_int*/                  0,
    /*nb_long*/                 0,
    /*nb_float*/                0,
    /*nb_oct*/                  0,
    /*nb_hex*/                  0,
    /*nb_inplace_add*/          0,
    /*nb_inplace_subtract*/     0,
    /*nb_inplace_multiply*/     0,
    /*nb_inplace_divide*/       0,
    /*nb_inplace_remainder*/    0,
    /*nb_inplace_power*/        0,
    /*nb_inplace_lshift*/       0,
    /*nb_inplace_rshift*/       0,
    /*nb_inplace_and*/          0,
    /*nb_inplace_xor*/          0,
    /*nb_inplace_or*/           0,
    /*nb_floor_divide*/         0,
    /*nb_true_divide*/          0,
    /*nb_inplace_floor_divide*/ 0,
    /*nb_inplace_true_divide*/  0,
    /*nb_index*/                0
};


// forward declaration of new function
static PyTypeObject SbkPySide_QtGui_QPainter_RenderHints_Type = {
    PyObject_HEAD_INIT(&PyType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "RenderHints",
    /*tp_basicsize*/        0,
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        &SbkPySide_QtGui_QPainter_RenderHint_as_number,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT | Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              PyInt_Type.tp_new,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};


PyObject* SbkPySide_QtGui_QPainter_PixmapFragmentHint___and__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QPainter::PixmapFragmentHints >::toPython(
        Shiboken::Converter<QPainter::PixmapFragmentHints>::toCpp(self)
        & Shiboken::Converter< QPainter::PixmapFragmentHints >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtGui_QPainter_PixmapFragmentHint___or__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QPainter::PixmapFragmentHints >::toPython(
        Shiboken::Converter<QPainter::PixmapFragmentHints>::toCpp(self)
        | Shiboken::Converter< QPainter::PixmapFragmentHints >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtGui_QPainter_PixmapFragmentHint___xor__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QPainter::PixmapFragmentHints >::toPython(
        Shiboken::Converter<QPainter::PixmapFragmentHints>::toCpp(self)
        ^ Shiboken::Converter< QPainter::PixmapFragmentHints >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtGui_QPainter_PixmapFragmentHint___invert__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QPainter::PixmapFragmentHints >::toPython(
        ~Shiboken::Converter<QPainter::PixmapFragmentHints >::toCpp(self)
    );
}


static PyNumberMethods SbkPySide_QtGui_QPainter_PixmapFragmentHint_as_number = {
    /*nb_add*/                  0,
    /*nb_subtract*/             0,
    /*nb_multiply*/             0,
    /*nb_divide*/               0,
    /*nb_remainder*/            0,
    /*nb_divmod*/               0,
    /*nb_power*/                0,
    /*nb_negative*/             0,
    /*nb_positive*/             0,
    /*nb_absolute*/             0,
    /*nb_nonzero*/              0,
    /*nb_invert*/               (unaryfunc)SbkPySide_QtGui_QPainter_PixmapFragmentHint___invert__,
    /*nb_lshift*/               0,
    /*nb_rshift*/               0,
    /*nb_and*/                  (binaryfunc)SbkPySide_QtGui_QPainter_PixmapFragmentHint___and__,
    /*nb_xor*/                  (binaryfunc)SbkPySide_QtGui_QPainter_PixmapFragmentHint___xor__,
    /*nb_or*/                   (binaryfunc)SbkPySide_QtGui_QPainter_PixmapFragmentHint___or__,
    /*nb_coerce*/               0,
    /*nb_int*/                  0,
    /*nb_long*/                 0,
    /*nb_float*/                0,
    /*nb_oct*/                  0,
    /*nb_hex*/                  0,
    /*nb_inplace_add*/          0,
    /*nb_inplace_subtract*/     0,
    /*nb_inplace_multiply*/     0,
    /*nb_inplace_divide*/       0,
    /*nb_inplace_remainder*/    0,
    /*nb_inplace_power*/        0,
    /*nb_inplace_lshift*/       0,
    /*nb_inplace_rshift*/       0,
    /*nb_inplace_and*/          0,
    /*nb_inplace_xor*/          0,
    /*nb_inplace_or*/           0,
    /*nb_floor_divide*/         0,
    /*nb_true_divide*/          0,
    /*nb_inplace_floor_divide*/ 0,
    /*nb_inplace_true_divide*/  0,
    /*nb_index*/                0
};


// forward declaration of new function
static PyTypeObject SbkPySide_QtGui_QPainter_PixmapFragmentHints_Type = {
    PyObject_HEAD_INIT(&PyType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PixmapFragmentHints",
    /*tp_basicsize*/        0,
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        &SbkPySide_QtGui_QPainter_PixmapFragmentHint_as_number,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT | Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              PyInt_Type.tp_new,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};



void init_QPainter(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QPAINTER_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QPainter_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QPainter_Type);
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QPainter_Type, &Shiboken::callCppDestructor<QPainter >);
    Py_INCREF((PyObject*)&Sbk_QPainter_Type); //Incref due the 'PyModule_AddObject' steals the reference.
    if (PyType_Ready((PyTypeObject*)&Sbk_QPainter_Type) < 0)
        return;

    Shiboken::ObjectType::setOriginalName(&Sbk_QPainter_Type, "QPainter*");
    PyModule_AddObject(module, "QPainter",
        ((PyObject*)&Sbk_QPainter_Type));

    // Initialize enums
    PyObject* enumItem;

    // init enum: CompositionMode
    PyTypeObject* SbkPySide_QtGui_QPainter_CompositionMode = Shiboken::Enum::newType("PySide.QtGui.QPainter.CompositionMode");
    SbkPySide_QtGuiTypes[SBK_QPAINTER_COMPOSITIONMODE_IDX] = SbkPySide_QtGui_QPainter_CompositionMode;
    if (PyType_Ready(SbkPySide_QtGui_QPainter_CompositionMode) < 0)
        return;
    PyDict_SetItemString(Sbk_QPainter_Type.super.ht_type.tp_dict,
            "CompositionMode",((PyObject*)SbkPySide_QtGui_QPainter_CompositionMode));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPainter_CompositionMode,(long) QPainter::CompositionMode_SourceOver, "CompositionMode_SourceOver");
    PyDict_SetItemString(Sbk_QPainter_Type.super.ht_type.tp_dict,"CompositionMode_SourceOver", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPainter_CompositionMode->tp_dict,"CompositionMode_SourceOver", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPainter_CompositionMode,(long) QPainter::CompositionMode_DestinationOver, "CompositionMode_DestinationOver");
    PyDict_SetItemString(Sbk_QPainter_Type.super.ht_type.tp_dict,"CompositionMode_DestinationOver", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPainter_CompositionMode->tp_dict,"CompositionMode_DestinationOver", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPainter_CompositionMode,(long) QPainter::CompositionMode_Clear, "CompositionMode_Clear");
    PyDict_SetItemString(Sbk_QPainter_Type.super.ht_type.tp_dict,"CompositionMode_Clear", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPainter_CompositionMode->tp_dict,"CompositionMode_Clear", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPainter_CompositionMode,(long) QPainter::CompositionMode_Source, "CompositionMode_Source");
    PyDict_SetItemString(Sbk_QPainter_Type.super.ht_type.tp_dict,"CompositionMode_Source", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPainter_CompositionMode->tp_dict,"CompositionMode_Source", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPainter_CompositionMode,(long) QPainter::CompositionMode_Destination, "CompositionMode_Destination");
    PyDict_SetItemString(Sbk_QPainter_Type.super.ht_type.tp_dict,"CompositionMode_Destination", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPainter_CompositionMode->tp_dict,"CompositionMode_Destination", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPainter_CompositionMode,(long) QPainter::CompositionMode_SourceIn, "CompositionMode_SourceIn");
    PyDict_SetItemString(Sbk_QPainter_Type.super.ht_type.tp_dict,"CompositionMode_SourceIn", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPainter_CompositionMode->tp_dict,"CompositionMode_SourceIn", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPainter_CompositionMode,(long) QPainter::CompositionMode_DestinationIn, "CompositionMode_DestinationIn");
    PyDict_SetItemString(Sbk_QPainter_Type.super.ht_type.tp_dict,"CompositionMode_DestinationIn", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPainter_CompositionMode->tp_dict,"CompositionMode_DestinationIn", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPainter_CompositionMode,(long) QPainter::CompositionMode_SourceOut, "CompositionMode_SourceOut");
    PyDict_SetItemString(Sbk_QPainter_Type.super.ht_type.tp_dict,"CompositionMode_SourceOut", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPainter_CompositionMode->tp_dict,"CompositionMode_SourceOut", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPainter_CompositionMode,(long) QPainter::CompositionMode_DestinationOut, "CompositionMode_DestinationOut");
    PyDict_SetItemString(Sbk_QPainter_Type.super.ht_type.tp_dict,"CompositionMode_DestinationOut", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPainter_CompositionMode->tp_dict,"CompositionMode_DestinationOut", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPainter_CompositionMode,(long) QPainter::CompositionMode_SourceAtop, "CompositionMode_SourceAtop");
    PyDict_SetItemString(Sbk_QPainter_Type.super.ht_type.tp_dict,"CompositionMode_SourceAtop", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPainter_CompositionMode->tp_dict,"CompositionMode_SourceAtop", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPainter_CompositionMode,(long) QPainter::CompositionMode_DestinationAtop, "CompositionMode_DestinationAtop");
    PyDict_SetItemString(Sbk_QPainter_Type.super.ht_type.tp_dict,"CompositionMode_DestinationAtop", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPainter_CompositionMode->tp_dict,"CompositionMode_DestinationAtop", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPainter_CompositionMode,(long) QPainter::CompositionMode_Xor, "CompositionMode_Xor");
    PyDict_SetItemString(Sbk_QPainter_Type.super.ht_type.tp_dict,"CompositionMode_Xor", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPainter_CompositionMode->tp_dict,"CompositionMode_Xor", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPainter_CompositionMode,(long) QPainter::CompositionMode_Plus, "CompositionMode_Plus");
    PyDict_SetItemString(Sbk_QPainter_Type.super.ht_type.tp_dict,"CompositionMode_Plus", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPainter_CompositionMode->tp_dict,"CompositionMode_Plus", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPainter_CompositionMode,(long) QPainter::CompositionMode_Multiply, "CompositionMode_Multiply");
    PyDict_SetItemString(Sbk_QPainter_Type.super.ht_type.tp_dict,"CompositionMode_Multiply", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPainter_CompositionMode->tp_dict,"CompositionMode_Multiply", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPainter_CompositionMode,(long) QPainter::CompositionMode_Screen, "CompositionMode_Screen");
    PyDict_SetItemString(Sbk_QPainter_Type.super.ht_type.tp_dict,"CompositionMode_Screen", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPainter_CompositionMode->tp_dict,"CompositionMode_Screen", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPainter_CompositionMode,(long) QPainter::CompositionMode_Overlay, "CompositionMode_Overlay");
    PyDict_SetItemString(Sbk_QPainter_Type.super.ht_type.tp_dict,"CompositionMode_Overlay", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPainter_CompositionMode->tp_dict,"CompositionMode_Overlay", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPainter_CompositionMode,(long) QPainter::CompositionMode_Darken, "CompositionMode_Darken");
    PyDict_SetItemString(Sbk_QPainter_Type.super.ht_type.tp_dict,"CompositionMode_Darken", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPainter_CompositionMode->tp_dict,"CompositionMode_Darken", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPainter_CompositionMode,(long) QPainter::CompositionMode_Lighten, "CompositionMode_Lighten");
    PyDict_SetItemString(Sbk_QPainter_Type.super.ht_type.tp_dict,"CompositionMode_Lighten", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPainter_CompositionMode->tp_dict,"CompositionMode_Lighten", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPainter_CompositionMode,(long) QPainter::CompositionMode_ColorDodge, "CompositionMode_ColorDodge");
    PyDict_SetItemString(Sbk_QPainter_Type.super.ht_type.tp_dict,"CompositionMode_ColorDodge", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPainter_CompositionMode->tp_dict,"CompositionMode_ColorDodge", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPainter_CompositionMode,(long) QPainter::CompositionMode_ColorBurn, "CompositionMode_ColorBurn");
    PyDict_SetItemString(Sbk_QPainter_Type.super.ht_type.tp_dict,"CompositionMode_ColorBurn", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPainter_CompositionMode->tp_dict,"CompositionMode_ColorBurn", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPainter_CompositionMode,(long) QPainter::CompositionMode_HardLight, "CompositionMode_HardLight");
    PyDict_SetItemString(Sbk_QPainter_Type.super.ht_type.tp_dict,"CompositionMode_HardLight", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPainter_CompositionMode->tp_dict,"CompositionMode_HardLight", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPainter_CompositionMode,(long) QPainter::CompositionMode_SoftLight, "CompositionMode_SoftLight");
    PyDict_SetItemString(Sbk_QPainter_Type.super.ht_type.tp_dict,"CompositionMode_SoftLight", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPainter_CompositionMode->tp_dict,"CompositionMode_SoftLight", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPainter_CompositionMode,(long) QPainter::CompositionMode_Difference, "CompositionMode_Difference");
    PyDict_SetItemString(Sbk_QPainter_Type.super.ht_type.tp_dict,"CompositionMode_Difference", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPainter_CompositionMode->tp_dict,"CompositionMode_Difference", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPainter_CompositionMode,(long) QPainter::CompositionMode_Exclusion, "CompositionMode_Exclusion");
    PyDict_SetItemString(Sbk_QPainter_Type.super.ht_type.tp_dict,"CompositionMode_Exclusion", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPainter_CompositionMode->tp_dict,"CompositionMode_Exclusion", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPainter_CompositionMode,(long) QPainter::RasterOp_SourceOrDestination, "RasterOp_SourceOrDestination");
    PyDict_SetItemString(Sbk_QPainter_Type.super.ht_type.tp_dict,"RasterOp_SourceOrDestination", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPainter_CompositionMode->tp_dict,"RasterOp_SourceOrDestination", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPainter_CompositionMode,(long) QPainter::RasterOp_SourceAndDestination, "RasterOp_SourceAndDestination");
    PyDict_SetItemString(Sbk_QPainter_Type.super.ht_type.tp_dict,"RasterOp_SourceAndDestination", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPainter_CompositionMode->tp_dict,"RasterOp_SourceAndDestination", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPainter_CompositionMode,(long) QPainter::RasterOp_SourceXorDestination, "RasterOp_SourceXorDestination");
    PyDict_SetItemString(Sbk_QPainter_Type.super.ht_type.tp_dict,"RasterOp_SourceXorDestination", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPainter_CompositionMode->tp_dict,"RasterOp_SourceXorDestination", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPainter_CompositionMode,(long) QPainter::RasterOp_NotSourceAndNotDestination, "RasterOp_NotSourceAndNotDestination");
    PyDict_SetItemString(Sbk_QPainter_Type.super.ht_type.tp_dict,"RasterOp_NotSourceAndNotDestination", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPainter_CompositionMode->tp_dict,"RasterOp_NotSourceAndNotDestination", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPainter_CompositionMode,(long) QPainter::RasterOp_NotSourceOrNotDestination, "RasterOp_NotSourceOrNotDestination");
    PyDict_SetItemString(Sbk_QPainter_Type.super.ht_type.tp_dict,"RasterOp_NotSourceOrNotDestination", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPainter_CompositionMode->tp_dict,"RasterOp_NotSourceOrNotDestination", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPainter_CompositionMode,(long) QPainter::RasterOp_NotSourceXorDestination, "RasterOp_NotSourceXorDestination");
    PyDict_SetItemString(Sbk_QPainter_Type.super.ht_type.tp_dict,"RasterOp_NotSourceXorDestination", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPainter_CompositionMode->tp_dict,"RasterOp_NotSourceXorDestination", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPainter_CompositionMode,(long) QPainter::RasterOp_NotSource, "RasterOp_NotSource");
    PyDict_SetItemString(Sbk_QPainter_Type.super.ht_type.tp_dict,"RasterOp_NotSource", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPainter_CompositionMode->tp_dict,"RasterOp_NotSource", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPainter_CompositionMode,(long) QPainter::RasterOp_NotSourceAndDestination, "RasterOp_NotSourceAndDestination");
    PyDict_SetItemString(Sbk_QPainter_Type.super.ht_type.tp_dict,"RasterOp_NotSourceAndDestination", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPainter_CompositionMode->tp_dict,"RasterOp_NotSourceAndDestination", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPainter_CompositionMode,(long) QPainter::RasterOp_SourceAndNotDestination, "RasterOp_SourceAndNotDestination");
    PyDict_SetItemString(Sbk_QPainter_Type.super.ht_type.tp_dict,"RasterOp_SourceAndNotDestination", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPainter_CompositionMode->tp_dict,"RasterOp_SourceAndNotDestination", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QPainter::CompositionMode");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::CompositionMode");
    // end of enum CompositionMode

    // init enum: RenderHint
    PyTypeObject* SbkPySide_QtGui_QPainter_RenderHint = Shiboken::Enum::newType("PySide.QtGui.QPainter.RenderHint");
    SbkPySide_QtGui_QPainter_RenderHint->tp_as_number = &SbkPySide_QtGui_QPainter_RenderHint_as_number;
    SbkPySide_QtGuiTypes[SBK_QPAINTER_RENDERHINT_IDX] = SbkPySide_QtGui_QPainter_RenderHint;
    if (PyType_Ready(SbkPySide_QtGui_QPainter_RenderHint) < 0)
        return;
    PyDict_SetItemString(Sbk_QPainter_Type.super.ht_type.tp_dict,
            "RenderHint",((PyObject*)SbkPySide_QtGui_QPainter_RenderHint));

    // init flags class: QFlags<QPainter::RenderHint>
    SbkPySide_QtGuiTypes[SBK_QFLAGS_QPAINTER_RENDERHINT__IDX] = &SbkPySide_QtGui_QPainter_RenderHints_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtGui_QPainter_RenderHints_Type) < 0)
        return;
    PyDict_SetItemString(Sbk_QPainter_Type.super.ht_type.tp_dict,
            "RenderHints",((PyObject*)&SbkPySide_QtGui_QPainter_RenderHints_Type));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPainter_RenderHint,(long) QPainter::Antialiasing, "Antialiasing");
    PyDict_SetItemString(Sbk_QPainter_Type.super.ht_type.tp_dict,"Antialiasing", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPainter_RenderHint->tp_dict,"Antialiasing", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPainter_RenderHint,(long) QPainter::TextAntialiasing, "TextAntialiasing");
    PyDict_SetItemString(Sbk_QPainter_Type.super.ht_type.tp_dict,"TextAntialiasing", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPainter_RenderHint->tp_dict,"TextAntialiasing", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPainter_RenderHint,(long) QPainter::SmoothPixmapTransform, "SmoothPixmapTransform");
    PyDict_SetItemString(Sbk_QPainter_Type.super.ht_type.tp_dict,"SmoothPixmapTransform", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPainter_RenderHint->tp_dict,"SmoothPixmapTransform", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPainter_RenderHint,(long) QPainter::HighQualityAntialiasing, "HighQualityAntialiasing");
    PyDict_SetItemString(Sbk_QPainter_Type.super.ht_type.tp_dict,"HighQualityAntialiasing", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPainter_RenderHint->tp_dict,"HighQualityAntialiasing", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPainter_RenderHint,(long) QPainter::NonCosmeticDefaultPen, "NonCosmeticDefaultPen");
    PyDict_SetItemString(Sbk_QPainter_Type.super.ht_type.tp_dict,"NonCosmeticDefaultPen", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPainter_RenderHint->tp_dict,"NonCosmeticDefaultPen", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QPainter::RenderHint");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::RenderHint");
    // end of enum RenderHint

    // init enum: PixmapFragmentHint
    PyTypeObject* SbkPySide_QtGui_QPainter_PixmapFragmentHint = Shiboken::Enum::newType("PySide.QtGui.QPainter.PixmapFragmentHint");
    SbkPySide_QtGui_QPainter_PixmapFragmentHint->tp_as_number = &SbkPySide_QtGui_QPainter_PixmapFragmentHint_as_number;
    SbkPySide_QtGuiTypes[SBK_QPAINTER_PIXMAPFRAGMENTHINT_IDX] = SbkPySide_QtGui_QPainter_PixmapFragmentHint;
    if (PyType_Ready(SbkPySide_QtGui_QPainter_PixmapFragmentHint) < 0)
        return;
    PyDict_SetItemString(Sbk_QPainter_Type.super.ht_type.tp_dict,
            "PixmapFragmentHint",((PyObject*)SbkPySide_QtGui_QPainter_PixmapFragmentHint));

    // init flags class: QFlags<QPainter::PixmapFragmentHint>
    SbkPySide_QtGuiTypes[SBK_QFLAGS_QPAINTER_PIXMAPFRAGMENTHINT__IDX] = &SbkPySide_QtGui_QPainter_PixmapFragmentHints_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtGui_QPainter_PixmapFragmentHints_Type) < 0)
        return;
    PyDict_SetItemString(Sbk_QPainter_Type.super.ht_type.tp_dict,
            "PixmapFragmentHints",((PyObject*)&SbkPySide_QtGui_QPainter_PixmapFragmentHints_Type));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPainter_PixmapFragmentHint,(long) QPainter::OpaqueHint, "OpaqueHint");
    PyDict_SetItemString(Sbk_QPainter_Type.super.ht_type.tp_dict,"OpaqueHint", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPainter_PixmapFragmentHint->tp_dict,"OpaqueHint", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QPainter::PixmapFragmentHint");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::PixmapFragmentHint");
    // end of enum PixmapFragmentHint


    Shiboken::TypeResolver::createObjectTypeResolver<QPainter >("QPainter*");
    Shiboken::TypeResolver::createObjectTypeResolver<QPainter >(typeid(QPainter).name());
    qRegisterMetaType< ::QPainter* >("QPainter*");
    qRegisterMetaType< ::QPainter::CompositionMode >("QPainter::CompositionMode");
    qRegisterMetaType< ::QPainter::RenderHint >("QPainter::RenderHint");
    qRegisterMetaType< ::QPainter::RenderHints >("QPainter::RenderHints");
    qRegisterMetaType< ::QPainter::PixmapFragmentHint >("QPainter::PixmapFragmentHint");
    qRegisterMetaType< ::QPainter::PixmapFragmentHints >("QPainter::PixmapFragmentHints");
}

