/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include "pyside_qtopengl_python.h"

#include "qglshaderprogram_wrapper.h"

// Extra includes
#include <QList>
#include <qbytearray.h>
#include <qcolor.h>
#include <qcoreevent.h>
#include <qgenericmatrix.h>
#include <qgl.h>
#include <qglshaderprogram.h>
#include <qmatrix4x4.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qpoint.h>
#include <qsize.h>
#include <qthread.h>
#include <qtransform.h>
#include <qvector2d.h>
#include <qvector3d.h>
#include <qvector4d.h>


// Native ---------------------------------------------------------

QGLShaderProgramWrapper::QGLShaderProgramWrapper(QObject * parent) : QGLShaderProgram(parent) {
    // ... middle
}

QGLShaderProgramWrapper::QGLShaderProgramWrapper(const QGLContext * context, QObject * parent) : QGLShaderProgram(context, parent) {
    // ... middle
}

void QGLShaderProgramWrapper::childEvent(QChildEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "childEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::childEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QChildEvent * >::toPython(arg__1)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QGLShaderProgramWrapper::connectNotify(const char * signal)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "connectNotify"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::connectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QGLShaderProgramWrapper::customEvent(QEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "customEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::customEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QEvent * >::toPython(arg__1)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QGLShaderProgramWrapper::disconnectNotify(const char * signal)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "disconnectNotify"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::disconnectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

bool QGLShaderProgramWrapper::event(QEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return bool(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "event"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::event(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QEvent * >::toPython(arg__1)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QGLShaderProgram.event", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
    return cppResult;
}

bool QGLShaderProgramWrapper::eventFilter(QObject * arg__1, QEvent * arg__2)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return bool(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "eventFilter"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::eventFilter(arg__1, arg__2);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter< ::QObject * >::toPython(arg__1),
        Shiboken::Converter< ::QEvent * >::toPython(arg__2)
    ));
    bool invalidadeArg2 = PyTuple_GET_ITEM(pyargs, 1)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QGLShaderProgram.eventFilter", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    if (invalidadeArg2)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 1));
    return cppResult;
}

bool QGLShaderProgramWrapper::link()
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return bool(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "link"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QGLShaderProgram::link();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QGLShaderProgram.link", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    return cppResult;
}

void QGLShaderProgramWrapper::timerEvent(QTimerEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "timerEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::timerEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QTimerEvent * >::toPython(arg__1)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

const QMetaObject* QGLShaderProgramWrapper::metaObject() const
{
    SbkObject* pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    return reinterpret_cast<QMetaObject*>(Shiboken::Object::getTypeUserData(pySelf));
}

int QGLShaderProgramWrapper::qt_metacall(QMetaObject::Call call, int id, void** args)
{
    int result = QGLShaderProgram::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

QGLShaderProgramWrapper::~QGLShaderProgramWrapper()
{
    SbkObject* wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QGLShaderProgram_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QGLShaderProgram >()))
        return -1;

    QGLShaderProgramWrapper* cptr = 0;
    int overloadId = -1;
    const char* argNames[] = {"parent"};
    const QMetaObject* metaObject;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_ParseTuple(args, "|OO:QGLShaderProgram", &(pyargs[0]), &(pyargs[1])))
        return -1;

    // Overloaded function decisor
    // 0: QGLShaderProgram(QObject*)
    // 1: QGLShaderProgram(const QGLContext*,QObject*)
    if (numArgs == 0) {
        overloadId = 0; // QGLShaderProgram(QObject*)
    } else if (Shiboken::Converter< ::QGLContext * >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 1; // QGLShaderProgram(const QGLContext*,QObject*)
        } else if (Shiboken::Converter< ::QObject * >::isConvertible(pyargs[1])) {
            overloadId = 1; // QGLShaderProgram(const QGLContext*,QObject*)
        }
    } else if (Shiboken::Converter< ::QObject * >::isConvertible(pyargs[0])) {
        overloadId = 0; // QGLShaderProgram(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGLShaderProgram_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QGLShaderProgram(QObject*)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "parent");
                    if (value) {
                        if (pyargs[0])
                            errorArgName = "parent";
                        else if (Shiboken::Converter< ::QObject * >::isConvertible(value))
                            pyargs[0] = value;
                        else
                            goto Sbk_QGLShaderProgram_Init_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtOpenGL.QGLShaderProgram(): got multiple values for keyword argument '%s'", errorArgName);
                        return -1;
                    }
                }
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QObject * cppArg0 = pyargs[0] ? Shiboken::Converter<QObject * >::toCpp(pyargs[0]) : 0;

                if(!PyErr_Occurred()) {
                    // QGLShaderProgram(QObject*)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QGLShaderProgramWrapper(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    Shiboken::Object::setParent(pyargs[0], self);
                }
                break;
            }
            case 1: // QGLShaderProgram(const QGLContext*,QObject*)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "parent");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "parent";
                        else if (Shiboken::Converter< ::QObject * >::isConvertible(value))
                            pyargs[1] = value;
                        else
                            goto Sbk_QGLShaderProgram_Init_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtOpenGL.QGLShaderProgram(): got multiple values for keyword argument '%s'", errorArgName);
                        return -1;
                    }
                }
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QGLContext * cppArg0 = Shiboken::Converter<QGLContext * >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return -1;
                QObject * cppArg1 = pyargs[1] ? Shiboken::Converter<QObject * >::toCpp(pyargs[1]) : 0;

                if(!PyErr_Occurred()) {
                    // QGLShaderProgram(const QGLContext*,QObject*)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QGLShaderProgramWrapper(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    Shiboken::Object::setParent(pyargs[1], self);
                }
                break;
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QGLShaderProgram >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QGLShaderProgram_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    metaObject = cptr->metaObject(); // <- init python qt properties
    if (kwds && !PySide::fillQtProperties(self, metaObject, kwds, argNames, 1))
        return -1;


    return 1;

    Sbk_QGLShaderProgram_Init_TypeError:
        const char* overloads[] = {"PySide.QtCore.QObject = None", "PySide.QtOpenGL.QGLContext, PySide.QtCore.QObject = None", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtOpenGL.QGLShaderProgram", overloads);
        return -1;
}

static PyObject* Sbk_QGLShaderProgramFunc_addShader(PyObject* self, PyObject* arg)
{
    QGLShaderProgram* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGLShaderProgram* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: addShader(QGLShader*)
    if (Shiboken::Converter< ::QGLShader * >::isConvertible(arg)) {
        overloadId = 0; // addShader(QGLShader*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGLShaderProgramFunc_addShader_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QGLShader * cppArg0 = Shiboken::Converter<QGLShader * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // addShader(QGLShader*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->addShader(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QGLShaderProgramFunc_addShader_TypeError:
        const char* overloads[] = {"PySide.QtOpenGL.QGLShader", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtOpenGL.QGLShaderProgram.addShader", overloads);
        return 0;
}

static PyObject* Sbk_QGLShaderProgramFunc_addShaderFromSourceCode(PyObject* self, PyObject* args)
{
    QGLShaderProgram* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGLShaderProgram* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "addShaderFromSourceCode", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: addShaderFromSourceCode(QFlags<QGLShader::ShaderTypeBit>,QByteArray)
    // 1: addShaderFromSourceCode(QFlags<QGLShader::ShaderTypeBit>,QString)
    // 2: addShaderFromSourceCode(QFlags<QGLShader::ShaderTypeBit>,const char*)
    if (Shiboken::Converter< ::QFlags<QGLShader::ShaderTypeBit> >::isConvertible(pyargs[0])) {
        if (numArgs == 2 && Shiboken::Converter< const char * >::isConvertible(pyargs[1])) {
            overloadId = 2; // addShaderFromSourceCode(QFlags<QGLShader::ShaderTypeBit>,const char*)
        } else if (numArgs == 2 && Shiboken::Converter< QString >::isConvertible(pyargs[1])) {
            overloadId = 1; // addShaderFromSourceCode(QFlags<QGLShader::ShaderTypeBit>,QString)
        } else if (numArgs == 2 && Shiboken::Converter< ::QByteArray >::isConvertible(pyargs[1])) {
            overloadId = 0; // addShaderFromSourceCode(QFlags<QGLShader::ShaderTypeBit>,QByteArray)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGLShaderProgramFunc_addShaderFromSourceCode_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // addShaderFromSourceCode(QFlags<QGLShader::ShaderTypeBit>,QByteArray)
            {
                QFlags<QGLShader::ShaderTypeBit> cppArg0 = Shiboken::Converter<QFlags<QGLShader::ShaderTypeBit> >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return 0;
                QByteArray cppArg1 = Shiboken::Converter<QByteArray >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // addShaderFromSourceCode(QFlags<QGLShader::ShaderTypeBit>,QByteArray)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    bool cppResult = cppSelf->addShaderFromSourceCode(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< bool >::toPython(cppResult);
                }
                break;
            }
            case 1: // addShaderFromSourceCode(QFlags<QGLShader::ShaderTypeBit>,QString)
            {
                QFlags<QGLShader::ShaderTypeBit> cppArg0 = Shiboken::Converter<QFlags<QGLShader::ShaderTypeBit> >::toCpp(pyargs[0]);
                QString cppArg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // addShaderFromSourceCode(QFlags<QGLShader::ShaderTypeBit>,QString)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    bool cppResult = cppSelf->addShaderFromSourceCode(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< bool >::toPython(cppResult);
                }
                break;
            }
            case 2: // addShaderFromSourceCode(QFlags<QGLShader::ShaderTypeBit>,const char*)
            {
                QFlags<QGLShader::ShaderTypeBit> cppArg0 = Shiboken::Converter<QFlags<QGLShader::ShaderTypeBit> >::toCpp(pyargs[0]);
                const char * cppArg1 = Shiboken::Converter<const char * >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // addShaderFromSourceCode(QFlags<QGLShader::ShaderTypeBit>,const char*)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    bool cppResult = cppSelf->addShaderFromSourceCode(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< bool >::toPython(cppResult);
                }
                break;
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QGLShaderProgramFunc_addShaderFromSourceCode_TypeError:
        const char* overloads[] = {"PySide.QtOpenGL.QGLShader.ShaderType, PySide.QtCore.QByteArray", "PySide.QtOpenGL.QGLShader.ShaderType, QString", "PySide.QtOpenGL.QGLShader.ShaderType, str", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtOpenGL.QGLShaderProgram.addShaderFromSourceCode", overloads);
        return 0;
}

static PyObject* Sbk_QGLShaderProgramFunc_addShaderFromSourceFile(PyObject* self, PyObject* args)
{
    QGLShaderProgram* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGLShaderProgram* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "addShaderFromSourceFile", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: addShaderFromSourceFile(QFlags<QGLShader::ShaderTypeBit>,QString)
    if (numArgs == 2 && Shiboken::Converter< ::QFlags<QGLShader::ShaderTypeBit> >::isConvertible(pyargs[0]) && Shiboken::Converter< QString >::isConvertible(pyargs[1])) {
        overloadId = 0; // addShaderFromSourceFile(QFlags<QGLShader::ShaderTypeBit>,QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGLShaderProgramFunc_addShaderFromSourceFile_TypeError;

    // Call function/method
    {
        {
            QFlags<QGLShader::ShaderTypeBit> cppArg0 = Shiboken::Converter<QFlags<QGLShader::ShaderTypeBit> >::toCpp(pyargs[0]);
            QString cppArg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // addShaderFromSourceFile(QFlags<QGLShader::ShaderTypeBit>,QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->addShaderFromSourceFile(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QGLShaderProgramFunc_addShaderFromSourceFile_TypeError:
        const char* overloads[] = {"PySide.QtOpenGL.QGLShader.ShaderType, QString", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtOpenGL.QGLShaderProgram.addShaderFromSourceFile", overloads);
        return 0;
}

static PyObject* Sbk_QGLShaderProgramFunc_attributeLocation(PyObject* self, PyObject* arg)
{
    QGLShaderProgram* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGLShaderProgram* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: attributeLocation(QByteArray)const
    // 1: attributeLocation(QString)const
    // 2: attributeLocation(const char*)const
    if (Shiboken::Converter< const char * >::isConvertible(arg)) {
        overloadId = 2; // attributeLocation(const char*)const
    } else if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 1; // attributeLocation(QString)const
    } else if (Shiboken::Converter< ::QByteArray >::isConvertible(arg)) {
        overloadId = 0; // attributeLocation(QByteArray)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGLShaderProgramFunc_attributeLocation_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // attributeLocation(QByteArray)const
            {
                if (!Shiboken::Object::isValid(arg))
                    return 0;
                QByteArray cppArg0 = Shiboken::Converter<QByteArray >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // attributeLocation(QByteArray)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    int cppResult = const_cast<const QGLShaderProgram*>(cppSelf)->attributeLocation(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< int >::toPython(cppResult);
                }
                break;
            }
            case 1: // attributeLocation(QString)const
            {
                QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // attributeLocation(QString)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    int cppResult = const_cast<const QGLShaderProgram*>(cppSelf)->attributeLocation(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< int >::toPython(cppResult);
                }
                break;
            }
            case 2: // attributeLocation(const char*)const
            {
                const char * cppArg0 = Shiboken::Converter<const char * >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // attributeLocation(const char*)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    int cppResult = const_cast<const QGLShaderProgram*>(cppSelf)->attributeLocation(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< int >::toPython(cppResult);
                }
                break;
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QGLShaderProgramFunc_attributeLocation_TypeError:
        const char* overloads[] = {"PySide.QtCore.QByteArray", "QString", "str", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtOpenGL.QGLShaderProgram.attributeLocation", overloads);
        return 0;
}

static PyObject* Sbk_QGLShaderProgramFunc_bind(PyObject* self)
{
    QGLShaderProgram* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGLShaderProgram* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // bind()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->bind();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QGLShaderProgramFunc_bindAttributeLocation(PyObject* self, PyObject* args)
{
    QGLShaderProgram* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGLShaderProgram* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "bindAttributeLocation", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: bindAttributeLocation(QByteArray,int)
    // 1: bindAttributeLocation(QString,int)
    // 2: bindAttributeLocation(const char*,int)
    if (numArgs == 2 && Shiboken::Converter< const char * >::isConvertible(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 2; // bindAttributeLocation(const char*,int)
    } else if (numArgs == 2 && Shiboken::Converter< QString >::isConvertible(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 1; // bindAttributeLocation(QString,int)
    } else if (numArgs == 2 && Shiboken::Converter< ::QByteArray >::isConvertible(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 0; // bindAttributeLocation(QByteArray,int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGLShaderProgramFunc_bindAttributeLocation_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // bindAttributeLocation(QByteArray,int)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QByteArray cppArg0 = Shiboken::Converter<QByteArray >::toCpp(pyargs[0]);
                int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // bindAttributeLocation(QByteArray,int)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->bindAttributeLocation(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // bindAttributeLocation(QString,int)
            {
                QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // bindAttributeLocation(QString,int)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->bindAttributeLocation(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 2: // bindAttributeLocation(const char*,int)
            {
                const char * cppArg0 = Shiboken::Converter<const char * >::toCpp(pyargs[0]);
                int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // bindAttributeLocation(const char*,int)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->bindAttributeLocation(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGLShaderProgramFunc_bindAttributeLocation_TypeError:
        const char* overloads[] = {"PySide.QtCore.QByteArray, int", "QString, int", "str, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtOpenGL.QGLShaderProgram.bindAttributeLocation", overloads);
        return 0;
}

static PyObject* Sbk_QGLShaderProgramFunc_disableAttributeArray(PyObject* self, PyObject* arg)
{
    QGLShaderProgram* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGLShaderProgram* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: disableAttributeArray(const char*)
    // 1: disableAttributeArray(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 1; // disableAttributeArray(int)
    } else if (Shiboken::Converter< const char * >::isConvertible(arg)) {
        overloadId = 0; // disableAttributeArray(const char*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGLShaderProgramFunc_disableAttributeArray_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // disableAttributeArray(const char*)
            {
                const char * cppArg0 = Shiboken::Converter<const char * >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // disableAttributeArray(const char*)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->disableAttributeArray(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // disableAttributeArray(int)
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // disableAttributeArray(int)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->disableAttributeArray(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGLShaderProgramFunc_disableAttributeArray_TypeError:
        const char* overloads[] = {"str", "int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtOpenGL.QGLShaderProgram.disableAttributeArray", overloads);
        return 0;
}

static PyObject* Sbk_QGLShaderProgramFunc_enableAttributeArray(PyObject* self, PyObject* arg)
{
    QGLShaderProgram* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGLShaderProgram* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: enableAttributeArray(const char*)
    // 1: enableAttributeArray(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 1; // enableAttributeArray(int)
    } else if (Shiboken::Converter< const char * >::isConvertible(arg)) {
        overloadId = 0; // enableAttributeArray(const char*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGLShaderProgramFunc_enableAttributeArray_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // enableAttributeArray(const char*)
            {
                const char * cppArg0 = Shiboken::Converter<const char * >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // enableAttributeArray(const char*)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->enableAttributeArray(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // enableAttributeArray(int)
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // enableAttributeArray(int)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->enableAttributeArray(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGLShaderProgramFunc_enableAttributeArray_TypeError:
        const char* overloads[] = {"str", "int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtOpenGL.QGLShaderProgram.enableAttributeArray", overloads);
        return 0;
}

static PyObject* Sbk_QGLShaderProgramFunc_geometryInputType(PyObject* self)
{
    QGLShaderProgram* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGLShaderProgram* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // geometryInputType()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                unsigned int cppResult = const_cast<const QGLShaderProgram*>(cppSelf)->geometryInputType();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< unsigned int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QGLShaderProgramFunc_geometryOutputType(PyObject* self)
{
    QGLShaderProgram* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGLShaderProgram* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // geometryOutputType()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                unsigned int cppResult = const_cast<const QGLShaderProgram*>(cppSelf)->geometryOutputType();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< unsigned int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QGLShaderProgramFunc_geometryOutputVertexCount(PyObject* self)
{
    QGLShaderProgram* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGLShaderProgram* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // geometryOutputVertexCount()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QGLShaderProgram*>(cppSelf)->geometryOutputVertexCount();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QGLShaderProgramFunc_hasOpenGLShaderPrograms(PyObject* self, PyObject* args, PyObject* kwds)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtOpenGL.QGLShaderProgram.hasOpenGLShaderPrograms(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:hasOpenGLShaderPrograms", &(pyargs[0])))
        return 0;


    // Overloaded function decisor
    // 0: hasOpenGLShaderPrograms(const QGLContext*)
    if (numArgs == 0) {
        overloadId = 0; // hasOpenGLShaderPrograms(const QGLContext*)
    } else if (Shiboken::Converter< ::QGLContext * >::isConvertible(pyargs[0])) {
        overloadId = 0; // hasOpenGLShaderPrograms(const QGLContext*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGLShaderProgramFunc_hasOpenGLShaderPrograms_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "context");
                if (value) {
                    if (pyargs[0])
                        errorArgName = "context";
                    else if (Shiboken::Converter< ::QGLContext * >::isConvertible(value))
                        pyargs[0] = value;
                    else
                        goto Sbk_QGLShaderProgramFunc_hasOpenGLShaderPrograms_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtOpenGL.QGLShaderProgram.hasOpenGLShaderPrograms(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QGLContext * cppArg0 = pyargs[0] ? Shiboken::Converter<QGLContext * >::toCpp(pyargs[0]) : 0;

            if(!PyErr_Occurred()) {
                // hasOpenGLShaderPrograms(const QGLContext*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = QGLShaderProgram::hasOpenGLShaderPrograms(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QGLShaderProgramFunc_hasOpenGLShaderPrograms_TypeError:
        const char* overloads[] = {"PySide.QtOpenGL.QGLContext = None", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtOpenGL.QGLShaderProgram.hasOpenGLShaderPrograms", overloads);
        return 0;
}

static PyObject* Sbk_QGLShaderProgramFunc_isLinked(PyObject* self)
{
    QGLShaderProgram* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGLShaderProgram* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isLinked()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QGLShaderProgram*>(cppSelf)->isLinked();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QGLShaderProgramFunc_link(PyObject* self)
{
    QGLShaderProgram* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGLShaderProgram* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // link()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = (Shiboken::Object::isUserType(self) ? cppSelf->::QGLShaderProgram::link() : cppSelf->link());
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QGLShaderProgramFunc_log(PyObject* self)
{
    QGLShaderProgram* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGLShaderProgram* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // log()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = const_cast<const QGLShaderProgram*>(cppSelf)->log();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QGLShaderProgramFunc_maxGeometryOutputVertices(PyObject* self)
{
    QGLShaderProgram* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGLShaderProgram* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // maxGeometryOutputVertices()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QGLShaderProgram*>(cppSelf)->maxGeometryOutputVertices();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QGLShaderProgramFunc_programId(PyObject* self)
{
    QGLShaderProgram* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGLShaderProgram* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // programId()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                unsigned int cppResult = const_cast<const QGLShaderProgram*>(cppSelf)->programId();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< unsigned int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QGLShaderProgramFunc_release(PyObject* self)
{
    QGLShaderProgram* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGLShaderProgram* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // release()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->release();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QGLShaderProgramFunc_removeAllShaders(PyObject* self)
{
    QGLShaderProgram* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGLShaderProgram* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // removeAllShaders()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->removeAllShaders();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QGLShaderProgramFunc_removeShader(PyObject* self, PyObject* arg)
{
    QGLShaderProgram* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGLShaderProgram* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: removeShader(QGLShader*)
    if (Shiboken::Converter< ::QGLShader * >::isConvertible(arg)) {
        overloadId = 0; // removeShader(QGLShader*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGLShaderProgramFunc_removeShader_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QGLShader * cppArg0 = Shiboken::Converter<QGLShader * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // removeShader(QGLShader*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->removeShader(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGLShaderProgramFunc_removeShader_TypeError:
        const char* overloads[] = {"PySide.QtOpenGL.QGLShader", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtOpenGL.QGLShaderProgram.removeShader", overloads);
        return 0;
}

static PyObject* Sbk_QGLShaderProgramFunc_setAttributeArray(PyObject* self, PyObject* args, PyObject* kwds)
{
    QGLShaderProgram* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGLShaderProgram* >::toCpp(self);

    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 4) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtOpenGL.QGLShaderProgram.setAttributeArray(): too many arguments");
        return 0;
    } else if (numArgs < 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtOpenGL.QGLShaderProgram.setAttributeArray(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOOO:setAttributeArray", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return 0;


    // Overloaded function decisor
    // 0: setAttributeArray(const char*,const QVector2D*,int)
    // 1: setAttributeArray(const char*,const QVector3D*,int)
    // 2: setAttributeArray(const char*,const QVector4D*,int)
    // 3: setAttributeArray(const char*,const float*,int,int)
    // 4: setAttributeArray(int,const QVector2D*,int)
    // 5: setAttributeArray(int,const QVector3D*,int)
    // 6: setAttributeArray(int,const QVector4D*,int)
    // 7: setAttributeArray(int,const float*,int,int)
    if (SbkNumber_Check(pyargs[0])) {
        if (numArgs >= 3 && PyFloat_Check(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
            if (numArgs == 3) {
                overloadId = 7; // setAttributeArray(int,const float*,int,int)
            } else if (SbkNumber_Check(pyargs[3])) {
                overloadId = 7; // setAttributeArray(int,const float*,int,int)
            }
        } else if (Shiboken::Converter< ::QVector2D * >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 4; // setAttributeArray(int,const QVector2D*,int)
            } else if (SbkNumber_Check(pyargs[2])) {
                overloadId = 4; // setAttributeArray(int,const QVector2D*,int)
            }
        } else if (Shiboken::Converter< ::QVector3D * >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 5; // setAttributeArray(int,const QVector3D*,int)
            } else if (SbkNumber_Check(pyargs[2])) {
                overloadId = 5; // setAttributeArray(int,const QVector3D*,int)
            }
        } else if (Shiboken::Converter< ::QVector4D * >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 6; // setAttributeArray(int,const QVector4D*,int)
            } else if (SbkNumber_Check(pyargs[2])) {
                overloadId = 6; // setAttributeArray(int,const QVector4D*,int)
            }
        }
    } else if (Shiboken::Converter< const char * >::isConvertible(pyargs[0])) {
        if (numArgs >= 3 && PyFloat_Check(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
            if (numArgs == 3) {
                overloadId = 3; // setAttributeArray(const char*,const float*,int,int)
            } else if (SbkNumber_Check(pyargs[3])) {
                overloadId = 3; // setAttributeArray(const char*,const float*,int,int)
            }
        } else if (Shiboken::Converter< ::QVector2D * >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 0; // setAttributeArray(const char*,const QVector2D*,int)
            } else if (SbkNumber_Check(pyargs[2])) {
                overloadId = 0; // setAttributeArray(const char*,const QVector2D*,int)
            }
        } else if (Shiboken::Converter< ::QVector3D * >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 1; // setAttributeArray(const char*,const QVector3D*,int)
            } else if (SbkNumber_Check(pyargs[2])) {
                overloadId = 1; // setAttributeArray(const char*,const QVector3D*,int)
            }
        } else if (Shiboken::Converter< ::QVector4D * >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 2; // setAttributeArray(const char*,const QVector4D*,int)
            } else if (SbkNumber_Check(pyargs[2])) {
                overloadId = 2; // setAttributeArray(const char*,const QVector4D*,int)
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGLShaderProgramFunc_setAttributeArray_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // setAttributeArray(const char*,const QVector2D*,int)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "stride");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "stride";
                        else if (SbkNumber_Check(value))
                            pyargs[2] = value;
                        else
                            goto Sbk_QGLShaderProgramFunc_setAttributeArray_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtOpenGL.QGLShaderProgram.setAttributeArray(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                const char * cppArg0 = Shiboken::Converter<const char * >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return 0;
                QVector2D * cppArg1 = Shiboken::Converter<QVector2D * >::toCpp(pyargs[1]);
                int cppArg2 = pyargs[2] ? Shiboken::Converter<int >::toCpp(pyargs[2]) : 0;

                if(!PyErr_Occurred()) {
                    // setAttributeArray(const char*,const QVector2D*,int)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setAttributeArray(cppArg0, cppArg1, cppArg2);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // setAttributeArray(const char*,const QVector3D*,int)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "stride");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "stride";
                        else if (SbkNumber_Check(value))
                            pyargs[2] = value;
                        else
                            goto Sbk_QGLShaderProgramFunc_setAttributeArray_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtOpenGL.QGLShaderProgram.setAttributeArray(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                const char * cppArg0 = Shiboken::Converter<const char * >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return 0;
                QVector3D * cppArg1 = Shiboken::Converter<QVector3D * >::toCpp(pyargs[1]);
                int cppArg2 = pyargs[2] ? Shiboken::Converter<int >::toCpp(pyargs[2]) : 0;

                if(!PyErr_Occurred()) {
                    // setAttributeArray(const char*,const QVector3D*,int)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setAttributeArray(cppArg0, cppArg1, cppArg2);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 2: // setAttributeArray(const char*,const QVector4D*,int)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "stride");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "stride";
                        else if (SbkNumber_Check(value))
                            pyargs[2] = value;
                        else
                            goto Sbk_QGLShaderProgramFunc_setAttributeArray_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtOpenGL.QGLShaderProgram.setAttributeArray(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                const char * cppArg0 = Shiboken::Converter<const char * >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return 0;
                QVector4D * cppArg1 = Shiboken::Converter<QVector4D * >::toCpp(pyargs[1]);
                int cppArg2 = pyargs[2] ? Shiboken::Converter<int >::toCpp(pyargs[2]) : 0;

                if(!PyErr_Occurred()) {
                    // setAttributeArray(const char*,const QVector4D*,int)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setAttributeArray(cppArg0, cppArg1, cppArg2);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 3: // setAttributeArray(const char*,const float*,int,int)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "stride");
                    if (value) {
                        if (pyargs[3])
                            errorArgName = "stride";
                        else if (SbkNumber_Check(value))
                            pyargs[3] = value;
                        else
                            goto Sbk_QGLShaderProgramFunc_setAttributeArray_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtOpenGL.QGLShaderProgram.setAttributeArray(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                const char * cppArg0 = Shiboken::Converter<const char * >::toCpp(pyargs[0]);
                float * cppArg1 = Shiboken::Converter<float * >::toCpp(pyargs[1]);
                int cppArg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);
                int cppArg3 = pyargs[3] ? Shiboken::Converter<int >::toCpp(pyargs[3]) : 0;

                if(!PyErr_Occurred()) {
                    // setAttributeArray(const char*,const float*,int,int)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setAttributeArray(cppArg0, cppArg1, cppArg2, cppArg3);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 4: // setAttributeArray(int,const QVector2D*,int)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "stride");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "stride";
                        else if (SbkNumber_Check(value))
                            pyargs[2] = value;
                        else
                            goto Sbk_QGLShaderProgramFunc_setAttributeArray_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtOpenGL.QGLShaderProgram.setAttributeArray(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return 0;
                QVector2D * cppArg1 = Shiboken::Converter<QVector2D * >::toCpp(pyargs[1]);
                int cppArg2 = pyargs[2] ? Shiboken::Converter<int >::toCpp(pyargs[2]) : 0;

                if(!PyErr_Occurred()) {
                    // setAttributeArray(int,const QVector2D*,int)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setAttributeArray(cppArg0, cppArg1, cppArg2);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 5: // setAttributeArray(int,const QVector3D*,int)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "stride");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "stride";
                        else if (SbkNumber_Check(value))
                            pyargs[2] = value;
                        else
                            goto Sbk_QGLShaderProgramFunc_setAttributeArray_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtOpenGL.QGLShaderProgram.setAttributeArray(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return 0;
                QVector3D * cppArg1 = Shiboken::Converter<QVector3D * >::toCpp(pyargs[1]);
                int cppArg2 = pyargs[2] ? Shiboken::Converter<int >::toCpp(pyargs[2]) : 0;

                if(!PyErr_Occurred()) {
                    // setAttributeArray(int,const QVector3D*,int)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setAttributeArray(cppArg0, cppArg1, cppArg2);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 6: // setAttributeArray(int,const QVector4D*,int)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "stride");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "stride";
                        else if (SbkNumber_Check(value))
                            pyargs[2] = value;
                        else
                            goto Sbk_QGLShaderProgramFunc_setAttributeArray_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtOpenGL.QGLShaderProgram.setAttributeArray(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return 0;
                QVector4D * cppArg1 = Shiboken::Converter<QVector4D * >::toCpp(pyargs[1]);
                int cppArg2 = pyargs[2] ? Shiboken::Converter<int >::toCpp(pyargs[2]) : 0;

                if(!PyErr_Occurred()) {
                    // setAttributeArray(int,const QVector4D*,int)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setAttributeArray(cppArg0, cppArg1, cppArg2);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 7: // setAttributeArray(int,const float*,int,int)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "stride");
                    if (value) {
                        if (pyargs[3])
                            errorArgName = "stride";
                        else if (SbkNumber_Check(value))
                            pyargs[3] = value;
                        else
                            goto Sbk_QGLShaderProgramFunc_setAttributeArray_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtOpenGL.QGLShaderProgram.setAttributeArray(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                float * cppArg1 = Shiboken::Converter<float * >::toCpp(pyargs[1]);
                int cppArg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);
                int cppArg3 = pyargs[3] ? Shiboken::Converter<int >::toCpp(pyargs[3]) : 0;

                if(!PyErr_Occurred()) {
                    // setAttributeArray(int,const float*,int,int)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setAttributeArray(cppArg0, cppArg1, cppArg2, cppArg3);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGLShaderProgramFunc_setAttributeArray_TypeError:
        const char* overloads[] = {"str, PySide.QtGui.QVector2D, int = 0", "str, PySide.QtGui.QVector3D, int = 0", "str, PySide.QtGui.QVector4D, int = 0", "str, float, int, int = 0", "int, PySide.QtGui.QVector2D, int = 0", "int, PySide.QtGui.QVector3D, int = 0", "int, PySide.QtGui.QVector4D, int = 0", "int, float, int, int = 0", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtOpenGL.QGLShaderProgram.setAttributeArray", overloads);
        return 0;
}

static PyObject* Sbk_QGLShaderProgramFunc_setAttributeBuffer(PyObject* self, PyObject* args, PyObject* kwds)
{
    QGLShaderProgram* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGLShaderProgram* >::toCpp(self);

    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 5) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtOpenGL.QGLShaderProgram.setAttributeBuffer(): too many arguments");
        return 0;
    } else if (numArgs < 4) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtOpenGL.QGLShaderProgram.setAttributeBuffer(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOOOO:setAttributeBuffer", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3]), &(pyargs[4])))
        return 0;


    // Overloaded function decisor
    // 0: setAttributeBuffer(const char*,uint,int,int,int)
    // 1: setAttributeBuffer(int,uint,int,int,int)
    if (numArgs >= 4 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2]) && SbkNumber_Check(pyargs[3])) {
        if (numArgs == 4) {
            overloadId = 1; // setAttributeBuffer(int,uint,int,int,int)
        } else if (SbkNumber_Check(pyargs[4])) {
            overloadId = 1; // setAttributeBuffer(int,uint,int,int,int)
        }
    } else if (numArgs >= 4 && Shiboken::Converter< const char * >::isConvertible(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2]) && SbkNumber_Check(pyargs[3])) {
        if (numArgs == 4) {
            overloadId = 0; // setAttributeBuffer(const char*,uint,int,int,int)
        } else if (SbkNumber_Check(pyargs[4])) {
            overloadId = 0; // setAttributeBuffer(const char*,uint,int,int,int)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGLShaderProgramFunc_setAttributeBuffer_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // setAttributeBuffer(const char*,uint,int,int,int)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "stride");
                    if (value) {
                        if (pyargs[4])
                            errorArgName = "stride";
                        else if (SbkNumber_Check(value))
                            pyargs[4] = value;
                        else
                            goto Sbk_QGLShaderProgramFunc_setAttributeBuffer_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtOpenGL.QGLShaderProgram.setAttributeBuffer(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                const char * cppArg0 = Shiboken::Converter<const char * >::toCpp(pyargs[0]);
                unsigned int cppArg1 = Shiboken::Converter<unsigned int >::toCpp(pyargs[1]);
                int cppArg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);
                int cppArg3 = Shiboken::Converter<int >::toCpp(pyargs[3]);
                int cppArg4 = pyargs[4] ? Shiboken::Converter<int >::toCpp(pyargs[4]) : 0;

                if(!PyErr_Occurred()) {
                    // setAttributeBuffer(const char*,uint,int,int,int)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setAttributeBuffer(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // setAttributeBuffer(int,uint,int,int,int)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "stride");
                    if (value) {
                        if (pyargs[4])
                            errorArgName = "stride";
                        else if (SbkNumber_Check(value))
                            pyargs[4] = value;
                        else
                            goto Sbk_QGLShaderProgramFunc_setAttributeBuffer_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtOpenGL.QGLShaderProgram.setAttributeBuffer(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                unsigned int cppArg1 = Shiboken::Converter<unsigned int >::toCpp(pyargs[1]);
                int cppArg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);
                int cppArg3 = Shiboken::Converter<int >::toCpp(pyargs[3]);
                int cppArg4 = pyargs[4] ? Shiboken::Converter<int >::toCpp(pyargs[4]) : 0;

                if(!PyErr_Occurred()) {
                    // setAttributeBuffer(int,uint,int,int,int)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setAttributeBuffer(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGLShaderProgramFunc_setAttributeBuffer_TypeError:
        const char* overloads[] = {"str, unsigned int, int, int, int = 0", "int, unsigned int, int, int, int = 0", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtOpenGL.QGLShaderProgram.setAttributeBuffer", overloads);
        return 0;
}

static PyObject* Sbk_QGLShaderProgramFunc_setAttributeValue(PyObject* self, PyObject* args)
{
    QGLShaderProgram* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGLShaderProgram* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setAttributeValue", 2, 5, &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3]), &(pyargs[4])))
        return 0;


    // Overloaded function decisor
    // 0: setAttributeValue(const char*,QColor)
    // 1: setAttributeValue(const char*,QVector2D)
    // 2: setAttributeValue(const char*,QVector3D)
    // 3: setAttributeValue(const char*,QVector4D)
    // 4: setAttributeValue(const char*,float)
    // 5: setAttributeValue(const char*,float,float)
    // 6: setAttributeValue(const char*,float,float,float)
    // 7: setAttributeValue(const char*,float,float,float,float)
    // 8: setAttributeValue(int,QColor)
    // 9: setAttributeValue(int,QVector2D)
    // 10: setAttributeValue(int,QVector3D)
    // 11: setAttributeValue(int,QVector4D)
    // 12: setAttributeValue(int,float)
    // 13: setAttributeValue(int,float,float)
    // 14: setAttributeValue(int,float,float,float)
    // 15: setAttributeValue(int,float,float,float,float)
    if (SbkNumber_Check(pyargs[0])) {
        if (SbkNumber_Check(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 12; // setAttributeValue(int,float)
            } else if (SbkNumber_Check(pyargs[2])) {
                if (numArgs == 3) {
                    overloadId = 13; // setAttributeValue(int,float,float)
                } else if (SbkNumber_Check(pyargs[3])) {
                    if (numArgs == 4) {
                        overloadId = 14; // setAttributeValue(int,float,float,float)
                    } else if (numArgs == 5 && SbkNumber_Check(pyargs[4])) {
                        overloadId = 15; // setAttributeValue(int,float,float,float,float)
                    }
                }
            }
        } else if (numArgs == 2 && Shiboken::Converter< ::QVector2D >::isConvertible(pyargs[1])) {
            overloadId = 9; // setAttributeValue(int,QVector2D)
        } else if (numArgs == 2 && Shiboken::Converter< ::QVector3D >::isConvertible(pyargs[1])) {
            overloadId = 10; // setAttributeValue(int,QVector3D)
        } else if (numArgs == 2 && Shiboken::Converter< ::QVector4D >::isConvertible(pyargs[1])) {
            overloadId = 11; // setAttributeValue(int,QVector4D)
        } else if (numArgs == 2 && Shiboken::Converter< ::QColor >::isConvertible(pyargs[1])) {
            overloadId = 8; // setAttributeValue(int,QColor)
        }
    } else if (Shiboken::Converter< const char * >::isConvertible(pyargs[0])) {
        if (SbkNumber_Check(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 4; // setAttributeValue(const char*,float)
            } else if (SbkNumber_Check(pyargs[2])) {
                if (numArgs == 3) {
                    overloadId = 5; // setAttributeValue(const char*,float,float)
                } else if (SbkNumber_Check(pyargs[3])) {
                    if (numArgs == 4) {
                        overloadId = 6; // setAttributeValue(const char*,float,float,float)
                    } else if (numArgs == 5 && SbkNumber_Check(pyargs[4])) {
                        overloadId = 7; // setAttributeValue(const char*,float,float,float,float)
                    }
                }
            }
        } else if (numArgs == 2 && Shiboken::Converter< ::QVector2D >::isConvertible(pyargs[1])) {
            overloadId = 1; // setAttributeValue(const char*,QVector2D)
        } else if (numArgs == 2 && Shiboken::Converter< ::QVector3D >::isConvertible(pyargs[1])) {
            overloadId = 2; // setAttributeValue(const char*,QVector3D)
        } else if (numArgs == 2 && Shiboken::Converter< ::QVector4D >::isConvertible(pyargs[1])) {
            overloadId = 3; // setAttributeValue(const char*,QVector4D)
        } else if (numArgs == 2 && Shiboken::Converter< ::QColor >::isConvertible(pyargs[1])) {
            overloadId = 0; // setAttributeValue(const char*,QColor)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGLShaderProgramFunc_setAttributeValue_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // setAttributeValue(const char*,QColor)
            {
                const char * cppArg0 = Shiboken::Converter<const char * >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return 0;
                QColor cppArg1 = Shiboken::Converter<QColor >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // setAttributeValue(const char*,QColor)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setAttributeValue(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // setAttributeValue(const char*,QVector2D)
            {
                const char * cppArg0 = Shiboken::Converter<const char * >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return 0;
                QVector2D cppArg1 = Shiboken::Converter<QVector2D >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // setAttributeValue(const char*,QVector2D)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setAttributeValue(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 2: // setAttributeValue(const char*,QVector3D)
            {
                const char * cppArg0 = Shiboken::Converter<const char * >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return 0;
                QVector3D cppArg1 = Shiboken::Converter<QVector3D >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // setAttributeValue(const char*,QVector3D)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setAttributeValue(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 3: // setAttributeValue(const char*,QVector4D)
            {
                const char * cppArg0 = Shiboken::Converter<const char * >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return 0;
                QVector4D cppArg1 = Shiboken::Converter<QVector4D >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // setAttributeValue(const char*,QVector4D)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setAttributeValue(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 4: // setAttributeValue(const char*,float)
            {
                const char * cppArg0 = Shiboken::Converter<const char * >::toCpp(pyargs[0]);
                float cppArg1 = Shiboken::Converter<float >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // setAttributeValue(const char*,float)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setAttributeValue(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 5: // setAttributeValue(const char*,float,float)
            {
                const char * cppArg0 = Shiboken::Converter<const char * >::toCpp(pyargs[0]);
                float cppArg1 = Shiboken::Converter<float >::toCpp(pyargs[1]);
                float cppArg2 = Shiboken::Converter<float >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                    // setAttributeValue(const char*,float,float)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setAttributeValue(cppArg0, cppArg1, cppArg2);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 6: // setAttributeValue(const char*,float,float,float)
            {
                const char * cppArg0 = Shiboken::Converter<const char * >::toCpp(pyargs[0]);
                float cppArg1 = Shiboken::Converter<float >::toCpp(pyargs[1]);
                float cppArg2 = Shiboken::Converter<float >::toCpp(pyargs[2]);
                float cppArg3 = Shiboken::Converter<float >::toCpp(pyargs[3]);

                if(!PyErr_Occurred()) {
                    // setAttributeValue(const char*,float,float,float)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setAttributeValue(cppArg0, cppArg1, cppArg2, cppArg3);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 7: // setAttributeValue(const char*,float,float,float,float)
            {
                const char * cppArg0 = Shiboken::Converter<const char * >::toCpp(pyargs[0]);
                float cppArg1 = Shiboken::Converter<float >::toCpp(pyargs[1]);
                float cppArg2 = Shiboken::Converter<float >::toCpp(pyargs[2]);
                float cppArg3 = Shiboken::Converter<float >::toCpp(pyargs[3]);
                float cppArg4 = Shiboken::Converter<float >::toCpp(pyargs[4]);

                if(!PyErr_Occurred()) {
                    // setAttributeValue(const char*,float,float,float,float)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setAttributeValue(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 8: // setAttributeValue(int,QColor)
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return 0;
                QColor cppArg1 = Shiboken::Converter<QColor >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // setAttributeValue(int,QColor)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setAttributeValue(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 9: // setAttributeValue(int,QVector2D)
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return 0;
                QVector2D cppArg1 = Shiboken::Converter<QVector2D >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // setAttributeValue(int,QVector2D)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setAttributeValue(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 10: // setAttributeValue(int,QVector3D)
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return 0;
                QVector3D cppArg1 = Shiboken::Converter<QVector3D >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // setAttributeValue(int,QVector3D)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setAttributeValue(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 11: // setAttributeValue(int,QVector4D)
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return 0;
                QVector4D cppArg1 = Shiboken::Converter<QVector4D >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // setAttributeValue(int,QVector4D)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setAttributeValue(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 12: // setAttributeValue(int,float)
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                float cppArg1 = Shiboken::Converter<float >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // setAttributeValue(int,float)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setAttributeValue(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 13: // setAttributeValue(int,float,float)
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                float cppArg1 = Shiboken::Converter<float >::toCpp(pyargs[1]);
                float cppArg2 = Shiboken::Converter<float >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                    // setAttributeValue(int,float,float)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setAttributeValue(cppArg0, cppArg1, cppArg2);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 14: // setAttributeValue(int,float,float,float)
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                float cppArg1 = Shiboken::Converter<float >::toCpp(pyargs[1]);
                float cppArg2 = Shiboken::Converter<float >::toCpp(pyargs[2]);
                float cppArg3 = Shiboken::Converter<float >::toCpp(pyargs[3]);

                if(!PyErr_Occurred()) {
                    // setAttributeValue(int,float,float,float)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setAttributeValue(cppArg0, cppArg1, cppArg2, cppArg3);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 15: // setAttributeValue(int,float,float,float,float)
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                float cppArg1 = Shiboken::Converter<float >::toCpp(pyargs[1]);
                float cppArg2 = Shiboken::Converter<float >::toCpp(pyargs[2]);
                float cppArg3 = Shiboken::Converter<float >::toCpp(pyargs[3]);
                float cppArg4 = Shiboken::Converter<float >::toCpp(pyargs[4]);

                if(!PyErr_Occurred()) {
                    // setAttributeValue(int,float,float,float,float)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setAttributeValue(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGLShaderProgramFunc_setAttributeValue_TypeError:
        const char* overloads[] = {"str, PySide.QtGui.QColor", "str, PySide.QtGui.QVector2D", "str, PySide.QtGui.QVector3D", "str, PySide.QtGui.QVector4D", "str, float", "str, float, float", "str, float, float, float", "str, float, float, float, float", "int, PySide.QtGui.QColor", "int, PySide.QtGui.QVector2D", "int, PySide.QtGui.QVector3D", "int, PySide.QtGui.QVector4D", "int, float", "int, float, float", "int, float, float, float", "int, float, float, float, float", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtOpenGL.QGLShaderProgram.setAttributeValue", overloads);
        return 0;
}

static PyObject* Sbk_QGLShaderProgramFunc_setGeometryInputType(PyObject* self, PyObject* arg)
{
    QGLShaderProgram* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGLShaderProgram* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setGeometryInputType(uint)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setGeometryInputType(uint)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGLShaderProgramFunc_setGeometryInputType_TypeError;

    // Call function/method
    {
        {
            unsigned int cppArg0 = Shiboken::Converter<unsigned int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setGeometryInputType(uint)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setGeometryInputType(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGLShaderProgramFunc_setGeometryInputType_TypeError:
        const char* overloads[] = {"unsigned int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtOpenGL.QGLShaderProgram.setGeometryInputType", overloads);
        return 0;
}

static PyObject* Sbk_QGLShaderProgramFunc_setGeometryOutputType(PyObject* self, PyObject* arg)
{
    QGLShaderProgram* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGLShaderProgram* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setGeometryOutputType(uint)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setGeometryOutputType(uint)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGLShaderProgramFunc_setGeometryOutputType_TypeError;

    // Call function/method
    {
        {
            unsigned int cppArg0 = Shiboken::Converter<unsigned int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setGeometryOutputType(uint)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setGeometryOutputType(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGLShaderProgramFunc_setGeometryOutputType_TypeError:
        const char* overloads[] = {"unsigned int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtOpenGL.QGLShaderProgram.setGeometryOutputType", overloads);
        return 0;
}

static PyObject* Sbk_QGLShaderProgramFunc_setGeometryOutputVertexCount(PyObject* self, PyObject* arg)
{
    QGLShaderProgram* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGLShaderProgram* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setGeometryOutputVertexCount(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setGeometryOutputVertexCount(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGLShaderProgramFunc_setGeometryOutputVertexCount_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setGeometryOutputVertexCount(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setGeometryOutputVertexCount(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGLShaderProgramFunc_setGeometryOutputVertexCount_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtOpenGL.QGLShaderProgram.setGeometryOutputVertexCount", overloads);
        return 0;
}

static PyObject* Sbk_QGLShaderProgramFunc_setUniformValue(PyObject* self, PyObject* args)
{
    QGLShaderProgram* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGLShaderProgram* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setUniformValue", 2, 5, &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3]), &(pyargs[4])))
        return 0;


    // Overloaded function decisor
    // 0: setUniformValue(const char*,QColor)
    // 1: setUniformValue(const char*,QMatrix2x2)
    // 2: setUniformValue(const char*,QMatrix2x3)
    // 3: setUniformValue(const char*,QMatrix2x4)
    // 4: setUniformValue(const char*,QMatrix3x2)
    // 5: setUniformValue(const char*,QMatrix3x3)
    // 6: setUniformValue(const char*,QMatrix3x4)
    // 7: setUniformValue(const char*,QMatrix4x2)
    // 8: setUniformValue(const char*,QMatrix4x3)
    // 9: setUniformValue(const char*,QMatrix4x4)
    // 10: setUniformValue(const char*,QPoint)
    // 11: setUniformValue(const char*,QPointF)
    // 12: setUniformValue(const char*,QSize)
    // 13: setUniformValue(const char*,QSizeF)
    // 14: setUniformValue(const char*,QTransform)
    // 15: setUniformValue(const char*,QVector2D)
    // 16: setUniformValue(const char*,QVector3D)
    // 17: setUniformValue(const char*,QVector4D)
    // 18: setUniformValue(const char*,float)
    // 19: setUniformValue(const char*,float,float)
    // 20: setUniformValue(const char*,float,float,float)
    // 21: setUniformValue(const char*,float,float,float,float)
    // 22: setUniformValue(const char*,int)
    // 23: setUniformValue(const char*,uint)
    // 24: setUniformValue(int,QColor)
    // 25: setUniformValue(int,QMatrix2x2)
    // 26: setUniformValue(int,QMatrix2x3)
    // 27: setUniformValue(int,QMatrix2x4)
    // 28: setUniformValue(int,QMatrix3x2)
    // 29: setUniformValue(int,QMatrix3x3)
    // 30: setUniformValue(int,QMatrix3x4)
    // 31: setUniformValue(int,QMatrix4x2)
    // 32: setUniformValue(int,QMatrix4x3)
    // 33: setUniformValue(int,QMatrix4x4)
    // 34: setUniformValue(int,QPoint)
    // 35: setUniformValue(int,QPointF)
    // 36: setUniformValue(int,QSize)
    // 37: setUniformValue(int,QSizeF)
    // 38: setUniformValue(int,QTransform)
    // 39: setUniformValue(int,QVector2D)
    // 40: setUniformValue(int,QVector3D)
    // 41: setUniformValue(int,QVector4D)
    // 42: setUniformValue(int,float)
    // 43: setUniformValue(int,float,float)
    // 44: setUniformValue(int,float,float,float)
    // 45: setUniformValue(int,float,float,float,float)
    // 46: setUniformValue(int,int)
    // 47: setUniformValue(int,uint)
    if (SbkNumber_Check(pyargs[0])) {
        if (numArgs == 2 && SbkNumber_Check(pyargs[1])) {
            overloadId = 47; // setUniformValue(int,uint)
        } else if (PyFloat_Check(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 42; // setUniformValue(int,float)
            } else if (SbkNumber_Check(pyargs[2])) {
                if (numArgs == 3) {
                    overloadId = 43; // setUniformValue(int,float,float)
                } else if (SbkNumber_Check(pyargs[3])) {
                    if (numArgs == 4) {
                        overloadId = 44; // setUniformValue(int,float,float,float)
                    } else if (numArgs == 5 && SbkNumber_Check(pyargs[4])) {
                        overloadId = 45; // setUniformValue(int,float,float,float,float)
                    }
                }
            }
        } else if (numArgs == 2 && SbkNumber_Check(pyargs[1])) {
            overloadId = 46; // setUniformValue(int,int)
        } else if (numArgs == 2 && Shiboken::Converter< ::QVector2D >::isConvertible(pyargs[1])) {
            overloadId = 39; // setUniformValue(int,QVector2D)
        } else if (numArgs == 2 && Shiboken::Converter< ::QVector3D >::isConvertible(pyargs[1])) {
            overloadId = 40; // setUniformValue(int,QVector3D)
        } else if (numArgs == 2 && Shiboken::Converter< ::QVector4D >::isConvertible(pyargs[1])) {
            overloadId = 41; // setUniformValue(int,QVector4D)
        } else if (numArgs == 2 && Shiboken::Converter< ::QTransform >::isConvertible(pyargs[1])) {
            overloadId = 38; // setUniformValue(int,QTransform)
        } else if (numArgs == 2 && Shiboken::Converter< ::QSize >::isConvertible(pyargs[1])) {
            overloadId = 36; // setUniformValue(int,QSize)
        } else if (numArgs == 2 && Shiboken::Converter< ::QSizeF >::isConvertible(pyargs[1])) {
            overloadId = 37; // setUniformValue(int,QSizeF)
        } else if (numArgs == 2 && Shiboken::Converter< ::QPoint >::isConvertible(pyargs[1])) {
            overloadId = 34; // setUniformValue(int,QPoint)
        } else if (numArgs == 2 && Shiboken::Converter< ::QPointF >::isConvertible(pyargs[1])) {
            overloadId = 35; // setUniformValue(int,QPointF)
        } else if (numArgs == 2 && Shiboken::Converter< ::QMatrix4x4 >::isConvertible(pyargs[1])) {
            overloadId = 33; // setUniformValue(int,QMatrix4x4)
        } else if (numArgs == 2 && Shiboken::Converter< ::QMatrix4x3 >::isConvertible(pyargs[1])) {
            overloadId = 32; // setUniformValue(int,QMatrix4x3)
        } else if (numArgs == 2 && Shiboken::Converter< ::QMatrix4x2 >::isConvertible(pyargs[1])) {
            overloadId = 31; // setUniformValue(int,QMatrix4x2)
        } else if (numArgs == 2 && Shiboken::Converter< ::QMatrix3x4 >::isConvertible(pyargs[1])) {
            overloadId = 30; // setUniformValue(int,QMatrix3x4)
        } else if (numArgs == 2 && Shiboken::Converter< ::QMatrix3x3 >::isConvertible(pyargs[1])) {
            overloadId = 29; // setUniformValue(int,QMatrix3x3)
        } else if (numArgs == 2 && Shiboken::Converter< ::QMatrix3x2 >::isConvertible(pyargs[1])) {
            overloadId = 28; // setUniformValue(int,QMatrix3x2)
        } else if (numArgs == 2 && Shiboken::Converter< ::QMatrix2x4 >::isConvertible(pyargs[1])) {
            overloadId = 27; // setUniformValue(int,QMatrix2x4)
        } else if (numArgs == 2 && Shiboken::Converter< ::QMatrix2x3 >::isConvertible(pyargs[1])) {
            overloadId = 26; // setUniformValue(int,QMatrix2x3)
        } else if (numArgs == 2 && Shiboken::Converter< ::QMatrix2x2 >::isConvertible(pyargs[1])) {
            overloadId = 25; // setUniformValue(int,QMatrix2x2)
        } else if (numArgs == 2 && Shiboken::Converter< ::QColor >::isConvertible(pyargs[1])) {
            overloadId = 24; // setUniformValue(int,QColor)
        }
    } else if (Shiboken::Converter< const char * >::isConvertible(pyargs[0])) {
        if (numArgs == 2 && SbkNumber_Check(pyargs[1])) {
            overloadId = 23; // setUniformValue(const char*,uint)
        } else if (PyFloat_Check(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 18; // setUniformValue(const char*,float)
            } else if (SbkNumber_Check(pyargs[2])) {
                if (numArgs == 3) {
                    overloadId = 19; // setUniformValue(const char*,float,float)
                } else if (SbkNumber_Check(pyargs[3])) {
                    if (numArgs == 4) {
                        overloadId = 20; // setUniformValue(const char*,float,float,float)
                    } else if (numArgs == 5 && SbkNumber_Check(pyargs[4])) {
                        overloadId = 21; // setUniformValue(const char*,float,float,float,float)
                    }
                }
            }
        } else if (numArgs == 2 && SbkNumber_Check(pyargs[1])) {
            overloadId = 22; // setUniformValue(const char*,int)
        } else if (numArgs == 2 && Shiboken::Converter< ::QVector2D >::isConvertible(pyargs[1])) {
            overloadId = 15; // setUniformValue(const char*,QVector2D)
        } else if (numArgs == 2 && Shiboken::Converter< ::QVector3D >::isConvertible(pyargs[1])) {
            overloadId = 16; // setUniformValue(const char*,QVector3D)
        } else if (numArgs == 2 && Shiboken::Converter< ::QVector4D >::isConvertible(pyargs[1])) {
            overloadId = 17; // setUniformValue(const char*,QVector4D)
        } else if (numArgs == 2 && Shiboken::Converter< ::QTransform >::isConvertible(pyargs[1])) {
            overloadId = 14; // setUniformValue(const char*,QTransform)
        } else if (numArgs == 2 && Shiboken::Converter< ::QSize >::isConvertible(pyargs[1])) {
            overloadId = 12; // setUniformValue(const char*,QSize)
        } else if (numArgs == 2 && Shiboken::Converter< ::QSizeF >::isConvertible(pyargs[1])) {
            overloadId = 13; // setUniformValue(const char*,QSizeF)
        } else if (numArgs == 2 && Shiboken::Converter< ::QPoint >::isConvertible(pyargs[1])) {
            overloadId = 10; // setUniformValue(const char*,QPoint)
        } else if (numArgs == 2 && Shiboken::Converter< ::QPointF >::isConvertible(pyargs[1])) {
            overloadId = 11; // setUniformValue(const char*,QPointF)
        } else if (numArgs == 2 && Shiboken::Converter< ::QMatrix4x4 >::isConvertible(pyargs[1])) {
            overloadId = 9; // setUniformValue(const char*,QMatrix4x4)
        } else if (numArgs == 2 && Shiboken::Converter< ::QMatrix4x3 >::isConvertible(pyargs[1])) {
            overloadId = 8; // setUniformValue(const char*,QMatrix4x3)
        } else if (numArgs == 2 && Shiboken::Converter< ::QMatrix4x2 >::isConvertible(pyargs[1])) {
            overloadId = 7; // setUniformValue(const char*,QMatrix4x2)
        } else if (numArgs == 2 && Shiboken::Converter< ::QMatrix3x4 >::isConvertible(pyargs[1])) {
            overloadId = 6; // setUniformValue(const char*,QMatrix3x4)
        } else if (numArgs == 2 && Shiboken::Converter< ::QMatrix3x3 >::isConvertible(pyargs[1])) {
            overloadId = 5; // setUniformValue(const char*,QMatrix3x3)
        } else if (numArgs == 2 && Shiboken::Converter< ::QMatrix3x2 >::isConvertible(pyargs[1])) {
            overloadId = 4; // setUniformValue(const char*,QMatrix3x2)
        } else if (numArgs == 2 && Shiboken::Converter< ::QMatrix2x4 >::isConvertible(pyargs[1])) {
            overloadId = 3; // setUniformValue(const char*,QMatrix2x4)
        } else if (numArgs == 2 && Shiboken::Converter< ::QMatrix2x3 >::isConvertible(pyargs[1])) {
            overloadId = 2; // setUniformValue(const char*,QMatrix2x3)
        } else if (numArgs == 2 && Shiboken::Converter< ::QMatrix2x2 >::isConvertible(pyargs[1])) {
            overloadId = 1; // setUniformValue(const char*,QMatrix2x2)
        } else if (numArgs == 2 && Shiboken::Converter< ::QColor >::isConvertible(pyargs[1])) {
            overloadId = 0; // setUniformValue(const char*,QColor)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGLShaderProgramFunc_setUniformValue_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // setUniformValue(const char*,QColor)
            {
                const char * cppArg0 = Shiboken::Converter<const char * >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return 0;
                QColor cppArg1 = Shiboken::Converter<QColor >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // setUniformValue(const char*,QColor)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setUniformValue(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // setUniformValue(const char*,QMatrix2x2)
            {
                const char * cppArg0 = Shiboken::Converter<const char * >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return 0;
                QMatrix2x2 cppArg1 = Shiboken::Converter<QMatrix2x2 >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // setUniformValue(const char*,QMatrix2x2)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setUniformValue(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 2: // setUniformValue(const char*,QMatrix2x3)
            {
                const char * cppArg0 = Shiboken::Converter<const char * >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return 0;
                QMatrix2x3 cppArg1 = Shiboken::Converter<QMatrix2x3 >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // setUniformValue(const char*,QMatrix2x3)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setUniformValue(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 3: // setUniformValue(const char*,QMatrix2x4)
            {
                const char * cppArg0 = Shiboken::Converter<const char * >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return 0;
                QMatrix2x4 cppArg1 = Shiboken::Converter<QMatrix2x4 >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // setUniformValue(const char*,QMatrix2x4)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setUniformValue(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 4: // setUniformValue(const char*,QMatrix3x2)
            {
                const char * cppArg0 = Shiboken::Converter<const char * >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return 0;
                QMatrix3x2 cppArg1 = Shiboken::Converter<QMatrix3x2 >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // setUniformValue(const char*,QMatrix3x2)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setUniformValue(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 5: // setUniformValue(const char*,QMatrix3x3)
            {
                const char * cppArg0 = Shiboken::Converter<const char * >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return 0;
                QMatrix3x3 cppArg1 = Shiboken::Converter<QMatrix3x3 >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // setUniformValue(const char*,QMatrix3x3)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setUniformValue(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 6: // setUniformValue(const char*,QMatrix3x4)
            {
                const char * cppArg0 = Shiboken::Converter<const char * >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return 0;
                QMatrix3x4 cppArg1 = Shiboken::Converter<QMatrix3x4 >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // setUniformValue(const char*,QMatrix3x4)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setUniformValue(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 7: // setUniformValue(const char*,QMatrix4x2)
            {
                const char * cppArg0 = Shiboken::Converter<const char * >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return 0;
                QMatrix4x2 cppArg1 = Shiboken::Converter<QMatrix4x2 >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // setUniformValue(const char*,QMatrix4x2)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setUniformValue(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 8: // setUniformValue(const char*,QMatrix4x3)
            {
                const char * cppArg0 = Shiboken::Converter<const char * >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return 0;
                QMatrix4x3 cppArg1 = Shiboken::Converter<QMatrix4x3 >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // setUniformValue(const char*,QMatrix4x3)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setUniformValue(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 9: // setUniformValue(const char*,QMatrix4x4)
            {
                const char * cppArg0 = Shiboken::Converter<const char * >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return 0;
                QMatrix4x4 cppArg1 = Shiboken::Converter<QMatrix4x4 >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // setUniformValue(const char*,QMatrix4x4)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setUniformValue(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 10: // setUniformValue(const char*,QPoint)
            {
                const char * cppArg0 = Shiboken::Converter<const char * >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return 0;
                QPoint cppArg1 = Shiboken::Converter<QPoint >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // setUniformValue(const char*,QPoint)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setUniformValue(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 11: // setUniformValue(const char*,QPointF)
            {
                const char * cppArg0 = Shiboken::Converter<const char * >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return 0;
                QPointF cppArg1 = Shiboken::Converter<QPointF >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // setUniformValue(const char*,QPointF)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setUniformValue(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 12: // setUniformValue(const char*,QSize)
            {
                const char * cppArg0 = Shiboken::Converter<const char * >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return 0;
                QSize cppArg1 = Shiboken::Converter<QSize >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // setUniformValue(const char*,QSize)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setUniformValue(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 13: // setUniformValue(const char*,QSizeF)
            {
                const char * cppArg0 = Shiboken::Converter<const char * >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return 0;
                QSizeF cppArg1 = Shiboken::Converter<QSizeF >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // setUniformValue(const char*,QSizeF)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setUniformValue(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 14: // setUniformValue(const char*,QTransform)
            {
                const char * cppArg0 = Shiboken::Converter<const char * >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return 0;
                QTransform cppArg1 = Shiboken::Converter<QTransform >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // setUniformValue(const char*,QTransform)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setUniformValue(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 15: // setUniformValue(const char*,QVector2D)
            {
                const char * cppArg0 = Shiboken::Converter<const char * >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return 0;
                QVector2D cppArg1 = Shiboken::Converter<QVector2D >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // setUniformValue(const char*,QVector2D)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setUniformValue(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 16: // setUniformValue(const char*,QVector3D)
            {
                const char * cppArg0 = Shiboken::Converter<const char * >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return 0;
                QVector3D cppArg1 = Shiboken::Converter<QVector3D >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // setUniformValue(const char*,QVector3D)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setUniformValue(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 17: // setUniformValue(const char*,QVector4D)
            {
                const char * cppArg0 = Shiboken::Converter<const char * >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return 0;
                QVector4D cppArg1 = Shiboken::Converter<QVector4D >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // setUniformValue(const char*,QVector4D)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setUniformValue(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 18: // setUniformValue(const char*,float)
            {
                const char * cppArg0 = Shiboken::Converter<const char * >::toCpp(pyargs[0]);
                float cppArg1 = Shiboken::Converter<float >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // setUniformValue(const char*,float)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setUniformValue(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 19: // setUniformValue(const char*,float,float)
            {
                const char * cppArg0 = Shiboken::Converter<const char * >::toCpp(pyargs[0]);
                float cppArg1 = Shiboken::Converter<float >::toCpp(pyargs[1]);
                float cppArg2 = Shiboken::Converter<float >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                    // setUniformValue(const char*,float,float)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setUniformValue(cppArg0, cppArg1, cppArg2);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 20: // setUniformValue(const char*,float,float,float)
            {
                const char * cppArg0 = Shiboken::Converter<const char * >::toCpp(pyargs[0]);
                float cppArg1 = Shiboken::Converter<float >::toCpp(pyargs[1]);
                float cppArg2 = Shiboken::Converter<float >::toCpp(pyargs[2]);
                float cppArg3 = Shiboken::Converter<float >::toCpp(pyargs[3]);

                if(!PyErr_Occurred()) {
                    // setUniformValue(const char*,float,float,float)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setUniformValue(cppArg0, cppArg1, cppArg2, cppArg3);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 21: // setUniformValue(const char*,float,float,float,float)
            {
                const char * cppArg0 = Shiboken::Converter<const char * >::toCpp(pyargs[0]);
                float cppArg1 = Shiboken::Converter<float >::toCpp(pyargs[1]);
                float cppArg2 = Shiboken::Converter<float >::toCpp(pyargs[2]);
                float cppArg3 = Shiboken::Converter<float >::toCpp(pyargs[3]);
                float cppArg4 = Shiboken::Converter<float >::toCpp(pyargs[4]);

                if(!PyErr_Occurred()) {
                    // setUniformValue(const char*,float,float,float,float)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setUniformValue(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 22: // setUniformValue(const char*,int)
            {
                const char * cppArg0 = Shiboken::Converter<const char * >::toCpp(pyargs[0]);
                int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // setUniformValue(const char*,int)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setUniformValue(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 23: // setUniformValue(const char*,uint)
            {
                const char * cppArg0 = Shiboken::Converter<const char * >::toCpp(pyargs[0]);
                unsigned int cppArg1 = Shiboken::Converter<unsigned int >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // setUniformValue(const char*,uint)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setUniformValue(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 24: // setUniformValue(int,QColor)
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return 0;
                QColor cppArg1 = Shiboken::Converter<QColor >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // setUniformValue(int,QColor)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setUniformValue(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 25: // setUniformValue(int,QMatrix2x2)
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return 0;
                QMatrix2x2 cppArg1 = Shiboken::Converter<QMatrix2x2 >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // setUniformValue(int,QMatrix2x2)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setUniformValue(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 26: // setUniformValue(int,QMatrix2x3)
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return 0;
                QMatrix2x3 cppArg1 = Shiboken::Converter<QMatrix2x3 >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // setUniformValue(int,QMatrix2x3)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setUniformValue(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 27: // setUniformValue(int,QMatrix2x4)
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return 0;
                QMatrix2x4 cppArg1 = Shiboken::Converter<QMatrix2x4 >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // setUniformValue(int,QMatrix2x4)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setUniformValue(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 28: // setUniformValue(int,QMatrix3x2)
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return 0;
                QMatrix3x2 cppArg1 = Shiboken::Converter<QMatrix3x2 >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // setUniformValue(int,QMatrix3x2)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setUniformValue(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 29: // setUniformValue(int,QMatrix3x3)
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return 0;
                QMatrix3x3 cppArg1 = Shiboken::Converter<QMatrix3x3 >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // setUniformValue(int,QMatrix3x3)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setUniformValue(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 30: // setUniformValue(int,QMatrix3x4)
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return 0;
                QMatrix3x4 cppArg1 = Shiboken::Converter<QMatrix3x4 >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // setUniformValue(int,QMatrix3x4)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setUniformValue(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 31: // setUniformValue(int,QMatrix4x2)
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return 0;
                QMatrix4x2 cppArg1 = Shiboken::Converter<QMatrix4x2 >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // setUniformValue(int,QMatrix4x2)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setUniformValue(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 32: // setUniformValue(int,QMatrix4x3)
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return 0;
                QMatrix4x3 cppArg1 = Shiboken::Converter<QMatrix4x3 >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // setUniformValue(int,QMatrix4x3)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setUniformValue(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 33: // setUniformValue(int,QMatrix4x4)
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return 0;
                QMatrix4x4 cppArg1 = Shiboken::Converter<QMatrix4x4 >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // setUniformValue(int,QMatrix4x4)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setUniformValue(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 34: // setUniformValue(int,QPoint)
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return 0;
                QPoint cppArg1 = Shiboken::Converter<QPoint >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // setUniformValue(int,QPoint)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setUniformValue(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 35: // setUniformValue(int,QPointF)
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return 0;
                QPointF cppArg1 = Shiboken::Converter<QPointF >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // setUniformValue(int,QPointF)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setUniformValue(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 36: // setUniformValue(int,QSize)
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return 0;
                QSize cppArg1 = Shiboken::Converter<QSize >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // setUniformValue(int,QSize)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setUniformValue(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 37: // setUniformValue(int,QSizeF)
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return 0;
                QSizeF cppArg1 = Shiboken::Converter<QSizeF >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // setUniformValue(int,QSizeF)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setUniformValue(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 38: // setUniformValue(int,QTransform)
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return 0;
                QTransform cppArg1 = Shiboken::Converter<QTransform >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // setUniformValue(int,QTransform)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setUniformValue(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 39: // setUniformValue(int,QVector2D)
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return 0;
                QVector2D cppArg1 = Shiboken::Converter<QVector2D >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // setUniformValue(int,QVector2D)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setUniformValue(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 40: // setUniformValue(int,QVector3D)
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return 0;
                QVector3D cppArg1 = Shiboken::Converter<QVector3D >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // setUniformValue(int,QVector3D)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setUniformValue(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 41: // setUniformValue(int,QVector4D)
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return 0;
                QVector4D cppArg1 = Shiboken::Converter<QVector4D >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // setUniformValue(int,QVector4D)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setUniformValue(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 42: // setUniformValue(int,float)
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                float cppArg1 = Shiboken::Converter<float >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // setUniformValue(int,float)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setUniformValue(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 43: // setUniformValue(int,float,float)
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                float cppArg1 = Shiboken::Converter<float >::toCpp(pyargs[1]);
                float cppArg2 = Shiboken::Converter<float >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                    // setUniformValue(int,float,float)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setUniformValue(cppArg0, cppArg1, cppArg2);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 44: // setUniformValue(int,float,float,float)
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                float cppArg1 = Shiboken::Converter<float >::toCpp(pyargs[1]);
                float cppArg2 = Shiboken::Converter<float >::toCpp(pyargs[2]);
                float cppArg3 = Shiboken::Converter<float >::toCpp(pyargs[3]);

                if(!PyErr_Occurred()) {
                    // setUniformValue(int,float,float,float)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setUniformValue(cppArg0, cppArg1, cppArg2, cppArg3);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 45: // setUniformValue(int,float,float,float,float)
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                float cppArg1 = Shiboken::Converter<float >::toCpp(pyargs[1]);
                float cppArg2 = Shiboken::Converter<float >::toCpp(pyargs[2]);
                float cppArg3 = Shiboken::Converter<float >::toCpp(pyargs[3]);
                float cppArg4 = Shiboken::Converter<float >::toCpp(pyargs[4]);

                if(!PyErr_Occurred()) {
                    // setUniformValue(int,float,float,float,float)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setUniformValue(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 46: // setUniformValue(int,int)
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // setUniformValue(int,int)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setUniformValue(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 47: // setUniformValue(int,uint)
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                unsigned int cppArg1 = Shiboken::Converter<unsigned int >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // setUniformValue(int,uint)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setUniformValue(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGLShaderProgramFunc_setUniformValue_TypeError:
        const char* overloads[] = {"str, PySide.QtGui.QColor", "str, PySide.QtGui.QMatrix2x2", "str, PySide.QtGui.QMatrix2x3", "str, PySide.QtGui.QMatrix2x4", "str, PySide.QtGui.QMatrix3x2", "str, PySide.QtGui.QMatrix3x3", "str, PySide.QtGui.QMatrix3x4", "str, PySide.QtGui.QMatrix4x2", "str, PySide.QtGui.QMatrix4x3", "str, PySide.QtGui.QMatrix4x4", "str, PySide.QtCore.QPoint", "str, PySide.QtCore.QPointF", "str, PySide.QtCore.QSize", "str, PySide.QtCore.QSizeF", "str, PySide.QtGui.QTransform", "str, PySide.QtGui.QVector2D", "str, PySide.QtGui.QVector3D", "str, PySide.QtGui.QVector4D", "str, float", "str, float, float", "str, float, float, float", "str, float, float, float, float", "str, int", "str, unsigned int", "int, PySide.QtGui.QColor", "int, PySide.QtGui.QMatrix2x2", "int, PySide.QtGui.QMatrix2x3", "int, PySide.QtGui.QMatrix2x4", "int, PySide.QtGui.QMatrix3x2", "int, PySide.QtGui.QMatrix3x3", "int, PySide.QtGui.QMatrix3x4", "int, PySide.QtGui.QMatrix4x2", "int, PySide.QtGui.QMatrix4x3", "int, PySide.QtGui.QMatrix4x4", "int, PySide.QtCore.QPoint", "int, PySide.QtCore.QPointF", "int, PySide.QtCore.QSize", "int, PySide.QtCore.QSizeF", "int, PySide.QtGui.QTransform", "int, PySide.QtGui.QVector2D", "int, PySide.QtGui.QVector3D", "int, PySide.QtGui.QVector4D", "int, float", "int, float, float", "int, float, float, float", "int, float, float, float, float", "int, int", "int, unsigned int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtOpenGL.QGLShaderProgram.setUniformValue", overloads);
        return 0;
}

static PyObject* Sbk_QGLShaderProgramFunc_setUniformValueArray(PyObject* self, PyObject* args)
{
    QGLShaderProgram* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGLShaderProgram* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setUniformValueArray", 3, 4, &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return 0;


    // Overloaded function decisor
    // 0: setUniformValueArray(const char*,const QMatrix2x2*,int)
    // 1: setUniformValueArray(const char*,const QMatrix2x3*,int)
    // 2: setUniformValueArray(const char*,const QMatrix2x4*,int)
    // 3: setUniformValueArray(const char*,const QMatrix3x2*,int)
    // 4: setUniformValueArray(const char*,const QMatrix3x3*,int)
    // 5: setUniformValueArray(const char*,const QMatrix3x4*,int)
    // 6: setUniformValueArray(const char*,const QMatrix4x2*,int)
    // 7: setUniformValueArray(const char*,const QMatrix4x3*,int)
    // 8: setUniformValueArray(const char*,const QMatrix4x4*,int)
    // 9: setUniformValueArray(const char*,const QVector2D*,int)
    // 10: setUniformValueArray(const char*,const QVector3D*,int)
    // 11: setUniformValueArray(const char*,const QVector4D*,int)
    // 12: setUniformValueArray(const char*,const float*,int,int)
    // 13: setUniformValueArray(const char*,const int*,int)
    // 14: setUniformValueArray(const char*,const uint*,int)
    // 15: setUniformValueArray(int,const QMatrix2x2*,int)
    // 16: setUniformValueArray(int,const QMatrix2x3*,int)
    // 17: setUniformValueArray(int,const QMatrix2x4*,int)
    // 18: setUniformValueArray(int,const QMatrix3x2*,int)
    // 19: setUniformValueArray(int,const QMatrix3x3*,int)
    // 20: setUniformValueArray(int,const QMatrix3x4*,int)
    // 21: setUniformValueArray(int,const QMatrix4x2*,int)
    // 22: setUniformValueArray(int,const QMatrix4x3*,int)
    // 23: setUniformValueArray(int,const QMatrix4x4*,int)
    // 24: setUniformValueArray(int,const QVector2D*,int)
    // 25: setUniformValueArray(int,const QVector3D*,int)
    // 26: setUniformValueArray(int,const QVector4D*,int)
    // 27: setUniformValueArray(int,const float*,int,int)
    // 28: setUniformValueArray(int,const int*,int)
    // 29: setUniformValueArray(int,const uint*,int)
    if (SbkNumber_Check(pyargs[0])) {
        if (numArgs == 3 && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
            overloadId = 29; // setUniformValueArray(int,const uint*,int)
        } else if (numArgs == 4 && PyFloat_Check(pyargs[1]) && SbkNumber_Check(pyargs[2]) && SbkNumber_Check(pyargs[3])) {
            overloadId = 27; // setUniformValueArray(int,const float*,int,int)
        } else if (numArgs == 3 && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
            overloadId = 28; // setUniformValueArray(int,const int*,int)
        } else if (numArgs == 3 && Shiboken::Converter< ::QVector2D * >::isConvertible(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
            overloadId = 24; // setUniformValueArray(int,const QVector2D*,int)
        } else if (numArgs == 3 && Shiboken::Converter< ::QVector3D * >::isConvertible(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
            overloadId = 25; // setUniformValueArray(int,const QVector3D*,int)
        } else if (numArgs == 3 && Shiboken::Converter< ::QVector4D * >::isConvertible(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
            overloadId = 26; // setUniformValueArray(int,const QVector4D*,int)
        } else if (numArgs == 3 && Shiboken::Converter< ::QMatrix4x4 * >::isConvertible(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
            overloadId = 23; // setUniformValueArray(int,const QMatrix4x4*,int)
        } else if (numArgs == 3 && Shiboken::Converter< ::QMatrix4x3 * >::isConvertible(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
            overloadId = 22; // setUniformValueArray(int,const QMatrix4x3*,int)
        } else if (numArgs == 3 && Shiboken::Converter< ::QMatrix4x2 * >::isConvertible(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
            overloadId = 21; // setUniformValueArray(int,const QMatrix4x2*,int)
        } else if (numArgs == 3 && Shiboken::Converter< ::QMatrix3x4 * >::isConvertible(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
            overloadId = 20; // setUniformValueArray(int,const QMatrix3x4*,int)
        } else if (numArgs == 3 && Shiboken::Converter< ::QMatrix3x3 * >::isConvertible(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
            overloadId = 19; // setUniformValueArray(int,const QMatrix3x3*,int)
        } else if (numArgs == 3 && Shiboken::Converter< ::QMatrix3x2 * >::isConvertible(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
            overloadId = 18; // setUniformValueArray(int,const QMatrix3x2*,int)
        } else if (numArgs == 3 && Shiboken::Converter< ::QMatrix2x4 * >::isConvertible(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
            overloadId = 17; // setUniformValueArray(int,const QMatrix2x4*,int)
        } else if (numArgs == 3 && Shiboken::Converter< ::QMatrix2x3 * >::isConvertible(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
            overloadId = 16; // setUniformValueArray(int,const QMatrix2x3*,int)
        } else if (numArgs == 3 && Shiboken::Converter< ::QMatrix2x2 * >::isConvertible(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
            overloadId = 15; // setUniformValueArray(int,const QMatrix2x2*,int)
        }
    } else if (Shiboken::Converter< const char * >::isConvertible(pyargs[0])) {
        if (numArgs == 3 && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
            overloadId = 14; // setUniformValueArray(const char*,const uint*,int)
        } else if (numArgs == 4 && PyFloat_Check(pyargs[1]) && SbkNumber_Check(pyargs[2]) && SbkNumber_Check(pyargs[3])) {
            overloadId = 12; // setUniformValueArray(const char*,const float*,int,int)
        } else if (numArgs == 3 && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
            overloadId = 13; // setUniformValueArray(const char*,const int*,int)
        } else if (numArgs == 3 && Shiboken::Converter< ::QVector2D * >::isConvertible(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
            overloadId = 9; // setUniformValueArray(const char*,const QVector2D*,int)
        } else if (numArgs == 3 && Shiboken::Converter< ::QVector3D * >::isConvertible(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
            overloadId = 10; // setUniformValueArray(const char*,const QVector3D*,int)
        } else if (numArgs == 3 && Shiboken::Converter< ::QVector4D * >::isConvertible(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
            overloadId = 11; // setUniformValueArray(const char*,const QVector4D*,int)
        } else if (numArgs == 3 && Shiboken::Converter< ::QMatrix4x4 * >::isConvertible(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
            overloadId = 8; // setUniformValueArray(const char*,const QMatrix4x4*,int)
        } else if (numArgs == 3 && Shiboken::Converter< ::QMatrix4x3 * >::isConvertible(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
            overloadId = 7; // setUniformValueArray(const char*,const QMatrix4x3*,int)
        } else if (numArgs == 3 && Shiboken::Converter< ::QMatrix4x2 * >::isConvertible(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
            overloadId = 6; // setUniformValueArray(const char*,const QMatrix4x2*,int)
        } else if (numArgs == 3 && Shiboken::Converter< ::QMatrix3x4 * >::isConvertible(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
            overloadId = 5; // setUniformValueArray(const char*,const QMatrix3x4*,int)
        } else if (numArgs == 3 && Shiboken::Converter< ::QMatrix3x3 * >::isConvertible(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
            overloadId = 4; // setUniformValueArray(const char*,const QMatrix3x3*,int)
        } else if (numArgs == 3 && Shiboken::Converter< ::QMatrix3x2 * >::isConvertible(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
            overloadId = 3; // setUniformValueArray(const char*,const QMatrix3x2*,int)
        } else if (numArgs == 3 && Shiboken::Converter< ::QMatrix2x4 * >::isConvertible(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
            overloadId = 2; // setUniformValueArray(const char*,const QMatrix2x4*,int)
        } else if (numArgs == 3 && Shiboken::Converter< ::QMatrix2x3 * >::isConvertible(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
            overloadId = 1; // setUniformValueArray(const char*,const QMatrix2x3*,int)
        } else if (numArgs == 3 && Shiboken::Converter< ::QMatrix2x2 * >::isConvertible(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
            overloadId = 0; // setUniformValueArray(const char*,const QMatrix2x2*,int)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGLShaderProgramFunc_setUniformValueArray_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // setUniformValueArray(const char*,const QMatrix2x2*,int)
            {
                const char * cppArg0 = Shiboken::Converter<const char * >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return 0;
                QMatrix2x2 * cppArg1 = Shiboken::Converter<QMatrix2x2 * >::toCpp(pyargs[1]);
                int cppArg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                    // setUniformValueArray(const char*,const QMatrix2x2*,int)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setUniformValueArray(cppArg0, cppArg1, cppArg2);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // setUniformValueArray(const char*,const QMatrix2x3*,int)
            {
                const char * cppArg0 = Shiboken::Converter<const char * >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return 0;
                QMatrix2x3 * cppArg1 = Shiboken::Converter<QMatrix2x3 * >::toCpp(pyargs[1]);
                int cppArg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                    // setUniformValueArray(const char*,const QMatrix2x3*,int)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setUniformValueArray(cppArg0, cppArg1, cppArg2);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 2: // setUniformValueArray(const char*,const QMatrix2x4*,int)
            {
                const char * cppArg0 = Shiboken::Converter<const char * >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return 0;
                QMatrix2x4 * cppArg1 = Shiboken::Converter<QMatrix2x4 * >::toCpp(pyargs[1]);
                int cppArg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                    // setUniformValueArray(const char*,const QMatrix2x4*,int)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setUniformValueArray(cppArg0, cppArg1, cppArg2);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 3: // setUniformValueArray(const char*,const QMatrix3x2*,int)
            {
                const char * cppArg0 = Shiboken::Converter<const char * >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return 0;
                QMatrix3x2 * cppArg1 = Shiboken::Converter<QMatrix3x2 * >::toCpp(pyargs[1]);
                int cppArg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                    // setUniformValueArray(const char*,const QMatrix3x2*,int)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setUniformValueArray(cppArg0, cppArg1, cppArg2);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 4: // setUniformValueArray(const char*,const QMatrix3x3*,int)
            {
                const char * cppArg0 = Shiboken::Converter<const char * >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return 0;
                QMatrix3x3 * cppArg1 = Shiboken::Converter<QMatrix3x3 * >::toCpp(pyargs[1]);
                int cppArg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                    // setUniformValueArray(const char*,const QMatrix3x3*,int)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setUniformValueArray(cppArg0, cppArg1, cppArg2);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 5: // setUniformValueArray(const char*,const QMatrix3x4*,int)
            {
                const char * cppArg0 = Shiboken::Converter<const char * >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return 0;
                QMatrix3x4 * cppArg1 = Shiboken::Converter<QMatrix3x4 * >::toCpp(pyargs[1]);
                int cppArg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                    // setUniformValueArray(const char*,const QMatrix3x4*,int)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setUniformValueArray(cppArg0, cppArg1, cppArg2);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 6: // setUniformValueArray(const char*,const QMatrix4x2*,int)
            {
                const char * cppArg0 = Shiboken::Converter<const char * >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return 0;
                QMatrix4x2 * cppArg1 = Shiboken::Converter<QMatrix4x2 * >::toCpp(pyargs[1]);
                int cppArg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                    // setUniformValueArray(const char*,const QMatrix4x2*,int)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setUniformValueArray(cppArg0, cppArg1, cppArg2);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 7: // setUniformValueArray(const char*,const QMatrix4x3*,int)
            {
                const char * cppArg0 = Shiboken::Converter<const char * >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return 0;
                QMatrix4x3 * cppArg1 = Shiboken::Converter<QMatrix4x3 * >::toCpp(pyargs[1]);
                int cppArg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                    // setUniformValueArray(const char*,const QMatrix4x3*,int)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setUniformValueArray(cppArg0, cppArg1, cppArg2);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 8: // setUniformValueArray(const char*,const QMatrix4x4*,int)
            {
                const char * cppArg0 = Shiboken::Converter<const char * >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return 0;
                QMatrix4x4 * cppArg1 = Shiboken::Converter<QMatrix4x4 * >::toCpp(pyargs[1]);
                int cppArg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                    // setUniformValueArray(const char*,const QMatrix4x4*,int)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setUniformValueArray(cppArg0, cppArg1, cppArg2);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 9: // setUniformValueArray(const char*,const QVector2D*,int)
            {
                const char * cppArg0 = Shiboken::Converter<const char * >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return 0;
                QVector2D * cppArg1 = Shiboken::Converter<QVector2D * >::toCpp(pyargs[1]);
                int cppArg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                    // setUniformValueArray(const char*,const QVector2D*,int)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setUniformValueArray(cppArg0, cppArg1, cppArg2);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 10: // setUniformValueArray(const char*,const QVector3D*,int)
            {
                const char * cppArg0 = Shiboken::Converter<const char * >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return 0;
                QVector3D * cppArg1 = Shiboken::Converter<QVector3D * >::toCpp(pyargs[1]);
                int cppArg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                    // setUniformValueArray(const char*,const QVector3D*,int)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setUniformValueArray(cppArg0, cppArg1, cppArg2);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 11: // setUniformValueArray(const char*,const QVector4D*,int)
            {
                const char * cppArg0 = Shiboken::Converter<const char * >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return 0;
                QVector4D * cppArg1 = Shiboken::Converter<QVector4D * >::toCpp(pyargs[1]);
                int cppArg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                    // setUniformValueArray(const char*,const QVector4D*,int)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setUniformValueArray(cppArg0, cppArg1, cppArg2);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 12: // setUniformValueArray(const char*,const float*,int,int)
            {
                const char * cppArg0 = Shiboken::Converter<const char * >::toCpp(pyargs[0]);
                float * cppArg1 = Shiboken::Converter<float * >::toCpp(pyargs[1]);
                int cppArg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);
                int cppArg3 = Shiboken::Converter<int >::toCpp(pyargs[3]);

                if(!PyErr_Occurred()) {
                    // setUniformValueArray(const char*,const float*,int,int)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setUniformValueArray(cppArg0, cppArg1, cppArg2, cppArg3);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 13: // setUniformValueArray(const char*,const int*,int)
            {
                const char * cppArg0 = Shiboken::Converter<const char * >::toCpp(pyargs[0]);
                int * cppArg1 = Shiboken::Converter<int * >::toCpp(pyargs[1]);
                int cppArg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                    // setUniformValueArray(const char*,const int*,int)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setUniformValueArray(cppArg0, cppArg1, cppArg2);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 14: // setUniformValueArray(const char*,const uint*,int)
            {
                const char * cppArg0 = Shiboken::Converter<const char * >::toCpp(pyargs[0]);
                unsigned int * cppArg1 = Shiboken::Converter<unsigned int * >::toCpp(pyargs[1]);
                int cppArg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                    // setUniformValueArray(const char*,const uint*,int)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setUniformValueArray(cppArg0, cppArg1, cppArg2);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 15: // setUniformValueArray(int,const QMatrix2x2*,int)
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return 0;
                QMatrix2x2 * cppArg1 = Shiboken::Converter<QMatrix2x2 * >::toCpp(pyargs[1]);
                int cppArg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                    // setUniformValueArray(int,const QMatrix2x2*,int)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setUniformValueArray(cppArg0, cppArg1, cppArg2);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 16: // setUniformValueArray(int,const QMatrix2x3*,int)
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return 0;
                QMatrix2x3 * cppArg1 = Shiboken::Converter<QMatrix2x3 * >::toCpp(pyargs[1]);
                int cppArg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                    // setUniformValueArray(int,const QMatrix2x3*,int)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setUniformValueArray(cppArg0, cppArg1, cppArg2);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 17: // setUniformValueArray(int,const QMatrix2x4*,int)
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return 0;
                QMatrix2x4 * cppArg1 = Shiboken::Converter<QMatrix2x4 * >::toCpp(pyargs[1]);
                int cppArg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                    // setUniformValueArray(int,const QMatrix2x4*,int)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setUniformValueArray(cppArg0, cppArg1, cppArg2);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 18: // setUniformValueArray(int,const QMatrix3x2*,int)
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return 0;
                QMatrix3x2 * cppArg1 = Shiboken::Converter<QMatrix3x2 * >::toCpp(pyargs[1]);
                int cppArg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                    // setUniformValueArray(int,const QMatrix3x2*,int)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setUniformValueArray(cppArg0, cppArg1, cppArg2);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 19: // setUniformValueArray(int,const QMatrix3x3*,int)
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return 0;
                QMatrix3x3 * cppArg1 = Shiboken::Converter<QMatrix3x3 * >::toCpp(pyargs[1]);
                int cppArg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                    // setUniformValueArray(int,const QMatrix3x3*,int)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setUniformValueArray(cppArg0, cppArg1, cppArg2);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 20: // setUniformValueArray(int,const QMatrix3x4*,int)
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return 0;
                QMatrix3x4 * cppArg1 = Shiboken::Converter<QMatrix3x4 * >::toCpp(pyargs[1]);
                int cppArg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                    // setUniformValueArray(int,const QMatrix3x4*,int)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setUniformValueArray(cppArg0, cppArg1, cppArg2);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 21: // setUniformValueArray(int,const QMatrix4x2*,int)
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return 0;
                QMatrix4x2 * cppArg1 = Shiboken::Converter<QMatrix4x2 * >::toCpp(pyargs[1]);
                int cppArg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                    // setUniformValueArray(int,const QMatrix4x2*,int)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setUniformValueArray(cppArg0, cppArg1, cppArg2);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 22: // setUniformValueArray(int,const QMatrix4x3*,int)
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return 0;
                QMatrix4x3 * cppArg1 = Shiboken::Converter<QMatrix4x3 * >::toCpp(pyargs[1]);
                int cppArg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                    // setUniformValueArray(int,const QMatrix4x3*,int)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setUniformValueArray(cppArg0, cppArg1, cppArg2);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 23: // setUniformValueArray(int,const QMatrix4x4*,int)
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return 0;
                QMatrix4x4 * cppArg1 = Shiboken::Converter<QMatrix4x4 * >::toCpp(pyargs[1]);
                int cppArg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                    // setUniformValueArray(int,const QMatrix4x4*,int)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setUniformValueArray(cppArg0, cppArg1, cppArg2);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 24: // setUniformValueArray(int,const QVector2D*,int)
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return 0;
                QVector2D * cppArg1 = Shiboken::Converter<QVector2D * >::toCpp(pyargs[1]);
                int cppArg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                    // setUniformValueArray(int,const QVector2D*,int)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setUniformValueArray(cppArg0, cppArg1, cppArg2);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 25: // setUniformValueArray(int,const QVector3D*,int)
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return 0;
                QVector3D * cppArg1 = Shiboken::Converter<QVector3D * >::toCpp(pyargs[1]);
                int cppArg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                    // setUniformValueArray(int,const QVector3D*,int)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setUniformValueArray(cppArg0, cppArg1, cppArg2);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 26: // setUniformValueArray(int,const QVector4D*,int)
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return 0;
                QVector4D * cppArg1 = Shiboken::Converter<QVector4D * >::toCpp(pyargs[1]);
                int cppArg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                    // setUniformValueArray(int,const QVector4D*,int)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setUniformValueArray(cppArg0, cppArg1, cppArg2);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 27: // setUniformValueArray(int,const float*,int,int)
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                float * cppArg1 = Shiboken::Converter<float * >::toCpp(pyargs[1]);
                int cppArg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);
                int cppArg3 = Shiboken::Converter<int >::toCpp(pyargs[3]);

                if(!PyErr_Occurred()) {
                    // setUniformValueArray(int,const float*,int,int)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setUniformValueArray(cppArg0, cppArg1, cppArg2, cppArg3);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 28: // setUniformValueArray(int,const int*,int)
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int * cppArg1 = Shiboken::Converter<int * >::toCpp(pyargs[1]);
                int cppArg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                    // setUniformValueArray(int,const int*,int)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setUniformValueArray(cppArg0, cppArg1, cppArg2);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 29: // setUniformValueArray(int,const uint*,int)
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                unsigned int * cppArg1 = Shiboken::Converter<unsigned int * >::toCpp(pyargs[1]);
                int cppArg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                    // setUniformValueArray(int,const uint*,int)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setUniformValueArray(cppArg0, cppArg1, cppArg2);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGLShaderProgramFunc_setUniformValueArray_TypeError:
        const char* overloads[] = {"str, PySide.QtGui.QMatrix2x2, int", "str, PySide.QtGui.QMatrix2x3, int", "str, PySide.QtGui.QMatrix2x4, int", "str, PySide.QtGui.QMatrix3x2, int", "str, PySide.QtGui.QMatrix3x3, int", "str, PySide.QtGui.QMatrix3x4, int", "str, PySide.QtGui.QMatrix4x2, int", "str, PySide.QtGui.QMatrix4x3, int", "str, PySide.QtGui.QMatrix4x4, int", "str, PySide.QtGui.QVector2D, int", "str, PySide.QtGui.QVector3D, int", "str, PySide.QtGui.QVector4D, int", "str, float, int, int", "str, int, int", "str, unsigned int, int", "int, PySide.QtGui.QMatrix2x2, int", "int, PySide.QtGui.QMatrix2x3, int", "int, PySide.QtGui.QMatrix2x4, int", "int, PySide.QtGui.QMatrix3x2, int", "int, PySide.QtGui.QMatrix3x3, int", "int, PySide.QtGui.QMatrix3x4, int", "int, PySide.QtGui.QMatrix4x2, int", "int, PySide.QtGui.QMatrix4x3, int", "int, PySide.QtGui.QMatrix4x4, int", "int, PySide.QtGui.QVector2D, int", "int, PySide.QtGui.QVector3D, int", "int, PySide.QtGui.QVector4D, int", "int, float, int, int", "int, int, int", "int, unsigned int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtOpenGL.QGLShaderProgram.setUniformValueArray", overloads);
        return 0;
}

static PyObject* Sbk_QGLShaderProgramFunc_shaders(PyObject* self)
{
    QGLShaderProgram* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGLShaderProgram* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // shaders()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QList<QGLShader * > cppResult = const_cast<const QGLShaderProgram*>(cppSelf)->shaders();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QList<QGLShader * > >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QGLShaderProgramFunc_uniformLocation(PyObject* self, PyObject* arg)
{
    QGLShaderProgram* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGLShaderProgram* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: uniformLocation(QByteArray)const
    // 1: uniformLocation(QString)const
    // 2: uniformLocation(const char*)const
    if (Shiboken::Converter< const char * >::isConvertible(arg)) {
        overloadId = 2; // uniformLocation(const char*)const
    } else if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 1; // uniformLocation(QString)const
    } else if (Shiboken::Converter< ::QByteArray >::isConvertible(arg)) {
        overloadId = 0; // uniformLocation(QByteArray)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGLShaderProgramFunc_uniformLocation_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // uniformLocation(QByteArray)const
            {
                if (!Shiboken::Object::isValid(arg))
                    return 0;
                QByteArray cppArg0 = Shiboken::Converter<QByteArray >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // uniformLocation(QByteArray)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    int cppResult = const_cast<const QGLShaderProgram*>(cppSelf)->uniformLocation(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< int >::toPython(cppResult);
                }
                break;
            }
            case 1: // uniformLocation(QString)const
            {
                QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // uniformLocation(QString)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    int cppResult = const_cast<const QGLShaderProgram*>(cppSelf)->uniformLocation(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< int >::toPython(cppResult);
                }
                break;
            }
            case 2: // uniformLocation(const char*)const
            {
                const char * cppArg0 = Shiboken::Converter<const char * >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // uniformLocation(const char*)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    int cppResult = const_cast<const QGLShaderProgram*>(cppSelf)->uniformLocation(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< int >::toPython(cppResult);
                }
                break;
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QGLShaderProgramFunc_uniformLocation_TypeError:
        const char* overloads[] = {"PySide.QtCore.QByteArray", "QString", "str", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtOpenGL.QGLShaderProgram.uniformLocation", overloads);
        return 0;
}

static PyMethodDef Sbk_QGLShaderProgram_methods[] = {
    {"addShader", (PyCFunction)Sbk_QGLShaderProgramFunc_addShader, METH_O},
    {"addShaderFromSourceCode", (PyCFunction)Sbk_QGLShaderProgramFunc_addShaderFromSourceCode, METH_VARARGS},
    {"addShaderFromSourceFile", (PyCFunction)Sbk_QGLShaderProgramFunc_addShaderFromSourceFile, METH_VARARGS},
    {"attributeLocation", (PyCFunction)Sbk_QGLShaderProgramFunc_attributeLocation, METH_O},
    {"bind", (PyCFunction)Sbk_QGLShaderProgramFunc_bind, METH_NOARGS},
    {"bindAttributeLocation", (PyCFunction)Sbk_QGLShaderProgramFunc_bindAttributeLocation, METH_VARARGS},
    {"disableAttributeArray", (PyCFunction)Sbk_QGLShaderProgramFunc_disableAttributeArray, METH_O},
    {"enableAttributeArray", (PyCFunction)Sbk_QGLShaderProgramFunc_enableAttributeArray, METH_O},
    {"geometryInputType", (PyCFunction)Sbk_QGLShaderProgramFunc_geometryInputType, METH_NOARGS},
    {"geometryOutputType", (PyCFunction)Sbk_QGLShaderProgramFunc_geometryOutputType, METH_NOARGS},
    {"geometryOutputVertexCount", (PyCFunction)Sbk_QGLShaderProgramFunc_geometryOutputVertexCount, METH_NOARGS},
    {"hasOpenGLShaderPrograms", (PyCFunction)Sbk_QGLShaderProgramFunc_hasOpenGLShaderPrograms, METH_VARARGS|METH_KEYWORDS|METH_STATIC},
    {"isLinked", (PyCFunction)Sbk_QGLShaderProgramFunc_isLinked, METH_NOARGS},
    {"link", (PyCFunction)Sbk_QGLShaderProgramFunc_link, METH_NOARGS},
    {"log", (PyCFunction)Sbk_QGLShaderProgramFunc_log, METH_NOARGS},
    {"maxGeometryOutputVertices", (PyCFunction)Sbk_QGLShaderProgramFunc_maxGeometryOutputVertices, METH_NOARGS},
    {"programId", (PyCFunction)Sbk_QGLShaderProgramFunc_programId, METH_NOARGS},
    {"release", (PyCFunction)Sbk_QGLShaderProgramFunc_release, METH_NOARGS},
    {"removeAllShaders", (PyCFunction)Sbk_QGLShaderProgramFunc_removeAllShaders, METH_NOARGS},
    {"removeShader", (PyCFunction)Sbk_QGLShaderProgramFunc_removeShader, METH_O},
    {"setAttributeArray", (PyCFunction)Sbk_QGLShaderProgramFunc_setAttributeArray, METH_VARARGS|METH_KEYWORDS},
    {"setAttributeBuffer", (PyCFunction)Sbk_QGLShaderProgramFunc_setAttributeBuffer, METH_VARARGS|METH_KEYWORDS},
    {"setAttributeValue", (PyCFunction)Sbk_QGLShaderProgramFunc_setAttributeValue, METH_VARARGS},
    {"setGeometryInputType", (PyCFunction)Sbk_QGLShaderProgramFunc_setGeometryInputType, METH_O},
    {"setGeometryOutputType", (PyCFunction)Sbk_QGLShaderProgramFunc_setGeometryOutputType, METH_O},
    {"setGeometryOutputVertexCount", (PyCFunction)Sbk_QGLShaderProgramFunc_setGeometryOutputVertexCount, METH_O},
    {"setUniformValue", (PyCFunction)Sbk_QGLShaderProgramFunc_setUniformValue, METH_VARARGS},
    {"setUniformValueArray", (PyCFunction)Sbk_QGLShaderProgramFunc_setUniformValueArray, METH_VARARGS},
    {"shaders", (PyCFunction)Sbk_QGLShaderProgramFunc_shaders, METH_NOARGS},
    {"uniformLocation", (PyCFunction)Sbk_QGLShaderProgramFunc_uniformLocation, METH_O},

    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QGLShaderProgram_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtOpenGL.QGLShaderProgram",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QGLShaderProgram_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QGLShaderProgram_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern

static SbkObjectType* Sbk_QGLShaderProgram_typeDiscovery(void* cptr, SbkObjectType* instanceType)
{
    if (instanceType == reinterpret_cast<SbkObjectType*>(Shiboken::SbkType<QObject >()) && dynamic_cast<QGLShaderProgram*>(reinterpret_cast<QObject*>(cptr)))
        return &Sbk_QGLShaderProgram_Type;
    return 0;
}


void init_QGLShaderProgram(PyObject* module)
{
    SbkPySide_QtOpenGLTypes[SBK_QGLSHADERPROGRAM_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QGLShaderProgram_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QGLShaderProgram_Type);
    Shiboken::ObjectType::setSubTypeInitHook(&Sbk_QGLShaderProgram_Type, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(&Sbk_QGLShaderProgram_Type, &QGLShaderProgram::staticMetaObject);    Sbk_QGLShaderProgram_Type.super.ht_type.tp_base = SbkPySide_QtCoreTypes[SBK_QOBJECT_IDX];
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QGLShaderProgram_Type, &Shiboken::callCppDestructor<QGLShaderProgram >);
    Py_INCREF((PyObject*)&Sbk_QGLShaderProgram_Type); //Incref due the 'PyModule_AddObject' steals the reference.
    if (PyType_Ready((PyTypeObject*)&Sbk_QGLShaderProgram_Type) < 0)
        return;

    // Fill type discovery information
    Shiboken::ObjectType::setTypeDiscoveryFunction(&Sbk_QGLShaderProgram_Type, &Sbk_QGLShaderProgram_typeDiscovery);
    Shiboken::BindingManager& bm = Shiboken::BindingManager::instance();
    bm.addClassInheritance(reinterpret_cast<SbkObjectType*>(SbkPySide_QtCoreTypes[SBK_QOBJECT_IDX]), &Sbk_QGLShaderProgram_Type);

    Shiboken::ObjectType::setOriginalName(&Sbk_QGLShaderProgram_Type, "QGLShaderProgram*");
    PyModule_AddObject(module, "QGLShaderProgram",
        ((PyObject*)&Sbk_QGLShaderProgram_Type));


    Shiboken::TypeResolver::createObjectTypeResolver<QGLShaderProgram >("QGLShaderProgram*");
    Shiboken::TypeResolver::createObjectTypeResolver<QGLShaderProgram >(typeid(QGLShaderProgram).name());
    Shiboken::TypeResolver::createObjectTypeResolver<QGLShaderProgram >(typeid(QGLShaderProgramWrapper).name());
    qRegisterMetaType< ::QGLShaderProgram* >("QGLShaderProgram*");
}

